@@ -2,12 +2,11 @@
 #include <QMap>
 #include <QString>
 #include <QStringList>
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
 #include <QUrlQuery>
 #endif
 
 #include "o2surveymonkey.h"
-#include "o2globals.h"
 
 static const char *SMEndpoint = "https://api.surveymonkey.net/oauth/authorize";
 static const char *SMTokenUrl = "https://api.surveymonkey.net/oauth/token";
