@@ -1,6 +1,11 @@
 #!/bin/sh
 
-dnf5 install -y --nogpgcheck \
+# To be removed
+# Workaround a bug where the initial /etc/dnf/dnf.conf file contains
+# just the "tsflags=nodocs" line
+printf '[main]\ngpgcheck=True\ninstallonly_limit=3\nclean_requirements_on_remove=True\nbest=False\nskip_if_unavailable=True\ntsflags=nodocs' > /etc/dnf/dnf.conf
+
+dnf install -y --nogpgcheck \
   mingw64-dlfcn \
   mingw64-exiv2 \
   mingw64-fcgi \
@@ -31,7 +36,6 @@ dnf5 install -y --nogpgcheck \
   mingw64-python3-OWSLib \
   mingw64-python3-pillow \
   mingw64-python3-psycopg2 \
-  mingw64-python3-pygments \
   mingw64-python3-PyQt-builder \
   mingw64-python3-pytz \
   mingw64-python3-pyyaml \
@@ -39,7 +43,6 @@ dnf5 install -y --nogpgcheck \
   mingw64-python3-qt5 \
   mingw64-python3-requests \
   mingw64-python3-shapely \
-  mingw64-python3-six \
   mingw64-python3-urllib3 \
   mingw64-qca-qt5 \
   mingw64-qscintilla-qt5 \
@@ -76,6 +79,7 @@ dnf5 install -y --nogpgcheck \
   proj-devel \
   python-devel \
   python-qt5 \
+  python3-qscintilla-qt5 \
   qt5-linguist \
   qt5-qtbase-devel \
   sqlite-devel \
