@@ -15,64 +15,73 @@
 ***************************************************************************
 """
 
-__author__ = 'Luigi Pirelli'
-__date__ = 'May 2015'
-__copyright__ = '(C) 2015, Luigi Pirelli'
+__author__ = "Luigi Pirelli"
+__date__ = "May 2015"
+__copyright__ = "(C) 2015, Luigi Pirelli"
 
 import html
 import pathlib
 
 from qgis.PyQt.QtCore import QCoreApplication
-from qgis.core import (QgsProcessing,
-                       QgsProcessingException,
-                       QgsProcessingParameterMultipleLayers,
-                       QgsProcessingParameterBoolean,
-                       QgsProcessingParameterVectorDestination,
-                       QgsProcessingOutputString,
-                       QgsProcessingParameters
-                       )
+from qgis.core import (
+    QgsProcessing,
+    QgsProcessingException,
+    QgsProcessingParameterMultipleLayers,
+    QgsProcessingParameterBoolean,
+    QgsProcessingParameterVectorDestination,
+    QgsProcessingOutputString,
+    QgsProcessingParameters,
+)
 from processing.algs.gdal.GdalAlgorithm import GdalAlgorithm
 from processing.algs.gdal.GdalUtils import GdalUtils
 
 
 class Datasources2Vrt(GdalAlgorithm):
-    INPUT = 'INPUT'
-    UNIONED = 'UNIONED'
-    OUTPUT = 'OUTPUT'
-    VRT_STRING = 'VRT_STRING'
+    INPUT = "INPUT"
+    UNIONED = "UNIONED"
+    OUTPUT = "OUTPUT"
+    VRT_STRING = "VRT_STRING"
 
     def createCustomParametersWidget(self, parent):
         return None
 
     def group(self):
-        return self.tr('Vector miscellaneous')
+        return self.tr("Vector miscellaneous")
 
     def groupId(self):
-        return 'vectormiscellaneous'
+        return "vectormiscellaneous"
 
     def name(self):
-        return 'buildvirtualvector'
+        return "buildvirtualvector"
 
     def displayName(self):
-        return self.tr('Build virtual vector')
+        return self.tr("Build virtual vector")
 
     def tags(self):
-        return ['ogr', 'gdal', 'vrt', 'create']
+        return ["ogr", "gdal", "vrt", "create"]
 
     def shortHelpString(self):
-        return self.tr("This algorithm creates a virtual layer that contains a set of vector layers.\n\n"
-                       "The output virtual layer will not be opened in the current project.")
+        return self.tr(
+            "This algorithm creates a virtual layer that contains a set of vector layers.\n\n"
+            "The output virtual layer will not be opened in the current project."
+        )
 
     def __init__(self):
         super().__init__()
 
     def initAlgorithm(self, config=None):
-        self.addParameter(QgsProcessingParameterMultipleLayers(self.INPUT,
-                                                               self.tr('Input datasources'),
-                                                               QgsProcessing.TypeVector))
-        self.addParameter(QgsProcessingParameterBoolean(self.UNIONED,
-                                                        self.tr('Create "unioned" VRT'),
-                                                        defaultValue=False))
+        self.addParameter(
+            QgsProcessingParameterMultipleLayers(
+                self.INPUT,
+                self.tr("Input datasources"),
+                QgsProcessing.SourceType.TypeVector,
+            )
+        )
+        self.addParameter(
+            QgsProcessingParameterBoolean(
+                self.UNIONED, self.tr('Create "unioned" VRT'), defaultValue=False
+            )
+        )
 
         class ParameterVectorVrtDestination(QgsProcessingParameterVectorDestination):
 
@@ -84,31 +93,39 @@ class Datasources2Vrt(GdalAlgorithm):
                 return copy
 
             def defaultFileExtension(self):
-                return 'vrt'
+                return "vrt"
 
             def createFileFilter(self):
-                return '{} (*.vrt *.VRT)'.format(QCoreApplication.translate("GdalAlgorithm", 'VRT files'))
+                return "{} (*.vrt *.VRT)".format(
+                    QCoreApplication.translate("GdalAlgorithm", "VRT files")
+                )
 
             def supportedOutputRasterLayerExtensions(self):
-                return ['vrt']
+                return ["vrt"]
 
             def isSupportedOutputValue(self, value, context):
-                output_path = QgsProcessingParameters.parameterAsOutputLayer(self, value, context, testOnly=True)
-                if pathlib.Path(output_path).suffix.lower() != '.vrt':
-                    return False, QCoreApplication.translate("GdalAlgorithm", 'Output filename must use a .vrt extension')
-                return True, ''
+                output_path = QgsProcessingParameters.parameterAsOutputLayer(
+                    self, value, context, testOnly=True
+                )
+                if pathlib.Path(output_path).suffix.lower() != ".vrt":
+                    return False, QCoreApplication.translate(
+                        "GdalAlgorithm", "Output filename must use a .vrt extension"
+                    )
+                return True, ""
 
-        self.addParameter(ParameterVectorVrtDestination(self.OUTPUT,
-                                                        self.tr('Virtual vector')))
-        self.addOutput(QgsProcessingOutputString(self.VRT_STRING,
-                                                 self.tr('Virtual string')))
+        self.addParameter(
+            ParameterVectorVrtDestination(self.OUTPUT, self.tr("Virtual vector"))
+        )
+        self.addOutput(
+            QgsProcessingOutputString(self.VRT_STRING, self.tr("Virtual string"))
+        )
 
     def processAlgorithm(self, parameters, context, feedback):
         input_layers = self.parameterAsLayerList(parameters, self.INPUT, context)
         unioned = self.parameterAsBoolean(parameters, self.UNIONED, context)
         vrtPath = self.parameterAsOutputLayer(parameters, self.OUTPUT, context)
 
-        vrt = '<OGRVRTDataSource>'
+        vrt = "<OGRVRTDataSource>"
         if unioned:
             vrt += '<OGRVRTUnionLayer name="UnionedLayer">'
 
@@ -117,24 +134,25 @@ class Datasources2Vrt(GdalAlgorithm):
             if feedback.isCanceled():
                 break
 
-            basePath = GdalUtils.ogrConnectionStringFromLayer(layer)
+            connection_details = GdalUtils.gdal_connection_details_from_layer(layer)
+            basePath = connection_details.connection_string
             layerName = GdalUtils.ogrLayerName(layer.source())
 
             vrt += f'<OGRVRTLayer name="{html.escape(layerName, True)}">'
-            vrt += f'<SrcDataSource>{html.escape(basePath, True)}</SrcDataSource>'
-            vrt += f'<SrcLayer>{html.escape(layerName, True)}</SrcLayer>'
-            vrt += '</OGRVRTLayer>'
+            vrt += f"<SrcDataSource>{html.escape(basePath, True)}</SrcDataSource>"
+            vrt += f"<SrcLayer>{html.escape(layerName, True)}</SrcLayer>"
+            vrt += "</OGRVRTLayer>"
 
             feedback.setProgress(int(current * total))
 
         if unioned:
-            vrt += '</OGRVRTUnionLayer>'
-        vrt += '</OGRVRTDataSource>'
+            vrt += "</OGRVRTUnionLayer>"
+        vrt += "</OGRVRTDataSource>"
 
-        with open(vrtPath, 'w', encoding='utf-8') as f:
+        with open(vrtPath, "w", encoding="utf-8") as f:
             f.write(vrt)
 
         return {self.OUTPUT: vrtPath, self.VRT_STRING: vrt}
 
     def commandName(self):
-        return ''
+        return ""
