@@ -15,96 +15,113 @@
 ***************************************************************************
 """
 
-__author__ = 'Michael Minn'
-__date__ = 'May 2010'
-__copyright__ = '(C) 2010, Michael Minn'
+__author__ = "Michael Minn"
+__date__ = "May 2010"
+__copyright__ = "(C) 2010, Michael Minn"
 
-from qgis.core import (QgsFeature,
-                       QgsGeometry,
-                       QgsMultiPoint,
-                       QgsMultiLineString,
-                       QgsLineString,
-                       QgsPolygon,
-                       QgsFeatureSink,
-                       QgsWkbTypes,
-                       QgsProcessingException,
-                       QgsProcessingParameterFeatureSource,
-                       QgsProcessingParameterEnum,
-                       QgsProcessingParameterFeatureSink)
+from qgis.core import (
+    QgsFeature,
+    QgsGeometry,
+    QgsMultiPoint,
+    QgsMultiLineString,
+    QgsLineString,
+    QgsPolygon,
+    QgsFeatureSink,
+    QgsWkbTypes,
+    QgsProcessingException,
+    QgsProcessingParameterFeatureSource,
+    QgsProcessingParameterEnum,
+    QgsProcessingParameterFeatureSink,
+)
 from processing.algs.qgis.QgisAlgorithm import QgisAlgorithm
 
 
 class GeometryConvert(QgisAlgorithm):
-    INPUT = 'INPUT'
-    TYPE = 'TYPE'
-    OUTPUT = 'OUTPUT'
+    INPUT = "INPUT"
+    TYPE = "TYPE"
+    OUTPUT = "OUTPUT"
 
     def group(self):
-        return self.tr('Vector geometry')
+        return self.tr("Vector geometry")
 
     def groupId(self):
-        return 'vectorgeometry'
+        return "vectorgeometry"
 
     def __init__(self):
         super().__init__()
 
     def initAlgorithm(self, config=None):
-        self.types = [self.tr('Centroids'),
-                      self.tr('Nodes'),
-                      self.tr('Linestrings'),
-                      self.tr('Multilinestrings'),
-                      self.tr('Polygons')]
+        self.types = [
+            self.tr("Centroids"),
+            self.tr("Nodes"),
+            self.tr("Linestrings"),
+            self.tr("Multilinestrings"),
+            self.tr("Polygons"),
+        ]
 
-        self.addParameter(QgsProcessingParameterFeatureSource(self.INPUT,
-                                                              self.tr('Input layer')))
-        self.addParameter(QgsProcessingParameterEnum(self.TYPE,
-                                                     self.tr('New geometry type'), options=self.types))
+        self.addParameter(
+            QgsProcessingParameterFeatureSource(self.INPUT, self.tr("Input layer"))
+        )
+        self.addParameter(
+            QgsProcessingParameterEnum(
+                self.TYPE, self.tr("New geometry type"), options=self.types
+            )
+        )
 
-        self.addParameter(QgsProcessingParameterFeatureSink(self.OUTPUT,
-                                                            self.tr('Converted')))
+        self.addParameter(
+            QgsProcessingParameterFeatureSink(self.OUTPUT, self.tr("Converted"))
+        )
 
     def name(self):
-        return 'convertgeometrytype'
+        return "convertgeometrytype"
 
     def displayName(self):
-        return self.tr('Convert geometry type')
+        return self.tr("Convert geometry type")
 
     def processAlgorithm(self, parameters, context, feedback):
         source = self.parameterAsSource(parameters, self.INPUT, context)
         if source is None:
-            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
+            raise QgsProcessingException(
+                self.invalidSourceError(parameters, self.INPUT)
+            )
 
         index = self.parameterAsEnum(parameters, self.TYPE, context)
 
         if index == 0:
-            newType = QgsWkbTypes.Point
+            newType = QgsWkbTypes.Type.Point
         elif index == 1:
-            newType = QgsWkbTypes.Point
+            newType = QgsWkbTypes.Type.Point
             if QgsWkbTypes.hasM(source.wkbType()):
                 newType = QgsWkbTypes.addM(newType)
             if QgsWkbTypes.hasZ(source.wkbType()):
                 newType = QgsWkbTypes.addZ(newType)
         elif index == 2:
-            newType = QgsWkbTypes.LineString
+            newType = QgsWkbTypes.Type.LineString
             if QgsWkbTypes.hasM(source.wkbType()):
                 newType = QgsWkbTypes.addM(newType)
             if QgsWkbTypes.hasZ(source.wkbType()):
                 newType = QgsWkbTypes.addZ(newType)
         elif index == 3:
-            newType = QgsWkbTypes.MultiLineString
+            newType = QgsWkbTypes.Type.MultiLineString
             if QgsWkbTypes.hasM(source.wkbType()):
                 newType = QgsWkbTypes.addM(newType)
             if QgsWkbTypes.hasZ(source.wkbType()):
                 newType = QgsWkbTypes.addZ(newType)
         else:
-            newType = QgsWkbTypes.Polygon
+            newType = QgsWkbTypes.Type.Polygon
             if QgsWkbTypes.hasM(source.wkbType()):
                 newType = QgsWkbTypes.addM(newType)
             if QgsWkbTypes.hasZ(source.wkbType()):
                 newType = QgsWkbTypes.addZ(newType)
 
-        (sink, dest_id) = self.parameterAsSink(parameters, self.OUTPUT, context,
-                                               source.fields(), newType, source.sourceCrs())
+        (sink, dest_id) = self.parameterAsSink(
+            parameters,
+            self.OUTPUT,
+            context,
+            source.fields(),
+            newType,
+            source.sourceCrs(),
+        )
         if sink is None:
             raise QgsProcessingException(self.invalidSinkError(parameters, self.OUTPUT))
 
@@ -116,13 +133,13 @@ class GeometryConvert(QgisAlgorithm):
                 break
 
             if not f.hasGeometry():
-                sink.addFeature(f, QgsFeatureSink.FastInsert)
+                sink.addFeature(f, QgsFeatureSink.Flag.FastInsert)
             else:
                 for p in self.convertGeometry(f.geometry(), index):
                     feat = QgsFeature()
                     feat.setAttributes(f.attributes())
                     feat.setGeometry(p)
-                    sink.addFeature(feat, QgsFeatureSink.FastInsert)
+                    sink.addFeature(feat, QgsFeatureSink.Flag.FastInsert)
 
             feedback.setProgress(int(current * total))
 
@@ -160,10 +177,19 @@ class GeometryConvert(QgisAlgorithm):
         return [QgsGeometry(mp)]
 
     def convertToLineStrings(self, geom):
-        if QgsWkbTypes.geometryType(geom.wkbType()) == QgsWkbTypes.PointGeometry:
+        if (
+            QgsWkbTypes.geometryType(geom.wkbType())
+            == QgsWkbTypes.GeometryType.PointGeometry
+        ):
             raise QgsProcessingException(
-                self.tr('Cannot convert from {0} to LineStrings').format(QgsWkbTypes.displayString(geom.wkbType())))
-        elif QgsWkbTypes.geometryType(geom.wkbType()) == QgsWkbTypes.LineGeometry:
+                self.tr("Cannot convert from {0} to LineStrings").format(
+                    QgsWkbTypes.displayString(geom.wkbType())
+                )
+            )
+        elif (
+            QgsWkbTypes.geometryType(geom.wkbType())
+            == QgsWkbTypes.GeometryType.LineGeometry
+        ):
             if QgsWkbTypes.isMultiType(geom.wkbType()):
                 return geom.asGeometryCollection()
             else:
@@ -177,10 +203,19 @@ class GeometryConvert(QgisAlgorithm):
             return boundary.asGeometryCollection()
 
     def convertToMultiLineStrings(self, geom):
-        if QgsWkbTypes.geometryType(geom.wkbType()) == QgsWkbTypes.PointGeometry:
+        if (
+            QgsWkbTypes.geometryType(geom.wkbType())
+            == QgsWkbTypes.GeometryType.PointGeometry
+        ):
             raise QgsProcessingException(
-                self.tr('Cannot convert from {0} to MultiLineStrings').format(QgsWkbTypes.displayString(geom.wkbType())))
-        elif QgsWkbTypes.geometryType(geom.wkbType()) == QgsWkbTypes.LineGeometry:
+                self.tr("Cannot convert from {0} to MultiLineStrings").format(
+                    QgsWkbTypes.displayString(geom.wkbType())
+                )
+            )
+        elif (
+            QgsWkbTypes.geometryType(geom.wkbType())
+            == QgsWkbTypes.GeometryType.LineGeometry
+        ):
             if QgsWkbTypes.isMultiType(geom.wkbType()):
                 return [geom]
             else:
@@ -194,10 +229,20 @@ class GeometryConvert(QgisAlgorithm):
             return [QgsGeometry(geom.constGet().boundary())]
 
     def convertToPolygon(self, geom):
-        if QgsWkbTypes.geometryType(geom.wkbType()) == QgsWkbTypes.PointGeometry and geom.constGet().nCoordinates() < 3:
+        if (
+            QgsWkbTypes.geometryType(geom.wkbType())
+            == QgsWkbTypes.GeometryType.PointGeometry
+            and geom.constGet().nCoordinates() < 3
+        ):
             raise QgsProcessingException(
-                self.tr('Cannot convert from Point to Polygon').format(QgsWkbTypes.displayString(geom.wkbType())))
-        elif QgsWkbTypes.geometryType(geom.wkbType()) == QgsWkbTypes.PointGeometry:
+                self.tr("Cannot convert from Point to Polygon").format(
+                    QgsWkbTypes.displayString(geom.wkbType())
+                )
+            )
+        elif (
+            QgsWkbTypes.geometryType(geom.wkbType())
+            == QgsWkbTypes.GeometryType.PointGeometry
+        ):
             # multipoint with at least 3 points
             # TODO: mega inefficient - needs rework when geometry iterators land
             # (but at least it doesn't lose Z/M values)
@@ -211,7 +256,10 @@ class GeometryConvert(QgisAlgorithm):
             p = QgsPolygon()
             p.setExteriorRing(linestring)
             return [QgsGeometry(p)]
-        elif QgsWkbTypes.geometryType(geom.wkbType()) == QgsWkbTypes.LineGeometry:
+        elif (
+            QgsWkbTypes.geometryType(geom.wkbType())
+            == QgsWkbTypes.GeometryType.LineGeometry
+        ):
             if QgsWkbTypes.isMultiType(geom.wkbType()):
                 parts = []
                 for i in range(geom.constGet().numGeometries()):
