@@ -15,63 +15,85 @@
 ***************************************************************************
 """
 
-__author__ = 'Alexander Bruy'
-__date__ = 'August 2013'
-__copyright__ = '(C) 2013, Alexander Bruy'
+__author__ = "Alexander Bruy"
+__date__ = "August 2013"
+__copyright__ = "(C) 2013, Alexander Bruy"
 
 from osgeo import gdal
-from qgis.PyQt.QtCore import QVariant
-from qgis.core import (QgsFeature,
-                       QgsFeatureSink,
-                       QgsFields,
-                       QgsField,
-                       QgsGeometry,
-                       QgsPointXY,
-                       QgsWkbTypes,
-                       QgsProcessing,
-                       QgsProcessingException,
-                       QgsFeatureRequest,
-                       QgsProcessingParameterRasterLayer,
-                       QgsProcessingParameterFeatureSource,
-                       QgsProcessingParameterFeatureSink)
+from qgis.PyQt.QtCore import QMetaType
+from qgis.core import (
+    QgsFeature,
+    QgsFeatureSink,
+    QgsFields,
+    QgsField,
+    QgsGeometry,
+    QgsPointXY,
+    QgsWkbTypes,
+    QgsProcessing,
+    QgsProcessingException,
+    QgsFeatureRequest,
+    QgsProcessingParameterRasterLayer,
+    QgsProcessingParameterFeatureSource,
+    QgsProcessingParameterFeatureSink,
+)
 from processing.tools import raster
 from processing.algs.qgis.QgisAlgorithm import QgisAlgorithm
 
+gdal.UseExceptions()
+
 
 class PointsFromLines(QgisAlgorithm):
-    INPUT_RASTER = 'INPUT_RASTER'
-    RASTER_BAND = 'RASTER_BAND'
-    INPUT_VECTOR = 'INPUT_VECTOR'
-    OUTPUT = 'OUTPUT'
+    INPUT_RASTER = "INPUT_RASTER"
+    RASTER_BAND = "RASTER_BAND"
+    INPUT_VECTOR = "INPUT_VECTOR"
+    OUTPUT = "OUTPUT"
 
     def group(self):
-        return self.tr('Vector creation')
+        return self.tr("Vector creation")
 
     def groupId(self):
-        return 'vectorcreation'
+        return "vectorcreation"
 
     def __init__(self):
         super().__init__()
 
     def initAlgorithm(self, config=None):
-        self.addParameter(QgsProcessingParameterRasterLayer(self.INPUT_RASTER,
-                                                            self.tr('Raster layer')))
-        self.addParameter(QgsProcessingParameterFeatureSource(self.INPUT_VECTOR,
-                                                              self.tr('Vector layer'), [QgsProcessing.TypeVectorLine]))
-        self.addParameter(QgsProcessingParameterFeatureSink(self.OUTPUT, self.tr('Points along lines'), QgsProcessing.TypeVectorPoint))
+        self.addParameter(
+            QgsProcessingParameterRasterLayer(
+                self.INPUT_RASTER, self.tr("Raster layer")
+            )
+        )
+        self.addParameter(
+            QgsProcessingParameterFeatureSource(
+                self.INPUT_VECTOR,
+                self.tr("Vector layer"),
+                [QgsProcessing.SourceType.TypeVectorLine],
+            )
+        )
+        self.addParameter(
+            QgsProcessingParameterFeatureSink(
+                self.OUTPUT,
+                self.tr("Points along lines"),
+                QgsProcessing.SourceType.TypeVectorPoint,
+            )
+        )
 
     def name(self):
-        return 'generatepointspixelcentroidsalongline'
+        return "generatepointspixelcentroidsalongline"
 
     def displayName(self):
-        return self.tr('Generate points (pixel centroids) along line')
+        return self.tr("Generate points (pixel centroids) along line")
 
     def processAlgorithm(self, parameters, context, feedback):
         source = self.parameterAsSource(parameters, self.INPUT_VECTOR, context)
         if source is None:
-            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT_VECTOR))
+            raise QgsProcessingException(
+                self.invalidSourceError(parameters, self.INPUT_VECTOR)
+            )
 
-        raster_layer = self.parameterAsRasterLayer(parameters, self.INPUT_RASTER, context)
+        raster_layer = self.parameterAsRasterLayer(
+            parameters, self.INPUT_RASTER, context
+        )
         rasterPath = raster_layer.source()
 
         rasterDS = gdal.Open(rasterPath, gdal.GA_ReadOnly)
@@ -79,12 +101,18 @@ class PointsFromLines(QgisAlgorithm):
         rasterDS = None
 
         fields = QgsFields()
-        fields.append(QgsField('id', QVariant.Int, '', 10, 0))
-        fields.append(QgsField('line_id', QVariant.Int, '', 10, 0))
-        fields.append(QgsField('point_id', QVariant.Int, '', 10, 0))
+        fields.append(QgsField("id", QMetaType.Type.Int, "", 10, 0))
+        fields.append(QgsField("line_id", QMetaType.Type.Int, "", 10, 0))
+        fields.append(QgsField("point_id", QMetaType.Type.Int, "", 10, 0))
 
-        (sink, dest_id) = self.parameterAsSink(parameters, self.OUTPUT, context,
-                                               fields, QgsWkbTypes.Point, raster_layer.crs())
+        (sink, dest_id) = self.parameterAsSink(
+            parameters,
+            self.OUTPUT,
+            context,
+            fields,
+            QgsWkbTypes.Type.Point,
+            raster_layer.crs(),
+        )
         if sink is None:
             raise QgsProcessingException(self.invalidSinkError(parameters, self.OUTPUT))
 
@@ -95,7 +123,11 @@ class PointsFromLines(QgisAlgorithm):
         self.lineId = 0
         self.pointId = 0
 
-        features = source.getFeatures(QgsFeatureRequest().setDestinationCrs(raster_layer.crs(), context.transformContext()))
+        features = source.getFeatures(
+            QgsFeatureRequest().setDestinationCrs(
+                raster_layer.crs(), context.transformContext()
+            )
+        )
         total = 100.0 / source.featureCount() if source.featureCount() else 0
         for current, f in enumerate(features):
             if feedback.isCanceled():
@@ -112,13 +144,10 @@ class PointsFromLines(QgisAlgorithm):
                         p1 = line[i]
                         p2 = line[i + 1]
 
-                        (x1, y1) = raster.mapToPixel(p1.x(), p1.y(),
-                                                     geoTransform)
-                        (x2, y2) = raster.mapToPixel(p2.x(), p2.y(),
-                                                     geoTransform)
+                        (x1, y1) = raster.mapToPixel(p1.x(), p1.y(), geoTransform)
+                        (x2, y2) = raster.mapToPixel(p2.x(), p2.y(), geoTransform)
 
-                        self.buildLine(x1, y1, x2, y2, geoTransform,
-                                       sink, outFeature)
+                        self.buildLine(x1, y1, x2, y2, geoTransform, sink, outFeature)
             else:
                 points = geom.asPolyline()
                 for i in range(len(points) - 1):
@@ -128,8 +157,7 @@ class PointsFromLines(QgisAlgorithm):
                     (x1, y1) = raster.mapToPixel(p1.x(), p1.y(), geoTransform)
                     (x2, y2) = raster.mapToPixel(p2.x(), p2.y(), geoTransform)
 
-                    self.buildLine(x1, y1, x2, y2, geoTransform, sink,
-                                   outFeature)
+                    self.buildLine(x1, y1, x2, y2, geoTransform, sink, outFeature)
 
             self.pointId = 0
             self.lineId += 1
@@ -195,11 +223,11 @@ class PointsFromLines(QgisAlgorithm):
         (x, y) = raster.pixelToMap(pX, pY, geoTransform)
 
         feature.setGeometry(QgsGeometry.fromPointXY(QgsPointXY(x, y)))
-        feature['id'] = self.fid
-        feature['line_id'] = self.lineId
-        feature['point_id'] = self.pointId
+        feature["id"] = self.fid
+        feature["line_id"] = self.lineId
+        feature["point_id"] = self.pointId
 
         self.fid += 1
         self.pointId += 1
 
-        writer.addFeature(feature, QgsFeatureSink.FastInsert)
+        writer.addFeature(feature, QgsFeatureSink.Flag.FastInsert)
