@@ -18,10 +18,10 @@
 
 #include "qgis_3d.h"
 
-#include <Qt3DRender/QMaterial>
 
 #include "qgsabstract3dsymbol.h"
 #include "qgscolorrampshader.h"
+#include "qgsmaterial.h"
 #include "qgspointcloudlayer.h"
 #include "qgscontrastenhancement.h"
 #include "qgspointcloudclassifiedrenderer.h"
@@ -38,7 +38,6 @@
 class _3D_EXPORT QgsPointCloud3DSymbol : public QgsAbstract3DSymbol SIP_ABSTRACT
 {
   public:
-
     /**
      * How to render the point cloud
      */
@@ -56,9 +55,7 @@ class _3D_EXPORT QgsPointCloud3DSymbol : public QgsAbstract3DSymbol SIP_ABSTRACT
       Classification
     };
 
-    //! Constructor for QgsPointCloud3DSymbol
     QgsPointCloud3DSymbol();
-    //! Destructor for QgsPointCloud3DSymbol
     ~QgsPointCloud3DSymbol() override;
 
     QString type() const override { return "pointcloud"; }
@@ -83,7 +80,7 @@ class _3D_EXPORT QgsPointCloud3DSymbol : public QgsAbstract3DSymbol SIP_ABSTRACT
     //! Returns the byte stride for the geometries used to for the vertex buffer
     virtual unsigned int byteStride() = 0;
     //! Used to fill material object with necessary QParameters (and consequently opengl uniforms)
-    virtual void fillMaterial( Qt3DRender::QMaterial *material ) = 0 SIP_SKIP;
+    virtual void fillMaterial( QgsMaterial *material ) = 0 SIP_SKIP;
 
     /**
      * Returns whether points are triangulated to render solid surface
@@ -200,7 +197,6 @@ class _3D_EXPORT QgsPointCloud3DSymbol : public QgsAbstract3DSymbol SIP_ABSTRACT
 class _3D_EXPORT QgsSingleColorPointCloud3DSymbol : public QgsPointCloud3DSymbol
 {
   public:
-    //! Constructor for QgsSingleColorPointCloud3DSymbol
     QgsSingleColorPointCloud3DSymbol();
 
     QString symbolType() const override;
@@ -222,7 +218,7 @@ class _3D_EXPORT QgsSingleColorPointCloud3DSymbol : public QgsPointCloud3DSymbol
     void setSingleColor( QColor color );
 
     unsigned int byteStride() override { return 3 * sizeof( float ); }
-    void fillMaterial( Qt3DRender::QMaterial *material ) override SIP_SKIP;
+    void fillMaterial( QgsMaterial *material ) override SIP_SKIP;
 
 
   private:
@@ -241,7 +237,6 @@ class _3D_EXPORT QgsSingleColorPointCloud3DSymbol : public QgsPointCloud3DSymbol
 class _3D_EXPORT QgsColorRampPointCloud3DSymbol : public QgsPointCloud3DSymbol
 {
   public:
-    //! Constructor for QgsColorRampPointCloud3DSymbol
     QgsColorRampPointCloud3DSymbol();
 
     QgsAbstract3DSymbol *clone() const override SIP_FACTORY;
@@ -288,12 +283,13 @@ class _3D_EXPORT QgsColorRampPointCloud3DSymbol : public QgsPointCloud3DSymbol
 
     /**
      * Sets the minimum and maximum values used when classifying colors in the color ramp shader
-     * \see colorRampShaderMin() colorRampShaderMax()
+     * \see colorRampShaderMin()
+     * \see colorRampShaderMax()
      */
     void setColorRampShaderMinMax( double min, double max );
 
     unsigned int byteStride() override { return 4 * sizeof( float ); }
-    void fillMaterial( Qt3DRender::QMaterial *material ) override SIP_SKIP;
+    void fillMaterial( QgsMaterial *material ) override SIP_SKIP;
 
   private:
     QString mRenderingParameter;
@@ -314,7 +310,6 @@ class _3D_EXPORT QgsColorRampPointCloud3DSymbol : public QgsPointCloud3DSymbol
 class _3D_EXPORT QgsRgbPointCloud3DSymbol : public QgsPointCloud3DSymbol
 {
   public:
-    //! Constructor for QgsRGBPointCloud3DSymbol
     QgsRgbPointCloud3DSymbol();
 
     //! QgsRgbPointCloud3DSymbol cannot be copied - use clone() instead
@@ -330,7 +325,7 @@ class _3D_EXPORT QgsRgbPointCloud3DSymbol : public QgsPointCloud3DSymbol
     void readXml( const QDomElement &elem, const QgsReadWriteContext &context ) override;
 
     unsigned int byteStride() override { return 6 * sizeof( float ); }
-    void fillMaterial( Qt3DRender::QMaterial *material ) override SIP_SKIP;
+    void fillMaterial( QgsMaterial *material ) override SIP_SKIP;
 
     /**
      * Returns the attribute to use for the red channel.
@@ -447,7 +442,6 @@ class _3D_EXPORT QgsRgbPointCloud3DSymbol : public QgsPointCloud3DSymbol
     void setBlueContrastEnhancement( QgsContrastEnhancement *enhancement SIP_TRANSFER );
 
   private:
-
 #ifdef SIP_RUN
     QgsRgbPointCloud3DSymbol( const QgsRgbPointCloud3DSymbol &other );
 #endif
@@ -456,10 +450,9 @@ class _3D_EXPORT QgsRgbPointCloud3DSymbol : public QgsPointCloud3DSymbol
     QString mGreenAttribute = QStringLiteral( "Green" );
     QString mBlueAttribute = QStringLiteral( "Blue" );
 
-    std::unique_ptr< QgsContrastEnhancement > mRedContrastEnhancement;
-    std::unique_ptr< QgsContrastEnhancement > mGreenContrastEnhancement;
-    std::unique_ptr< QgsContrastEnhancement > mBlueContrastEnhancement;
-
+    std::unique_ptr<QgsContrastEnhancement> mRedContrastEnhancement;
+    std::unique_ptr<QgsContrastEnhancement> mGreenContrastEnhancement;
+    std::unique_ptr<QgsContrastEnhancement> mBlueContrastEnhancement;
 };
 
 /**
@@ -474,7 +467,6 @@ class _3D_EXPORT QgsRgbPointCloud3DSymbol : public QgsPointCloud3DSymbol
 class _3D_EXPORT QgsClassificationPointCloud3DSymbol : public QgsPointCloud3DSymbol
 {
   public:
-    //! Constructor for QgsClassificationPointCloud3DSymbol
     QgsClassificationPointCloud3DSymbol();
 
     QgsAbstract3DSymbol *clone() const override SIP_FACTORY;
@@ -509,12 +501,13 @@ class _3D_EXPORT QgsClassificationPointCloud3DSymbol : public QgsPointCloud3DSym
 
     /**
      * Gets the list of categories of the classification that should not be rendered
-     * \see categoriesList() setCategoriesList()
+     * \see categoriesList()
+     * \see setCategoriesList()
      */
     QgsPointCloudCategoryList getFilteredOutCategories() const;
 
-    unsigned int byteStride() override { return 4 * sizeof( float ); }
-    void fillMaterial( Qt3DRender::QMaterial *material ) override SIP_SKIP;
+    unsigned int byteStride() override { return 5 * sizeof( float ); }
+    void fillMaterial( QgsMaterial *material ) override SIP_SKIP;
 
   private:
     QString mRenderingParameter;
