@@ -15,6 +15,7 @@
 
 #include "qgsterraindownloader.h"
 
+#include "qgs3dutils.h"
 #include "qgslogger.h"
 #include "qgsrasterlayer.h"
 #include "qgscoordinatetransform.h"
@@ -75,7 +76,7 @@ void QgsTerrainDownloader::adjustExtentAndResolution( double mupp, const QgsRect
 }
 
 
-double QgsTerrainDownloader::findBestTileResolution( double requestedMupp )
+double QgsTerrainDownloader::findBestTileResolution( double requestedMupp ) const
 {
   int zoom = 0;
   for ( ; zoom <= 15; ++zoom )
@@ -85,7 +86,8 @@ double QgsTerrainDownloader::findBestTileResolution( double requestedMupp )
       break;
   }
 
-  if ( zoom > 15 ) zoom = 15;
+  if ( zoom > 15 )
+    zoom = 15;
   const double finalMupp = mXSpan / ( 256 * ( 1 << zoom ) );
   return finalMupp;
 }
@@ -121,19 +123,11 @@ QByteArray QgsTerrainDownloader::getHeightMap( const QgsRectangle &extentOrig, i
 {
   if ( !mOnlineDtm || !mOnlineDtm->isValid() )
   {
-    QgsDebugMsg( "missing a valid data source" );
+    QgsDebugError( "missing a valid data source" );
     return QByteArray();
   }
 
-  QgsRectangle extentTr = extentOrig;
-  if ( destCrs != mOnlineDtm->crs() )
-  {
-    // if in different CRS - need to reproject extent and resolution
-    QgsCoordinateTransform ct( destCrs, mOnlineDtm->crs(), context );
-    ct.setBallparkTransformsAreAppropriate( true );
-    extentTr = ct.transformBoundingBox( extentOrig );
-  }
-
+  QgsRectangle extentTr = Qgs3DUtils::tryReprojectExtent2D( extentOrig, destCrs, mOnlineDtm->crs(), context );
   const double requestedMupp = extentTr.width() / res;
   const double finalMupp = findBestTileResolution( requestedMupp );
 
@@ -167,20 +161,19 @@ QByteArray QgsTerrainDownloader::getHeightMap( const QgsRectangle &extentOrig, i
 
   if ( !hSrcDS || !hDstDS )
   {
-    QgsDebugMsg( "failed to create GDAL dataset for heightmap" );
+    QgsDebugError( "failed to create GDAL dataset for heightmap" );
     return QByteArray();
   }
 
   const CPLErr err = GDALRasterIO( GDALGetRasterBand( hSrcDS.get(), 1 ), GF_Write, 0, 0, res, res, heightMap.data(), res, res, GDT_Float32, 0, 0 );
   if ( err != CE_None )
   {
-    QgsDebugMsg( "failed to write heightmap data to GDAL dataset" );
+    QgsDebugError( "failed to write heightmap data to GDAL dataset" );
     return QByteArray();
   }
 
   // resample to the desired extent + resolution
-  QgsGdalUtils::resampleSingleBandRaster( hSrcDS.get(), hDstDS.get(), GRA_Bilinear,
-                                          context.calculateCoordinateOperation( mOnlineDtm->crs(), destCrs ).toUtf8().constData() );
+  QgsGdalUtils::resampleSingleBandRaster( hSrcDS.get(), hDstDS.get(), GRA_Bilinear, context.calculateCoordinateOperation( mOnlineDtm->crs(), destCrs ).toUtf8().constData() );
 
   QByteArray heightMapOut;
   heightMapOut.resize( resOrig * resOrig * sizeof( float ) );
@@ -191,7 +184,7 @@ QByteArray QgsTerrainDownloader::getHeightMap( const QgsRectangle &extentOrig, i
   const CPLErr err2 = GDALRasterIO( GDALGetRasterBand( hDstDS.get(), 1 ), GF_Read, 0, 0, resOrig, resOrig, data, resOrig, resOrig, GDT_Float32, 0, 0 );
   if ( err2 != CE_None )
   {
-    QgsDebugMsg( "failed to read heightmap data from GDAL dataset" );
+    QgsDebugError( "failed to read heightmap data from GDAL dataset" );
     return QByteArray();
   }
 
