@@ -18,6 +18,7 @@
 #include "qgslogger.h"
 #include "qgspoint.h"
 #include "Vector3D.h"
+#include "qgsgeometryutils_base.h"
 
 bool MathUtils::calcBarycentricCoordinates( double x, double y, QgsPoint *p1, QgsPoint *p2, QgsPoint *p3, QgsPoint *result )
 {
@@ -25,7 +26,7 @@ bool MathUtils::calcBarycentricCoordinates( double x, double y, QgsPoint *p1, Qg
   {
     QgsPoint p( x, y, 0 );
     const double area = triArea( p1, p2, p3 );
-    if ( area == 0 )//p1, p2, p3 are in a line
+    if ( area == 0 ) //p1, p2, p3 are in a line
     {
       return false;
     }
@@ -40,14 +41,14 @@ bool MathUtils::calcBarycentricCoordinates( double x, double y, QgsPoint *p1, Qg
     result->setZ( w );
     return true;
   }
-  else//null pointer
+  else //null pointer
   {
-    QgsDebugMsg( QStringLiteral( "warning, null pointer" ) );
+    QgsDebugError( QStringLiteral( "warning, null pointer" ) );
     return false;
   }
 }
 
-bool MathUtils::BarycentricToXY( double u, double v, double w, QgsPoint *p1, QgsPoint *p2, QgsPoint *p3, QgsPoint *result )//this is wrong at the moment. Furthermore, the case, where the denominators are 0 have to be treated (two ways of calculating px and py)
+bool MathUtils::BarycentricToXY( double u, double v, double w, QgsPoint *p1, QgsPoint *p2, QgsPoint *p3, QgsPoint *result ) //this is wrong at the moment. Furthermore, the case, where the denominators are 0 have to be treated (two ways of calculating px and py)
 {
   Q_UNUSED( w )
 
@@ -58,12 +59,12 @@ bool MathUtils::BarycentricToXY( double u, double v, double w, QgsPoint *p1, Qgs
 
     if ( area == 0 )
     {
-      QgsDebugMsg( QStringLiteral( "warning, p1, p2 and p3 are in a line" ) );
+      QgsDebugError( QStringLiteral( "warning, p1, p2 and p3 are in a line" ) );
       return false;
     }
 
     const double denominator = ( ( p2->y() - p3->y() ) * ( p1->x() - p3->x() ) - ( p3->y() - p1->y() ) * ( p3->x() - p2->x() ) );
-    if ( denominator != 0 )//drop out py in the two equations
+    if ( denominator != 0 ) //drop out py in the two equations
     {
       px = ( 2 * u * area * ( p1->x() - p3->x() ) - 2 * v * area * ( p3->x() - p2->x() ) - p2->x() * p3->y() * ( p1->x() - p3->x() ) + p3->x() * p1->y() * ( p3->x() - p2->x() ) + p3->x() * p2->y() * ( p1->x() - p3->x() ) - p1->x() * p3->y() * ( p3->x() - p2->x() ) ) / denominator;
       if ( ( p3->x() - p2->x() ) != 0 )
@@ -75,7 +76,7 @@ bool MathUtils::BarycentricToXY( double u, double v, double w, QgsPoint *p1, Qgs
         py = ( 2 * v * area - px * ( p3->y() - p1->y() ) - p3->x() * p1->y() + p1->x() * p3->y() ) / ( p1->x() - p3->x() );
       }
     }
-    else//drop out px in the two equations(maybe this possibility occurs only, if p1, p2 and p3 are coplanar
+    else //drop out px in the two equations(maybe this possibility occurs only, if p1, p2 and p3 are coplanar
     {
       py = ( 2 * u * area * ( p3->y() - p1->y() ) - 2 * v * area * ( p2->y() - p3->y() ) - p2->x() * p3->y() * ( p3->y() - p1->y() ) + p3->x() * p1->y() * ( p2->y() - p3->y() ) + p3->x() * p2->y() * ( p3->y() - p1->y() ) - p1->x() * p3->y() * ( p2->y() - p3->y() ) ) / ( ( p3->x() - p2->x() ) * ( p3->y() - p1->y() ) - ( p1->x() - p3->x() ) * ( p2->y() - p3->y() ) );
       if ( ( p2->y() - p3->y() ) != 0 )
@@ -91,9 +92,9 @@ bool MathUtils::BarycentricToXY( double u, double v, double w, QgsPoint *p1, Qgs
     result->setY( py );
     return true;
   }
-  else//null pointer
+  else //null pointer
   {
-    QgsDebugMsg( QStringLiteral( "warning, null pointer" ) );
+    QgsDebugError( QStringLiteral( "warning, null pointer" ) );
     return false;
   }
 }
@@ -113,12 +114,12 @@ double MathUtils::cFDerBernsteinPoly( int n, int i, double t )
   return n * ( calcBernsteinPoly( n - 1, i - 1, t ) - calcBernsteinPoly( n - 1, i, t ) );
 }
 
-bool MathUtils::circumcenter( QgsPoint *p1, QgsPoint *p2, QgsPoint *p3, QgsPoint *result )//version using the property that the distances from p1, p2, p3 to the circumcenter have to be equal. Possibly there is a bug
+bool MathUtils::circumcenter( QgsPoint *p1, QgsPoint *p2, QgsPoint *p3, QgsPoint *result ) //version using the property that the distances from p1, p2, p3 to the circumcenter have to be equal. Possibly there is a bug
 {
   if ( p1 && p2 && p3 && result )
   {
-    const double distp1p2 = std::sqrt( ( p1->x() - p2->x() ) * ( p1->x() - p2->x() ) + ( p1->y() - p2->y() ) * ( p1->y() - p2->y() ) );
-    const double distp2p3 = std::sqrt( ( p2->x() - p3->x() ) * ( p2->x() - p3->x() ) + ( p2->y() - p3->y() ) * ( p2->y() - p3->y() ) );
+    const double distp1p2 = p1->distance( *p2 );
+    const double distp2p3 = p2->distance( *p3 );
     if ( distp1p2 > distp2p3 )
     {
       //swap p1 and p3 to avoid round-off errors
@@ -130,74 +131,24 @@ bool MathUtils::circumcenter( QgsPoint *p1, QgsPoint *p2, QgsPoint *p3, QgsPoint
     //if one of the denominator is zero we will have problems
     if ( denominator == 0 )
     {
-      QgsDebugMsg( QStringLiteral( "error: the three points are in a line" ) );
+      QgsDebugError( QStringLiteral( "error: the three points are in a line" ) );
       return false;
     }
     else
     {
-      result->setX( 0.5 * ( p1->x()*p1->x()*p2->y() - p1->x()*p1->x()*p3->y() - p3->x()*p3->x()*p2->y() - p1->y()*p2->x()*p2->x() - p1->y()*p1->y()*p3->y() - p3->y()*p3->y()*p2->y() + p1->y()*p1->y()*p2->y() + p3->y()*p2->x()*p2->x() - p1->y()*p2->y()*p2->y() + p1->y()*p3->y()*p3->y() + p1->y()*p3->x()*p3->x() + p3->y()*p2->y()*p2->y() ) / denominator );
-      result->setY( -0.5 * ( p3->x()*p2->x()*p2->x() + p2->x()*p1->y()*p1->y() + p3->x()*p2->y()*p2->y() - p3->x()*p1->x()*p1->x() + p1->x()*p3->y()*p3->y() - p3->x()*p1->y()*p1->y() - p1->x()*p2->x()*p2->x() - p2->x()*p3->y()*p3->y() - p1->x()*p2->y()*p2->y() - p2->x()*p3->x()*p3->x() + p1->x()*p3->x()*p3->x() + p2->x()*p1->x()*p1->x() ) / denominator );
-
-#if 0
-      //debugging: test, if the distances from p1, p2, p3 to result are equal
-      double dist1 = std::sqrt( ( p1->getX() - result->getX() ) * ( p1->getX() - result->getX() ) + ( p1->getY() - result->getY() ) * ( p1->getY() - result->getY() ) );
-      double dist2 = std::sqrt( ( p2->getX() - result->getX() ) * ( p2->getX() - result->getX() ) + ( p2->getY() - result->getY() ) * ( p2->getY() - result->getY() ) );
-      double dist3 = std::sqrt( ( p3->getX() - result->getX() ) * ( p3->getX() - result->getX() ) + ( p3->getY() - result->getY() ) * ( p3->getY() - result->getY() ) );
-
-      if ( dist1 - dist2 > 1 || dist2 - dist1 > 1 || dist1 - dist3 > 1 || dist3 - dist1 > 1 )
-      {
-        bool debug = true;
-      }
-#endif
+      result->setX( 0.5 * ( p1->x() * p1->x() * p2->y() - p1->x() * p1->x() * p3->y() - p3->x() * p3->x() * p2->y() - p1->y() * p2->x() * p2->x() - p1->y() * p1->y() * p3->y() - p3->y() * p3->y() * p2->y() + p1->y() * p1->y() * p2->y() + p3->y() * p2->x() * p2->x() - p1->y() * p2->y() * p2->y() + p1->y() * p3->y() * p3->y() + p1->y() * p3->x() * p3->x() + p3->y() * p2->y() * p2->y() ) / denominator );
+      result->setY( -0.5 * ( p3->x() * p2->x() * p2->x() + p2->x() * p1->y() * p1->y() + p3->x() * p2->y() * p2->y() - p3->x() * p1->x() * p1->x() + p1->x() * p3->y() * p3->y() - p3->x() * p1->y() * p1->y() - p1->x() * p2->x() * p2->x() - p2->x() * p3->y() * p3->y() - p1->x() * p2->y() * p2->y() - p2->x() * p3->x() * p3->x() + p1->x() * p3->x() * p3->x() + p2->x() * p1->x() * p1->x() ) / denominator );
 
       return true;
     }
   }
   else
   {
-    QgsDebugMsg( QStringLiteral( "warning, null pointer" ) );
+    QgsDebugError( QStringLiteral( "warning, null pointer" ) );
     return false;
   }
 }
 
-#if 0
-bool MathUtils::circumcenter( QgsPoint *p1, QgsPoint *p2, QgsPoint *p3, QgsPoint *result )//version imitating the geometric construction
-{
-  if ( p1 && p2 && p3 && result )
-  {
-    QgsPoint midpoint12( ( p1->getX() + p2->getX() ) / 2, ( p1->getY() + p2->getY() ) / 2, 0 );
-    QgsPoint midpoint23( ( p2->getX() + p3->getX() ) / 2, ( p2->getY() + p3->getY() ) / 2, 0 );
-    Vector3D v12( p2->getX() - p1->getX(), p2->getY() - p1->getY(), 0 );
-    Vector3D v23( p3->getX() - p2->getX(), p3->getY() - p2->getY(), 0 );
-    Vector3D n12;
-    MathUtils::normalLeft( &v12, &n12, 10000 );
-    Vector3D n23;
-    MathUtils::normalLeft( &v23, &n23, 10000 );
-    QgsPoint helppoint1( midpoint12.getX() + n12.getX(), midpoint12.getY() + n12.getY(), 0 );
-    QgsPoint helppoint2( midpoint23.getX() + n23.getX(), midpoint23.getY() + n23.getY(), 0 );
-    MathUtils::lineIntersection( &midpoint12, &helppoint1, &midpoint23, &helppoint2, result );
-
-    //debugging: test, if the distances from p1, p2, p3 to result are equal
-    double dist1 = std::sqrt( ( p1->getX() - result->getX() ) * ( p1->getX() - result->getX() ) + ( p1->getY() - result->getY() ) * ( p1->getY() - result->getY() ) );
-    double dist2 = std::sqrt( ( p2->getX() - result->getX() ) * ( p2->getX() - result->getX() ) + ( p2->getY() - result->getY() ) * ( p2->getY() - result->getY() ) );
-    double dist3 = std::sqrt( ( p3->getX() - result->getX() ) * ( p3->getX() - result->getX() ) + ( p3->getY() - result->getY() ) * ( p3->getY() - result->getY() ) );
-
-    if ( dist1 - dist2 > 1 || dist2 - dist1 > 1 || dist1 - dist3 > 1 || dist3 - dist1 > 1 )
-    {
-      bool debug = true;
-    }
-
-    return true;
-
-  }
-  else
-  {
-    cout << "null pointer in method MathUtils::circumcenter" << endl << flush;
-    return false;
-  }
-}
-#endif // 0
-
 double MathUtils::distPointFromLine( QgsPoint *thepoint, QgsPoint *p1, QgsPoint *p2 )
 {
   if ( thepoint && p1 && p2 )
@@ -213,7 +164,7 @@ double MathUtils::distPointFromLine( QgsPoint *thepoint, QgsPoint *p1, QgsPoint
   }
   else
   {
-    QgsDebugMsg( QStringLiteral( "warning, null pointer" ) );
+    QgsDebugError( QStringLiteral( "warning, null pointer" ) );
     return 0;
   }
 }
@@ -225,7 +176,7 @@ int MathUtils::faculty( int n )
 
 bool MathUtils::inCircle( QgsPoint *testp, QgsPoint *p1, QgsPoint *p2, QgsPoint *p3 )
 {
-  const double tolerance = 0.0001;//if the amount of aValue is below this, testp is approximately on the circle and we have to define another criterion to tell, if it is inside or outside.
+  const double tolerance = 0.0001; //if the amount of aValue is below this, testp is approximately on the circle and we have to define another criterion to tell, if it is inside or outside.
 
   if ( testp && p1 && p2 && p3 )
   {
@@ -258,7 +209,7 @@ bool MathUtils::inCircle( QgsPoint *testp, QgsPoint *p1, QgsPoint *p2, QgsPoint
   }
   else
   {
-    QgsDebugMsg( QStringLiteral( "warning, null pointer" ) );
+    QgsDebugError( QStringLiteral( "warning, null pointer" ) );
     return false;
   }
 }
@@ -268,27 +219,6 @@ bool MathUtils::inDiametral( QgsPoint *p1, QgsPoint *p2, QgsPoint *point )
   return angle( p1, point, p2, point ) > 90;
 }
 
-#if 0
-bool MathUtils::inDiametral( QgsPoint *p1, QgsPoint *p2, QgsPoint *point )
-{
-  if ( p1 && p2 && point )
-  {
-    Vector3D p1p2( p2->getX() - p1->getX(), p2->getY() - p1->getY(), 0 );
-    Vector3D orthogonalvec;//vector orthogonal to p1p2 (length radius)
-    QgsPoint midpoint( ( p1->getX() + p2->getX() ) / 2, ( p1->getY() + p2->getY() ) / 2, 0 );
-    double radius = p1p2.getLength() / 2;
-    normalLeft( &p1p2, &orthogonalvec, radius );
-    QgsPoint p3( midpoint.getX() + orthogonalvec.getX(), midpoint.getY() + orthogonalvec.getY(), 0 );
-    return inCircle( point, p1, p2, &p3 );
-  }
-  else
-  {
-    cout << "null pointer in MathUtils::inDiametral" << endl << flush;
-    return false;
-  }
-}
-#endif // 0
-
 double MathUtils::leftOf( const QgsPoint &thepoint, const QgsPoint *p1, const QgsPoint *p2 )
 {
   if ( p1 && p2 )
@@ -303,7 +233,7 @@ double MathUtils::leftOf( const QgsPoint &thepoint, const QgsPoint *p1, const Qg
   }
   else
   {
-    QgsDebugMsg( QStringLiteral( "warning, null pointer" ) );
+    QgsDebugError( QStringLiteral( "warning, null pointer" ) );
     return 0;
   }
 }
@@ -315,17 +245,17 @@ bool MathUtils::lineIntersection( QgsPoint *p1, QgsPoint *p2, QgsPoint *p3, QgsP
     double t1, t2;
     const Vector3D p1p2( p2->x() - p1->x(), p2->y() - p1->y(), 0 );
     const Vector3D p3p4( p4->x() - p3->x(), p4->y() - p3->y(), 0 );
-    if ( ( p3p4.getX()*p1p2.getY() - p3p4.getY()*p1p2.getX() ) != 0 && p1p2.getX() != 0 ) //avoid division through zero
+    if ( ( p3p4.getX() * p1p2.getY() - p3p4.getY() * p1p2.getX() ) != 0 && p1p2.getX() != 0 ) //avoid division through zero
     {
       t2 = ( p1->x() * p1p2.getY() - p1->y() * p1p2.getX() + p3->y() * p1p2.getX() - p3->x() * p1p2.getY() ) / ( p3p4.getX() * p1p2.getY() - p3p4.getY() * p1p2.getX() );
       t1 = ( p3->x() - p1->x() + t2 * p3p4.getX() ) / p1p2.getX();
     }
-    else if ( ( p1p2.getX()*p3p4.getY() - p1p2.getY()*p3p4.getX() ) != 0 && p3p4.getX() != 0 )
+    else if ( ( p1p2.getX() * p3p4.getY() - p1p2.getY() * p3p4.getX() ) != 0 && p3p4.getX() != 0 )
     {
       t1 = ( p3->x() * p3p4.getY() - p3->y() * p3p4.getX() - p1->x() * p3p4.getY() + p1->y() * p3p4.getX() ) / ( p1p2.getX() * p3p4.getY() - p1p2.getY() * p3p4.getX() );
       t2 = ( p1->x() + t1 * p1p2.getX() - p3->x() ) / p3p4.getX();
     }
-    else//the lines are parallel
+    else //the lines are parallel
     {
       return false;
     }
@@ -346,7 +276,7 @@ bool MathUtils::lineIntersection( QgsPoint *p1, QgsPoint *p2, QgsPoint *p3, QgsP
 
   else
   {
-    QgsDebugMsg( QStringLiteral( "warning, null pointer" ) );
+    QgsDebugError( QStringLiteral( "warning, null pointer" ) );
     return false;
   }
 }
@@ -358,17 +288,17 @@ bool MathUtils::lineIntersection( QgsPoint *p1, QgsPoint *p2, QgsPoint *p3, QgsP
     double t1, t2;
     const Vector3D p1p2( p2->x() - p1->x(), p2->y() - p1->y(), 0 );
     const Vector3D p3p4( p4->x() - p3->x(), p4->y() - p3->y(), 0 );
-    if ( ( p3p4.getX()*p1p2.getY() - p3p4.getY()*p1p2.getX() ) != 0 && p1p2.getX() != 0 ) //avoid division through zero
+    if ( ( p3p4.getX() * p1p2.getY() - p3p4.getY() * p1p2.getX() ) != 0 && p1p2.getX() != 0 ) //avoid division through zero
     {
       t2 = ( p1->x() * p1p2.getY() - p1->y() * p1p2.getX() + p3->y() * p1p2.getX() - p3->x() * p1p2.getY() ) / ( p3p4.getX() * p1p2.getY() - p3p4.getY() * p1p2.getX() );
       t1 = ( p3->x() - p1->x() + t2 * p3p4.getX() ) / p1p2.getX();
     }
-    else if ( ( p1p2.getX()*p3p4.getY() - p1p2.getY()*p3p4.getX() ) != 0 && p3p4.getX() != 0 )
+    else if ( ( p1p2.getX() * p3p4.getY() - p1p2.getY() * p3p4.getX() ) != 0 && p3p4.getX() != 0 )
     {
       t1 = ( p3->x() * p3p4.getY() - p3->y() * p3p4.getX() - p1->x() * p3p4.getY() + p1->y() * p3p4.getX() ) / ( p1p2.getX() * p3p4.getY() - p1p2.getY() * p3p4.getX() );
       t2 = ( p1->x() + t1 * p1p2.getX() - p3->x() ) / p3p4.getX();
     }
-    else//the lines are parallel
+    else //the lines are parallel
     {
       intersection_point->setX( 0 );
       intersection_point->setY( 0 );
@@ -386,8 +316,8 @@ bool MathUtils::lineIntersection( QgsPoint *p1, QgsPoint *p2, QgsPoint *p3, QgsP
         return false;
       }
       //calculate the intersection point
-      intersection_point->setX( p1->x() * ( 1 - t1 ) + p2->x()*t1 );
-      intersection_point->setY( p1->y() * ( 1 - t1 ) + p2->y()*t1 );
+      intersection_point->setX( p1->x() * ( 1 - t1 ) + p2->x() * t1 );
+      intersection_point->setY( p1->y() * ( 1 - t1 ) + p2->y() * t1 );
       intersection_point->setZ( 0 );
       return true;
     }
@@ -399,7 +329,7 @@ bool MathUtils::lineIntersection( QgsPoint *p1, QgsPoint *p2, QgsPoint *p3, QgsP
 
   else
   {
-    QgsDebugMsg( QStringLiteral( "warning, null pointer" ) );
+    QgsDebugError( QStringLiteral( "warning, null pointer" ) );
     return false;
   }
 }
@@ -423,9 +353,9 @@ double MathUtils::triArea( QgsPoint *pa, QgsPoint *pb, QgsPoint *pc )
     const double deter = ( pa->x() * pb->y() + pb->x() * pc->y() + pc->x() * pa->y() - pa->x() * pc->y() - pb->x() * pa->y() - pc->x() * pb->y() );
     return 0.5 * deter;
   }
-  else//null pointer
+  else //null pointer
   {
-    QgsDebugMsg( QStringLiteral( "warning, null pointer" ) );
+    QgsDebugError( QStringLiteral( "warning, null pointer" ) );
     return 0;
   }
 }
@@ -434,7 +364,7 @@ double MathUtils::calcCubicHermitePoly( int n, int i, double t )
 {
   if ( n != 3 || i > n )
   {
-    QgsDebugMsg( QStringLiteral( "error, can't calculate hermite polynom" ) );
+    QgsDebugError( QStringLiteral( "error, can't calculate hermite polynom" ) );
   }
 
   if ( n == 3 && i == 0 )
@@ -456,9 +386,9 @@ double MathUtils::calcCubicHermitePoly( int n, int i, double t )
   {
     return ( calcBernsteinPoly( 3, 2, t ) + calcBernsteinPoly( 3, 3, t ) );
   }
-  else//something went wrong
+  else //something went wrong
   {
-    QgsDebugMsg( QStringLiteral( "unexpected error" ) );
+    QgsDebugError( QStringLiteral( "unexpected error" ) );
     return 0;
   }
 }
@@ -467,7 +397,7 @@ double MathUtils::cFDerCubicHermitePoly( int n, int i, double t )
 {
   if ( n != 3 || i > n )
   {
-    QgsDebugMsg( QStringLiteral( "error, can't calculate hermite polynom" ) );
+    QgsDebugError( QStringLiteral( "error, can't calculate hermite polynom" ) );
   }
 
   if ( n == 3 && i == 0 )
@@ -497,14 +427,14 @@ double MathUtils::cFDerCubicHermitePoly( int n, int i, double t )
   }
   else
   {
-    QgsDebugMsg( QStringLiteral( "unexpected error" ) );
+    QgsDebugError( QStringLiteral( "unexpected error" ) );
     return 0;
   }
 }
 
 bool MathUtils::derVec( const Vector3D *v1, const Vector3D *v2, Vector3D *result, double x, double y )
 {
-  if ( v1 && v2 && result )//no null pointers
+  if ( v1 && v2 && result ) //no null pointers
   {
     const double u = ( x * v2->getY() - y * v2->getX() ) / ( v1->getX() * v2->getY() - v1->getY() * v2->getX() );
     const double v = ( x * v1->getY() - y * v1->getX() ) / ( v2->getX() * v1->getY() - v2->getY() * v1->getX() );
@@ -519,9 +449,9 @@ bool MathUtils::derVec( const Vector3D *v1, const Vector3D *v2, Vector3D *result
 
 bool MathUtils::normalLeft( Vector3D *v1, Vector3D *result, double length )
 {
-  if ( v1 && result )//we don't like null pointers
+  if ( v1 && result ) //we don't like null pointers
   {
-    if ( v1->getY() == 0 )//this would cause a division with zero
+    if ( v1->getY() == 0 ) //this would cause a division with zero
     {
       result->setX( 0 );
 
@@ -543,20 +473,20 @@ bool MathUtils::normalLeft( Vector3D *v1, Vector3D *result, double length )
     const double c = -( length * length );
     const double d = b * b - 4 * a * c;
 
-    if ( d < 0 )//no solution in R
+    if ( d < 0 ) //no solution in R
     {
-      QgsDebugMsg( QStringLiteral( "Determinant Error" ) );
+      QgsDebugError( QStringLiteral( "Determinant Error" ) );
       return false;
     }
 
     result->setX( ( -b + std::sqrt( d ) ) / ( 2 * a ) ); //take one of the two solutions of the quadratic equation
-    result->setY( ( -result->getX()*v1->getX() ) / v1->getY() );
+    result->setY( ( -result->getX() * v1->getX() ) / v1->getY() );
 
     const QgsPoint point1( 0, 0, 0 );
     const QgsPoint point2( v1->getX(), v1->getY(), 0 );
     const QgsPoint point3( result->getX(), result->getY(), 0 );
 
-    if ( !( leftOf( point1, &point2, &point3 ) < 0 ) )//if we took the solution on the right side, change the sign of the components of the result
+    if ( !( leftOf( point1, &point2, &point3 ) < 0 ) ) //if we took the solution on the right side, change the sign of the components of the result
     {
       result->setX( -result->getX() );
       result->setY( -result->getY() );
@@ -572,13 +502,11 @@ bool MathUtils::normalLeft( Vector3D *v1, Vector3D *result, double length )
 }
 
 
-
 bool MathUtils::normalRight( Vector3D *v1, Vector3D *result, double length )
 {
-  if ( v1 && result )//we don't like null pointers
+  if ( v1 && result ) //we don't like null pointers
   {
-
-    if ( v1->getY() == 0 )//this would cause a division with zero
+    if ( v1->getY() == 0 ) //this would cause a division with zero
     {
       result->setX( 0 );
 
@@ -600,14 +528,14 @@ bool MathUtils::normalRight( Vector3D *v1, Vector3D *result, double length )
     const double c = -( length * length );
     const double d = b * b - 4 * a * c;
 
-    if ( d < 0 )//no solution in R
+    if ( d < 0 ) //no solution in R
     {
-      QgsDebugMsg( QStringLiteral( "Determinant Error" ) );
+      QgsDebugError( QStringLiteral( "Determinant Error" ) );
       return false;
     }
 
     result->setX( ( -b + std::sqrt( d ) ) / ( 2 * a ) ); //take one of the two solutions of the quadratic equation
-    result->setY( ( -result->getX()*v1->getX() ) / v1->getY() );
+    result->setY( ( -result->getX() * v1->getX() ) / v1->getY() );
 
     const QgsPoint point1( 0, 0, 0 );
     const QgsPoint point2( v1->getX(), v1->getY(), 0 );
@@ -631,7 +559,7 @@ bool MathUtils::normalRight( Vector3D *v1, Vector3D *result, double length )
 
 void MathUtils::normalFromPoints( QgsPoint *p1, QgsPoint *p2, QgsPoint *p3, Vector3D *vec )
 {
-  if ( p1 && p2 && p3 && vec )//no null pointers
+  if ( p1 && p2 && p3 && vec ) //no null pointers
   {
     const double ax = p2->x() - p1->x();
     const double ay = p2->y() - p1->y();
@@ -644,14 +572,13 @@ void MathUtils::normalFromPoints( QgsPoint *p1, QgsPoint *p2, QgsPoint *p3, Vect
     vec->setY( az * bx - ax * bz );
     vec->setZ( ax * by - ay * bx );
   }
-
 }
 
 double MathUtils::crossVec( QgsPoint *first, Vector3D *vec1, QgsPoint *second, Vector3D *vec2 )
 {
   if ( first && vec1 && second && vec2 )
   {
-    if ( ( vec2->getX()*vec1->getY() - vec2->getY()*vec1->getX() ) != 0 )
+    if ( ( vec2->getX() * vec1->getY() - vec2->getY() * vec1->getX() ) != 0 )
     {
       /*cout << "first: " << first->getX() << "//" << first->getY() << "//" << first->getZ() << endl << flush;
       cout << "vec1: " << vec1->getX() << "//" << vec1->getY() << "//" << vec1->getZ() << endl << flush;
@@ -660,19 +587,18 @@ double MathUtils::crossVec( QgsPoint *first, Vector3D *vec1, QgsPoint *second, V
       cout << "t2: " << ((first->getX()*vec1->getY()-first->getY()*vec1->getX()-second->getX()*vec1->getY()+second->getY()*vec1->getX())/(vec2->getX()*vec1->getY()-vec2->getY()*vec1->getX())) << endl << flush;*/
 
       return ( ( first->x() * vec1->getY() - first->y() * vec1->getX() - second->x() * vec1->getY() + second->y() * vec1->getX() ) / ( vec2->getX() * vec1->getY() - vec2->getY() * vec1->getX() ) );
-
     }
-    else//if a division by zero would occur
+    else //if a division by zero would occur
     {
-      QgsDebugMsg( QStringLiteral( "warning: vectors are parallel" ) );
+      QgsDebugError( QStringLiteral( "warning: vectors are parallel" ) );
       return 0;
     }
   }
 
 
-  else//null pointer
+  else //null pointer
   {
-    QgsDebugMsg( QStringLiteral( "warning, null pointer" ) );
+    QgsDebugError( QStringLiteral( "warning, null pointer" ) );
     return 0;
   }
 }
@@ -707,14 +633,14 @@ bool MathUtils::normalMinDistance( Vector3D *tangent, Vector3D *target, Vector3D
     const double yw = target->getY();
     const double zw = target->getZ();
 
-    double xg1, yg1, zg1;//the coordinates of the first result
-    double xg2, yg2, zg2;//the coordinates of the second result
+    double xg1, yg1, zg1; //the coordinates of the first result
+    double xg2, yg2, zg2; //the coordinates of the second result
 
     //calculate xg
     const double xgalpha1 = 1 / ( 2 * xt * xt * yw * yw * zt * zt - 2 * zt * zt * zt * xt * zw * xw + yt * yt * yt * yt * zw * zw + yt * yt * zw * zw * zt * zt + xt * xt * yt * yt * xw * xw + xt * xt * yw * yw * yt * yt - 2 * xt * xt * xt * zt * zw * xw + yt * yt * yt * yt * xw * xw + yt * yt * yw * yw * zt * zt + 2 * xt * xt * yt * yt * zw * zw - 2 * yt * yt * yt * yw * zt * zw + zt * zt * xt * xt * zw * zw + zt * zt * zt * zt * xw * xw + xt * xt * zt * zt * xw * xw + 2 * zt * zt * xw * xw * yt * yt - 2 * xt * xt * yw * zt * yt * zw - 2 * xt * yt * yt * yt * xw * yw - 2 * xt * xt * xt * yw * yt * xw - 2 * xt * zt * zt * xw * yt * yw - 2 * xt * zt * xw * yt * yt * zw - 2 * yw * zt * zt * zt * yt * zw + xt * xt * xt * xt * yw * yw + yw * yw * zt * zt * zt * zt + xt * xt * xt * xt * zw * zw );
     if ( xgalpha1 < 0 )
     {
-      QgsDebugMsg( QStringLiteral( "warning, only complex solution of xg" ) );
+      QgsDebugError( QStringLiteral( "warning, only complex solution of xg" ) );
       return false;
     }
     xg1 = std::sqrt( xgalpha1 ) * ( -yt * yw * xt + yt * yt * xw + xw * zt * zt - zt * xt * zw );
@@ -724,7 +650,7 @@ bool MathUtils::normalMinDistance( Vector3D *tangent, Vector3D *target, Vector3D
     const double ygalpha1 = 1 / ( 2 * xt * xt * yw * yw * zt * zt - 2 * zt * zt * zt * xt * zw * xw + yt * yt * yt * yt * zw * zw + yt * yt * zw * zw * zt * zt + xt * xt * yt * yt * xw * xw + xt * xt * yw * yw * yt * yt - 2 * xt * xt * xt * zt * zw * xw + yt * yt * yt * yt * xw * xw + yt * yt * yw * yw * zt * zt + 2 * xt * xt * yt * yt * zw * zw - 2 * yt * yt * yt * yw * zt * zw + zt * zt * xt * xt * zw * zw + zt * zt * zt * zt * xw * xw + xt * xt * zt * zt * xw * xw + 2 * zt * zt * xw * xw * yt * yt - 2 * xt * xt * yw * zt * yt * zw - 2 * xt * yt * yt * yt * xw * yw - 2 * xt * xt * xt * yw * yt * xw - 2 * xt * zt * zt * xw * yt * yw - 2 * xt * zt * xw * yt * yt * zw - 2 * yw * zt * zt * zt * yt * zw + xt * xt * xt * xt * yw * yw + yw * yw * zt * zt * zt * zt + xt * xt * xt * xt * zw * zw );
     if ( ygalpha1 < 0 )
     {
-      QgsDebugMsg( QStringLiteral( "warning, only complex solution of yg" ) );
+      QgsDebugError( QStringLiteral( "warning, only complex solution of yg" ) );
       return false;
     }
     yg1 = -sqrt( ygalpha1 ) * ( -yw * xt * xt - zt * zt * yw + zt * yt * zw + yt * xw * xt );
@@ -734,16 +660,16 @@ bool MathUtils::normalMinDistance( Vector3D *tangent, Vector3D *target, Vector3D
     const double zgalpha1 = 1 / ( 2 * xt * xt * yw * yw * zt * zt - 2 * zt * zt * zt * xt * zw * xw + yt * yt * yt * yt * zw * zw + yt * yt * zw * zw * zt * zt + xt * xt * yt * yt * xw * xw + xt * xt * yw * yw * yt * yt - 2 * xt * xt * xt * zt * zw * xw + yt * yt * yt * yt * xw * xw + yt * yt * yw * yw * zt * zt + 2 * xt * xt * yt * yt * zw * zw - 2 * yt * yt * yt * yw * zt * zw + zt * zt * xt * xt * zw * zw + zt * zt * zt * zt * xw * xw + xt * xt * zt * zt * xw * xw + 2 * zt * zt * xw * xw * yt * yt - 2 * xt * xt * yw * zt * yt * zw - 2 * xt * yt * yt * yt * xw * yw - 2 * xt * xt * xt * yw * yt * xw - 2 * xt * zt * zt * xw * yt * yw - 2 * xt * zt * xw * yt * yt * zw - 2 * yw * zt * zt * zt * yt * zw + xt * xt * xt * xt * yw * yw + yw * yw * zt * zt * zt * zt + xt * xt * xt * xt * zw * zw );
     if ( zgalpha1 < 0 )
     {
-      QgsDebugMsg( QStringLiteral( "warning, only complex solution of zg" ) );
+      QgsDebugError( QStringLiteral( "warning, only complex solution of zg" ) );
       return false;
     }
     zg1 = -sqrt( zgalpha1 ) * ( yt * yw * zt - yt * yt * zw + xw * zt * xt - xt * xt * zw );
     zg2 = std::sqrt( zgalpha1 ) * ( yt * yw * zt - yt * yt * zw + xw * zt * xt - xt * xt * zw );
 
-    const double distance1 = std::sqrt( ( xw - xg1 ) * ( xw - xg1 ) + ( yw - yg1 ) * ( yw - yg1 ) + ( zw - zg1 ) * ( zw - zg1 ) );
-    const double distance2 = std::sqrt( ( xw - xg2 ) * ( xw - xg2 ) + ( yw - yg2 ) * ( yw - yg2 ) + ( zw - zg2 ) * ( zw - zg2 ) );
+    const double distance1 = QgsGeometryUtilsBase::distance2D( xw, yw, xg1, yg1 );
+    const double distance2 = QgsGeometryUtilsBase::distance2D( xw, yw, xg2, yg2 );
 
-    if ( distance1 <= distance2 )//find out, which solution is the maximum and which the minimum
+    if ( distance1 <= distance2 ) //find out, which solution is the maximum and which the minimum
     {
       result->setX( xg1 );
       result->setY( yg1 );
@@ -760,7 +686,7 @@ bool MathUtils::normalMinDistance( Vector3D *tangent, Vector3D *target, Vector3D
 
   else
   {
-    QgsDebugMsg( QStringLiteral( "warning, null pointer" ) );
+    QgsDebugError( QStringLiteral( "warning, null pointer" ) );
     return false;
   }
 }
@@ -778,7 +704,7 @@ double MathUtils::planeTest( QgsPoint *test, QgsPoint *pt1, QgsPoint *pt2, QgsPo
   }
   else
   {
-    QgsDebugMsg( QStringLiteral( "warning, null pointer" ) );
+    QgsDebugError( QStringLiteral( "warning, null pointer" ) );
     return 0;
   }
 }
@@ -794,7 +720,7 @@ double MathUtils::angle( QgsPoint *p1, QgsPoint *p2, QgsPoint *p3, QgsPoint *p4
   }
   else
   {
-    QgsDebugMsg( QStringLiteral( "warning, null pointer" ) );
+    QgsDebugError( QStringLiteral( "warning, null pointer" ) );
     return 0;
   }
 }
