@@ -42,7 +42,7 @@ QString QgsBoundaryAlgorithm::group() const
 
 QString QgsBoundaryAlgorithm::groupId() const
 {
-  return  QStringLiteral( "vectorgeometry" );
+  return QStringLiteral( "vectorgeometry" );
 }
 
 QString QgsBoundaryAlgorithm::outputName() const
@@ -60,7 +60,7 @@ QString QgsBoundaryAlgorithm::shortHelpString() const
 
 QList<int> QgsBoundaryAlgorithm::inputLayerTypes() const
 {
-  return QList<int>() << QgsProcessing::TypeVectorLine << QgsProcessing::TypeVectorPolygon;
+  return QList<int>() << static_cast<int>( Qgis::ProcessingSourceType::VectorLine ) << static_cast<int>( Qgis::ProcessingSourceType::VectorPolygon );
 }
 
 bool QgsBoundaryAlgorithm::supportInPlaceEdit( const QgsMapLayer * ) const
@@ -73,23 +73,28 @@ QgsBoundaryAlgorithm *QgsBoundaryAlgorithm::createInstance() const
   return new QgsBoundaryAlgorithm();
 }
 
-QgsWkbTypes::Type QgsBoundaryAlgorithm::outputWkbType( QgsWkbTypes::Type inputWkbType ) const
+Qgis::ProcessingFeatureSourceFlags QgsBoundaryAlgorithm::sourceFlags() const
 {
-  QgsWkbTypes::Type outputWkb = QgsWkbTypes::Unknown;
+  return Qgis::ProcessingFeatureSourceFlag::SkipGeometryValidityChecks;
+}
+
+Qgis::WkbType QgsBoundaryAlgorithm::outputWkbType( Qgis::WkbType inputWkbType ) const
+{
+  Qgis::WkbType outputWkb = Qgis::WkbType::Unknown;
   switch ( QgsWkbTypes::geometryType( inputWkbType ) )
   {
-    case QgsWkbTypes::LineGeometry:
-      outputWkb = QgsWkbTypes::MultiPoint;
+    case Qgis::GeometryType::Line:
+      outputWkb = Qgis::WkbType::MultiPoint;
       break;
 
-    case QgsWkbTypes::PolygonGeometry:
-      outputWkb = QgsWkbTypes::MultiLineString;
+    case Qgis::GeometryType::Polygon:
+      outputWkb = Qgis::WkbType::MultiLineString;
       break;
 
-    case QgsWkbTypes::PointGeometry:
-    case QgsWkbTypes::UnknownGeometry:
-    case QgsWkbTypes::NullGeometry:
-      outputWkb = QgsWkbTypes::NoGeometry;
+    case Qgis::GeometryType::Point:
+    case Qgis::GeometryType::Unknown:
+    case Qgis::GeometryType::Null:
+      outputWkb = Qgis::WkbType::NoGeometry;
       break;
   }
 
@@ -107,11 +112,11 @@ QgsFeatureList QgsBoundaryAlgorithm::processFeature( const QgsFeature &feature,
 
   if ( feature.hasGeometry() )
   {
-    QgsGeometry inputGeometry = feature.geometry();
-    QgsGeometry outputGeometry = QgsGeometry( inputGeometry.constGet()->boundary() );
+    const QgsGeometry inputGeometry = feature.geometry();
+    const QgsGeometry outputGeometry = QgsGeometry( inputGeometry.constGet()->boundary() );
     if ( outputGeometry.isNull() )
     {
-      feedback->reportError( QObject::tr( "No boundary for feature %1 (possibly a closed linestring?)'" ).arg( feature.id() ) );
+      feedback->reportError( QObject::tr( "No boundary for feature %1 (possibly a closed linestring?)" ).arg( feature.id() ) );
       outFeature.clearGeometry();
     }
     else
