@@ -58,14 +58,19 @@ QString QgsExplodeAlgorithm::shortHelpString() const
                       "same type and contain only single curve segments." );
 }
 
-QList<int> QgsExplodeAlgorithm::inputLayerTypes() const
+Qgis::ProcessingAlgorithmDocumentationFlags QgsExplodeAlgorithm::documentationFlags() const
 {
-  return QList<int>() << QgsProcessing::TypeVectorLine;
+  return Qgis::ProcessingAlgorithmDocumentationFlag::RegeneratesPrimaryKey;
 }
 
-QgsProcessing::SourceType QgsExplodeAlgorithm::outputLayerType() const
+QList<int> QgsExplodeAlgorithm::inputLayerTypes() const
 {
-  return QgsProcessing::TypeVectorLine;
+  return QList<int>() << static_cast<int>( Qgis::ProcessingSourceType::VectorLine );
+}
+
+Qgis::ProcessingSourceType QgsExplodeAlgorithm::outputLayerType() const
+{
+  return Qgis::ProcessingSourceType::VectorLine;
 }
 
 QgsExplodeAlgorithm *QgsExplodeAlgorithm::createInstance() const
@@ -78,7 +83,7 @@ QString QgsExplodeAlgorithm::outputName() const
   return QObject::tr( "Exploded" );
 }
 
-QgsWkbTypes::Type QgsExplodeAlgorithm::outputWkbType( QgsWkbTypes::Type inputWkbType ) const
+Qgis::WkbType QgsExplodeAlgorithm::outputWkbType( Qgis::WkbType inputWkbType ) const
 {
   return QgsWkbTypes::singleType( inputWkbType );
 }
@@ -105,6 +110,11 @@ QgsFeatureList QgsExplodeAlgorithm::processFeature( const QgsFeature &f, QgsProc
   }
 }
 
+Qgis::ProcessingFeatureSourceFlags QgsExplodeAlgorithm::sourceFlags() const
+{
+  return Qgis::ProcessingFeatureSourceFlag::SkipGeometryValidityChecks;
+}
+
 QgsFeatureSink::SinkFlags QgsExplodeAlgorithm::sinkFlags() const
 {
   return QgsFeatureSink::RegeneratePrimaryKey;
@@ -115,10 +125,10 @@ std::vector<QgsGeometry> QgsExplodeAlgorithm::extractAsParts( const QgsGeometry
   if ( geometry.isMultipart() )
   {
     std::vector<QgsGeometry> parts;
-    const QgsGeometryCollection *collection = qgsgeometry_cast< const QgsGeometryCollection * >( geometry.constGet() );
+    const QgsGeometryCollection *collection = qgsgeometry_cast<const QgsGeometryCollection *>( geometry.constGet() );
     for ( int part = 0; part < collection->numGeometries(); ++part )
     {
-      std::vector<QgsGeometry> segments = curveAsSingleSegments( qgsgeometry_cast< const QgsCurve * >( collection->geometryN( part ) ) );
+      std::vector<QgsGeometry> segments = curveAsSingleSegments( qgsgeometry_cast<const QgsCurve *>( collection->geometryN( part ) ) );
       parts.reserve( parts.size() + segments.size() );
       std::move( std::begin( segments ), std::end( segments ), std::back_inserter( parts ) );
     }
@@ -126,7 +136,7 @@ std::vector<QgsGeometry> QgsExplodeAlgorithm::extractAsParts( const QgsGeometry
   }
   else
   {
-    return curveAsSingleSegments( qgsgeometry_cast< const QgsCurve * >( geometry.constGet() ) );
+    return curveAsSingleSegments( qgsgeometry_cast<const QgsCurve *>( geometry.constGet() ) );
   }
 }
 
@@ -137,21 +147,21 @@ std::vector<QgsGeometry> QgsExplodeAlgorithm::curveAsSingleSegments( const QgsCu
     return parts;
   switch ( QgsWkbTypes::flatType( curve->wkbType() ) )
   {
-    case QgsWkbTypes::LineString:
+    case Qgis::WkbType::LineString:
     {
-      const QgsLineString *line = qgsgeometry_cast< const QgsLineString * >( curve );
+      const QgsLineString *line = qgsgeometry_cast<const QgsLineString *>( curve );
       for ( int i = 0; i < line->numPoints() - 1; ++i )
       {
         const QgsPoint ptA = line->pointN( i );
         const QgsPoint ptB = line->pointN( i + 1 );
-        std::unique_ptr< QgsLineString > ls = std::make_unique< QgsLineString >( QVector< QgsPoint >() << ptA << ptB );
+        std::unique_ptr<QgsLineString> ls = std::make_unique<QgsLineString>( QVector<QgsPoint>() << ptA << ptB );
         if ( !useCompoundCurves )
         {
           parts.emplace_back( QgsGeometry( std::move( ls ) ) );
         }
         else
         {
-          std::unique_ptr< QgsCompoundCurve > cc = std::make_unique< QgsCompoundCurve >();
+          std::unique_ptr<QgsCompoundCurve> cc = std::make_unique<QgsCompoundCurve>();
           cc->addCurve( ls.release() );
           parts.emplace_back( QgsGeometry( std::move( cc ) ) );
         }
@@ -159,15 +169,15 @@ std::vector<QgsGeometry> QgsExplodeAlgorithm::curveAsSingleSegments( const QgsCu
       break;
     }
 
-    case QgsWkbTypes::CircularString:
+    case Qgis::WkbType::CircularString:
     {
-      const QgsCircularString *string = qgsgeometry_cast< const QgsCircularString * >( curve );
+      const QgsCircularString *string = qgsgeometry_cast<const QgsCircularString *>( curve );
       for ( int i = 0; i < string->numPoints() - 2; i += 2 )
       {
         const QgsPoint ptA = string->pointN( i );
         const QgsPoint ptB = string->pointN( i + 1 );
         const QgsPoint ptC = string->pointN( i + 2 );
-        std::unique_ptr< QgsCircularString > cs = std::make_unique< QgsCircularString >();
+        std::unique_ptr<QgsCircularString> cs = std::make_unique<QgsCircularString>();
         cs->setPoints( QgsPointSequence() << ptA << ptB << ptC );
         if ( !useCompoundCurves )
         {
@@ -175,7 +185,7 @@ std::vector<QgsGeometry> QgsExplodeAlgorithm::curveAsSingleSegments( const QgsCu
         }
         else
         {
-          std::unique_ptr< QgsCompoundCurve > cc = std::make_unique< QgsCompoundCurve >();
+          std::unique_ptr<QgsCompoundCurve> cc = std::make_unique<QgsCompoundCurve>();
           cc->addCurve( cs.release() );
           parts.emplace_back( QgsGeometry( std::move( cc ) ) );
         }
@@ -183,9 +193,9 @@ std::vector<QgsGeometry> QgsExplodeAlgorithm::curveAsSingleSegments( const QgsCu
       break;
     }
 
-    case QgsWkbTypes::CompoundCurve:
+    case Qgis::WkbType::CompoundCurve:
     {
-      const QgsCompoundCurve *compoundCurve = qgsgeometry_cast< QgsCompoundCurve * >( curve );
+      const QgsCompoundCurve *compoundCurve = qgsgeometry_cast<QgsCompoundCurve *>( curve );
       for ( int i = 0; i < compoundCurve->nCurves(); ++i )
       {
         std::vector<QgsGeometry> segments = curveAsSingleSegments( compoundCurve->curveAt( i ), true );
@@ -197,12 +207,8 @@ std::vector<QgsGeometry> QgsExplodeAlgorithm::curveAsSingleSegments( const QgsCu
 
     default:
       break;
-
   }
   return parts;
 }
 
 ///@endcond
-
-
-
