@@ -26,8 +26,8 @@
 
 #include <QMatrix4x4>
 
-#define TINYGLTF_NO_STB_IMAGE         // we use QImage-based reading of images
-#define TINYGLTF_NO_STB_IMAGE_WRITE   // we don't need writing of images
+#define TINYGLTF_NO_STB_IMAGE       // we use QImage-based reading of images
+#define TINYGLTF_NO_STB_IMAGE_WRITE // we don't need writing of images
 
 #include "tiny_gltf.h"
 
@@ -70,20 +70,20 @@ QgsGltfToVectorFeaturesAlgorithm *QgsGltfToVectorFeaturesAlgorithm::createInstan
 
 void QgsGltfToVectorFeaturesAlgorithm::initAlgorithm( const QVariantMap & )
 {
-  addParameter( new QgsProcessingParameterFile( QStringLiteral( "INPUT" ), QObject::tr( "Input GLTF" ), QgsProcessingParameterFile::File,
-                QStringLiteral( "gltf" ), QVariant(), false, QStringLiteral( "GLTF (*.gltf *.GLTF);;GLB (*.glb *.GLB)" ) ) );
+  addParameter( new QgsProcessingParameterFile( QStringLiteral( "INPUT" ), QObject::tr( "Input GLTF" ), Qgis::ProcessingFileParameterBehavior::File, QStringLiteral( "gltf" ), QVariant(), false, QStringLiteral( "GLTF (*.gltf *.GLTF);;GLB (*.glb *.GLB)" ) ) );
 
-  addParameter( new QgsProcessingParameterFeatureSink( QStringLiteral( "OUTPUT_POLYGONS" ), QObject::tr( "Output polygons" ), QgsProcessing::TypeVectorPolygon, QVariant(), true, true ) );
-  addParameter( new QgsProcessingParameterFeatureSink( QStringLiteral( "OUTPUT_LINES" ), QObject::tr( "Output lines" ), QgsProcessing::TypeVectorLine, QVariant(), true, true ) );
+  addParameter( new QgsProcessingParameterFeatureSink( QStringLiteral( "OUTPUT_POLYGONS" ), QObject::tr( "Output polygons" ), Qgis::ProcessingSourceType::VectorPolygon, QVariant(), true, true ) );
+  addParameter( new QgsProcessingParameterFeatureSink( QStringLiteral( "OUTPUT_LINES" ), QObject::tr( "Output lines" ), Qgis::ProcessingSourceType::VectorLine, QVariant(), true, true ) );
 }
 
-std::unique_ptr< QgsAbstractGeometry > extractTriangles(
+std::unique_ptr<QgsAbstractGeometry> extractTriangles(
   const tinygltf::Model &model,
   const tinygltf::Primitive &primitive,
   const QgsCoordinateTransform &ecefTransform,
   const QgsVector3D &tileTranslationEcef,
   const QMatrix4x4 *gltfLocalTransform,
-  QgsProcessingFeedback *feedback )
+  QgsProcessingFeedback *feedback
+)
 {
   auto posIt = primitive.attributes.find( "POSITION" );
   if ( posIt == primitive.attributes.end() )
@@ -93,9 +93,9 @@ std::unique_ptr< QgsAbstractGeometry > extractTriangles(
   }
   int positionAccessorIndex = posIt->second;
 
-  QVector< double > x;
-  QVector< double > y;
-  QVector< double > z;
+  QVector<double> x;
+  QVector<double> y;
+  QVector<double> z;
   QgsGltfUtils::accessorToMapCoordinates(
     model, positionAccessorIndex, QgsMatrix4x4(),
     &ecefTransform,
@@ -105,7 +105,7 @@ std::unique_ptr< QgsAbstractGeometry > extractTriangles(
     x, y, z
   );
 
-  std::unique_ptr< QgsMultiPolygon > mp = std::make_unique< QgsMultiPolygon >();
+  std::unique_ptr<QgsMultiPolygon> mp = std::make_unique<QgsMultiPolygon>();
 
   if ( primitive.indices == -1 )
   {
@@ -114,7 +114,7 @@ std::unique_ptr< QgsAbstractGeometry > extractTriangles(
     mp->reserve( x.size() );
     for ( int i = 0; i < x.size(); i += 3 )
     {
-      mp->addGeometry( new QgsPolygon( new QgsLineString( QVector<QgsPoint> { QgsPoint( x[i], y[i], z[i] ), QgsPoint( x[i + 1], y[i + 1], z[i + 1] ), QgsPoint( x[i + 2], y[i + 2 ], z[i + 2] ), QgsPoint( x[i], y[i], z[i] ) } ) ) );
+      mp->addGeometry( new QgsPolygon( new QgsLineString( QVector<QgsPoint> { QgsPoint( x[i], y[i], z[i] ), QgsPoint( x[i + 1], y[i + 1], z[i + 1] ), QgsPoint( x[i + 2], y[i + 2], z[i + 2] ), QgsPoint( x[i], y[i], z[i] ) } ) ) );
     }
   }
   else
@@ -123,12 +123,9 @@ std::unique_ptr< QgsAbstractGeometry > extractTriangles(
     const tinygltf::BufferView &bvPrimitive = model.bufferViews[primitiveAccessor.bufferView];
     const tinygltf::Buffer &bPrimitive = model.buffers[bvPrimitive.buffer];
 
-    Q_ASSERT( ( primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_SHORT
-                || primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_INT
-                || primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_BYTE )
-              && primitiveAccessor.type == TINYGLTF_TYPE_SCALAR );
+    Q_ASSERT( ( primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_SHORT || primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_INT || primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_BYTE ) && primitiveAccessor.type == TINYGLTF_TYPE_SCALAR );
 
-    const char *primitivePtr = reinterpret_cast< const char * >( bPrimitive.data.data() ) + bvPrimitive.byteOffset + primitiveAccessor.byteOffset;
+    const char *primitivePtr = reinterpret_cast<const char *>( bPrimitive.data.data() ) + bvPrimitive.byteOffset + primitiveAccessor.byteOffset;
 
     mp->reserve( primitiveAccessor.count / 3 );
     for ( std::size_t i = 0; i < primitiveAccessor.count / 3; i++ )
@@ -139,7 +136,7 @@ std::unique_ptr< QgsAbstractGeometry > extractTriangles(
 
       if ( primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_SHORT )
       {
-        const unsigned short *usPtrPrimitive = reinterpret_cast< const unsigned short * >( primitivePtr );
+        const unsigned short *usPtrPrimitive = reinterpret_cast<const unsigned short *>( primitivePtr );
         if ( bvPrimitive.byteStride )
           primitivePtr += bvPrimitive.byteStride;
         else
@@ -151,7 +148,7 @@ std::unique_ptr< QgsAbstractGeometry > extractTriangles(
       }
       else if ( primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_BYTE )
       {
-        const unsigned char *usPtrPrimitive = reinterpret_cast< const unsigned char * >( primitivePtr );
+        const unsigned char *usPtrPrimitive = reinterpret_cast<const unsigned char *>( primitivePtr );
         if ( bvPrimitive.byteStride )
           primitivePtr += bvPrimitive.byteStride;
         else
@@ -163,7 +160,7 @@ std::unique_ptr< QgsAbstractGeometry > extractTriangles(
       }
       else
       {
-        const unsigned int *uintPtrPrimitive = reinterpret_cast< const unsigned int * >( primitivePtr );
+        const unsigned int *uintPtrPrimitive = reinterpret_cast<const unsigned int *>( primitivePtr );
         if ( bvPrimitive.byteStride )
           primitivePtr += bvPrimitive.byteStride;
         else
@@ -180,13 +177,14 @@ std::unique_ptr< QgsAbstractGeometry > extractTriangles(
   return mp;
 }
 
-std::unique_ptr< QgsAbstractGeometry > extractLines(
+std::unique_ptr<QgsAbstractGeometry> extractLines(
   const tinygltf::Model &model,
   const tinygltf::Primitive &primitive,
   const QgsCoordinateTransform &ecefTransform,
   const QgsVector3D &tileTranslationEcef,
   const QMatrix4x4 *gltfLocalTransform,
-  QgsProcessingFeedback *feedback )
+  QgsProcessingFeedback *feedback
+)
 {
   auto posIt = primitive.attributes.find( "POSITION" );
   if ( posIt == primitive.attributes.end() )
@@ -196,9 +194,9 @@ std::unique_ptr< QgsAbstractGeometry > extractLines(
   }
   int positionAccessorIndex = posIt->second;
 
-  QVector< double > x;
-  QVector< double > y;
-  QVector< double > z;
+  QVector<double> x;
+  QVector<double> y;
+  QVector<double> z;
   QgsGltfUtils::accessorToMapCoordinates(
     model, positionAccessorIndex, QgsMatrix4x4(),
     &ecefTransform,
@@ -208,7 +206,7 @@ std::unique_ptr< QgsAbstractGeometry > extractLines(
     x, y, z
   );
 
-  std::unique_ptr< QgsMultiLineString > ml = std::make_unique< QgsMultiLineString >();
+  std::unique_ptr<QgsMultiLineString> ml = std::make_unique<QgsMultiLineString>();
 
   if ( primitive.indices == -1 )
   {
@@ -226,12 +224,9 @@ std::unique_ptr< QgsAbstractGeometry > extractLines(
     const tinygltf::BufferView &bvPrimitive = model.bufferViews[primitiveAccessor.bufferView];
     const tinygltf::Buffer &bPrimitive = model.buffers[bvPrimitive.buffer];
 
-    Q_ASSERT( ( primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_SHORT
-                || primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_INT
-                || primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_BYTE )
-              && primitiveAccessor.type == TINYGLTF_TYPE_SCALAR );
+    Q_ASSERT( ( primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_SHORT || primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_INT || primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_BYTE ) && primitiveAccessor.type == TINYGLTF_TYPE_SCALAR );
 
-    const char *primitivePtr = reinterpret_cast< const char * >( bPrimitive.data.data() ) + bvPrimitive.byteOffset + primitiveAccessor.byteOffset;
+    const char *primitivePtr = reinterpret_cast<const char *>( bPrimitive.data.data() ) + bvPrimitive.byteOffset + primitiveAccessor.byteOffset;
 
     ml->reserve( primitiveAccessor.count / 2 );
     for ( std::size_t i = 0; i < primitiveAccessor.count / 2; i++ )
@@ -241,7 +236,7 @@ std::unique_ptr< QgsAbstractGeometry > extractLines(
 
       if ( primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_SHORT )
       {
-        const unsigned short *usPtrPrimitive = reinterpret_cast< const unsigned short * >( primitivePtr );
+        const unsigned short *usPtrPrimitive = reinterpret_cast<const unsigned short *>( primitivePtr );
         if ( bvPrimitive.byteStride )
           primitivePtr += bvPrimitive.byteStride;
         else
@@ -252,7 +247,7 @@ std::unique_ptr< QgsAbstractGeometry > extractLines(
       }
       else if ( primitiveAccessor.componentType == TINYGLTF_COMPONENT_TYPE_UNSIGNED_BYTE )
       {
-        const unsigned char *usPtrPrimitive = reinterpret_cast< const unsigned char * >( primitivePtr );
+        const unsigned char *usPtrPrimitive = reinterpret_cast<const unsigned char *>( primitivePtr );
         if ( bvPrimitive.byteStride )
           primitivePtr += bvPrimitive.byteStride;
         else
@@ -263,7 +258,7 @@ std::unique_ptr< QgsAbstractGeometry > extractLines(
       }
       else
       {
-        const unsigned int *uintPtrPrimitive = reinterpret_cast< const unsigned int * >( primitivePtr );
+        const unsigned int *uintPtrPrimitive = reinterpret_cast<const unsigned int *>( primitivePtr );
         if ( bvPrimitive.byteStride )
           primitivePtr += bvPrimitive.byteStride;
         else
@@ -287,13 +282,11 @@ QVariantMap QgsGltfToVectorFeaturesAlgorithm::processAlgorithm( const QVariantMa
   QgsFields fields;
 
   QString polygonDest;
-  std::unique_ptr< QgsFeatureSink > polygonSink( parameterAsSink( parameters, QStringLiteral( "OUTPUT_POLYGONS" ), context, polygonDest, fields,
-      Qgis::WkbType::MultiPolygonZ, destCrs ) );
+  std::unique_ptr<QgsFeatureSink> polygonSink( parameterAsSink( parameters, QStringLiteral( "OUTPUT_POLYGONS" ), context, polygonDest, fields, Qgis::WkbType::MultiPolygonZ, destCrs ) );
   if ( !polygonSink && parameters.value( QStringLiteral( "OUTPUT_POLYGONS" ) ).isValid() )
     throw QgsProcessingException( invalidSinkError( parameters, QStringLiteral( "OUTPUT_POLYGONS" ) ) );
   QString lineDest;
-  std::unique_ptr< QgsFeatureSink > lineSink( parameterAsSink( parameters, QStringLiteral( "OUTPUT_LINES" ), context, lineDest, fields,
-      Qgis::WkbType::MultiLineStringZ, destCrs ) );
+  std::unique_ptr<QgsFeatureSink> lineSink( parameterAsSink( parameters, QStringLiteral( "OUTPUT_LINES" ), context, lineDest, fields, Qgis::WkbType::MultiLineStringZ, destCrs ) );
   if ( !lineSink && parameters.value( QStringLiteral( "OUTPUT_LINES" ) ).isValid() )
     throw QgsProcessingException( invalidSinkError( parameters, QStringLiteral( "OUTPUT_LINES" ) ) );
 
@@ -333,14 +326,13 @@ QVariantMap QgsGltfToVectorFeaturesAlgorithm::processAlgorithm( const QVariantMa
   const tinygltf::Scene &scene = model.scenes[sceneIndex];
   feedback->pushDebugInfo( QObject::tr( "Found %1 nodes in default scene [%2]" ).arg( scene.nodes.size() ).arg( sceneIndex ) );
 
-  QSet< int > warnedPrimitiveTypes;
+  QSet<int> warnedPrimitiveTypes;
 
   const QgsVector3D tileTranslationEcef = QgsGltfUtils::extractTileTranslation( model );
-  std::function< void( int nodeIndex, const QMatrix4x4 &transform ) > traverseNode;
-  traverseNode = [&model, feedback, &polygonSink, &lineSink, &warnedPrimitiveTypes, &ecefTransform, &tileTranslationEcef, &traverseNode]( int nodeIndex, const QMatrix4x4 & parentTransform )
-  {
+  std::function<void( int nodeIndex, const QMatrix4x4 &transform )> traverseNode;
+  traverseNode = [&model, feedback, &polygonSink, &lineSink, &warnedPrimitiveTypes, &ecefTransform, &tileTranslationEcef, &traverseNode]( int nodeIndex, const QMatrix4x4 &parentTransform ) {
     const tinygltf::Node &gltfNode = model.nodes[nodeIndex];
-    std::unique_ptr< QMatrix4x4 > gltfLocalTransform = QgsGltfUtils::parseNodeTransform( gltfNode );
+    std::unique_ptr<QMatrix4x4> gltfLocalTransform = QgsGltfUtils::parseNodeTransform( gltfNode );
     if ( !parentTransform.isIdentity() )
     {
       if ( gltfLocalTransform )
@@ -364,7 +356,7 @@ QVariantMap QgsGltfToVectorFeaturesAlgorithm::processAlgorithm( const QVariantMa
           {
             if ( polygonSink )
             {
-              std::unique_ptr< QgsAbstractGeometry > geometry = extractTriangles( model, primitive, ecefTransform, tileTranslationEcef, gltfLocalTransform.get(), feedback );
+              std::unique_ptr<QgsAbstractGeometry> geometry = extractTriangles( model, primitive, ecefTransform, tileTranslationEcef, gltfLocalTransform.get(), feedback );
               if ( geometry )
               {
                 QgsFeature f;
@@ -379,12 +371,12 @@ QVariantMap QgsGltfToVectorFeaturesAlgorithm::processAlgorithm( const QVariantMa
           {
             if ( lineSink )
             {
-              std::unique_ptr< QgsAbstractGeometry > geometry = extractLines( model, primitive, ecefTransform, tileTranslationEcef, gltfLocalTransform.get(), feedback );
+              std::unique_ptr<QgsAbstractGeometry> geometry = extractLines( model, primitive, ecefTransform, tileTranslationEcef, gltfLocalTransform.get(), feedback );
               if ( geometry )
               {
                 QgsFeature f;
                 f.setGeometry( std::move( geometry ) );
-                polygonSink->addFeature( f, QgsFeatureSink::FastInsert );
+                lineSink->addFeature( f, QgsFeatureSink::FastInsert );
               }
             }
             break;
@@ -445,7 +437,6 @@ QVariantMap QgsGltfToVectorFeaturesAlgorithm::processAlgorithm( const QVariantMa
     {
       traverseNode( childNode, gltfLocalTransform ? *gltfLocalTransform : QMatrix4x4() );
     }
-
   };
 
   if ( !scene.nodes.empty() )
