@@ -34,9 +34,7 @@
  */
 class QgsMergeLinesAlgorithm : public QgsProcessingFeatureBasedAlgorithm
 {
-
   public:
-
     QgsMergeLinesAlgorithm() = default;
     QString name() const override;
     QString displayName() const override;
@@ -49,14 +47,11 @@ class QgsMergeLinesAlgorithm : public QgsProcessingFeatureBasedAlgorithm
 
   protected:
     QString outputName() const override;
-    QgsProcessing::SourceType outputLayerType() const override;
-    QgsWkbTypes::Type outputWkbType( QgsWkbTypes::Type ) const override;
-    QgsFeatureList processFeature( const QgsFeature &feature,  QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
-
+    Qgis::ProcessingSourceType outputLayerType() const override;
+    Qgis::WkbType outputWkbType( Qgis::WkbType ) const override;
+    QgsFeatureList processFeature( const QgsFeature &feature, QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
 };
 
 ///@endcond PRIVATE
 
 #endif // QGSALGORITHMMERGELINES_H
-
-
