@@ -30,9 +30,7 @@
  */
 class QgsShortestPathLayerToPointAlgorithm : public QgsNetworkAnalysisAlgorithmBase
 {
-
   public:
-
     QgsShortestPathLayerToPointAlgorithm() = default;
     void initAlgorithm( const QVariantMap &configuration = QVariantMap() ) override;
     QString name() const override;
@@ -42,10 +40,7 @@ class QgsShortestPathLayerToPointAlgorithm : public QgsNetworkAnalysisAlgorithmB
     QgsShortestPathLayerToPointAlgorithm *createInstance() const override SIP_FACTORY;
 
   protected:
-
-    QVariantMap processAlgorithm( const QVariantMap &parameters,
-                                  QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
-
+    QVariantMap processAlgorithm( const QVariantMap &parameters, QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
 };
 
 ///@endcond PRIVATE
