@@ -33,12 +33,9 @@ QString QgsVectorizeAlgorithmBase::groupId() const
 
 void QgsVectorizeAlgorithmBase::initAlgorithm( const QVariantMap & )
 {
-  addParameter( new QgsProcessingParameterRasterLayer( QStringLiteral( "INPUT_RASTER" ),
-                QObject::tr( "Raster layer" ) ) );
-  addParameter( new QgsProcessingParameterBand( QStringLiteral( "RASTER_BAND" ),
-                QObject::tr( "Band number" ), 1, QStringLiteral( "INPUT_RASTER" ) ) );
-  addParameter( new QgsProcessingParameterString( QStringLiteral( "FIELD_NAME" ),
-                QObject::tr( "Field name" ), QStringLiteral( "VALUE" ) ) );
+  addParameter( new QgsProcessingParameterRasterLayer( QStringLiteral( "INPUT_RASTER" ), QObject::tr( "Raster layer" ) ) );
+  addParameter( new QgsProcessingParameterBand( QStringLiteral( "RASTER_BAND" ), QObject::tr( "Band number" ), 1, QStringLiteral( "INPUT_RASTER" ) ) );
+  addParameter( new QgsProcessingParameterString( QStringLiteral( "FIELD_NAME" ), QObject::tr( "Field name" ), QStringLiteral( "VALUE" ) ) );
 
   addParameter( new QgsProcessingParameterFeatureSink( QStringLiteral( "OUTPUT" ), outputName(), outputType() ) );
 }
@@ -52,8 +49,7 @@ bool QgsVectorizeAlgorithmBase::prepareAlgorithm( const QVariantMap &parameters,
 
   mBand = parameterAsInt( parameters, QStringLiteral( "RASTER_BAND" ), context );
   if ( mBand < 1 || mBand > layer->bandCount() )
-    throw QgsProcessingException( QObject::tr( "Invalid band number for RASTER_BAND (%1): Valid values for input raster are 1 to %2" ).arg( mBand )
-                                  .arg( layer->bandCount() ) );
+    throw QgsProcessingException( QObject::tr( "Invalid band number for RASTER_BAND (%1): Valid values for input raster are 1 to %2" ).arg( mBand ).arg( layer->bandCount() ) );
 
   mInterface.reset( layer->dataProvider()->clone() );
   mExtent = layer->extent();
@@ -69,10 +65,10 @@ QVariantMap QgsVectorizeAlgorithmBase::processAlgorithm( const QVariantMap &para
 {
   const QString fieldName = parameterAsString( parameters, QStringLiteral( "FIELD_NAME" ), context );
   QgsFields fields;
-  fields.append( QgsField( fieldName, QVariant::Double, QString(), 20, 8 ) );
+  fields.append( QgsField( fieldName, QMetaType::Type::Double, QString(), 20, 8 ) );
 
   QString dest;
-  std::unique_ptr< QgsFeatureSink > sink( parameterAsSink( parameters, QStringLiteral( "OUTPUT" ), context, dest, fields, sinkType(), mCrs ) );
+  std::unique_ptr<QgsFeatureSink> sink( parameterAsSink( parameters, QStringLiteral( "OUTPUT" ), context, dest, fields, sinkType(), mCrs ) );
   if ( !sink )
     throw QgsProcessingException( invalidSinkError( parameters, QStringLiteral( "OUTPUT" ) ) );
 
@@ -83,15 +79,15 @@ QVariantMap QgsVectorizeAlgorithmBase::processAlgorithm( const QVariantMap &para
   QgsRasterIterator iter( mInterface.get() );
   iter.startRasterRead( mBand, mNbCellsXProvider, mNbCellsYProvider, mExtent );
 
-  const int nbBlocksWidth = static_cast< int >( std::ceil( 1.0 * mNbCellsXProvider / maxWidth ) );
-  const int nbBlocksHeight = static_cast< int >( std::ceil( 1.0 * mNbCellsYProvider / maxHeight ) );
+  const int nbBlocksWidth = static_cast<int>( std::ceil( 1.0 * mNbCellsXProvider / maxWidth ) );
+  const int nbBlocksHeight = static_cast<int>( std::ceil( 1.0 * mNbCellsYProvider / maxHeight ) );
   const int nbBlocks = nbBlocksWidth * nbBlocksHeight;
 
   int iterLeft = 0;
   int iterTop = 0;
   int iterCols = 0;
   int iterRows = 0;
-  std::unique_ptr< QgsRasterBlock > rasterBlock;
+  std::unique_ptr<QgsRasterBlock> rasterBlock;
   QgsRectangle blockExtent;
   bool isNoData = false;
   while ( iter.readNextRasterPart( mBand, iterCols, iterRows, rasterBlock, iterLeft, iterTop, &blockExtent ) )
@@ -157,7 +153,7 @@ QString QgsRasterPixelsToPolygonsAlgorithm::shortHelpString() const
 {
   return QObject::tr( "This algorithm converts a raster layer to a vector layer, by creating polygon features "
                       "for each individual pixel's extent in the raster layer.\n\n"
-                      "Any nodata pixels are skipped in the output." );
+                      "Any NoData pixels are skipped in the output." );
 }
 
 QString QgsRasterPixelsToPolygonsAlgorithm::shortDescription() const
@@ -175,9 +171,9 @@ QString QgsRasterPixelsToPolygonsAlgorithm::outputName() const
   return QObject::tr( "Vector polygons" );
 }
 
-QgsProcessing::SourceType QgsRasterPixelsToPolygonsAlgorithm::outputType() const
+Qgis::ProcessingSourceType QgsRasterPixelsToPolygonsAlgorithm::outputType() const
 {
-  return QgsProcessing::TypeVectorPolygon;
+  return Qgis::ProcessingSourceType::VectorPolygon;
 }
 
 Qgis::WkbType QgsRasterPixelsToPolygonsAlgorithm::sinkType() const
@@ -216,7 +212,7 @@ QString QgsRasterPixelsToPointsAlgorithm::shortHelpString() const
 {
   return QObject::tr( "This algorithm converts a raster layer to a vector layer, by creating point features "
                       "for each individual pixel's center in the raster layer.\n\n"
-                      "Any nodata pixels are skipped in the output." );
+                      "Any NoData pixels are skipped in the output." );
 }
 
 QString QgsRasterPixelsToPointsAlgorithm::shortDescription() const
@@ -234,9 +230,9 @@ QString QgsRasterPixelsToPointsAlgorithm::outputName() const
   return QObject::tr( "Vector points" );
 }
 
-QgsProcessing::SourceType QgsRasterPixelsToPointsAlgorithm::outputType() const
+Qgis::ProcessingSourceType QgsRasterPixelsToPointsAlgorithm::outputType() const
 {
-  return QgsProcessing::TypeVectorPoint;
+  return Qgis::ProcessingSourceType::VectorPoint;
 }
 
 Qgis::WkbType QgsRasterPixelsToPointsAlgorithm::sinkType() const
@@ -250,5 +246,3 @@ QgsGeometry QgsRasterPixelsToPointsAlgorithm::createGeometryForPixel( double cen
 }
 
 ///@endcond
-
-
