@@ -36,11 +36,11 @@ QgsRelief::QgsRelief( const QString &inputFile, const QString &outputFile, const
   : mInputFile( inputFile )
   , mOutputFile( outputFile )
   , mOutputFormat( outputFormat )
-  , mSlopeFilter( std::make_unique< QgsSlopeFilter >( inputFile, outputFile, outputFormat ) )
-  , mAspectFilter( std::make_unique< QgsAspectFilter > ( inputFile, outputFile, outputFormat ) )
-  , mHillshadeFilter285( std::make_unique< QgsHillshadeFilter >( inputFile, outputFile, outputFormat, 285, 30 ) )
-  , mHillshadeFilter300( std::make_unique< QgsHillshadeFilter >( inputFile, outputFile, outputFormat, 300, 30 ) )
-  , mHillshadeFilter315( std::make_unique< QgsHillshadeFilter >( inputFile, outputFile, outputFormat, 315, 30 ) )
+  , mSlopeFilter( std::make_unique<QgsSlopeFilter>( inputFile, outputFile, outputFormat ) )
+  , mAspectFilter( std::make_unique<QgsAspectFilter>( inputFile, outputFile, outputFormat ) )
+  , mHillshadeFilter285( std::make_unique<QgsHillshadeFilter>( inputFile, outputFile, outputFormat, 285, 30 ) )
+  , mHillshadeFilter300( std::make_unique<QgsHillshadeFilter>( inputFile, outputFile, outputFormat, 300, 30 ) )
+  , mHillshadeFilter315( std::make_unique<QgsHillshadeFilter>( inputFile, outputFile, outputFormat, 315, 30 ) )
 {
   /*mReliefColors = calculateOptimizedReliefClasses();
     setDefaultReliefColors();*/
@@ -162,7 +162,7 @@ int QgsRelief::processRaster( QgsFeedback *feedback )
   {
     if ( feedback )
     {
-      feedback->setProgress( 100.0 * i / static_cast< double >( ySize ) );
+      feedback->setProgress( 100.0 * i / static_cast<double>( ySize ) );
     }
 
     if ( feedback && feedback->isCanceled() )
@@ -177,7 +177,7 @@ int QgsRelief::processRaster( QgsFeedback *feedback )
       {
         scanLine1[a] = mInputNodataValue;
       }
-      if ( GDALRasterIO( rasterBand, GF_Read, 0, 0, xSize, 1, scanLine2, xSize, 1, GDT_Float32, 0, 0 )  != CE_None )
+      if ( GDALRasterIO( rasterBand, GF_Read, 0, 0, xSize, 1, scanLine2, xSize, 1, GDT_Float32, 0, 0 ) != CE_None )
       {
         QgsDebugError( QStringLiteral( "Raster IO Error" ) );
       }
@@ -210,21 +210,15 @@ int QgsRelief::processRaster( QgsFeedback *feedback )
     {
       if ( j == 0 )
       {
-        resultOk = processNineCellWindow( &mInputNodataValue, &scanLine1[j], &scanLine1[j + 1], &mInputNodataValue, &scanLine2[j], \
-                                          &scanLine2[j + 1], &mInputNodataValue, &scanLine3[j], &scanLine3[j + 1], \
-                                          &resultRedLine[j], &resultGreenLine[j], &resultBlueLine[j] );
+        resultOk = processNineCellWindow( &mInputNodataValue, &scanLine1[j], &scanLine1[j + 1], &mInputNodataValue, &scanLine2[j], &scanLine2[j + 1], &mInputNodataValue, &scanLine3[j], &scanLine3[j + 1], &resultRedLine[j], &resultGreenLine[j], &resultBlueLine[j] );
       }
       else if ( j == xSize - 1 )
       {
-        resultOk = processNineCellWindow( &scanLine1[j - 1], &scanLine1[j], &mInputNodataValue, &scanLine2[j - 1], &scanLine2[j], \
-                                          &mInputNodataValue, &scanLine3[j - 1], &scanLine3[j], &mInputNodataValue, \
-                                          &resultRedLine[j], &resultGreenLine[j], &resultBlueLine[j] );
+        resultOk = processNineCellWindow( &scanLine1[j - 1], &scanLine1[j], &mInputNodataValue, &scanLine2[j - 1], &scanLine2[j], &mInputNodataValue, &scanLine3[j - 1], &scanLine3[j], &mInputNodataValue, &resultRedLine[j], &resultGreenLine[j], &resultBlueLine[j] );
       }
       else
       {
-        resultOk = processNineCellWindow( &scanLine1[j - 1], &scanLine1[j], &scanLine1[j + 1], &scanLine2[j - 1], &scanLine2[j], \
-                                          &scanLine2[j + 1], &scanLine3[j - 1], &scanLine3[j], &scanLine3[j + 1], \
-                                          &resultRedLine[j], &resultGreenLine[j], &resultBlueLine[j] );
+        resultOk = processNineCellWindow( &scanLine1[j - 1], &scanLine1[j], &scanLine1[j + 1], &scanLine2[j - 1], &scanLine2[j], &scanLine2[j + 1], &scanLine3[j - 1], &scanLine3[j], &scanLine3[j + 1], &resultRedLine[j], &resultGreenLine[j], &resultBlueLine[j] );
       }
 
       if ( !resultOk )
@@ -271,8 +265,7 @@ int QgsRelief::processRaster( QgsFeedback *feedback )
   return 0;
 }
 
-bool QgsRelief::processNineCellWindow( float *x1, float *x2, float *x3, float *x4, float *x5, float *x6, float *x7, float *x8, float *x9,
-                                       unsigned char *red, unsigned char *green, unsigned char *blue )
+bool QgsRelief::processNineCellWindow( float *x1, float *x2, float *x3, float *x4, float *x5, float *x6, float *x7, float *x8, float *x9, unsigned char *red, unsigned char *green, unsigned char *blue )
 {
   //1. component: color and hillshade from 300 degrees
   int r = 0;
@@ -282,7 +275,7 @@ bool QgsRelief::processNineCellWindow( float *x1, float *x2, float *x3, float *x
   const float hillShadeValue300 = mHillshadeFilter300->processNineCellWindow( x1, x2, x3, x4, x5, x6, x7, x8, x9 );
   if ( hillShadeValue300 != mOutputNodataValue )
   {
-    if ( !setElevationColor( *x5, &r, &g, &b ) )
+    if ( !getElevationColor( *x5, &r, &g, &b ) )
     {
       r = hillShadeValue300;
       g = hillShadeValue300;
@@ -359,15 +352,15 @@ bool QgsRelief::processNineCellWindow( float *x1, float *x2, float *x3, float *x
     b = b3 * 0.1 + b * 0.9;
   }
 
-  *red = ( unsigned char )r;
-  *green = ( unsigned char )g;
-  *blue = ( unsigned char )b;
+  *red = ( unsigned char ) r;
+  *green = ( unsigned char ) g;
+  *blue = ( unsigned char ) b;
   return true;
 }
 
-bool QgsRelief::setElevationColor( double elevation, int *red, int *green, int *blue )
+bool QgsRelief::getElevationColor( double elevation, int *red, int *green, int *blue ) const
 {
-  QList< ReliefColor >::const_iterator reliefColorIt = mReliefColors.constBegin();
+  QList<ReliefColor>::const_iterator reliefColorIt = mReliefColors.constBegin();
   for ( ; reliefColorIt != mReliefColors.constEnd(); ++reliefColorIt )
   {
     if ( elevation >= reliefColorIt->minElevation && elevation <= reliefColorIt->maxElevation )
@@ -502,17 +495,15 @@ bool QgsRelief::exportFrequencyDistributionToCsv( const QString &file )
   //2. go through raster cells and get frequency of classes
 
   //store elevation frequency in 256 elevation classes
-  double frequency[252] = {0};
+  double frequency[252] = { 0 };
   const double frequencyClassRange = ( minMax[1] - minMax[0] ) / 252.0;
 
-  float *scanLine = ( float * ) CPLMalloc( sizeof( float ) *  nCellsX );
+  float *scanLine = ( float * ) CPLMalloc( sizeof( float ) * nCellsX );
   int elevationClass = -1;
 
   for ( int i = 0; i < nCellsY; ++i )
   {
-    if ( GDALRasterIO( elevationBand, GF_Read, 0, i, nCellsX, 1,
-                       scanLine, nCellsX, 1, GDT_Float32,
-                       0, 0 ) != CE_None )
+    if ( GDALRasterIO( elevationBand, GF_Read, 0, i, nCellsX, 1, scanLine, nCellsX, 1, GDT_Float32, 0, 0 ) != CE_None )
     {
       QgsDebugError( QStringLiteral( "Raster IO Error" ) );
     }
@@ -543,7 +534,7 @@ bool QgsRelief::exportFrequencyDistributionToCsv( const QString &file )
   }
 
   QTextStream outstream( &outFile );
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
   outstream.setCodec( "UTF-8" );
 #endif
   for ( int i = 0; i < 252; ++i )
@@ -554,9 +545,9 @@ bool QgsRelief::exportFrequencyDistributionToCsv( const QString &file )
   return true;
 }
 
-QList< QgsRelief::ReliefColor > QgsRelief::calculateOptimizedReliefClasses()
+QList<QgsRelief::ReliefColor> QgsRelief::calculateOptimizedReliefClasses()
 {
-  QList< QgsRelief::ReliefColor > resultList;
+  QList<QgsRelief::ReliefColor> resultList;
 
   int nCellsX, nCellsY;
   const gdal::dataset_unique_ptr inputDataset = openInputFile( nCellsX, nCellsY );
@@ -586,17 +577,15 @@ QList< QgsRelief::ReliefColor > QgsRelief::calculateOptimizedReliefClasses()
   //2. go through raster cells and get frequency of classes
 
   //store elevation frequency in 256 elevation classes
-  double frequency[252] = {0};
+  double frequency[252] = { 0 };
   const double frequencyClassRange = ( minMax[1] - minMax[0] ) / 252.0;
 
-  float *scanLine = ( float * ) CPLMalloc( sizeof( float ) *  nCellsX );
+  float *scanLine = ( float * ) CPLMalloc( sizeof( float ) * nCellsX );
   int elevationClass = -1;
 
   for ( int i = 0; i < nCellsY; ++i )
   {
-    if ( GDALRasterIO( elevationBand, GF_Read, 0, i, nCellsX, 1,
-                       scanLine, nCellsX, 1, GDT_Float32,
-                       0, 0 ) != CE_None )
+    if ( GDALRasterIO( elevationBand, GF_Read, 0, i, nCellsX, 1, scanLine, nCellsX, 1, GDT_Float32, 0, 0 ) != CE_None )
     {
       QgsDebugError( QStringLiteral( "Raster IO Error" ) );
     }
@@ -673,7 +662,7 @@ void QgsRelief::optimiseClassBreaks( QList<int> &breaks, double *frequencies )
   for ( int i = 0; i < nClasses; ++i )
   {
     //get all the values between the class breaks into input
-    QList< QPair < int, double > > regressionInput;
+    QList<QPair<int, double>> regressionInput;
     regressionInput.reserve( breaks.at( i + 1 ) - breaks.at( i ) );
     for ( int j = breaks.at( i ); j < breaks.at( i + 1 ); ++j )
     {
@@ -696,20 +685,20 @@ void QgsRelief::optimiseClassBreaks( QList<int> &breaks, double *frequencies )
   const QList<int> classesToRemove;
 
   //shift class boundaries or eliminate classes which fall together
-  for ( int i = 1; i < nClasses ; ++i )
+  for ( int i = 1; i < nClasses; ++i )
   {
-    if ( breaks[i] == breaks[ i - 1 ] )
+    if ( breaks[i] == breaks[i - 1] )
     {
       continue;
     }
 
-    if ( qgsDoubleNear( a[i - 1 ], a[i] ) )
+    if ( qgsDoubleNear( a[i - 1], a[i] ) )
     {
       continue;
     }
     else
     {
-      int newX = ( b[i - 1] - b[ i ] ) / ( a[ i ] - a[ i - 1 ] );
+      int newX = ( b[i - 1] - b[i] ) / ( a[i] - a[i - 1] );
 
       if ( newX <= breaks[i - 1] )
       {
@@ -728,7 +717,7 @@ void QgsRelief::optimiseClassBreaks( QList<int> &breaks, double *frequencies )
 
   for ( int i = classesToRemove.size() - 1; i >= 0; --i )
   {
-    breaks.removeAt( classesToRemove.at( i ) );
+    breaks.removeAt( classesToRemove.at( i ) ); // cppcheck-suppress containerOutOfBounds
   }
 
   delete[] a;
@@ -740,12 +729,12 @@ int QgsRelief::frequencyClassForElevation( double elevation, double minElevation
   return ( elevation - minElevation ) / elevationClassRange;
 }
 
-bool QgsRelief::calculateRegression( const QList< QPair < int, double > > &input, double &a, double &b )
+bool QgsRelief::calculateRegression( const QList<QPair<int, double>> &input, double &a, double &b )
 {
   double xMean, yMean;
   double xSum = 0;
   double ySum = 0;
-  QList< QPair < int, double > >::const_iterator inputIt = input.constBegin();
+  QList<QPair<int, double>>::const_iterator inputIt = input.constBegin();
   for ( ; inputIt != input.constEnd(); ++inputIt )
   {
     xSum += inputIt->first;
@@ -768,4 +757,3 @@ bool QgsRelief::calculateRegression( const QList< QPair < int, double > > &input
 
   return true;
 }
-
