@@ -31,20 +31,13 @@
 class ANALYSIS_EXPORT QgsGeometryGapCheckError : public QgsGeometryCheckError
 {
   public:
-
     /**
      * Create a new gap check error produced by \a check on the layer \a layerId.
      * The \a geometry of the gap needs to be in map coordinates.
      * The \a neighbors are a map of layer ids and feature ids.
      * The \a area of the gap in map units and the bounding box of the gap in map units too.
      */
-    QgsGeometryGapCheckError( const QgsGeometryCheck *check,
-                              const QString &layerId,
-                              const QgsGeometry &geometry,
-                              const QMap<QString, QgsFeatureIds> &neighbors,
-                              double area,
-                              const QgsRectangle &gapAreaBBox,
-                              const QgsRectangle &contextArea )
+    QgsGeometryGapCheckError( const QgsGeometryCheck *check, const QString &layerId, const QgsGeometry &geometry, const QMap<QString, QgsFeatureIds> &neighbors, double area, const QgsRectangle &gapAreaBBox, const QgsRectangle &contextArea )
       : QgsGeometryCheckError( check, layerId, FID_NULL, geometry, geometry.constGet()->centroid(), QgsVertexId(), area, ValueArea )
       , mNeighbors( neighbors )
       , mGapAreaBBox( gapAreaBBox )
@@ -69,7 +62,7 @@ class ANALYSIS_EXPORT QgsGeometryGapCheckError : public QgsGeometryCheckError
 
     QgsRectangle affectedAreaBBox() const override;
 
-    QMap<QString, QgsFeatureIds > involvedFeatures() const override;
+    QMap<QString, QgsFeatureIds> involvedFeatures() const override;
 
     QIcon icon() const override;
 
@@ -96,7 +89,7 @@ class ANALYSIS_EXPORT QgsGeometryGapCheck : public QgsGeometryCheck
     enum ResolutionMethod
     {
       MergeLongestEdge, //!< Merge the gap with the polygon with the longest shared edge.
-      NoChange, //!< Do not handle the error.
+      NoChange,         //!< Do not handle the error.
       AddToAllowedGaps, //!< Add gap geometry to allowed gaps layer
       CreateNewFeature, //!< Create a new feature with the gap geometry
       MergeLargestArea, //!< Merge with neighbouring polygon with largest area
@@ -125,14 +118,14 @@ class ANALYSIS_EXPORT QgsGeometryGapCheck : public QgsGeometryCheck
     QgsGeometryCheck::Flags flags() const override;
     QgsGeometryCheck::CheckType checkType() const override { return factoryCheckType(); }
 
-///@cond private
+    ///@cond private
     static QString factoryDescription() SIP_SKIP;
     static QString factoryId() SIP_SKIP;
     static QgsGeometryCheck::Flags factoryFlags() SIP_SKIP;
     static QList<Qgis::GeometryType> factoryCompatibleGeometryTypes() SIP_SKIP;
     static bool factoryIsCompatible( QgsVectorLayer *layer ) SIP_SKIP;
     static QgsGeometryCheck::CheckType factoryCheckType() SIP_SKIP;
-///@endcond private
+    ///@endcond private
 
   private:
     enum Condition
@@ -141,14 +134,12 @@ class ANALYSIS_EXPORT QgsGeometryGapCheck : public QgsGeometryCheck
       LargestArea
     };
 
-    bool mergeWithNeighbor( const QMap<QString, QgsFeaturePool *> &featurePools,
-                            QgsGeometryGapCheckError *err, Changes &changes, QString &errMsg, Condition condition ) const;
+    bool mergeWithNeighbor( const QMap<QString, QgsFeaturePool *> &featurePools, QgsGeometryGapCheckError *err, Changes &changes, QString &errMsg, Condition condition ) const;
 
     const double mGapThresholdMapUnits;
     QgsWeakMapLayerPointer mAllowedGapsLayer;
     std::unique_ptr<QgsVectorLayerFeatureSource> mAllowedGapsSource;
     double mAllowedGapsBuffer = 0;
-
 };
 
 #endif // QGS_GEOMETRY_GAP_CHECK_H
