@@ -17,17 +17,20 @@
 #include <QFileInfo>
 #include <QMessageBox>
 
-#include "qgsprojectionselectiontreewidget.h"
-#include "qgsapplication.h"
 #include "qgsfilewidget.h"
 #include "qgstransformsettingsdialog.h"
+#include "moc_qgstransformsettingsdialog.cpp"
 #include "qgscoordinatereferencesystem.h"
 #include "qgsgui.h"
 #include "qgshelp.h"
-#include "qgsproviderregistry.h"
 #include "qgsvectorfilewriter.h"
+#include "qgssettingsentryimpl.h"
 
-QgsTransformSettingsDialog::QgsTransformSettingsDialog( QgsMapLayerType type, const QString &source, const QString &output, QWidget *parent )
+const QgsSettingsEntryString *QgsTransformSettingsDialog::settingLastDestinationFolder = new QgsSettingsEntryString( QStringLiteral( "last-destination-folder" ), QgsGeoreferencerMainWindow::sTreeGeoreferencer, QString(), QObject::tr( "Last used folder for georeferencer destination files" ) );
+
+const QgsSettingsEntryString *QgsTransformSettingsDialog::settingLastPdfFolder = new QgsSettingsEntryString( QStringLiteral( "last-pdf-folder" ), QgsGeoreferencerMainWindow::sTreeGeoreferencer, QString(), QObject::tr( "Last used folder for georeferencer PDF report files" ) );
+
+QgsTransformSettingsDialog::QgsTransformSettingsDialog( Qgis::LayerType type, const QString &source, const QString &output, QWidget *parent )
   : QDialog( parent )
   , mType( type )
   , mSourceFile( source )
@@ -35,7 +38,7 @@ QgsTransformSettingsDialog::QgsTransformSettingsDialog( QgsMapLayerType type, co
   setupUi( this );
   QgsGui::enableAutoGeometryRestore( this );
 
-  QgsFileWidget *outputFile = mType == QgsMapLayerType::RasterLayer ? mRasterOutputFile : mVectorOutputFile;
+  QgsFileWidget *outputFile = mType == Qgis::LayerType::Raster ? mRasterOutputFile : mVectorOutputFile;
   outputFile->setStorageMode( QgsFileWidget::SaveFile );
   if ( output.isEmpty() )
   {
@@ -48,52 +51,50 @@ QgsTransformSettingsDialog::QgsTransformSettingsDialog( QgsMapLayerType type, co
 
   switch ( mType )
   {
-    case QgsMapLayerType::VectorLayer:
+    case Qgis::LayerType::Vector:
       mOutputSettingsStackedWidget->setCurrentWidget( mVectorOutputSettings );
       mOutputSettingsStackedWidget->removeWidget( mRasterOutputSettings );
       outputFile->setFilter( QgsVectorFileWriter::fileFilterString() );
       break;
-    case QgsMapLayerType::RasterLayer:
+    case Qgis::LayerType::Raster:
       mOutputSettingsStackedWidget->setCurrentWidget( mRasterOutputSettings );
       mOutputSettingsStackedWidget->removeWidget( mVectorOutputSettings );
       outputFile->setFilter( tr( "TIF files" ) + " (*.tif *.tiff *.TIF *.TIFF)" );
       break;
-    case QgsMapLayerType::PluginLayer:
-    case QgsMapLayerType::MeshLayer:
-    case QgsMapLayerType::VectorTileLayer:
-    case QgsMapLayerType::AnnotationLayer:
-    case QgsMapLayerType::PointCloudLayer:
-    case QgsMapLayerType::GroupLayer:
+    case Qgis::LayerType::Plugin:
+    case Qgis::LayerType::Mesh:
+    case Qgis::LayerType::VectorTile:
+    case Qgis::LayerType::Annotation:
+    case Qgis::LayerType::PointCloud:
+    case Qgis::LayerType::Group:
+    case Qgis::LayerType::TiledScene:
       break;
   }
   mOutputSettingsStackedWidget->adjustSize();
   mOutputSettingsGroupBox->adjustSize();
 
   outputFile->setDialogTitle( tr( "Destination File" ) );
-  const QString lastDestinationFolder = settingLastDestinationFolder.value();
+  const QString lastDestinationFolder = settingLastDestinationFolder->value();
   outputFile->setDefaultRoot( lastDestinationFolder.isEmpty() ? QDir::homePath() : lastDestinationFolder );
-  connect( outputFile, &QgsFileWidget::fileChanged, this, [ = ]
-  {
-    settingLastDestinationFolder.setValue( QFileInfo( outputFile->filePath() ).absolutePath() );
+  connect( outputFile, &QgsFileWidget::fileChanged, this, [=] {
+    settingLastDestinationFolder->setValue( QFileInfo( outputFile->filePath() ).absolutePath() );
   } );
 
   mPdfMap->setStorageMode( QgsFileWidget::SaveFile );
   mPdfMap->setFilter( tr( "PDF files" ) + " (*.pdf *.PDF)" );
   mPdfMap->setDialogTitle( tr( "Save Map File As" ) );
-  const QString lastPdfFolder = settingLastPdfFolder.value();
+  const QString lastPdfFolder = settingLastPdfFolder->value();
   mPdfMap->setDefaultRoot( lastPdfFolder.isEmpty() ? QDir::homePath() : lastPdfFolder );
-  connect( mPdfMap, &QgsFileWidget::fileChanged, this, [ = ]
-  {
-    settingLastPdfFolder.setValue( QFileInfo( mPdfMap->filePath() ).absolutePath() );
+  connect( mPdfMap, &QgsFileWidget::fileChanged, this, [=] {
+    settingLastPdfFolder->setValue( QFileInfo( mPdfMap->filePath() ).absolutePath() );
   } );
 
   mPdfReport->setStorageMode( QgsFileWidget::SaveFile );
   mPdfReport->setFilter( tr( "PDF files" ) + " (*.pdf *.PDF)" );
   mPdfReport->setDialogTitle( tr( "Save Report File As" ) );
   mPdfReport->setDefaultRoot( lastPdfFolder.isEmpty() ? QDir::homePath() : lastPdfFolder );
-  connect( mPdfReport, &QgsFileWidget::fileChanged, this, [ = ]
-  {
-    settingLastPdfFolder.setValue( QFileInfo( mPdfMap->filePath() ).absolutePath() );
+  connect( mPdfReport, &QgsFileWidget::fileChanged, this, [=] {
+    settingLastPdfFolder->setValue( QFileInfo( mPdfMap->filePath() ).absolutePath() );
   } );
 
   connect( cmbTransformType, &QComboBox::currentTextChanged, this, &QgsTransformSettingsDialog::cmbTransformType_currentIndexChanged );
@@ -113,11 +114,11 @@ QgsTransformSettingsDialog::QgsTransformSettingsDialog( QgsMapLayerType type, co
   cmbCompressionComboBox->addItem( tr( "PACKBITS" ), QStringLiteral( "PACKBITS" ) );
   cmbCompressionComboBox->addItem( tr( "DEFLATE" ), QStringLiteral( "DEFLATE" ) );
 
-  cmbResampling->addItem( tr( "Nearest Neighbour" ), static_cast< int >( QgsImageWarper::ResamplingMethod::NearestNeighbour ) );
-  cmbResampling->addItem( tr( "Linear" ), static_cast< int >( QgsImageWarper::ResamplingMethod::Bilinear ) );
-  cmbResampling->addItem( tr( "Cubic" ), static_cast< int >( QgsImageWarper::ResamplingMethod::Cubic ) );
-  cmbResampling->addItem( tr( "Cubic Spline" ), static_cast< int >( QgsImageWarper::ResamplingMethod::CubicSpline ) );
-  cmbResampling->addItem( tr( "Lanczos" ), static_cast< int >( QgsImageWarper::ResamplingMethod::Lanczos ) );
+  cmbResampling->addItem( tr( "Nearest Neighbour" ), static_cast<int>( QgsImageWarper::ResamplingMethod::NearestNeighbour ) );
+  cmbResampling->addItem( tr( "Bilinear (2x2 Kernel)" ), static_cast<int>( QgsImageWarper::ResamplingMethod::Bilinear ) );
+  cmbResampling->addItem( tr( "Cubic (4x4 Kernel)" ), static_cast<int>( QgsImageWarper::ResamplingMethod::Cubic ) );
+  cmbResampling->addItem( tr( "Cubic B-Spline (4x4 Kernel)" ), static_cast<int>( QgsImageWarper::ResamplingMethod::CubicSpline ) );
+  cmbResampling->addItem( tr( "Lanczos (6x6 Kernel)" ), static_cast<int>( QgsImageWarper::ResamplingMethod::Lanczos ) );
 
   connect( buttonBox, &QDialogButtonBox::helpRequested, this, &QgsTransformSettingsDialog::showHelp );
 }
@@ -148,7 +149,7 @@ QgsGcpTransformerInterface::TransformMethod QgsTransformSettingsDialog::transfor
   if ( cmbTransformType->currentIndex() == -1 )
     return QgsGcpTransformerInterface::TransformMethod::InvalidTransform;
   else
-    return static_cast< QgsGcpTransformerInterface::TransformMethod >( cmbTransformType->currentData().toInt() );
+    return static_cast<QgsGcpTransformerInterface::TransformMethod>( cmbTransformType->currentData().toInt() );
 }
 
 void QgsTransformSettingsDialog::setTransformMethod( QgsGcpTransformerInterface::TransformMethod method )
@@ -156,17 +157,17 @@ void QgsTransformSettingsDialog::setTransformMethod( QgsGcpTransformerInterface:
   if ( method == QgsGcpTransformerInterface::TransformMethod::InvalidTransform )
     cmbTransformType->setCurrentIndex( 0 );
   else
-    cmbTransformType->setCurrentIndex( cmbTransformType->findData( static_cast< int >( method ) ) );
+    cmbTransformType->setCurrentIndex( cmbTransformType->findData( static_cast<int>( method ) ) );
 }
 
 QgsImageWarper::ResamplingMethod QgsTransformSettingsDialog::resamplingMethod() const
 {
-  return static_cast< QgsImageWarper::ResamplingMethod >( cmbResampling->currentData().toInt() );
+  return static_cast<QgsImageWarper::ResamplingMethod>( cmbResampling->currentData().toInt() );
 }
 
 void QgsTransformSettingsDialog::setResamplingMethod( QgsImageWarper::ResamplingMethod method )
 {
-  cmbResampling->setCurrentIndex( cmbResampling->findData( static_cast< int >( method ) ) );
+  cmbResampling->setCurrentIndex( cmbResampling->findData( static_cast<int>( method ) ) );
 }
 
 QString QgsTransformSettingsDialog::compressionMethod() const
@@ -181,7 +182,7 @@ void QgsTransformSettingsDialog::setCompressionMethod( const QString &method )
 
 QString QgsTransformSettingsDialog::destinationFilename() const
 {
-  QgsFileWidget *outputFile = mType == QgsMapLayerType::RasterLayer ? mRasterOutputFile : mVectorOutputFile;
+  QgsFileWidget *outputFile = mType == Qgis::LayerType::Raster ? mRasterOutputFile : mVectorOutputFile;
   return outputFile->filePath();
 }
 
@@ -236,7 +237,8 @@ void QgsTransformSettingsDialog::setLoadInProject( bool enabled )
 }
 
 void QgsTransformSettingsDialog::outputResolution(
-  double &resX, double &resY )
+  double &resX, double &resY
+)
 {
   resX = 0.0;
   resY = 0.0;
@@ -256,7 +258,7 @@ void QgsTransformSettingsDialog::setOutputResolution( double resX, double resY )
 
 void QgsTransformSettingsDialog::accept()
 {
-  QgsFileWidget *outputFile = mType == QgsMapLayerType::RasterLayer ? mRasterOutputFile : mVectorOutputFile;
+  QgsFileWidget *outputFile = mType == Qgis::LayerType::Raster ? mRasterOutputFile : mVectorOutputFile;
   if ( !outputFile->filePath().isEmpty() )
   {
     //if the file path is relative, make it relative to the input file directory
@@ -284,8 +286,7 @@ void QgsTransformSettingsDialog::accept()
 void QgsTransformSettingsDialog::cmbTransformType_currentIndexChanged( const QString & )
 {
   if ( cmbTransformType->currentIndex() != -1
-       && ( static_cast< QgsGcpTransformerInterface::TransformMethod >( cmbTransformType->currentData().toInt() ) == QgsGcpTransformerInterface::TransformMethod::Linear
-            || static_cast< QgsGcpTransformerInterface::TransformMethod >( cmbTransformType->currentData().toInt() ) == QgsGcpTransformerInterface::TransformMethod::Helmert ) )
+       && ( static_cast<QgsGcpTransformerInterface::TransformMethod>( cmbTransformType->currentData().toInt() ) == QgsGcpTransformerInterface::TransformMethod::Linear || static_cast<QgsGcpTransformerInterface::TransformMethod>( cmbTransformType->currentData().toInt() ) == QgsGcpTransformerInterface::TransformMethod::Helmert ) )
   {
     mWorldFileCheckBox->setEnabled( true );
   }
@@ -306,7 +307,7 @@ void QgsTransformSettingsDialog::mWorldFileCheckBox_stateChanged( int state )
   }
   label_2->setEnabled( enableOutputRaster );
 
-  QgsFileWidget *outputFile = mType == QgsMapLayerType::RasterLayer ? mRasterOutputFile : mVectorOutputFile;
+  QgsFileWidget *outputFile = mType == Qgis::LayerType::Raster ? mRasterOutputFile : mVectorOutputFile;
   outputFile->setEnabled( enableOutputRaster );
 }
 
@@ -324,18 +325,19 @@ QString QgsTransformSettingsDialog::generateModifiedFileName( const QString &fil
 
   switch ( mType )
   {
-    case QgsMapLayerType::VectorLayer:
+    case Qgis::LayerType::Vector:
       modifiedFileName.replace( pos, modifiedFileName.size(), QStringLiteral( "gpkg" ) );
       break;
-    case QgsMapLayerType::RasterLayer:
+    case Qgis::LayerType::Raster:
       modifiedFileName.replace( pos, modifiedFileName.size(), QStringLiteral( "tif" ) );
       break;
-    case QgsMapLayerType::PluginLayer:
-    case QgsMapLayerType::MeshLayer:
-    case QgsMapLayerType::VectorTileLayer:
-    case QgsMapLayerType::AnnotationLayer:
-    case QgsMapLayerType::PointCloudLayer:
-    case QgsMapLayerType::GroupLayer:
+    case Qgis::LayerType::Plugin:
+    case Qgis::LayerType::Mesh:
+    case Qgis::LayerType::VectorTile:
+    case Qgis::LayerType::Annotation:
+    case Qgis::LayerType::PointCloud:
+    case Qgis::LayerType::Group:
+    case Qgis::LayerType::TiledScene:
       break;
   }
 
