@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgsalllayersfeatureslocatorfilter.h"
+#include "moc_qgsalllayersfeatureslocatorfilter.cpp"
 #include "qgssettings.h"
 #include "qgsproject.h"
 #include "qgsvectorlayer.h"
@@ -53,7 +54,7 @@ QStringList QgsAllLayersFeaturesLocatorFilter::prepare( const QString &string, c
   const QMap<QString, QgsMapLayer *> layers = QgsProject::instance()->mapLayers();
   for ( auto it = layers.constBegin(); it != layers.constEnd(); ++it )
   {
-    QgsVectorLayer *layer = qobject_cast< QgsVectorLayer *>( it.value() );
+    QgsVectorLayer *layer = qobject_cast<QgsVectorLayer *>( it.value() );
     if ( !layer || !layer->dataProvider() || !layer->flags().testFlag( QgsMapLayer::Searchable ) )
       continue;
 
@@ -65,16 +66,16 @@ QStringList QgsAllLayersFeaturesLocatorFilter::prepare( const QString &string, c
     QgsFeatureRequest req;
     req.setSubsetOfAttributes( qgis::setToList( expression.referencedAttributeIndexes( layer->fields() ) ) );
     if ( !expression.needsGeometry() )
-      req.setFlags( QgsFeatureRequest::NoGeometry );
+      req.setFlags( Qgis::FeatureRequestFlag::NoGeometry );
     QString enhancedSearch = string;
     enhancedSearch.replace( ' ', '%' );
     req.setFilterExpression( QStringLiteral( "%1 ILIKE '%%2%'" )
-                             .arg( layer->displayExpression(), enhancedSearch ) );
+                               .arg( layer->displayExpression(), enhancedSearch ) );
     req.setLimit( mMaxResultsPerLayer );
 
     QgsFeatureRequest exactMatchRequest = req;
     exactMatchRequest.setFilterExpression( QStringLiteral( "%1 ILIKE '%2'" )
-                                           .arg( layer->displayExpression(), enhancedSearch ) );
+                                             .arg( layer->displayExpression(), enhancedSearch ) );
     exactMatchRequest.setLimit( mMaxResultsPerLayer );
 
     std::shared_ptr<PreparedLayer> preparedLayer( new PreparedLayer() );
@@ -123,7 +124,7 @@ void QgsAllLayersFeaturesLocatorFilter::fetchResults( const QString &string, con
       result.setUserData( ResultData( f.id(), preparedLayer->layerId, preparedLayer->layerIsSpatial ).toVariant() );
       foundFeatureIds << f.id();
       result.icon = preparedLayer->layerIcon;
-      result.score = static_cast< double >( string.length() ) / result.displayString.size();
+      result.score = static_cast<double>( string.length() ) / result.displayString.size();
 
       result.actions << QgsLocatorResult::ResultAction( OpenForm, tr( "Open form…" ) );
       emit resultFetched( result );
@@ -156,7 +157,7 @@ void QgsAllLayersFeaturesLocatorFilter::fetchResults( const QString &string, con
 
       result.setUserData( ResultData( f.id(), preparedLayer->layerId, preparedLayer->layerIsSpatial ).toVariant() );
       result.icon = preparedLayer->layerIcon;
-      result.score = static_cast< double >( string.length() ) / result.displayString.size();
+      result.score = static_cast<double>( string.length() ) / result.displayString.size();
 
       if ( preparedLayer->layerIsSpatial )
         result.actions << QgsLocatorResult::ResultAction( OpenForm, tr( "Open form…" ) );
@@ -179,7 +180,7 @@ void QgsAllLayersFeaturesLocatorFilter::triggerResult( const QgsLocatorResult &r
 
 void QgsAllLayersFeaturesLocatorFilter::triggerResultFromAction( const QgsLocatorResult &result, const int actionId )
 {
-  ResultData data = ResultData::fromVariant( result.getUserData() );
+  ResultData data = ResultData::fromVariant( result.userData() );
   QgsFeatureId fid = data.id();
   QString layerId = data.layerId();
   bool layerIsSpatial = data.layerIsSpatial();
@@ -233,8 +234,7 @@ void QgsAllLayersFeaturesLocatorFilter::openConfigWidget( QWidget *parent )
   QDialogButtonBox *buttonbBox = new QDialogButtonBox( QDialogButtonBox::Ok | QDialogButtonBox::Cancel, dlg.get() );
   formLayout->addRow( buttonbBox );
   dlg->setLayout( formLayout );
-  connect( buttonbBox, &QDialogButtonBox::accepted, dlg.get(), [&]()
-  {
+  connect( buttonbBox, &QDialogButtonBox::accepted, dlg.get(), [&]() {
     settings.setValue( QStringLiteral( "%1/limit_global" ).arg( key ), globalLimitSpinBox->value(), QgsSettings::App );
     settings.setValue( QStringLiteral( "%1/limit_per_layer" ).arg( key ), perLayerLimitSpinBox->value(), QgsSettings::App );
     dlg->accept();
