@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgssettingslocatorfilter.h"
+#include "moc_qgssettingslocatorfilter.cpp"
 #include "qgisapp.h"
 
 
@@ -32,7 +33,7 @@ void QgsSettingsLocatorFilter::fetchResults( const QString &string, const QgsLoc
 {
   QMap<QString, QMap<QString, QString>> matchingSettingsPagesMap;
 
-  const QMap<QString, QString > optionsPagesMap = QgisApp::instance()->optionsPagesMap();
+  const QMap<QString, QString> optionsPagesMap = QgisApp::instance()->optionsPagesMap();
   for ( auto optionsPagesIterator = optionsPagesMap.constBegin(); optionsPagesIterator != optionsPagesMap.constEnd(); ++optionsPagesIterator )
   {
     const QString title = optionsPagesIterator.key();
@@ -60,7 +61,7 @@ void QgsSettingsLocatorFilter::fetchResults( const QString &string, const QgsLoc
     QgsLocatorResult result;
     result.filter = this;
     result.displayString = title;
-    result.getUserData().setValue( settingsPage );
+    result.userData().setValue( settingsPage );
 
     if ( context.usingPrefix && string.isEmpty() )
     {
@@ -75,7 +76,7 @@ void QgsSettingsLocatorFilter::fetchResults( const QString &string, const QgsLoc
   }
 }
 
-QMap<QString, QString> QgsSettingsLocatorFilter::settingsPage( const QString &type,  const QString &page )
+QMap<QString, QString> QgsSettingsLocatorFilter::settingsPage( const QString &type, const QString &page )
 {
   QMap<QString, QString> returnPage;
   returnPage.insert( QStringLiteral( "type" ), type );
@@ -85,8 +86,7 @@ QMap<QString, QString> QgsSettingsLocatorFilter::settingsPage( const QString &ty
 
 void QgsSettingsLocatorFilter::triggerResult( const QgsLocatorResult &result )
 {
-
-  const QMap<QString, QString> settingsPage = qvariant_cast<QMap<QString, QString>>( result.getUserData() );
+  const QMap<QString, QString> settingsPage = qvariant_cast<QMap<QString, QString>>( result.userData() );
   const QString type = settingsPage.value( QStringLiteral( "type" ) );
   const QString page = settingsPage.value( QStringLiteral( "page" ) );
 
