@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgspointcloudlayerproperties.h"
+#include "moc_qgspointcloudlayerproperties.cpp"
 #include "qgshelp.h"
 #include "qgsmaplayerstyleguiutils.h"
 #include "qgspointcloudlayer.h"
@@ -21,6 +22,7 @@
 #include "qgsapplication.h"
 #include "qgsmetadatawidget.h"
 #include "qgsmaplayerconfigwidget.h"
+#include "qgsmaplayerstylemanager.h"
 #include "qgspointcloudattributemodel.h"
 #include "qgsdatumtransformdialog.h"
 #include "qgspointcloudquerybuilder.h"
@@ -70,12 +72,12 @@ QgsPointCloudLayerProperties::QgsPointCloudLayerProperties( QgsPointCloudLayer *
 
   // update based on lyr's current state
   syncToLayer();
+  connect( lyr->styleManager(), &QgsMapLayerStyleManager::currentStyleChanged, this, &QgsPointCloudLayerProperties::syncToLayer );
 
   QgsSettings settings;
   if ( !settings.contains( QStringLiteral( "/Windows/PointCloudLayerProperties/tab" ) ) )
   {
-    settings.setValue( QStringLiteral( "Windows/PointCloudLayerProperties/tab" ),
-                       mOptStackedWidget->indexOf( mOptsPage_Information ) );
+    settings.setValue( QStringLiteral( "Windows/PointCloudLayerProperties/tab" ), mOptStackedWidget->indexOf( mOptsPage_Information ) );
   }
 
   mBtnStyle = new QPushButton( tr( "Style" ) );
@@ -127,8 +129,7 @@ QgsPointCloudLayerProperties::QgsPointCloudLayerProperties( QgsPointCloudLayer *
 
   mStatisticsCalculationWarningLabel->setHidden( mLayer->statisticsCalculationState() != QgsPointCloudLayer::PointCloudStatisticsCalculationState::Calculated );
 
-  connect( mLayer, &QgsPointCloudLayer::statisticsCalculationStateChanged, this, [this]( QgsPointCloudLayer::PointCloudStatisticsCalculationState state )
-  {
+  connect( mLayer, &QgsPointCloudLayer::statisticsCalculationStateChanged, this, [this]( QgsPointCloudLayer::PointCloudStatisticsCalculationState state ) {
     mStatisticsCalculationWarningLabel->setHidden( state != QgsPointCloudLayer::PointCloudStatisticsCalculationState::Calculated );
   } );
 
@@ -184,8 +185,7 @@ void QgsPointCloudLayerProperties::syncToLayer()
   txtSubsetSQL->setReadOnly( true );
   txtSubsetSQL->setCaretWidth( 0 );
   txtSubsetSQL->setCaretLineVisible( false );
-  pbnQueryBuilder->setEnabled( mLayer->dataProvider() &&
-                               mLayer->dataProvider()->supportsSubsetString() );
+  pbnQueryBuilder->setEnabled( mLayer->dataProvider() && mLayer->dataProvider()->supportsSubsetString() );
 
   for ( QgsMapLayerConfigWidget *w : std::as_const( mConfigWidgets ) )
     w->syncToLayer( mLayer );
@@ -242,7 +242,6 @@ QgsPointCloudAttributeStatisticsModel::QgsPointCloudAttributeStatisticsModel( Qg
   , mLayer( layer )
   , mAttributes( layer->attributes() )
 {
-
 }
 
 int QgsPointCloudAttributeStatisticsModel::columnCount( const QModelIndex & ) const
@@ -281,7 +280,6 @@ QVariant QgsPointCloudAttributeStatisticsModel::data( const QModelIndex &index,
           return stats.mean( attr.name() );
         case StDev:
           return stats.stDev( attr.name() );
-
       }
       return QVariant();
     }
@@ -298,7 +296,6 @@ QVariant QgsPointCloudAttributeStatisticsModel::data( const QModelIndex &index,
         case Mean:
         case StDev:
           return static_cast<Qt::Alignment::Int>( Qt::AlignRight | Qt::AlignVCenter );
-
       }
       return QVariant();
     }
@@ -397,9 +394,8 @@ QVariant QgsPointCloudClassificationStatisticsModel::data( const QModelIndex &in
         case Percent:
         {
           qint64 pointCount = stats.sampledPointsCount();
-          return ( ( double )stats.availableClasses( mAttribute ).value( classValue.toInt(), 0 ) ) / pointCount * 100;
+          return ( ( double ) stats.availableClasses( mAttribute ).value( classValue.toInt(), 0 ) ) / pointCount * 100;
         }
-
       }
       return QVariant();
     }
@@ -415,7 +411,6 @@ QVariant QgsPointCloudClassificationStatisticsModel::data( const QModelIndex &in
         case Count:
         case Percent:
           return QVariant( Qt::AlignRight | Qt::AlignVCenter );
-
       }
       return QVariant();
     }
@@ -455,4 +450,3 @@ QVariant QgsPointCloudClassificationStatisticsModel::headerData( int section, Qt
   }
   return QVariant();
 }
-
