@@ -26,6 +26,7 @@
 #include <QUiLoader>
 
 #include "qgisappinterface.h"
+#include "moc_qgisappinterface.cpp"
 #include "qgisappstylesheet.h"
 #include "qgisapp.h"
 #include "qgsapplayertreeviewmenuprovider.h"
@@ -52,23 +53,17 @@ QgisAppInterface::QgisAppInterface( QgisApp *_qgis )
   , pluginManagerIface( _qgis->pluginManager() )
 {
   // connect signals
-  connect( qgis, &QgisApp::activeLayerChanged,
-           this, &QgisInterface::currentLayerChanged );
-  connect( qgis, &QgisApp::currentThemeChanged,
-           this, &QgisAppInterface::currentThemeChanged );
+  connect( qgis, &QgisApp::activeLayerChanged, this, &QgisInterface::currentLayerChanged );
+  connect( qgis, &QgisApp::currentThemeChanged, this, &QgisAppInterface::currentThemeChanged );
 
   connect( qgis, &QgisApp::layoutDesignerOpened, this, &QgisAppInterface::layoutDesignerOpened );
   connect( qgis, &QgisApp::layoutDesignerWillBeClosed, this, &QgisAppInterface::layoutDesignerWillBeClosed );
   connect( qgis, &QgisApp::layoutDesignerClosed, this, &QgisAppInterface::layoutDesignerClosed );
 
-  connect( qgis, &QgisApp::initializationCompleted,
-           this, &QgisInterface::initializationCompleted );
-  connect( qgis, &QgisApp::newProject,
-           this, &QgisInterface::newProjectCreated );
-  connect( qgis, &QgisApp::projectRead,
-           this, &QgisInterface::projectRead );
-  connect( qgis, &QgisApp::layerSavedAs,
-           this, &QgisInterface::layerSavedAs );
+  connect( qgis, &QgisApp::initializationCompleted, this, &QgisInterface::initializationCompleted );
+  connect( qgis, &QgisApp::newProject, this, &QgisInterface::newProjectCreated );
+  connect( qgis, &QgisApp::projectRead, this, &QgisInterface::projectRead );
+  connect( qgis, &QgisApp::layerSavedAs, this, &QgisInterface::layerSavedAs );
 }
 
 QgsPluginManagerInterface *QgisAppInterface::pluginManagerInterface()
@@ -81,8 +76,7 @@ QgsLayerTreeView *QgisAppInterface::layerTreeView()
   return qgis->layerTreeView();
 }
 
-void QgisAppInterface::addCustomActionForLayerType( QAction *action,
-    QString menu, Qgis::LayerType type, bool allLayers )
+void QgisAppInterface::addCustomActionForLayerType( QAction *action, QString menu, Qgis::LayerType type, bool allLayers )
 {
   QgsAppLayerTreeViewMenuProvider *menuProvider = dynamic_cast<QgsAppLayerTreeViewMenuProvider *>( qgis->layerTreeView()->menuProvider() );
   if ( !menuProvider )
@@ -188,7 +182,7 @@ bool QgisAppInterface::newProject( bool promptToSaveFlag )
 
 void QgisAppInterface::reloadConnections()
 {
-  qgis->reloadConnections( );
+  qgis->reloadConnections();
 }
 
 QgsMapLayer *QgisAppInterface::activeLayer()
@@ -391,6 +385,21 @@ void QgisAppInterface::closeMapCanvas( const QString &name )
   qgis->closeMapCanvas( name );
 }
 
+QList<Qgs3DMapCanvas *> QgisAppInterface::mapCanvases3D()
+{
+  return qgis->mapCanvases3D();
+}
+
+Qgs3DMapCanvas *QgisAppInterface::createNewMapCanvas3D( const QString &name )
+{
+  return qgis->createNewMapCanvas3D( name );
+}
+
+void QgisAppInterface::closeMapCanvas3D( const QString &name )
+{
+  qgis->close3DMapView( name );
+}
+
 QSize QgisAppInterface::iconSize( bool dockedToolbar ) const
 {
   return qgis->iconSize( dockedToolbar );
@@ -484,15 +493,12 @@ QMap<QString, QVariant> QgisAppInterface::defaultStyleSheetOptions()
 void QgisAppInterface::buildStyleSheet( const QMap<QString, QVariant> &opts )
 {
   // remove unwanted fontPointSize / fontFamily keys, which may be present from older code
-  QMap< QString, QVariant> newOpts = opts;
-  if ( newOpts.contains( QStringLiteral( "fontPointSize" ) ) && (
-         newOpts.value( QStringLiteral( "fontPointSize" ) ).toDouble() == qgis->styleSheetBuilder()->defaultFont().pointSizeF()
-         || newOpts.value( QStringLiteral( "fontPointSize" ) ).toString() == QString::number( qgis->styleSheetBuilder()->defaultFont().pointSizeF() ) ) )
+  QMap<QString, QVariant> newOpts = opts;
+  if ( newOpts.contains( QStringLiteral( "fontPointSize" ) ) && ( newOpts.value( QStringLiteral( "fontPointSize" ) ).toDouble() == qgis->styleSheetBuilder()->defaultFont().pointSizeF() || newOpts.value( QStringLiteral( "fontPointSize" ) ).toString() == QString::number( qgis->styleSheetBuilder()->defaultFont().pointSizeF() ) ) )
   {
     newOpts.remove( QStringLiteral( "fontPointSize" ) );
   }
-  if ( newOpts.contains( QStringLiteral( "fontFamily" ) ) &&
-       newOpts.value( QStringLiteral( "fontFamily" ) ).toString() == qgis->styleSheetBuilder()->defaultFont().family() )
+  if ( newOpts.contains( QStringLiteral( "fontFamily" ) ) && newOpts.value( QStringLiteral( "fontFamily" ) ).toString() == qgis->styleSheetBuilder()->defaultFont().family() )
   {
     newOpts.remove( QStringLiteral( "fontFamily" ) );
   }
@@ -503,15 +509,12 @@ void QgisAppInterface::buildStyleSheet( const QMap<QString, QVariant> &opts )
 void QgisAppInterface::saveStyleSheetOptions( const QMap<QString, QVariant> &opts )
 {
   // remove unwanted fontPointSize / fontFamily keys, which may be present from older code
-  QMap< QString, QVariant> newOpts = opts;
-  if ( newOpts.contains( QStringLiteral( "fontPointSize" ) ) && (
-         newOpts.value( QStringLiteral( "fontPointSize" ) ).toDouble() == qgis->styleSheetBuilder()->defaultFont().pointSizeF()
-         || newOpts.value( QStringLiteral( "fontPointSize" ) ).toString() == QString::number( qgis->styleSheetBuilder()->defaultFont().pointSizeF() ) ) )
+  QMap<QString, QVariant> newOpts = opts;
+  if ( newOpts.contains( QStringLiteral( "fontPointSize" ) ) && ( newOpts.value( QStringLiteral( "fontPointSize" ) ).toDouble() == qgis->styleSheetBuilder()->defaultFont().pointSizeF() || newOpts.value( QStringLiteral( "fontPointSize" ) ).toString() == QString::number( qgis->styleSheetBuilder()->defaultFont().pointSizeF() ) ) )
   {
     newOpts.remove( QStringLiteral( "fontPointSize" ) );
   }
-  if ( newOpts.contains( QStringLiteral( "fontFamily" ) ) &&
-       newOpts.value( QStringLiteral( "fontFamily" ) ).toString() == qgis->styleSheetBuilder()->defaultFont().family() )
+  if ( newOpts.contains( QStringLiteral( "fontFamily" ) ) && newOpts.value( QStringLiteral( "fontFamily" ) ).toString() == qgis->styleSheetBuilder()->defaultFont().family() )
   {
     newOpts.remove( QStringLiteral( "fontFamily" ) );
   }
@@ -701,7 +704,7 @@ void QgisAppInterface::addProjectExportAction( QAction *action )
   if ( QMenu *menu = projectImportExportMenu() )
   {
     // export actions come before import actions in the menu, so find separator in menu
-    const QList< QAction * > actions = menu->actions();
+    const QList<QAction *> actions = menu->actions();
     for ( QAction *menuAction : actions )
     {
       if ( menuAction->isSeparator() )
@@ -736,6 +739,7 @@ QMenu *QgisAppInterface::rasterMenu() { return qgis->rasterMenu(); }
 QMenu *QgisAppInterface::vectorMenu() { return qgis->vectorMenu(); }
 QMenu *QgisAppInterface::databaseMenu() { return qgis->databaseMenu(); }
 QMenu *QgisAppInterface::webMenu() { return qgis->webMenu(); }
+QMenu *QgisAppInterface::meshMenu() { return qgis->meshMenu(); }
 QMenu *QgisAppInterface::firstRightStandardMenu() { return qgis->firstRightStandardMenu(); }
 QMenu *QgisAppInterface::windowMenu() { return qgis->windowMenu(); }
 QMenu *QgisAppInterface::helpMenu() { return qgis->helpMenu(); }
@@ -884,8 +888,7 @@ bool QgisAppInterface::openFeatureForm( QgsVectorLayer *vlayer, QgsFeature &f, b
 
 void QgisAppInterface::preloadForm( const QString &uifile )
 {
-  QTimer::singleShot( 0, this, [ = ]
-  {
+  QTimer::singleShot( 0, this, [=] {
     cacheloadForm( uifile );
   } );
 }
@@ -999,3 +1002,7 @@ QgsUserProfileManager *QgisAppInterface::userProfileManager()
   return qgis->userProfileManager();
 }
 
+void QgisAppInterface::blockActiveLayerChanges( bool blocked )
+{
+  qgis->blockActiveLayerChanges( blocked );
+}
