@@ -17,6 +17,7 @@
 #include "qgsmessagebar.h"
 #include "qgsmapcanvas.h"
 #include "qgsmaptoolsplitfeatures.h"
+#include "moc_qgsmaptoolsplitfeatures.cpp"
 #include "qgsproject.h"
 #include "qgssnappingutils.h"
 #include "qgsvectorlayer.h"
@@ -30,14 +31,17 @@ QgsMapToolSplitFeatures::QgsMapToolSplitFeatures( QgsMapCanvas *canvas )
   setSnapToLayerGridEnabled( false );
 }
 
-bool QgsMapToolSplitFeatures::supportsTechnique( QgsMapToolCapture::CaptureTechnique technique ) const
+bool QgsMapToolSplitFeatures::supportsTechnique( Qgis::CaptureTechnique technique ) const
 {
   switch ( technique )
   {
-    case QgsMapToolCapture::StraightSegments:
-    case QgsMapToolCapture::CircularString:
-    case QgsMapToolCapture::Streaming:
+    case Qgis::CaptureTechnique::StraightSegments:
+    case Qgis::CaptureTechnique::CircularString:
+    case Qgis::CaptureTechnique::Streaming:
       return true;
+
+    case Qgis::CaptureTechnique::Shape:
+      return false;
   }
   return false;
 }
@@ -61,28 +65,32 @@ void QgsMapToolSplitFeatures::cadCanvasReleaseEvent( QgsMapMouseEvent *e )
 
   bool split = false;
 
-
   //add point to list and to rubber band
   if ( e->button() == Qt::LeftButton )
   {
+    int error = 0;
     //If we snap the first point on a vertex of a line layer, we directly split the feature at this point
-    if ( vlayer->geometryType() == QgsWkbTypes::LineGeometry && pointsZM().isEmpty() )
+    if ( vlayer->geometryType() == Qgis::GeometryType::Line && pointsZM().isEmpty() )
     {
       const QgsPointLocator::Match m = mCanvas->snappingUtils()->snapToCurrentLayer( e->pos(), QgsPointLocator::Vertex );
       if ( m.isValid() )
       {
+        error = addVertex( e->mapPoint(), m );
         split = true;
       }
     }
 
-    const int error = addVertex( e->mapPoint(), e->mapPointMatch() );
+    if ( !split )
+      error = addVertex( e->mapPoint(), e->mapPointMatch() );
+
     if ( error == 2 )
     {
       //problem with coordinate transformation
       QgisApp::instance()->messageBar()->pushMessage(
         tr( "Coordinate transform error" ),
         tr( "Cannot transform the point to the layers coordinate system" ),
-        Qgis::MessageLevel::Info );
+        Qgis::MessageLevel::Info
+      );
       return;
     }
 
@@ -90,6 +98,12 @@ void QgsMapToolSplitFeatures::cadCanvasReleaseEvent( QgsMapMouseEvent *e )
   }
   else if ( e->button() == Qt::RightButton )
   {
+    if ( !split && size() < 2 )
+    {
+      stopCapturing();
+      return;
+    }
+
     split = true;
   }
 
@@ -101,7 +115,14 @@ void QgsMapToolSplitFeatures::cadCanvasReleaseEvent( QgsMapMouseEvent *e )
     const bool topologicalEditing = QgsProject::instance()->topologicalEditing();
     QgsPointSequence topologyTestPoints;
     vlayer->beginEditCommand( tr( "Features split" ) );
-    const Qgis::GeometryOperationResult returnCode = vlayer->splitFeatures( captureCurve(), topologyTestPoints, true, topologicalEditing );
+
+    // we need to drop Z value to properly split 3D feature in 2D. If not, generated vertices Z value
+    // will be assigned with the mean value between the interpolated Z values of the intersecting point
+    // and the default Z value, which is not what we want
+    std::unique_ptr<QgsCompoundCurve> curve( captureCurve()->clone() );
+    curve->dropZValue();
+
+    const Qgis::GeometryOperationResult returnCode = vlayer->splitFeatures( curve.get(), topologyTestPoints, true, topologicalEditing );
     if ( returnCode == Qgis::GeometryOperationResult::Success )
     {
       vlayer->endEditCommand();
@@ -114,21 +135,14 @@ void QgsMapToolSplitFeatures::cadCanvasReleaseEvent( QgsMapMouseEvent *e )
     switch ( returnCode )
     {
       case Qgis::GeometryOperationResult::Success:
-        if ( topologicalEditing == true &&
-             ! topologyTestPoints.isEmpty() )
+        if ( topologicalEditing == true && !topologyTestPoints.isEmpty() )
         {
           //check if we need to add topological points to other layers
-          const QList<QgsVectorLayer *> editableLayers;
-          const auto layers = canvas()->layers();
+          const auto layers = canvas()->layers( true );
           for ( QgsMapLayer *layer : layers )
           {
             QgsVectorLayer *vectorLayer = qobject_cast<QgsVectorLayer *>( layer );
-            if ( vectorLayer &&
-                 vectorLayer->isEditable() &&
-                 vectorLayer->isSpatial() &&
-                 vectorLayer != vlayer &&
-                 ( vectorLayer->geometryType() == QgsWkbTypes::LineGeometry ||
-                   vectorLayer->geometryType() == QgsWkbTypes::PolygonGeometry ) )
+            if ( vectorLayer && vectorLayer->isEditable() && vectorLayer->isSpatial() && vectorLayer != vlayer && ( vectorLayer->geometryType() == Qgis::GeometryType::Line || vectorLayer->geometryType() == Qgis::GeometryType::Polygon ) )
             {
               vectorLayer->beginEditCommand( tr( "Topological points from Features split" ) );
               const int returnValue = vectorLayer->addTopologicalPoints( topologyTestPoints );
@@ -149,26 +163,30 @@ void QgsMapToolSplitFeatures::cadCanvasReleaseEvent( QgsMapMouseEvent *e )
         QgisApp::instance()->messageBar()->pushMessage(
           tr( "No features were split" ),
           tr( "If there are selected features, the split tool only applies to those. If you would like to split all features under the split line, clear the selection." ),
-          Qgis::MessageLevel::Warning );
+          Qgis::MessageLevel::Warning
+        );
         break;
       case Qgis::GeometryOperationResult::GeometryEngineError:
         QgisApp::instance()->messageBar()->pushMessage(
           tr( "No feature split done" ),
           tr( "Cut edges detected. Make sure the line splits features into multiple parts." ),
-          Qgis::MessageLevel::Warning );
+          Qgis::MessageLevel::Warning
+        );
         break;
       case Qgis::GeometryOperationResult::InvalidBaseGeometry:
         QgisApp::instance()->messageBar()->pushMessage(
           tr( "No feature split done" ),
           tr( "The geometry is invalid. Please repair before trying to split it." ),
-          Qgis::MessageLevel::Warning );
+          Qgis::MessageLevel::Warning
+        );
         break;
       default:
         //several intersections but only one split (most likely line)
         QgisApp::instance()->messageBar()->pushMessage(
           tr( "No feature split done" ),
           tr( "An error occurred during splitting." ),
-          Qgis::MessageLevel::Warning );
+          Qgis::MessageLevel::Warning
+        );
         break;
     }
     stopCapturing();
