@@ -28,6 +28,7 @@ class QgsMapCanvas;
 
 #include "qgis_app.h"
 #include "qgspointxy.h"
+#include "qgscoordinatereferencesystem.h"
 
 #include <QWidget>
 #include <QElapsedTimer>
@@ -57,7 +58,7 @@ class APP_EXPORT QgsStatusBarCoordinatesWidget : public QWidget
     void weAreBored();
 
   private slots:
-    void showMouseCoordinates( const QgsPointXY &p );
+    void showMouseCoordinates( const QgsPointXY &mapPoint );
     void extentsViewToggled( bool flag );
     void validateCoordinates();
     void dizzy();
@@ -87,10 +88,10 @@ class APP_EXPORT QgsStatusBarCoordinatesWidget : public QWidget
     unsigned int mMousePrecisionDecimalPlaces;
 
     QgsPointXY mLastCoordinate;
+    QgsCoordinateReferenceSystem mLastCoordinateCrs;
 
     bool mIsFirstSizeChange = true;
     QElapsedTimer mLastSizeChangeTimer;
-
 };
 
 #endif // QGSSTATUSBARCOORDINATESWIDGET_H
