@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsvectorelevationpropertieswidget.h"
+#include "moc_qgsvectorelevationpropertieswidget.cpp"
 #include "qgsapplication.h"
 #include "qgsmaplayer.h"
 #include "qgsvectorlayer.h"
@@ -22,6 +23,7 @@
 #include "qgsmarkersymbol.h"
 #include "qgsfillsymbol.h"
 #include "qgsexpressioncontextutils.h"
+#include "qgsprojectionselectionwidget.h"
 
 QgsVectorElevationPropertiesWidget::QgsVectorElevationPropertiesWidget( QgsVectorLayer *layer, QgsMapCanvas *canvas, QWidget *parent )
   : QgsMapLayerConfigWidget( layer, canvas, parent )
@@ -29,6 +31,17 @@ QgsVectorElevationPropertiesWidget::QgsVectorElevationPropertiesWidget( QgsVecto
   setupUi( this );
   setObjectName( QStringLiteral( "mOptsPage_Elevation" ) );
 
+  mVerticalCrsStackedWidget->setSizeMode( QgsStackedWidget::SizeMode::CurrentPageOnly );
+
+  QVBoxLayout *vl = new QVBoxLayout();
+  vl->setContentsMargins( 0, 0, 0, 0 );
+  mVerticalCrsWidget = new QgsProjectionSelectionWidget( nullptr, QgsCoordinateReferenceSystemProxyModel::FilterVertical );
+  mVerticalCrsWidget->setOptionVisible( QgsProjectionSelectionWidget::CrsNotSet, true );
+  mVerticalCrsWidget->setNotSetText( tr( "Not set" ) );
+  mVerticalCrsWidget->setDialogTitle( tr( "Layer Vertical CRS" ) );
+  vl->addWidget( mVerticalCrsWidget );
+  mCrsPageEnabled->setLayout( vl );
+
   mOffsetZSpinBox->setClearValue( 0 );
   mScaleZSpinBox->setClearValue( 1 );
   mExtrusionSpinBox->setClearValue( 0 );
@@ -41,37 +54,36 @@ QgsVectorElevationPropertiesWidget::QgsVectorElevationPropertiesWidget( QgsVecto
   mSurfaceMarkerStyleButton->setSymbolType( Qgis::SymbolType::Marker );
   mElevationLimitSpinBox->setClearValue( mElevationLimitSpinBox->minimum(), tr( "Not set" ) );
 
-  mComboClamping->addItem( tr( "Clamped to Terrain" ), static_cast< int >( Qgis::AltitudeClamping::Terrain ) );
-  mComboClamping->addItem( tr( "Relative to Terrain" ), static_cast< int >( Qgis::AltitudeClamping::Relative ) );
-  mComboClamping->addItem( tr( "Absolute" ), static_cast< int >( Qgis::AltitudeClamping::Absolute ) );
+  mComboClamping->addItem( tr( "Clamped to Terrain" ), static_cast<int>( Qgis::AltitudeClamping::Terrain ) );
+  mComboClamping->addItem( tr( "Relative to Terrain" ), static_cast<int>( Qgis::AltitudeClamping::Relative ) );
+  mComboClamping->addItem( tr( "Absolute" ), static_cast<int>( Qgis::AltitudeClamping::Absolute ) );
 
-  mComboBinding->addItem( tr( "Vertex" ), static_cast< int >( Qgis::AltitudeBinding::Vertex ) );
-  mComboBinding->addItem( tr( "Centroid" ), static_cast< int >( Qgis::AltitudeBinding::Centroid ) );
+  mComboBinding->addItem( tr( "Vertex" ), static_cast<int>( Qgis::AltitudeBinding::Vertex ) );
+  mComboBinding->addItem( tr( "Centroid" ), static_cast<int>( Qgis::AltitudeBinding::Centroid ) );
 
-  mTypeComboBox->addItem( tr( "Individual Features" ), static_cast< int >( Qgis::VectorProfileType::IndividualFeatures ) );
-  mTypeComboBox->addItem( tr( "Continuous Surface (e.g. Contours)" ), static_cast< int >( Qgis::VectorProfileType::ContinuousSurface ) );
+  mTypeComboBox->addItem( tr( "Individual Features" ), static_cast<int>( Qgis::VectorProfileType::IndividualFeatures ) );
+  mTypeComboBox->addItem( tr( "Continuous Surface (e.g. Contours)" ), static_cast<int>( Qgis::VectorProfileType::ContinuousSurface ) );
 
-  mStyleComboBox->addItem( QgsApplication::getThemeIcon( QStringLiteral( "mIconSurfaceElevationLine.svg" ) ), tr( "Line" ), static_cast< int >( Qgis::ProfileSurfaceSymbology::Line ) );
-  mStyleComboBox->addItem( QgsApplication::getThemeIcon( QStringLiteral( "mIconSurfaceElevationFillBelow.svg" ) ), tr( "Fill Below" ), static_cast< int >( Qgis::ProfileSurfaceSymbology::FillBelow ) );
-  mStyleComboBox->addItem( QgsApplication::getThemeIcon( QStringLiteral( "mIconSurfaceElevationFillAbove.svg" ) ), tr( "Fill Above" ), static_cast< int >( Qgis::ProfileSurfaceSymbology::FillAbove ) );
+  mStyleComboBox->addItem( QgsApplication::getThemeIcon( QStringLiteral( "mIconSurfaceElevationLine.svg" ) ), tr( "Line" ), static_cast<int>( Qgis::ProfileSurfaceSymbology::Line ) );
+  mStyleComboBox->addItem( QgsApplication::getThemeIcon( QStringLiteral( "mIconSurfaceElevationFillBelow.svg" ) ), tr( "Fill Below" ), static_cast<int>( Qgis::ProfileSurfaceSymbology::FillBelow ) );
+  mStyleComboBox->addItem( QgsApplication::getThemeIcon( QStringLiteral( "mIconSurfaceElevationFillAbove.svg" ) ), tr( "Fill Above" ), static_cast<int>( Qgis::ProfileSurfaceSymbology::FillAbove ) );
 
-  initializeDataDefinedButton( mOffsetDDBtn, QgsMapLayerElevationProperties::ZOffset );
-  initializeDataDefinedButton( mExtrusionDDBtn, QgsMapLayerElevationProperties::ExtrusionHeight );
+  initializeDataDefinedButton( mOffsetDDBtn, QgsMapLayerElevationProperties::Property::ZOffset );
+  initializeDataDefinedButton( mExtrusionDDBtn, QgsMapLayerElevationProperties::Property::ExtrusionHeight );
 
   syncToLayer( layer );
 
-  connect( mOffsetZSpinBox, qOverload<double >( &QDoubleSpinBox::valueChanged ), this, &QgsVectorElevationPropertiesWidget::onChanged );
-  connect( mScaleZSpinBox, qOverload<double >( &QDoubleSpinBox::valueChanged ), this, &QgsVectorElevationPropertiesWidget::onChanged );
-  connect( mElevationLimitSpinBox, qOverload<double >( &QDoubleSpinBox::valueChanged ), this, &QgsVectorElevationPropertiesWidget::onChanged );
-  connect( mExtrusionSpinBox, qOverload<double >( &QDoubleSpinBox::valueChanged ), this, &QgsVectorElevationPropertiesWidget::onChanged );
+  connect( mOffsetZSpinBox, qOverload<double>( &QDoubleSpinBox::valueChanged ), this, &QgsVectorElevationPropertiesWidget::onChanged );
+  connect( mScaleZSpinBox, qOverload<double>( &QDoubleSpinBox::valueChanged ), this, &QgsVectorElevationPropertiesWidget::onChanged );
+  connect( mElevationLimitSpinBox, qOverload<double>( &QDoubleSpinBox::valueChanged ), this, &QgsVectorElevationPropertiesWidget::onChanged );
+  connect( mExtrusionSpinBox, qOverload<double>( &QDoubleSpinBox::valueChanged ), this, &QgsVectorElevationPropertiesWidget::onChanged );
   connect( mExtrusionGroupBox, &QGroupBox::toggled, this, &QgsVectorElevationPropertiesWidget::onChanged );
   connect( mComboClamping, qOverload<int>( &QComboBox::currentIndexChanged ), this, &QgsVectorElevationPropertiesWidget::onChanged );
   connect( mComboBinding, qOverload<int>( &QComboBox::currentIndexChanged ), this, &QgsVectorElevationPropertiesWidget::onChanged );
   connect( mComboClamping, qOverload<int>( &QComboBox::currentIndexChanged ), this, &QgsVectorElevationPropertiesWidget::clampingChanged );
   connect( mComboBinding, qOverload<int>( &QComboBox::currentIndexChanged ), this, &QgsVectorElevationPropertiesWidget::bindingChanged );
-  connect( mTypeComboBox, qOverload<int>( &QComboBox::currentIndexChanged ), this, [ = ]
-  {
-    switch ( static_cast< Qgis::VectorProfileType >( mTypeComboBox->currentData().toInt() ) )
+  connect( mTypeComboBox, qOverload<int>( &QComboBox::currentIndexChanged ), this, [=] {
+    switch ( static_cast<Qgis::VectorProfileType>( mTypeComboBox->currentData().toInt() ) )
     {
       case Qgis::VectorProfileType::IndividualFeatures:
         mInterpretationStackedWidget->setCurrentWidget( mPageIndividualFeatures );
@@ -83,9 +95,8 @@ QgsVectorElevationPropertiesWidget::QgsVectorElevationPropertiesWidget( QgsVecto
     onChanged();
   } );
 
-  connect( mStyleComboBox, qOverload< int >( &QComboBox::currentIndexChanged ), this, [ = ]
-  {
-    switch ( static_cast< Qgis::ProfileSurfaceSymbology >( mStyleComboBox->currentData().toInt() ) )
+  connect( mStyleComboBox, qOverload<int>( &QComboBox::currentIndexChanged ), this, [=] {
+    switch ( static_cast<Qgis::ProfileSurfaceSymbology>( mStyleComboBox->currentData().toInt() ) )
     {
       case Qgis::ProfileSurfaceSymbology::Line:
         mSymbologyStackedWidget->setCurrentWidget( mPageLine );
@@ -109,30 +120,33 @@ QgsVectorElevationPropertiesWidget::QgsVectorElevationPropertiesWidget( QgsVecto
   connect( mSurfaceMarkerStyleButton, &QgsSymbolButton::changed, this, &QgsVectorElevationPropertiesWidget::onChanged );
   connect( mExtrusionGroupBox, &QGroupBox::toggled, this, &QgsVectorElevationPropertiesWidget::toggleSymbolWidgets );
 
+  connect( mLayer, &QgsMapLayer::crsChanged, this, &QgsVectorElevationPropertiesWidget::updateVerticalCrsOptions );
+
+
   setProperty( "helpPage", QStringLiteral( "working_with_vector/vector_properties.html#elevation-properties" ) );
 }
 
 void QgsVectorElevationPropertiesWidget::syncToLayer( QgsMapLayer *layer )
 {
-  mLayer = qobject_cast< QgsVectorLayer * >( layer );
+  mLayer = qobject_cast<QgsVectorLayer *>( layer );
   if ( !mLayer )
     return;
 
   if ( !QgsWkbTypes::hasZ( mLayer->wkbType() ) )
   {
-    const int clampingIndex = mComboClamping->findData( static_cast< int >( Qgis::AltitudeClamping::Relative ) );
+    const int clampingIndex = mComboClamping->findData( static_cast<int>( Qgis::AltitudeClamping::Relative ) );
     if ( clampingIndex >= 0 )
       mComboClamping->removeItem( clampingIndex );
   }
 
   mBlockUpdates = true;
-  const QgsVectorLayerElevationProperties *props = qgis::down_cast< const QgsVectorLayerElevationProperties * >( mLayer->elevationProperties() );
+  const QgsVectorLayerElevationProperties *props = qgis::down_cast<const QgsVectorLayerElevationProperties *>( mLayer->elevationProperties() );
 
-  mComboClamping->setCurrentIndex( mComboClamping->findData( static_cast< int >( props->clamping() ) ) );
+  mComboClamping->setCurrentIndex( mComboClamping->findData( static_cast<int>( props->clamping() ) ) );
   if ( mComboClamping->currentIndex() == -1 )
     mComboClamping->setCurrentIndex( 0 );
 
-  mComboBinding->setCurrentIndex( mComboBinding->findData( static_cast< int >( props->binding() ) ) );
+  mComboBinding->setCurrentIndex( mComboBinding->findData( static_cast<int>( props->binding() ) ) );
   mOffsetZSpinBox->setValue( props->zOffset() );
   mScaleZSpinBox->setValue( props->zScale() );
   if ( std::isnan( props->elevationLimit() ) )
@@ -141,7 +155,7 @@ void QgsVectorElevationPropertiesWidget::syncToLayer( QgsMapLayer *layer )
     mElevationLimitSpinBox->setValue( props->elevationLimit() );
   mExtrusionGroupBox->setChecked( props->extrusionEnabled() );
   mExtrusionSpinBox->setValue( props->extrusionHeight() );
-  mTypeComboBox->setCurrentIndex( mTypeComboBox->findData( static_cast< int >( props->type() ) ) );
+  mTypeComboBox->setCurrentIndex( mTypeComboBox->findData( static_cast<int>( props->type() ) ) );
   switch ( props->type() )
   {
     case Qgis::VectorProfileType::IndividualFeatures:
@@ -151,7 +165,7 @@ void QgsVectorElevationPropertiesWidget::syncToLayer( QgsMapLayer *layer )
       mInterpretationStackedWidget->setCurrentWidget( mPageContinuousSurface );
       break;
   }
-  mStyleComboBox->setCurrentIndex( mStyleComboBox->findData( static_cast <int >( props->profileSymbology() ) ) );
+  mStyleComboBox->setCurrentIndex( mStyleComboBox->findData( static_cast<int>( props->profileSymbology() ) ) );
   switch ( props->profileSymbology() )
   {
     case Qgis::ProfileSurfaceSymbology::Line:
@@ -195,6 +209,8 @@ void QgsVectorElevationPropertiesWidget::syncToLayer( QgsMapLayer *layer )
 
   clampingChanged();
   bindingChanged();
+
+  updateVerticalCrsOptions();
 }
 
 QgsExpressionContext QgsVectorElevationPropertiesWidget::createExpressionContext() const
@@ -209,40 +225,41 @@ void QgsVectorElevationPropertiesWidget::apply()
   if ( !mLayer )
     return;
 
-  QgsVectorLayerElevationProperties *props = qgis::down_cast< QgsVectorLayerElevationProperties * >( mLayer->elevationProperties() );
+  QgsVectorLayerElevationProperties *props = qgis::down_cast<QgsVectorLayerElevationProperties *>( mLayer->elevationProperties() );
 
   props->setZOffset( mOffsetZSpinBox->value() );
   props->setZScale( mScaleZSpinBox->value() );
-  props->setType( static_cast< Qgis::VectorProfileType >( mTypeComboBox->currentData().toInt() ) );
-  props->setClamping( static_cast< Qgis::AltitudeClamping >( mComboClamping->currentData().toInt() ) );
-  props->setBinding( static_cast< Qgis::AltitudeBinding >( mComboBinding->currentData().toInt() ) );
+  props->setType( static_cast<Qgis::VectorProfileType>( mTypeComboBox->currentData().toInt() ) );
+  props->setClamping( static_cast<Qgis::AltitudeClamping>( mComboClamping->currentData().toInt() ) );
+  props->setBinding( static_cast<Qgis::AltitudeBinding>( mComboBinding->currentData().toInt() ) );
   props->setExtrusionEnabled( mExtrusionGroupBox->isChecked() );
   props->setExtrusionHeight( mExtrusionSpinBox->value() );
   if ( mElevationLimitSpinBox->value() != mElevationLimitSpinBox->clearValue() )
     props->setElevationLimit( mElevationLimitSpinBox->value() );
   else
-    props->setElevationLimit( std::numeric_limits< double >::quiet_NaN() );
+    props->setElevationLimit( std::numeric_limits<double>::quiet_NaN() );
 
   props->setRespectLayerSymbology( mCheckRespectLayerSymbology->isChecked() );
   props->setShowMarkerSymbolInSurfacePlots( mCheckBoxShowMarkersAtSampledPoints->isChecked() );
 
-  props->setProfileSymbology( static_cast< Qgis::ProfileSurfaceSymbology >( mStyleComboBox->currentData().toInt() ) );
+  props->setProfileSymbology( static_cast<Qgis::ProfileSurfaceSymbology>( mStyleComboBox->currentData().toInt() ) );
   switch ( props->type() )
   {
     case Qgis::VectorProfileType::IndividualFeatures:
-      props->setProfileLineSymbol( mLineStyleButton->clonedSymbol< QgsLineSymbol >() );
-      props->setProfileFillSymbol( mFillStyleButton->clonedSymbol< QgsFillSymbol >() );
-      props->setProfileMarkerSymbol( mMarkerStyleButton->clonedSymbol< QgsMarkerSymbol >() );
+      props->setProfileLineSymbol( mLineStyleButton->clonedSymbol<QgsLineSymbol>() );
+      props->setProfileFillSymbol( mFillStyleButton->clonedSymbol<QgsFillSymbol>() );
+      props->setProfileMarkerSymbol( mMarkerStyleButton->clonedSymbol<QgsMarkerSymbol>() );
       break;
     case Qgis::VectorProfileType::ContinuousSurface:
-      props->setProfileLineSymbol( mSurfaceLineStyleButton->clonedSymbol< QgsLineSymbol >() );
-      props->setProfileFillSymbol( mSurfaceFillStyleButton->clonedSymbol< QgsFillSymbol >() );
-      props->setProfileMarkerSymbol( mSurfaceMarkerStyleButton->clonedSymbol< QgsMarkerSymbol >() );
+      props->setProfileLineSymbol( mSurfaceLineStyleButton->clonedSymbol<QgsLineSymbol>() );
+      props->setProfileFillSymbol( mSurfaceFillStyleButton->clonedSymbol<QgsFillSymbol>() );
+      props->setProfileMarkerSymbol( mSurfaceMarkerStyleButton->clonedSymbol<QgsMarkerSymbol>() );
       break;
   }
 
   props->setDataDefinedProperties( mPropertyCollection );
 
+  mLayer->setVerticalCrs( mVerticalCrsWidget->crs() );
   mLayer->trigger3DUpdate();
 }
 
@@ -256,13 +273,11 @@ void QgsVectorElevationPropertiesWidget::clampingChanged()
 {
   bool enableScale = true;
   bool enableBinding = !mLayer || mLayer->geometryType() != Qgis::GeometryType::Point;
-  switch ( static_cast< Qgis::AltitudeClamping >( mComboClamping->currentData().toInt() ) )
+  switch ( static_cast<Qgis::AltitudeClamping>( mComboClamping->currentData().toInt() ) )
   {
     case Qgis::AltitudeClamping::Absolute:
       mLabelClampingExplanation->setText(
-        QStringLiteral( "<p><b>%1</b></p><p>%2</p>" ).arg(
-          tr( "Elevation will be taken directly from features." ),
-          tr( "Z values from the features will be used for elevation, and the terrain height will be ignored." ) )
+        QStringLiteral( "<p><b>%1</b></p><p>%2</p>" ).arg( tr( "Elevation will be taken directly from features." ), tr( "Z values from the features will be used for elevation, and the terrain height will be ignored." ) )
       );
       enableBinding = false; // not used in absolute mode
 
@@ -278,17 +293,13 @@ void QgsVectorElevationPropertiesWidget::clampingChanged()
     case Qgis::AltitudeClamping::Relative:
       mOffsetLabel->setText( tr( "Offset" ) );
       mLabelClampingExplanation->setText(
-        QStringLiteral( "<p><b>%1</b></p><p>%2</p>" ).arg(
-          tr( "Elevation is relative to terrain height." ),
-          tr( "Any z values present in the features will be added to the terrain height." ) )
+        QStringLiteral( "<p><b>%1</b></p><p>%2</p>" ).arg( tr( "Elevation is relative to terrain height." ), tr( "Any z values present in the features will be added to the terrain height." ) )
       );
       break;
     case Qgis::AltitudeClamping::Terrain:
       mOffsetLabel->setText( tr( "Offset" ) );
       mLabelClampingExplanation->setText(
-        QStringLiteral( "<p><b>%1</b></p><p>%2</p>" ).arg(
-          tr( "Feature elevation will be taken directly from the terrain height." ),
-          tr( "Any existing z values present in the features will be ignored." ) )
+        QStringLiteral( "<p><b>%1</b></p><p>%2</p>" ).arg( tr( "Feature elevation will be taken directly from the terrain height." ), tr( "Any existing z values present in the features will be ignored." ) )
       );
       enableScale = false; // not used in terrain mode
       break;
@@ -301,25 +312,18 @@ void QgsVectorElevationPropertiesWidget::clampingChanged()
 
 void QgsVectorElevationPropertiesWidget::bindingChanged()
 {
-  switch ( static_cast< Qgis::AltitudeBinding >( mComboBinding->currentData().toInt() ) )
+  switch ( static_cast<Qgis::AltitudeBinding>( mComboBinding->currentData().toInt() ) )
   {
     case Qgis::AltitudeBinding::Vertex:
       mLabelBindingExplanation->setText(
-        QStringLiteral( "<p><b>%1</b></p><p>%2</p>" ).arg(
-          tr( "Feature elevation is relative to the terrain height at every vertex." ),
-          tr( "The terrain will be sampled at every individual vertex before being added to the vertex's z value." )
-        )
+        QStringLiteral( "<p><b>%1</b></p><p>%2</p>" ).arg( tr( "Feature elevation is relative to the terrain height at every vertex." ), tr( "The terrain will be sampled at every individual vertex before being added to the vertex's z value." ) )
       );
       break;
     case Qgis::AltitudeBinding::Centroid:
       mLabelBindingExplanation->setText(
-        QStringLiteral( "<p><b>%1</b></p><p>%2</p>" ).arg(
-          tr( "Feature elevation is relative to the terrain height at feature's centroid only." ),
-          tr( "The terrain will be sampled once at the feature's centroid, with the centroid height being added to each vertex's z value." )
-        )
+        QStringLiteral( "<p><b>%1</b></p><p>%2</p>" ).arg( tr( "Feature elevation is relative to the terrain height at feature's centroid only." ), tr( "The terrain will be sampled once at the feature's centroid, with the centroid height being added to each vertex's z value." ) )
       );
       break;
-
   }
 }
 
@@ -359,14 +363,57 @@ void QgsVectorElevationPropertiesWidget::toggleSymbolWidgets()
 void QgsVectorElevationPropertiesWidget::updateProperty()
 {
   QgsPropertyOverrideButton *button = qobject_cast<QgsPropertyOverrideButton *>( sender() );
-  QgsMapLayerElevationProperties::Property key = static_cast<  QgsMapLayerElevationProperties::Property >( button->propertyKey() );
+  QgsMapLayerElevationProperties::Property key = static_cast<QgsMapLayerElevationProperties::Property>( button->propertyKey() );
   mPropertyCollection.setProperty( key, button->toProperty() );
 }
 
+void QgsVectorElevationPropertiesWidget::updateVerticalCrsOptions()
+{
+  switch ( mLayer->crs().type() )
+  {
+    case Qgis::CrsType::Compound:
+      mVerticalCrsStackedWidget->setCurrentWidget( mCrsPageDisabled );
+      mCrsDisabledLabel->setText( tr( "Layer coordinate reference system is set to a compound CRS (%1), so the layer's vertical CRS is the vertical component of this CRS (%2)." ).arg( mLayer->crs().userFriendlyIdentifier(), mLayer->verticalCrs().userFriendlyIdentifier() ) );
+      break;
+
+    case Qgis::CrsType::Geographic3d:
+      mVerticalCrsStackedWidget->setCurrentWidget( mCrsPageDisabled );
+      mCrsDisabledLabel->setText( tr( "Layer coordinate reference system is set to a geographic 3D CRS (%1), so the vertical CRS cannot be manually specified." ).arg( mLayer->crs().userFriendlyIdentifier() ) );
+      break;
+
+    case Qgis::CrsType::Geocentric:
+      mVerticalCrsStackedWidget->setCurrentWidget( mCrsPageDisabled );
+      mCrsDisabledLabel->setText( tr( "Layer coordinate reference system is set to a geocentric CRS (%1), so the vertical CRS cannot be manually specified." ).arg( mLayer->crs().userFriendlyIdentifier() ) );
+      break;
+
+    case Qgis::CrsType::Projected:
+      if ( mLayer->crs().hasVerticalAxis() )
+      {
+        mVerticalCrsStackedWidget->setCurrentWidget( mCrsPageDisabled );
+        mCrsDisabledLabel->setText( tr( "Layer coordinate reference system is set to a projected 3D CRS (%1), so the vertical CRS cannot be manually specified." ).arg( mLayer->crs().userFriendlyIdentifier() ) );
+        break;
+      }
+      [[fallthrough]];
+
+    case Qgis::CrsType::Unknown:
+    case Qgis::CrsType::Geodetic:
+    case Qgis::CrsType::Geographic2d:
+    case Qgis::CrsType::Vertical:
+    case Qgis::CrsType::Temporal:
+    case Qgis::CrsType::Engineering:
+    case Qgis::CrsType::Bound:
+    case Qgis::CrsType::Other:
+    case Qgis::CrsType::DerivedProjected:
+      mVerticalCrsStackedWidget->setCurrentWidget( mCrsPageEnabled );
+      mVerticalCrsWidget->setCrs( mLayer->verticalCrs() );
+      break;
+  }
+}
+
 void QgsVectorElevationPropertiesWidget::initializeDataDefinedButton( QgsPropertyOverrideButton *button, QgsMapLayerElevationProperties::Property key )
 {
   button->blockSignals( true );
-  button->init( key, mPropertyCollection, QgsMapLayerElevationProperties::propertyDefinitions(), nullptr );
+  button->init( static_cast<int>( key ), mPropertyCollection, QgsMapLayerElevationProperties::propertyDefinitions(), nullptr );
   connect( button, &QgsPropertyOverrideButton::changed, this, &QgsVectorElevationPropertiesWidget::updateProperty );
   button->registerExpressionContextGenerator( this );
   button->blockSignals( false );
@@ -374,7 +421,7 @@ void QgsVectorElevationPropertiesWidget::initializeDataDefinedButton( QgsPropert
 
 void QgsVectorElevationPropertiesWidget::updateDataDefinedButtons()
 {
-  const auto propertyOverrideButtons { findChildren< QgsPropertyOverrideButton * >() };
+  const QList<QgsPropertyOverrideButton *> propertyOverrideButtons { findChildren<QgsPropertyOverrideButton *>() };
   for ( QgsPropertyOverrideButton *button : propertyOverrideButtons )
   {
     updateDataDefinedButton( button );
@@ -389,7 +436,7 @@ void QgsVectorElevationPropertiesWidget::updateDataDefinedButton( QgsPropertyOve
   if ( button->propertyKey() < 0 )
     return;
 
-  QgsMapLayerElevationProperties::Property key = static_cast< QgsMapLayerElevationProperties::Property >( button->propertyKey() );
+  QgsMapLayerElevationProperties::Property key = static_cast<QgsMapLayerElevationProperties::Property>( button->propertyKey() );
   whileBlocking( button )->setToProperty( mPropertyCollection.property( key ) );
   whileBlocking( button )->setVectorLayer( mLayer );
 }
@@ -408,7 +455,7 @@ QgsVectorElevationPropertiesWidgetFactory::QgsVectorElevationPropertiesWidgetFac
 
 QgsMapLayerConfigWidget *QgsVectorElevationPropertiesWidgetFactory::createWidget( QgsMapLayer *layer, QgsMapCanvas *canvas, bool, QWidget *parent ) const
 {
-  return new QgsVectorElevationPropertiesWidget( qobject_cast< QgsVectorLayer * >( layer ), canvas, parent );
+  return new QgsVectorElevationPropertiesWidget( qobject_cast<QgsVectorLayer *>( layer ), canvas, parent );
 }
 
 bool QgsVectorElevationPropertiesWidgetFactory::supportLayerPropertiesDialog() const
@@ -430,4 +477,3 @@ QString QgsVectorElevationPropertiesWidgetFactory::layerPropertiesPagePositionHi
 {
   return QStringLiteral( "mOptsPage_Metadata" );
 }
-
