@@ -43,7 +43,6 @@ namespace Qt3DCore
  * Renderers may store some custom properties (e.g. materials, sizes) that are written to and read from
  * XML. It is therefore not recommended to store large amount of data within a renderer (e.g. arrays of vertices).
  *
- * \since QGIS 3.0
  */
 class CORE_EXPORT QgsAbstract3DRenderer SIP_ABSTRACT
 {
@@ -55,7 +54,7 @@ class CORE_EXPORT QgsAbstract3DRenderer SIP_ABSTRACT
     //! Returns a cloned instance
     virtual QgsAbstract3DRenderer *clone() const = 0 SIP_FACTORY;
     //! Returns a 3D entity that will be used to show renderer's data in 3D scene
-    virtual Qt3DCore::QEntity *createEntity( const Qgs3DMapSettings &map ) const = 0 SIP_SKIP;
+    virtual Qt3DCore::QEntity *createEntity( Qgs3DMapSettings *map ) const = 0 SIP_SKIP;
 
     //! Writes renderer's properties to given XML element
     virtual void writeXml( QDomElement &elem, const QgsReadWriteContext &context ) const = 0;
@@ -65,7 +64,7 @@ class CORE_EXPORT QgsAbstract3DRenderer SIP_ABSTRACT
     virtual void resolveReferences( const QgsProject &project );
 
   protected:
-    //! Default constructor
+
     QgsAbstract3DRenderer() = default;
 
   private:
