@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsabstractgeocoderlocatorfilter.h"
+#include "moc_qgsabstractgeocoderlocatorfilter.cpp"
 #include "qgsgeocoder.h"
 #include "qgsgeocodercontext.h"
 
@@ -72,7 +73,7 @@ QgsGeocoderInterface *QgsAbstractGeocoderLocatorFilter::geocoder() const
 
 QgsGeocoderResult QgsAbstractGeocoderLocatorFilter::locatorResultToGeocoderResult( const QgsLocatorResult &result ) const
 {
-  const QVariantMap attrs = result.getUserData().toMap();
+  const QVariantMap attrs = result.userData().toMap();
   QgsGeocoderResult geocodeResult( attrs.value( QStringLiteral( "identifier" ) ).toString(),
                                    attrs.value( QStringLiteral( "geom" ) ).value< QgsGeometry >(),
                                    attrs.value( QStringLiteral( "crs" ) ).value< QgsCoordinateReferenceSystem >() );
