@@ -34,7 +34,6 @@
  * associated with them.
  *
  * \see QgsReferencedRectangle
- * \since QGIS 3.0
  */
 class CORE_EXPORT QgsReferencedGeometryBase
 {
@@ -68,7 +67,6 @@ class CORE_EXPORT QgsReferencedGeometryBase
 /**
  * \ingroup core
  * \brief A QgsRectangle with associated coordinate reference system.
- * \since QGIS 3.0
  */
 class CORE_EXPORT QgsReferencedRectangle : public QgsRectangle, public QgsReferencedGeometryBase
 {
@@ -80,13 +78,10 @@ class CORE_EXPORT QgsReferencedRectangle : public QgsRectangle, public QgsRefere
      */
     QgsReferencedRectangle( const QgsRectangle &rectangle, const QgsCoordinateReferenceSystem &crs );
 
-    /**
-     * Constructor for QgsReferencedRectangle.
-     */
     QgsReferencedRectangle() = default;
 
     //! Allows direct construction of QVariants from rectangle.
-    operator QVariant() const
+    operator QVariant() const // cppcheck-suppress duplInheritedMember
     {
       return QVariant::fromValue( *this );
     }
@@ -109,7 +104,6 @@ Q_DECLARE_METATYPE( QgsReferencedRectangle )
 /**
  * \ingroup core
  * \brief A QgsPointXY with associated coordinate reference system.
- * \since QGIS 3.0
  */
 class CORE_EXPORT QgsReferencedPointXY : public QgsPointXY, public QgsReferencedGeometryBase
 {
@@ -121,9 +115,6 @@ class CORE_EXPORT QgsReferencedPointXY : public QgsPointXY, public QgsReferenced
      */
     QgsReferencedPointXY( const QgsPointXY &point, const QgsCoordinateReferenceSystem &crs );
 
-    /**
-     * Constructor for QgsReferencedPointXY.
-     */
     QgsReferencedPointXY() = default;
 
     //! Allows direct construction of QVariants from point.
@@ -162,13 +153,10 @@ class CORE_EXPORT QgsReferencedGeometry : public QgsGeometry, public QgsReferenc
      */
     QgsReferencedGeometry( const QgsGeometry &geometry, const QgsCoordinateReferenceSystem &crs );
 
-    /**
-     * Constructor for QgsReferencedGeometry.
-     */
     QgsReferencedGeometry() = default;
 
     //! Allows direct construction of QVariants from geometry.
-    operator QVariant() const
+    operator QVariant() const // cppcheck-suppress duplInheritedMember
     {
       return QVariant::fromValue( *this );
     }
