@@ -15,6 +15,7 @@
  ***************************************************************************/
 
 #include "qgslayertreefilterproxymodel.h"
+#include "moc_qgslayertreefilterproxymodel.cpp"
 
 #include "qgslayertree.h"
 #include "qgslayertreemodel.h"
@@ -23,7 +24,7 @@
 QgsLayerTreeFilterProxyModel::QgsLayerTreeFilterProxyModel( QObject *parent )
   : QSortFilterProxyModel( parent )
 {
-  connect( QgsProject::instance(), &QgsProject::readProject, this, [ = ]
+  connect( QgsProject::instance(), &QgsProject::readProject, this, [this] // skip-keyword-check
   {
     beginResetModel();
     endResetModel();
@@ -107,6 +108,20 @@ void QgsLayerTreeFilterProxyModel::setLayerTreeModel( QgsLayerTreeModel *layerTr
   QSortFilterProxyModel::setSourceModel( layerTreeModel );
 }
 
+bool QgsLayerTreeFilterProxyModel::showPrivateLayers() const
+{
+  return mShowPrivateLayers;
+}
+
+void QgsLayerTreeFilterProxyModel::setShowPrivateLayers( bool showPrivate )
+{
+  if ( showPrivate == mShowPrivateLayers )
+    return;
+
+  mShowPrivateLayers = showPrivate;
+  invalidateFilter();
+}
+
 void QgsLayerTreeFilterProxyModel::setFilters( Qgis::LayerFilters filters )
 {
   mFilters = filters;
@@ -180,6 +195,10 @@ bool QgsLayerTreeFilterProxyModel::nodeShown( QgsLayerTreeNode *node ) const
       return false;
     if ( !mFilterText.isEmpty() && !layer->name().contains( mFilterText, Qt::CaseInsensitive ) )
       return false;
+    if ( ! mShowPrivateLayers && layer->flags().testFlag( QgsMapLayer::LayerFlag::Private ) )
+    {
+      return false;
+    }
     if ( !QgsMapLayerProxyModel::layerMatchesFilters( layer, mFilters ) )
       return false;
 
