@@ -18,12 +18,13 @@
 
 #include <QObject>
 #include <QStringList>
+#include <QPointer>
 
 #include "qgis_core.h"
 #include "qgis_sip.h"
 #include "qgis.h"
+#include "qgslayertreegroup.h"
 
-class QgsLayerTreeGroup;
 class QgsLayerTreeNode;
 class QgsMapLayer;
 class QgsProject;
@@ -40,7 +41,6 @@ class QgsProject;
  * If a layer is completely removed from the layer tree, it will be also removed
  * from the map layer registry.
  *
- * \since QGIS 2.4
  */
 class CORE_EXPORT QgsLayerTreeRegistryBridge : public QObject
 {
@@ -58,7 +58,7 @@ class CORE_EXPORT QgsLayerTreeRegistryBridge : public QObject
       InsertionPoint( QgsLayerTreeGroup *group, int position )
         : group( group ), position( position ) {}
 
-      QgsLayerTreeGroup *group = nullptr;
+      QgsLayerTreeGroup *group;
       int position = 0;
     };
 
@@ -74,7 +74,7 @@ class CORE_EXPORT QgsLayerTreeRegistryBridge : public QObject
     /**
      * Set where the new layers should be inserted - can be used to follow current selection.
      * By default it is root group with zero index.
-     * \deprecated since QGIS 3.10 use setLayerInsertionPoint( const InsertionPoint &insertionPoint ) instead
+     * \deprecated QGIS 3.10. Use setLayerInsertionPoint( const InsertionPoint &insertionPoint ) instead.
      */
     Q_DECL_DEPRECATED void setLayerInsertionPoint( QgsLayerTreeGroup *parentGroup, int index ) SIP_DEPRECATED;
 
@@ -85,6 +85,12 @@ class CORE_EXPORT QgsLayerTreeRegistryBridge : public QObject
      */
     void setLayerInsertionPoint( const InsertionPoint &insertionPoint );
 
+    /**
+     * Returns the insertion point used to add layers to the tree
+     * \since QGIS 3.42
+     */
+    InsertionPoint layerInsertionPoint() const;
+
     /**
      * Sets the insertion \a method used to add layers to the tree
      * \since QGIS 3.30
@@ -101,7 +107,6 @@ class CORE_EXPORT QgsLayerTreeRegistryBridge : public QObject
 
     /**
      * Tell others we have just added layers to the tree (used in QGIS to auto-select first newly added layer)
-     * \since QGIS 2.6
      */
     void addedLayersToLayerTree( const QList<QgsMapLayer *> &layers );
 
@@ -122,7 +127,9 @@ class CORE_EXPORT QgsLayerTreeRegistryBridge : public QObject
     bool mEnabled;
     bool mNewLayersVisible;
 
-    InsertionPoint mInsertionPoint;
+    QPointer< QgsLayerTreeGroup > mInsertionPointGroup;
+    int mInsertionPointPosition = 0;
+
     Qgis::LayerTreeInsertionMethod mInsertionMethod = Qgis::LayerTreeInsertionMethod::AboveInsertionPoint;
 };
 
