@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgslayoutitemlabel.h"
+#include "moc_qgslayoutitemlabel.cpp"
 #include "qgslayoutitemregistry.h"
 #include "qgslayoututils.h"
 #include "qgslayoutmodel.h"
@@ -58,7 +59,7 @@ QgsLayoutItemLabel::QgsLayoutItemLabel( QgsLayout *layout )
   mFormat.setSize( 10 );
   mFormat.setSizeUnit( Qgis::RenderUnit::Points );
 
-  connect( this, &QgsLayoutItem::sizePositionChanged, this, [ = ]
+  connect( this, &QgsLayoutItem::sizePositionChanged, this, [this]
   {
     updateBoundingRect();
   } );
