@@ -33,7 +33,6 @@ class QgsLayoutTableColumn;
  * \ingroup core
  * \brief List of QVariants, representing a the contents of a single row in
  * a QgsLayoutTable
- * \since QGIS 3.0
 */
 typedef QVector< QVariant > QgsLayoutTableRow;
 
@@ -41,7 +40,6 @@ typedef QVector< QVariant > QgsLayoutTableRow;
  * \ingroup core
  * \brief List of QgsLayoutTableRows, representing rows and column cell contents
  * for a QgsLayoutTable
- * \since QGIS 3.0
 */
 #ifndef SIP_RUN
 typedef QVector< QgsLayoutTableRow > QgsLayoutTableContents;
@@ -53,7 +51,6 @@ typedef QVector< QVector< QVariant > > QgsLayoutTableContents;
 /**
  * \ingroup core
  * \brief List of column definitions for a QgsLayoutTable
- * \since QGIS 3.0
 */
 typedef QVector<QgsLayoutTableColumn> QgsLayoutTableColumns;
 
@@ -70,14 +67,12 @@ typedef QVector<QgsLayoutTableColumn> QgsLayoutTableSortColumns;
  * \ingroup core
  *  \class QgsLayoutTableStyle
  *  \brief Styling option for a layout table cell
- *  \since QGIS 3.0
  */
 
 class CORE_EXPORT QgsLayoutTableStyle
 {
   public:
 
-    //! Constructor for QgsLayoutTableStyle
     QgsLayoutTableStyle() = default;
 
     //! Whether the styling option is enabled
@@ -107,7 +102,6 @@ class CORE_EXPORT QgsLayoutTableStyle
  * \brief A class to display a table in the print layout, and allow
  * the table to span over multiple frames
  * \ingroup core
- * \since QGIS 3.0
  */
 class CORE_EXPORT QgsLayoutTable: public QgsLayoutMultiFrame
 {
@@ -238,7 +232,7 @@ class CORE_EXPORT QgsLayoutTable: public QgsLayoutMultiFrame
      * Sets the \a font used to draw header text in the table.
      * \see headerFont()
      * \see setContentFont()
-     * \deprecated use setHeaderTextFormat() instead
+     * \deprecated QGIS 3.40. Use setHeaderTextFormat() instead.
      */
     Q_DECL_DEPRECATED void setHeaderFont( const QFont &font ) SIP_DEPRECATED;
 
@@ -246,7 +240,7 @@ class CORE_EXPORT QgsLayoutTable: public QgsLayoutMultiFrame
      * Returns the font used to draw header text in the table.
      * \see setHeaderFont()
      * \see contentFont()
-     * \deprecated use headerTextFormat() instead
+     * \deprecated QGIS 3.40. Use headerTextFormat() instead.
      */
     Q_DECL_DEPRECATED QFont headerFont() const SIP_DEPRECATED;
 
@@ -255,7 +249,7 @@ class CORE_EXPORT QgsLayoutTable: public QgsLayoutMultiFrame
      * \see headerFontColor()
      * \see setHeaderFont()
      * \see setContentFontColor()
-     * \deprecated use setHeaderTextFormat() instead
+     * \deprecated QGIS 3.40. Use setHeaderTextFormat() instead.
      */
     Q_DECL_DEPRECATED void setHeaderFontColor( const QColor &color ) SIP_DEPRECATED;
 
@@ -264,7 +258,7 @@ class CORE_EXPORT QgsLayoutTable: public QgsLayoutMultiFrame
      * \see setHeaderFontColor()
      * \see headerFont()
      * \see contentFontColor()
-     * \deprecated use headerTextFormat() instead
+     * \deprecated QGIS 3.40. Use headerTextFormat() instead.
      */
     Q_DECL_DEPRECATED QColor headerFontColor() const SIP_DEPRECATED;
 
@@ -314,7 +308,7 @@ class CORE_EXPORT QgsLayoutTable: public QgsLayoutMultiFrame
      * Sets the \a font used to draw text in table body cells.
      * \see contentFont()
      * \see setHeaderFont()
-     * \deprecated use setContentTextFormat() instead
+     * \deprecated QGIS 3.40. Use setContentTextFormat() instead.
      */
     Q_DECL_DEPRECATED void setContentFont( const QFont &font ) SIP_DEPRECATED;
 
@@ -322,7 +316,7 @@ class CORE_EXPORT QgsLayoutTable: public QgsLayoutMultiFrame
      * Returns the font used to draw text in table body cells.
      * \see setContentFont()
      * \see headerFont()
-     * \deprecated use contextTextFormat() instead
+     * \deprecated QGIS 3.40. Use contextTextFormat() instead.
      */
     Q_DECL_DEPRECATED QFont contentFont() const SIP_DEPRECATED;
 
@@ -331,7 +325,7 @@ class CORE_EXPORT QgsLayoutTable: public QgsLayoutMultiFrame
      * \see contentFontColor()
      * \see setContentFont()
      * \see setHeaderFontColor()
-     * \deprecated use setContentTextFormat() instead
+     * \deprecated QGIS 3.40. Use setContentTextFormat() instead.
      */
     Q_DECL_DEPRECATED void setContentFontColor( const QColor &color ) SIP_DEPRECATED;
 
@@ -340,7 +334,7 @@ class CORE_EXPORT QgsLayoutTable: public QgsLayoutMultiFrame
      * \see setContentFontColor()
      * \see contentFont()
      * \see headerFontColor()
-     * \deprecated use contextTextFormat() instead
+     * \deprecated QGIS 3.40. Use contextTextFormat() instead.
      */
     Q_DECL_DEPRECATED QColor contentFontColor() const SIP_DEPRECATED;
 
@@ -553,6 +547,22 @@ class CORE_EXPORT QgsLayoutTable: public QgsLayoutMultiFrame
      */
     virtual QgsExpressionContextScope *scopeForCell( int row, int column ) const SIP_FACTORY;
 
+    /**
+     * Returns the row span for the cell a \a row, \a column.
+     *
+     * \see columnSpan()
+     * \since QGIS 3.40
+     */
+    virtual int rowSpan( int row, int column ) const;
+
+    /**
+     * Returns the column span for the cell a \a row, \a column.
+     *
+     * \see rowSpan()
+     * \since QGIS 3.40
+     */
+    virtual int columnSpan( int row, int column ) const;
+
     /**
      * Returns the current contents of the table. Excludes header cells.
      */
@@ -780,17 +790,15 @@ class CORE_EXPORT QgsLayoutTable: public QgsLayoutMultiFrame
     //! Initializes cell style map
     void initStyles();
 
-    bool textRequiresWrapping( QgsRenderContext &context, const QString &text, double columnWidth, const QgsTextFormat &format ) const;
-
-    QStringList wrappedText( QgsRenderContext &context, const QString &value, double columnWidth, const QgsTextFormat &format ) const;
-
     /**
      * Returns the calculated background color for a row and column combination.
      * \param row row number, where -1 is the header row, and 0 is the first body row
      * \param column column number, where 0 is the first column
+     * \param rowSpan number of rows spanned by cell
+     * \param columnSpan number of columns spanned by cell
      * \returns background color, or invalid QColor if no background should be drawn
      */
-    QColor backgroundColor( int row, int column ) const;
+    QColor backgroundColor( int row, int column, int rowSpan = 1, int columnSpan = 1 ) const;
 
     friend class TestQgsLayoutTable;
     friend class TestQgsLayoutManualTable;
