@@ -22,9 +22,9 @@
 #include "qgspointcloudlayer.h"
 #include "qgsrendercontext.h"
 #include "qgspointcloudindex.h"
-#include "qgsstyle.h"
 #include "qgscolorramp.h"
 #include "qgselevationmap.h"
+#include "qgsmeshlayerutils.h"
 #include "qgspointcloudrequest.h"
 #include "qgspointcloudattribute.h"
 #include "qgspointcloudrenderer.h"
@@ -32,22 +32,34 @@
 #include "qgslogger.h"
 #include "qgspointcloudlayerelevationproperties.h"
 #include "qgsmessagelog.h"
-#include "qgscircle.h"
 #include "qgsmapclippingutils.h"
 #include "qgspointcloudblockrequest.h"
+#include "qgsruntimeprofiler.h"
+#include "qgsapplication.h"
+
+#include <delaunator.hpp>
+
 
 QgsPointCloudLayerRenderer::QgsPointCloudLayerRenderer( QgsPointCloudLayer *layer, QgsRenderContext &context )
   : QgsMapLayerRenderer( layer->id(), &context )
   , mLayer( layer )
+  , mLayerName( layer->name() )
   , mLayerAttributes( layer->attributes() )
+  , mSubIndexes( layer && layer->dataProvider() ? layer->dataProvider()->subIndexes() : QVector<QgsPointCloudSubIndex>() )
   , mFeedback( new QgsFeedback )
+  , mEnableProfile( context.flags() & Qgis::RenderContextFlag::RecordProfile )
 {
   // TODO: we must not keep pointer to mLayer (it's dangerous) - we must copy anything we need for rendering
   // or use some locking to prevent read/write from multiple threads
   if ( !mLayer || !mLayer->dataProvider() || !mLayer->renderer() )
     return;
 
+  QElapsedTimer timer;
+  timer.start();
+
   mRenderer.reset( mLayer->renderer()->clone() );
+  if ( !mSubIndexes.isEmpty() )
+    mSubIndexExtentRenderer.reset( new QgsPointCloudExtentRenderer() );
 
   if ( mLayer->dataProvider()->index() )
   {
@@ -66,21 +78,30 @@ QgsPointCloudLayerRenderer::QgsPointCloudLayerRenderer( QgsPointCloudLayer *laye
   mClippingRegions = QgsMapClippingUtils::collectClippingRegionsForLayer( *renderContext(), layer );
 
   mReadyToCompose = false;
+
+  mPreparationTime = timer.elapsed();
 }
 
 bool QgsPointCloudLayerRenderer::render()
 {
+  std::unique_ptr< QgsScopedRuntimeProfile > profile;
+  if ( mEnableProfile )
+  {
+    profile = std::make_unique< QgsScopedRuntimeProfile >( mLayerName, QStringLiteral( "rendering" ), layerId() );
+    if ( mPreparationTime > 0 )
+      QgsApplication::profiler()->record( QObject::tr( "Create renderer" ), mPreparationTime / 1000.0, QStringLiteral( "rendering" ) );
+  }
+
+  std::unique_ptr< QgsScopedRuntimeProfile > preparingProfile;
+  if ( mEnableProfile )
+  {
+    preparingProfile = std::make_unique< QgsScopedRuntimeProfile >( QObject::tr( "Preparing render" ), QStringLiteral( "rendering" ) );
+  }
+
   QgsPointCloudRenderContext context( *renderContext(), mScale, mOffset, mZScale, mZOffset, mFeedback.get() );
 
   // Set up the render configuration options
   QPainter *painter = context.renderContext().painter();
-  bool applyEdl = mRenderer && mRenderer->eyeDomeLightingEnabled();
-
-  if ( QImage *painterImage = dynamic_cast<QImage *>( painter->device() ) )
-  {
-    if ( applyEdl )
-      context.setElevationMap( new QgsElevationMap( painterImage->size() ) );
-  }
 
   QgsScopedQPainterState painterState( painter );
   context.renderContext().setPainterFlagsUsingContext( painter );
@@ -88,7 +109,7 @@ bool QgsPointCloudLayerRenderer::render()
   if ( !mClippingRegions.empty() )
   {
     bool needsPainterClipPath = false;
-    const QPainterPath path = QgsMapClippingUtils::calculatePainterClipRegion( mClippingRegions, *renderContext(), QgsMapLayerType::VectorTileLayer, needsPainterClipPath );
+    const QPainterPath path = QgsMapClippingUtils::calculatePainterClipRegion( mClippingRegions, *renderContext(), Qgis::LayerType::VectorTile, needsPainterClipPath );
     if ( needsPainterClipPath )
       renderContext()->painter()->setClipPath( path, Qt::IntersectClip );
   }
@@ -105,7 +126,8 @@ bool QgsPointCloudLayerRenderer::render()
 
   // TODO cache!?
   QgsPointCloudIndex *pc = mLayer->dataProvider()->index();
-  if ( !pc || !pc->isValid() )
+  if ( mSubIndexes.isEmpty() &&
+       ( !pc || !pc->isValid() ) )
   {
     mReadyToCompose = true;
     return false;
@@ -127,7 +149,7 @@ bool QgsPointCloudLayerRenderer::render()
   if ( !context.renderContext().zRange().isInfinite() ||
        mRenderer->drawOrder2d() == Qgis::PointCloudDrawOrder::BottomToTop ||
        mRenderer->drawOrder2d() == Qgis::PointCloudDrawOrder::TopToBottom ||
-       applyEdl )
+       renderContext()->elevationMap() )
     mAttributes.push_back( QgsPointCloudAttribute( QStringLiteral( "Z" ), QgsPointCloudAttribute::Int32 ) );
 
   // collect attributes required by renderer
@@ -149,7 +171,69 @@ bool QgsPointCloudLayerRenderer::render()
     mAttributes.push_back( mLayerAttributes.at( layerIndex ) );
   }
 
-  QgsPointCloudDataBounds db;
+  QgsRectangle renderExtent;
+  try
+  {
+    renderExtent = renderContext()->coordinateTransform().transformBoundingBox( renderContext()->mapExtent(), Qgis::TransformDirection::Reverse );
+  }
+  catch ( QgsCsException & )
+  {
+    QgsDebugError( QStringLiteral( "Transformation of extent failed!" ) );
+  }
+
+  preparingProfile.reset();
+  std::unique_ptr< QgsScopedRuntimeProfile > renderingProfile;
+  if ( mEnableProfile )
+  {
+    renderingProfile = std::make_unique< QgsScopedRuntimeProfile >( QObject::tr( "Rendering" ), QStringLiteral( "rendering" ) );
+  }
+
+  bool canceled = false;
+  if ( mSubIndexes.isEmpty() )
+  {
+    canceled = !renderIndex( pc );
+  }
+  else
+  {
+    mSubIndexExtentRenderer->startRender( context );
+    for ( const auto &si : mSubIndexes )
+    {
+      if ( canceled )
+        break;
+
+      QgsPointCloudIndex *pc = si.index();
+
+      if ( !renderExtent.intersects( si.extent() ) )
+        continue;
+
+      if ( !pc || !pc->isValid() || renderExtent.width() > si.extent().width() )
+      {
+        // when dealing with virtual point clouds, we want to render the individual extents when zoomed out
+        // and only use the selected renderer when zoomed in
+        mSubIndexExtentRenderer->renderExtent( si.polygonBounds(), context );
+      }
+      else
+      {
+        canceled = !renderIndex( pc );
+      }
+    }
+    mSubIndexExtentRenderer->stopRender( context );
+  }
+
+  mRenderer->stopRender( context );
+  mReadyToCompose = true;
+  return !canceled;
+}
+
+bool QgsPointCloudLayerRenderer::renderIndex( QgsPointCloudIndex *pc )
+{
+  QgsPointCloudRenderContext context( *renderContext(),
+                                      pc->scale(),
+                                      pc->offset(),
+                                      mZScale,
+                                      mZOffset,
+                                      mFeedback.get() );
+
 
 #ifdef QGISDEBUG
   QElapsedTimer t;
@@ -172,7 +256,7 @@ bool QgsPointCloudLayerRenderer::render()
     }
     catch ( QgsCsException & )
     {
-      QgsDebugMsg( QStringLiteral( "Could not transform node extent to map CRS" ) );
+      QgsDebugError( QStringLiteral( "Could not transform node extent to map CRS" ) );
       rootNodeExtentMapCoords = rootNodeExtentLayerCoords;
     }
   }
@@ -186,8 +270,7 @@ bool QgsPointCloudLayerRenderer::render()
   double mapUnitsPerPixel = context.renderContext().mapToPixel().mapUnitsPerPixel();
   if ( ( rootErrorInMapCoordinates < 0.0 ) || ( mapUnitsPerPixel < 0.0 ) || ( maximumError < 0.0 ) )
   {
-    QgsDebugMsg( QStringLiteral( "invalid screen error" ) );
-    mReadyToCompose = true;
+    QgsDebugError( QStringLiteral( "invalid screen error" ) );
     return false;
   }
   double rootErrorPixels = rootErrorInMapCoordinates / mapUnitsPerPixel; // in pixels
@@ -200,7 +283,15 @@ bool QgsPointCloudLayerRenderer::render()
   int nodesDrawn = 0;
   bool canceled = false;
 
-  switch ( mRenderer->drawOrder2d() )
+  Qgis::PointCloudDrawOrder drawOrder = mRenderer->drawOrder2d();
+  if ( mRenderer->renderAsTriangles() )
+  {
+    // Ordered rendering is ignored when drawing as surface, because all points are used for triangulation.
+    // We would need to have a way to detect if a point is occluded by some other points, which may be costly.
+    drawOrder = Qgis::PointCloudDrawOrder::Default;
+  }
+
+  switch ( drawOrder )
   {
     case Qgis::PointCloudDrawOrder::BottomToTop:
     case Qgis::PointCloudDrawOrder::TopToBottom:
@@ -234,26 +325,19 @@ bool QgsPointCloudLayerRenderer::render()
   ( void )nodesDrawn;
 #endif
 
-  mRenderer->stopRender( context );
-
-  if ( applyEdl )
-  {
-    if ( QImage *drawnImage = dynamic_cast<QImage *>( painter->device() ) )
-    {
-      double strength = mRenderer->eyeDomeLightingStrength();
-      double distanceDouble = context.renderContext().convertToPainterUnits(
-                                mRenderer->eyeDomeLightingDistance(), mRenderer->eyeDomeLightingDistanceUnit() );
-      int distance = static_cast<int>( std::round( distanceDouble ) );
-      context.elevationMap()->applyEyeDomeLighting( *drawnImage, distance, strength, context.renderContext().rendererScale() );
-    }
-  }
-
-  mReadyToCompose = true;
   return !canceled;
 }
 
 int QgsPointCloudLayerRenderer::renderNodesSync( const QVector<IndexedPointCloudNode> &nodes, QgsPointCloudIndex *pc, QgsPointCloudRenderContext &context, QgsPointCloudRequest &request, bool &canceled )
 {
+  QPainter *finalPainter = context.renderContext().painter();
+  if ( mRenderer->renderAsTriangles() && context.renderContext().previewRenderPainter() )
+  {
+    // swap out the destination painter for the preview render painter to render points
+    // until the actual triangles are ready to be rendered
+    context.renderContext().setPainter( context.renderContext().previewRenderPainter() );
+  }
+
   int nodesDrawn = 0;
   for ( const IndexedPointCloudNode &n : nodes )
   {
@@ -291,16 +375,35 @@ int QgsPointCloudLayerRenderer::renderNodesSync( const QVector<IndexedPointCloud
       mReadyToCompose = true;
     }
   }
+
+  if ( mRenderer->renderAsTriangles() )
+  {
+    // Switch back from the preview painter to the destination painter to render the triangles
+    context.renderContext().setPainter( finalPainter );
+    renderTriangulatedSurface( context );
+  }
+
   return nodesDrawn;
 }
 
 int QgsPointCloudLayerRenderer::renderNodesAsync( const QVector<IndexedPointCloudNode> &nodes, QgsPointCloudIndex *pc, QgsPointCloudRenderContext &context, QgsPointCloudRequest &request, bool &canceled )
 {
-  int nodesDrawn = 0;
+  if ( nodes.isEmpty() )
+    return 0;
 
   if ( context.feedback() && context.feedback()->isCanceled() )
     return 0;
 
+  QPainter *finalPainter = context.renderContext().painter();
+  if ( mRenderer->renderAsTriangles() && context.renderContext().previewRenderPainter() )
+  {
+    // swap out the destination painter for the preview render painter to render points
+    // until the actual triangles are ready to be rendered
+    context.renderContext().setPainter( context.renderContext().previewRenderPainter() );
+  }
+
+  int nodesDrawn = 0;
+
   // Async loading of nodes
   QVector<QgsPointCloudBlockRequest *> blockRequests;
   QEventLoop loop;
@@ -322,7 +425,7 @@ int QgsPointCloudLayerRenderer::renderNodesAsync( const QVector<IndexedPointClou
       if ( blockRequests.isEmpty() )
         loop.exit();
 
-      std::unique_ptr<QgsPointCloudBlock> block( blockRequest->block() );
+      std::unique_ptr<QgsPointCloudBlock> block( blockRequest->takeBlock() );
 
       blockRequest->deleteLater();
 
@@ -334,7 +437,7 @@ int QgsPointCloudLayerRenderer::renderNodesAsync( const QVector<IndexedPointClou
 
       if ( !block )
       {
-        QgsDebugMsg( QStringLiteral( "Unable to load node %1, error: %2" ).arg( nStr, blockRequest->errorStr() ) );
+        QgsDebugError( QStringLiteral( "Unable to load node %1, error: %2" ).arg( nStr, blockRequest->errorStr() ) );
         return;
       }
 
@@ -364,16 +467,26 @@ int QgsPointCloudLayerRenderer::renderNodesAsync( const QVector<IndexedPointClou
   }
 
   // Wait for all point cloud nodes to finish loading
-  loop.exec();
+  if ( !blockRequests.isEmpty() )
+    loop.exec();
 
   // Rendering may have got canceled and the event loop exited before finished()
   // was called for all blocks, so let's clean up anything that is left
   for ( QgsPointCloudBlockRequest *blockRequest : std::as_const( blockRequests ) )
   {
-    delete blockRequest->block();
+    std::unique_ptr<QgsPointCloudBlock> block = blockRequest->takeBlock();
+    block.reset();
+
     blockRequest->deleteLater();
   }
 
+  if ( mRenderer->renderAsTriangles() )
+  {
+    // Switch back from the preview painter to the destination painter to render the triangles
+    context.renderContext().setPainter( finalPainter );
+    renderTriangulatedSurface( context );
+  }
+
   return nodesDrawn;
 }
 
@@ -503,6 +616,140 @@ int QgsPointCloudLayerRenderer::renderNodesSorted( const QVector<IndexedPointClo
   return blockCount;
 }
 
+inline bool isEdgeTooLong( const QPointF &p1, const QPointF &p2, float length )
+{
+  QPointF p = p1 - p2;
+  return p.x() * p.x() + p.y() * p.y() > length;
+}
+
+static void renderTriangle( QImage &img, QPointF *pts, QRgb c0, QRgb c1, QRgb c2, float horizontalFilter, float *elev, QgsElevationMap *elevationMap )
+{
+  if ( horizontalFilter > 0 )
+  {
+    float filterThreshold2 = horizontalFilter * horizontalFilter;
+    if ( isEdgeTooLong( pts[0], pts[1], filterThreshold2 ) ||
+         isEdgeTooLong( pts[1], pts[2], filterThreshold2 ) ||
+         isEdgeTooLong( pts[2], pts[0], filterThreshold2 ) )
+      return;
+  }
+
+  QgsRectangle screenBBox = QgsMeshLayerUtils::triangleBoundingBox( pts[0], pts[1], pts[2] );
+
+  QSize outputSize = img.size();
+
+  int topLim = std::max( int( screenBBox.yMinimum() ), 0 );
+  int bottomLim = std::min( int( screenBBox.yMaximum() ), outputSize.height() - 1 );
+  int leftLim = std::max( int( screenBBox.xMinimum() ), 0 );
+  int rightLim = std::min( int( screenBBox.xMaximum() ), outputSize.width() - 1 );
+
+  int red0 = qRed( c0 ), green0 = qGreen( c0 ), blue0 = qBlue( c0 );
+  int red1 = qRed( c1 ), green1 = qGreen( c1 ), blue1 = qBlue( c1 );
+  int red2 = qRed( c2 ), green2 = qGreen( c2 ), blue2 = qBlue( c2 );
+
+  QRgb *elevData = elevationMap ? elevationMap->rawElevationImageData() : nullptr;
+
+  for ( int j = topLim; j <= bottomLim; j++ )
+  {
+    QRgb *scanLine = ( QRgb * ) img.scanLine( j );
+    QRgb *elevScanLine = elevData ? elevData + static_cast<size_t>( outputSize.width() * j ) : nullptr;
+    for ( int k = leftLim; k <= rightLim; k++ )
+    {
+      QPointF pt( k, j );
+      double lam1, lam2, lam3;
+      if ( !QgsMeshLayerUtils::calculateBarycentricCoordinates( pts[0], pts[1], pts[2], pt, lam3, lam2, lam1 ) )
+        continue;
+
+      // interpolate color
+      int r = static_cast<int>( red0 * lam1 + red1 * lam2 + red2 * lam3 );
+      int g = static_cast<int>( green0 * lam1 + green1 * lam2 + green2 * lam3 );
+      int b = static_cast<int>( blue0 * lam1 + blue1 * lam2 + blue2 * lam3 );
+      scanLine[k] = qRgb( r, g, b );
+
+      // interpolate elevation - in case we are doing global map shading
+      if ( elevScanLine )
+      {
+        float z = static_cast<float>( elev[0] * lam1 + elev[1] * lam2 + elev[2] * lam3 );
+        elevScanLine[k] = QgsElevationMap::encodeElevation( z );
+      }
+    }
+  }
+}
+
+void QgsPointCloudLayerRenderer::renderTriangulatedSurface( QgsPointCloudRenderContext &context )
+{
+  const QgsPointCloudRenderContext::TriangulationData &triangulation = context.triangulationData();
+  const std::vector<double> &points = triangulation.points;
+
+  // Delaunator would crash if it gets less than three points
+  if ( points.size() < 3 )
+  {
+    QgsDebugMsgLevel( QStringLiteral( "Need at least 3 points to triangulate" ), 4 );
+    return;
+  }
+
+  std::unique_ptr<delaunator::Delaunator> delaunator;
+  try
+  {
+    delaunator.reset( new delaunator::Delaunator( points ) );
+  }
+  catch ( std::exception & )
+  {
+    // something went wrong, better to retrieve initial state
+    QgsDebugMsgLevel( QStringLiteral( "Error with triangulation" ), 4 );
+    return;
+  }
+
+  float horizontalFilter = 0;
+  if ( mRenderer->horizontalTriangleFilter() )
+  {
+    horizontalFilter = static_cast<float>( renderContext()->convertToPainterUnits(
+        mRenderer->horizontalTriangleFilterThreshold(), mRenderer->horizontalTriangleFilterUnit() ) );
+  }
+
+  QImage img( context.renderContext().deviceOutputSize(), QImage::Format_ARGB32_Premultiplied );
+  img.setDevicePixelRatio( context.renderContext().devicePixelRatio() );
+  img.fill( 0 );
+
+  const std::vector<size_t> &triangleIndexes = delaunator->triangles;
+  QPainter *painter = context.renderContext().painter();
+  QgsElevationMap *elevationMap = context.renderContext().elevationMap();
+  QPointF triangle[3];
+  float elev[3] {0, 0, 0};
+  for ( size_t i = 0; i < triangleIndexes.size(); i += 3 )
+  {
+    size_t v0 = triangleIndexes[i], v1 = triangleIndexes[i + 1], v2 = triangleIndexes[i + 2];
+    triangle[0].rx() = points[v0 * 2];
+    triangle[0].ry() = points[v0 * 2 + 1];
+    triangle[1].rx() = points[v1 * 2];
+    triangle[1].ry() = points[v1 * 2 + 1];
+    triangle[2].rx() = points[v2 * 2];
+    triangle[2].ry() = points[v2 * 2 + 1];
+
+    if ( elevationMap )
+    {
+      elev[0] = triangulation.elevations[v0];
+      elev[1] = triangulation.elevations[v1];
+      elev[2] = triangulation.elevations[v2];
+    }
+
+    QRgb c0 = triangulation.colors[v0], c1 = triangulation.colors[v1], c2 = triangulation.colors[v2];
+    renderTriangle( img, triangle, c0, c1, c2, horizontalFilter, elev, elevationMap );
+  }
+
+  painter->drawImage( 0, 0, img );
+}
+
+Qgis::MapLayerRendererFlags QgsPointCloudLayerRenderer::flags() const
+{
+  // when rendering as triangles we still want to show temporary incremental renders as points until
+  // the final triangulated surface is ready, which may be slow
+  // So we request here a preview render image for the temporary incremental updates:
+  if ( mRenderer->renderAsTriangles() )
+    return Qgis::MapLayerRendererFlag::RenderPartialOutputs | Qgis::MapLayerRendererFlag::RenderPartialOutputOverPreviousCachedImage;
+
+  return Qgis::MapLayerRendererFlags();
+}
+
 bool QgsPointCloudLayerRenderer::forceRasterRender() const
 {
   // unless we are using the extent only renderer, point cloud layers should always be rasterized -- we don't want to export points as vectors
