@@ -100,7 +100,7 @@ void QgsPointCloudRenderer::startRender( QgsPointCloudRenderContext &context )
   }
 #endif
 
-  mPainterPenWidth = context.renderContext().convertToPainterUnits( pointSize(), pointSizeUnit(), pointSizeMapUnitScale() );
+  mDefaultPainterPenWidth = context.renderContext().convertToPainterUnits( pointSize(), pointSizeUnit(), pointSizeMapUnitScale() );
 
   switch ( mPointSymbol )
   {
@@ -162,6 +162,11 @@ QStringList QgsPointCloudRenderer::legendRuleKeys() const
 }
 
 void QgsPointCloudRenderer::drawPointToElevationMap( double x, double y, double z, QgsPointCloudRenderContext &context ) const
+{
+  drawPointToElevationMap( x, y, z, mDefaultPainterPenWidth, context );
+}
+
+void QgsPointCloudRenderer::drawPointToElevationMap( double x, double y, double z, int width, QgsPointCloudRenderContext &context ) const
 {
   const QPointF originalXY( x, y );
   context.renderContext().mapToPixel().transformInPlace( x, y );
@@ -171,17 +176,17 @@ void QgsPointCloudRenderer::drawPointToElevationMap( double x, double y, double
   switch ( mPointSymbol )
   {
     case Qgis::PointCloudSymbol::Square:
-      elevationPainter->fillRect( QRectF( x - mPainterPenWidth * 0.5,
-                                          y - mPainterPenWidth * 0.5,
-                                          mPainterPenWidth, mPainterPenWidth ), brush );
+      elevationPainter->fillRect( QRectF( x - width * 0.5,
+                                          y - width * 0.5,
+                                          width, width ), brush );
       break;
 
     case Qgis::PointCloudSymbol::Circle:
       elevationPainter->setBrush( brush );
       elevationPainter->setPen( Qt::NoPen );
-      elevationPainter->drawEllipse( QRectF( x - mPainterPenWidth * 0.5,
-                                             y - mPainterPenWidth * 0.5,
-                                             mPainterPenWidth, mPainterPenWidth ) );
+      elevationPainter->drawEllipse( QRectF( x - width * 0.5,
+                                             y - width * 0.5,
+                                             width, width ) );
       break;
   };
 }
@@ -195,6 +200,11 @@ void QgsPointCloudRenderer::copyCommonProperties( QgsPointCloudRenderer *destina
   destination->setMaximumScreenErrorUnit( mMaximumScreenErrorUnit );
   destination->setPointSymbol( mPointSymbol );
   destination->setDrawOrder2d( mDrawOrder2d );
+
+  destination->setRenderAsTriangles( mRenderAsTriangles );
+  destination->setHorizontalTriangleFilter( mHorizontalTriangleFilter );
+  destination->setHorizontalTriangleFilterThreshold( mHorizontalTriangleFilterThreshold );
+  destination->setHorizontalTriangleFilterUnit( mHorizontalTriangleFilterUnit );
 }
 
 void QgsPointCloudRenderer::restoreCommonProperties( const QDomElement &element, const QgsReadWriteContext & )
@@ -207,6 +217,11 @@ void QgsPointCloudRenderer::restoreCommonProperties( const QDomElement &element,
   mMaximumScreenErrorUnit = QgsUnitTypes::decodeRenderUnit( element.attribute( QStringLiteral( "maximumScreenErrorUnit" ), QStringLiteral( "MM" ) ) );
   mPointSymbol = static_cast< Qgis::PointCloudSymbol >( element.attribute( QStringLiteral( "pointSymbol" ), QStringLiteral( "0" ) ).toInt() );
   mDrawOrder2d = static_cast< Qgis::PointCloudDrawOrder >( element.attribute( QStringLiteral( "drawOrder2d" ), QStringLiteral( "0" ) ).toInt() );
+
+  mRenderAsTriangles = element.attribute( QStringLiteral( "renderAsTriangles" ), QStringLiteral( "0" ) ).toInt();
+  mHorizontalTriangleFilter = element.attribute( QStringLiteral( "horizontalTriangleFilter" ), QStringLiteral( "0" ) ).toInt();
+  mHorizontalTriangleFilterThreshold = element.attribute( QStringLiteral( "horizontalTriangleFilterThreshold" ), QStringLiteral( "5" ) ).toDouble();
+  mHorizontalTriangleFilterUnit = QgsUnitTypes::decodeRenderUnit( element.attribute( QStringLiteral( "horizontalTriangleFilterUnit" ), QStringLiteral( "MM" ) ) );
 }
 
 void QgsPointCloudRenderer::saveCommonProperties( QDomElement &element, const QgsReadWriteContext & ) const
@@ -219,6 +234,11 @@ void QgsPointCloudRenderer::saveCommonProperties( QDomElement &element, const Qg
   element.setAttribute( QStringLiteral( "maximumScreenErrorUnit" ), QgsUnitTypes::encodeUnit( mMaximumScreenErrorUnit ) );
   element.setAttribute( QStringLiteral( "pointSymbol" ), QString::number( static_cast< int >( mPointSymbol ) ) );
   element.setAttribute( QStringLiteral( "drawOrder2d" ), QString::number( static_cast< int >( mDrawOrder2d ) ) );
+
+  element.setAttribute( QStringLiteral( "renderAsTriangles" ), QString::number( static_cast< int >( mRenderAsTriangles ) ) );
+  element.setAttribute( QStringLiteral( "horizontalTriangleFilter" ), QString::number( static_cast< int >( mHorizontalTriangleFilter ) ) );
+  element.setAttribute( QStringLiteral( "horizontalTriangleFilterThreshold" ), qgsDoubleToString( mHorizontalTriangleFilterThreshold ) );
+  element.setAttribute( QStringLiteral( "horizontalTriangleFilterUnit" ), QgsUnitTypes::encodeUnit( mHorizontalTriangleFilterUnit ) );
 }
 
 Qgis::PointCloudSymbol QgsPointCloudRenderer::pointSymbol() const
@@ -245,48 +265,33 @@ QVector<QVariantMap> QgsPointCloudRenderer::identify( QgsPointCloudLayer *layer,
 {
   QVector<QVariantMap> selectedPoints;
 
-  QgsPointCloudIndex *index = layer->dataProvider()->index();
-
-  if ( !index || !index->isValid() )
-    return selectedPoints;
-
-  const IndexedPointCloudNode root = index->root();
-
   const double maxErrorPixels = renderContext.convertToPainterUnits( maximumScreenError(), maximumScreenErrorUnit() );// in pixels
 
-  const QgsRectangle rootNodeExtentLayerCoords = index->nodeMapExtent( root );
-  QgsRectangle rootNodeExtentMapCoords;
+  const QgsRectangle layerExtentLayerCoords = layer->dataProvider()->extent();
+  QgsRectangle layerExtentMapCoords = layerExtentLayerCoords;
   if ( !renderContext.coordinateTransform().isShortCircuited() )
   {
     try
     {
       QgsCoordinateTransform extentTransform = renderContext.coordinateTransform();
       extentTransform.setBallparkTransformsAreAppropriate( true );
-      rootNodeExtentMapCoords = extentTransform.transformBoundingBox( rootNodeExtentLayerCoords );
+      layerExtentMapCoords = extentTransform.transformBoundingBox( layerExtentLayerCoords );
     }
     catch ( QgsCsException & )
     {
       QgsDebugError( QStringLiteral( "Could not transform node extent to map CRS" ) );
-      rootNodeExtentMapCoords = rootNodeExtentLayerCoords;
     }
   }
-  else
-  {
-    rootNodeExtentMapCoords = rootNodeExtentLayerCoords;
-  }
-
-  const double rootErrorInMapCoordinates = rootNodeExtentMapCoords.width() / index->span();
-  const double rootErrorInLayerCoordinates = rootNodeExtentLayerCoords.width() / index->span();
 
   const double mapUnitsPerPixel = renderContext.mapToPixel().mapUnitsPerPixel();
-  if ( ( rootErrorInMapCoordinates < 0.0 ) || ( mapUnitsPerPixel < 0.0 ) || ( maxErrorPixels < 0.0 ) )
+  if ( ( mapUnitsPerPixel < 0.0 ) || ( maxErrorPixels < 0.0 ) )
   {
     QgsDebugError( QStringLiteral( "invalid screen error" ) );
     return selectedPoints;
   }
 
   const double maxErrorInMapCoordinates = maxErrorPixels * mapUnitsPerPixel;
-  const double maxErrorInLayerCoordinates = maxErrorInMapCoordinates * rootErrorInLayerCoordinates / rootErrorInMapCoordinates;
+  const double maxErrorInLayerCoordinates = maxErrorInMapCoordinates * layerExtentLayerCoords.width() / layerExtentMapCoords.width();
 
   QgsGeometry selectionGeometry = geometry;
   if ( geometry.type() == Qgis::GeometryType::Point )
