@@ -77,6 +77,11 @@ QString QgsProcessingAlgorithm::helpUrl() const
   return QString();
 }
 
+Qgis::ProcessingAlgorithmDocumentationFlags QgsProcessingAlgorithm::documentationFlags() const
+{
+  return Qgis::ProcessingAlgorithmDocumentationFlags();
+}
+
 QIcon QgsProcessingAlgorithm::icon() const
 {
   return QgsApplication::getThemeIcon( "/processingAlgorithm.svg" );
@@ -87,9 +92,9 @@ QString QgsProcessingAlgorithm::svgIconPath() const
   return QgsApplication::iconPath( QStringLiteral( "processingAlgorithm.svg" ) );
 }
 
-QgsProcessingAlgorithm::Flags QgsProcessingAlgorithm::flags() const
+Qgis::ProcessingAlgorithmFlags QgsProcessingAlgorithm::flags() const
 {
-  return FlagSupportsBatch | FlagCanCancel;
+  return Qgis::ProcessingAlgorithmFlag::SupportsBatch | Qgis::ProcessingAlgorithmFlag::CanCancel;
 }
 
 bool QgsProcessingAlgorithm::canExecute( QString * ) const
@@ -183,7 +188,7 @@ QgsExpressionContext QgsProcessingAlgorithm::createExpressionContext( const QVar
 
 bool QgsProcessingAlgorithm::validateInputCrs( const QVariantMap &parameters, QgsProcessingContext &context ) const
 {
-  if ( !( flags() & FlagRequiresMatchingCrs ) )
+  if ( !( flags() & Qgis::ProcessingAlgorithmFlag::RequiresMatchingCrs ) )
   {
     // I'm a well behaved algorithm - I take work AWAY from users!
     return true;
@@ -296,7 +301,7 @@ QString QgsProcessingAlgorithm::asPythonCommand( const QVariantMap &parameters,
   QStringList parts;
   for ( const QgsProcessingParameterDefinition *def : mParameters )
   {
-    if ( def->flags() & QgsProcessingParameterDefinition::FlagHidden )
+    if ( def->flags() & Qgis::ProcessingParameterFlag::Hidden )
       continue;
 
     if ( !parameters.contains( def->name() ) )
@@ -319,7 +324,7 @@ QString QgsProcessingAlgorithm::asQgisProcessCommand( const QVariantMap &paramet
 
   QgsProcessingContext::ProcessArgumentFlags argumentFlags;
   // we only include the project path argument if a project is actually required by the algorithm
-  if ( flags() & FlagRequiresProject )
+  if ( flags() & Qgis::ProcessingAlgorithmFlag::RequiresProject )
     argumentFlags |= QgsProcessingContext::ProcessArgumentFlag::IncludeProjectPath;
 
   parts.append( context.asQgisProcessArguments( argumentFlags ) );
@@ -342,7 +347,7 @@ QString QgsProcessingAlgorithm::asQgisProcessCommand( const QVariantMap &paramet
 
   for ( const QgsProcessingParameterDefinition *def : mParameters )
   {
-    if ( def->flags() & QgsProcessingParameterDefinition::FlagHidden )
+    if ( def->flags() & Qgis::ProcessingParameterFlag::Hidden )
       continue;
 
     if ( !parameters.contains( def->name() ) )
@@ -366,13 +371,13 @@ QVariantMap QgsProcessingAlgorithm::asMap( const QVariantMap &parameters, QgsPro
   QVariantMap properties = context.exportToMap();
 
   // we only include the project path argument if a project is actually required by the algorithm
-  if ( !( flags() & FlagRequiresProject ) )
+  if ( !( flags() & Qgis::ProcessingAlgorithmFlag::RequiresProject ) )
     properties.remove( QStringLiteral( "project_path" ) );
 
   QVariantMap paramValues;
   for ( const QgsProcessingParameterDefinition *def : mParameters )
   {
-    if ( def->flags() & QgsProcessingParameterDefinition::FlagHidden )
+    if ( def->flags() & Qgis::ProcessingParameterFlag::Hidden )
       continue;
 
     if ( !parameters.contains( def->name() ) )
@@ -483,7 +488,7 @@ int QgsProcessingAlgorithm::countVisibleParameters() const
   int count = 0;
   for ( const QgsProcessingParameterDefinition *def : mParameters )
   {
-    if ( !( def->flags() & QgsProcessingParameterDefinition::FlagHidden ) )
+    if ( !( def->flags() & Qgis::ProcessingParameterFlag::Hidden ) )
       count++;
   }
   return count;
@@ -536,24 +541,28 @@ QVariantMap QgsProcessingAlgorithm::run( const QVariantMap &parameters, QgsProce
     return QVariantMap();
 
   QVariantMap runRes;
+  bool success = false;
   try
   {
     runRes = alg->runPrepared( parameters, context, feedback );
+    success = true;
   }
   catch ( QgsProcessingException &e )
   {
     if ( !catchExceptions )
+    {
+      alg->postProcess( context, feedback, false );
       throw e;
+    }
 
     QgsMessageLog::logMessage( e.what(), QObject::tr( "Processing" ), Qgis::MessageLevel::Critical );
     feedback->reportError( e.what() );
-    return QVariantMap();
   }
 
   if ( ok )
-    *ok = true;
+    *ok = success;
 
-  QVariantMap ppRes = alg->postProcess( context, feedback );
+  QVariantMap ppRes = alg->postProcess( context, feedback, success );
   if ( !ppRes.isEmpty() )
     return ppRes;
   else
@@ -604,15 +613,30 @@ QVariantMap QgsProcessingAlgorithm::runPrepared( const QVariantMap &parameters,
     mLocalContext.reset( new QgsProcessingContext() );
     // copy across everything we can safely do from the passed context
     mLocalContext->copyThreadSafeSettings( context );
+
     // and we'll run the actual algorithm processing using the local thread safe context
     runContext = mLocalContext.get();
   }
 
+  std::unique_ptr< QgsProcessingModelInitialRunConfig > modelConfig = context.takeModelInitialRunConfig();
+  if ( modelConfig )
+  {
+    std::unique_ptr< QgsMapLayerStore > modelPreviousLayerStore = modelConfig->takePreviousLayerStore();
+    if ( modelPreviousLayerStore )
+    {
+      // move layers from previous layer store to context's temporary layer store, in a thread-safe way
+      Q_ASSERT_X( !modelPreviousLayerStore->thread(), "QgsProcessingAlgorithm::runPrepared", "QgsProcessingModelConfig::modelPreviousLayerStore must have been pushed to a nullptr thread" );
+      modelPreviousLayerStore->moveToThread( QThread::currentThread() );
+      runContext->temporaryLayerStore()->transferLayersFromStore( modelPreviousLayerStore.get() );
+    }
+    runContext->setModelInitialRunConfig( std::move( modelConfig ) );
+  }
+
+  mHasExecuted = true;
   try
   {
     QVariantMap runResults = processAlgorithm( parameters, *runContext, feedback );
 
-    mHasExecuted = true;
     if ( mLocalContext )
     {
       // ok, time to clean things up. We need to push the temporary context back into
@@ -634,7 +658,7 @@ QVariantMap QgsProcessingAlgorithm::runPrepared( const QVariantMap &parameters,
   }
 }
 
-QVariantMap QgsProcessingAlgorithm::postProcess( QgsProcessingContext &context, QgsProcessingFeedback *feedback )
+QVariantMap QgsProcessingAlgorithm::postProcess( QgsProcessingContext &context, QgsProcessingFeedback *feedback, bool runResult )
 {
   // cppcheck-suppress assertWithSideEffect
   Q_ASSERT_X( QThread::currentThread() == context.temporaryLayerStore()->thread(), "QgsProcessingAlgorithm::postProcess", "postProcess() must be called from the same thread the context was created in" );
@@ -652,14 +676,21 @@ QVariantMap QgsProcessingAlgorithm::postProcess( QgsProcessingContext &context,
   }
 
   mHasPostProcessed = true;
-  try
+  if ( runResult )
   {
-    return postProcessAlgorithm( context, feedback );
+    try
+    {
+      return postProcessAlgorithm( context, feedback );
+    }
+    catch ( QgsProcessingException &e )
+    {
+      QgsMessageLog::logMessage( e.what(), QObject::tr( "Processing" ), Qgis::MessageLevel::Critical );
+      feedback->reportError( e.what() );
+      return QVariantMap();
+    }
   }
-  catch ( QgsProcessingException &e )
+  else
   {
-    QgsMessageLog::logMessage( e.what(), QObject::tr( "Processing" ), Qgis::MessageLevel::Critical );
-    feedback->reportError( e.what() );
     return QVariantMap();
   }
 }
@@ -899,20 +930,20 @@ QString QgsProcessingAlgorithm::invalidSourceError( const QVariantMap &parameter
   else
   {
     QVariant var = parameters.value( name );
-    if ( var.userType() == QMetaType::type( "QgsProcessingFeatureSourceDefinition" ) )
+    if ( var.userType() == qMetaTypeId<QgsProcessingFeatureSourceDefinition>() )
     {
       QgsProcessingFeatureSourceDefinition fromVar = qvariant_cast<QgsProcessingFeatureSourceDefinition>( var );
       var = fromVar.source;
     }
-    else if ( var.userType() == QMetaType::type( "QgsProcessingOutputLayerDefinition" ) )
+    else if ( var.userType() == qMetaTypeId<QgsProcessingOutputLayerDefinition>() )
     {
       QgsProcessingOutputLayerDefinition fromVar = qvariant_cast<QgsProcessingOutputLayerDefinition>( var );
       var = fromVar.sink;
     }
-    if ( var.userType() == QMetaType::type( "QgsProperty" ) )
+    if ( var.userType() == qMetaTypeId<QgsProperty>() )
     {
       QgsProperty p = var.value< QgsProperty >();
-      if ( p.propertyType() == QgsProperty::StaticProperty )
+      if ( p.propertyType() == Qgis::PropertyType::Static )
       {
         var = p.staticValue();
       }
@@ -931,10 +962,10 @@ QString QgsProcessingAlgorithm::invalidRasterError( const QVariantMap &parameter
   else
   {
     QVariant var = parameters.value( name );
-    if ( var.userType() == QMetaType::type( "QgsProperty" ) )
+    if ( var.userType() == qMetaTypeId<QgsProperty>() )
     {
       QgsProperty p = var.value< QgsProperty >();
-      if ( p.propertyType() == QgsProperty::StaticProperty )
+      if ( p.propertyType() == Qgis::PropertyType::Static )
       {
         var = p.staticValue();
       }
@@ -953,15 +984,15 @@ QString QgsProcessingAlgorithm::invalidSinkError( const QVariantMap &parameters,
   else
   {
     QVariant var = parameters.value( name );
-    if ( var.userType() == QMetaType::type( "QgsProcessingOutputLayerDefinition" ) )
+    if ( var.userType() == qMetaTypeId<QgsProcessingOutputLayerDefinition>() )
     {
       QgsProcessingOutputLayerDefinition fromVar = qvariant_cast<QgsProcessingOutputLayerDefinition>( var );
       var = fromVar.sink;
     }
-    if ( var.userType() == QMetaType::type( "QgsProperty" ) )
+    if ( var.userType() == qMetaTypeId<QgsProperty>() )
     {
       QgsProperty p = var.value< QgsProperty >();
-      if ( p.propertyType() == QgsProperty::StaticProperty )
+      if ( p.propertyType() == Qgis::PropertyType::Static )
       {
         var = p.staticValue();
       }
@@ -980,10 +1011,10 @@ QString QgsProcessingAlgorithm::invalidPointCloudError( const QVariantMap &param
   else
   {
     QVariant var = parameters.value( name );
-    if ( var.userType() == QMetaType::type( "QgsProperty" ) )
+    if ( var.userType() == qMetaTypeId<QgsProperty>() )
     {
       QgsProperty p = var.value< QgsProperty >();
-      if ( p.propertyType() == QgsProperty::StaticProperty )
+      if ( p.propertyType() == Qgis::PropertyType::Static )
       {
         var = p.staticValue();
       }
@@ -1039,10 +1070,10 @@ bool QgsProcessingAlgorithm::createAutoOutputForParameter( QgsProcessingParamete
 // QgsProcessingFeatureBasedAlgorithm
 //
 
-QgsProcessingAlgorithm::Flags QgsProcessingFeatureBasedAlgorithm::flags() const
+Qgis::ProcessingAlgorithmFlags QgsProcessingFeatureBasedAlgorithm::flags() const
 {
-  Flags f = QgsProcessingAlgorithm::flags();
-  f |= QgsProcessingAlgorithm::FlagSupportsInPlaceEdits;
+  Qgis::ProcessingAlgorithmFlags f = QgsProcessingAlgorithm::flags();
+  f |= Qgis::ProcessingAlgorithmFlag::SupportsInPlaceEdits;
   return f;
 }
 
@@ -1068,14 +1099,14 @@ QList<int> QgsProcessingFeatureBasedAlgorithm::inputLayerTypes() const
   return QList<int>();
 }
 
-QgsProcessing::SourceType QgsProcessingFeatureBasedAlgorithm::outputLayerType() const
+Qgis::ProcessingSourceType QgsProcessingFeatureBasedAlgorithm::outputLayerType() const
 {
-  return QgsProcessing::TypeVectorAnyGeometry;
+  return Qgis::ProcessingSourceType::VectorAnyGeometry;
 }
 
-QgsProcessingFeatureSource::Flag QgsProcessingFeatureBasedAlgorithm::sourceFlags() const
+Qgis::ProcessingFeatureSourceFlags QgsProcessingFeatureBasedAlgorithm::sourceFlags() const
 {
-  return static_cast<QgsProcessingFeatureSource::Flag>( 0 );
+  return Qgis::ProcessingFeatureSourceFlags();
 }
 
 QgsFeatureSink::SinkFlags QgsProcessingFeatureBasedAlgorithm::sinkFlags() const
@@ -1175,11 +1206,11 @@ bool QgsProcessingFeatureBasedAlgorithm::supportInPlaceEdit( const QgsMapLayer *
 
   Qgis::GeometryType inPlaceGeometryType = layer->geometryType();
   if ( !inputLayerTypes().empty() &&
-       !inputLayerTypes().contains( QgsProcessing::TypeVector ) &&
-       !inputLayerTypes().contains( QgsProcessing::TypeVectorAnyGeometry ) &&
-       ( ( inPlaceGeometryType == Qgis::GeometryType::Polygon && !inputLayerTypes().contains( QgsProcessing::TypeVectorPolygon ) ) ||
-         ( inPlaceGeometryType == Qgis::GeometryType::Line && !inputLayerTypes().contains( QgsProcessing::TypeVectorLine ) ) ||
-         ( inPlaceGeometryType == Qgis::GeometryType::Point && !inputLayerTypes().contains( QgsProcessing::TypeVectorPoint ) ) ) )
+       !inputLayerTypes().contains( static_cast< int >( Qgis::ProcessingSourceType::Vector ) ) &&
+       !inputLayerTypes().contains( static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) &&
+       ( ( inPlaceGeometryType == Qgis::GeometryType::Polygon && !inputLayerTypes().contains( static_cast< int >( Qgis::ProcessingSourceType::VectorPolygon ) ) ) ||
+         ( inPlaceGeometryType == Qgis::GeometryType::Line && !inputLayerTypes().contains( static_cast< int >( Qgis::ProcessingSourceType::VectorLine ) ) ) ||
+         ( inPlaceGeometryType == Qgis::GeometryType::Point && !inputLayerTypes().contains( static_cast< int >( Qgis::ProcessingSourceType::VectorPoint ) ) ) ) )
     return false;
 
   Qgis::WkbType type = Qgis::WkbType::Unknown;
@@ -1212,13 +1243,13 @@ QgsProcessingAlgorithm::VectorProperties QgsProcessingFeatureBasedAlgorithm::sin
   QgsProcessingAlgorithm::VectorProperties result;
   if ( sink == QLatin1String( "OUTPUT" ) )
   {
-    if ( sourceProperties.value( QStringLiteral( "INPUT" ) ).availability == QgsProcessingAlgorithm::Available )
+    if ( sourceProperties.value( QStringLiteral( "INPUT" ) ).availability == Qgis::ProcessingPropertyAvailability::Available )
     {
       const VectorProperties inputProps = sourceProperties.value( QStringLiteral( "INPUT" ) );
       result.fields = outputFields( inputProps.fields );
       result.crs = outputCrs( inputProps.crs );
       result.wkbType = outputWkbType( inputProps.wkbType );
-      result.availability = Available;
+      result.availability = Qgis::ProcessingPropertyAvailability::Available;
       return result;
     }
     else
@@ -1229,7 +1260,7 @@ QgsProcessingAlgorithm::VectorProperties QgsProcessingFeatureBasedAlgorithm::sin
         result.fields = outputFields( source->fields() );
         result.crs = outputCrs( source->sourceCrs() );
         result.wkbType = outputWkbType( source->wkbType() );
-        result.availability = Available;
+        result.availability = Qgis::ProcessingPropertyAvailability::Available;
         return result;
       }
     }
