@@ -14,6 +14,7 @@
 ***************************************************************************/
 
 #include "qgsmaplayerproxymodel.h"
+#include "moc_qgsmaplayerproxymodel.cpp"
 #include "qgsmaplayermodel.h"
 #include "qgsmaplayer.h"
 #include "qgsproject.h"
@@ -40,6 +41,9 @@ QgsMapLayerProxyModel *QgsMapLayerProxyModel::setFilters( Qgis::LayerFilters fil
 
 bool QgsMapLayerProxyModel::layerMatchesFilters( const QgsMapLayer *layer, const Qgis::LayerFilters &filters )
 {
+  if ( filters.testFlag( Qgis::LayerFilter::WritableLayer ) && layer->readOnly() )
+    return false;
+
   if ( filters.testFlag( Qgis::LayerFilter::All ) )
     return true;
 
@@ -58,8 +62,7 @@ bool QgsMapLayerProxyModel::layerMatchesFilters( const QgsMapLayer *layer, const
   const bool detectGeometry = filters.testFlag( Qgis::LayerFilter::NoGeometry ) ||
                               filters.testFlag( Qgis::LayerFilter::PointLayer ) ||
                               filters.testFlag( Qgis::LayerFilter::LineLayer ) ||
-                              filters.testFlag( Qgis::LayerFilter::PolygonLayer ) ||
-                              filters.testFlag( Qgis::LayerFilter::HasGeometry );
+                              filters.testFlag( Qgis::LayerFilter::PolygonLayer );
   if ( detectGeometry && layer->type() == Qgis::LayerType::Vector )
   {
     if ( const QgsVectorLayer *vl = qobject_cast<const QgsVectorLayer *>( layer ) )
@@ -115,7 +118,7 @@ void QgsMapLayerProxyModel::setExceptedLayerIds( const QStringList &ids )
   const auto constIds = ids;
   for ( const QString &id : constIds )
   {
-    QgsMapLayer *l = QgsProject::instance()->mapLayer( id );
+    QgsMapLayer *l = QgsProject::instance()->mapLayer( id ); // skip-keyword-check
     if ( l )
       mExceptList << l;
   }
@@ -153,9 +156,6 @@ bool QgsMapLayerProxyModel::acceptsLayer( QgsMapLayer *layer ) const
   if ( layer->dataProvider() && mExcludedProviders.contains( layer->providerType() ) )
     return false;
 
-  if ( mFilters.testFlag( Qgis::LayerFilter::WritableLayer ) && layer->readOnly() )
-    return false;
-
   if ( !layer->name().contains( mFilterString, Qt::CaseInsensitive ) )
     return false;
 
@@ -175,8 +175,8 @@ bool QgsMapLayerProxyModel::filterAcceptsRow( int source_row, const QModelIndex
 
   const QModelIndex index = sourceModel()->index( source_row, 0, source_parent );
 
-  if ( sourceModel()->data( index, QgsMapLayerModel::EmptyRole ).toBool()
-       || sourceModel()->data( index, QgsMapLayerModel::AdditionalRole ).toBool() )
+  if ( sourceModel()->data( index, static_cast< int >( QgsMapLayerModel::CustomRole::Empty ) ).toBool()
+       || sourceModel()->data( index, static_cast< int >( QgsMapLayerModel::CustomRole::Additional ) ).toBool() )
     return true;
 
   return acceptsLayer( static_cast<QgsMapLayer *>( index.internalPointer() ) );
@@ -185,14 +185,14 @@ bool QgsMapLayerProxyModel::filterAcceptsRow( int source_row, const QModelIndex
 bool QgsMapLayerProxyModel::lessThan( const QModelIndex &left, const QModelIndex &right ) const
 {
   // empty row is always first
-  if ( sourceModel()->data( left, QgsMapLayerModel::EmptyRole ).toBool() )
+  if ( sourceModel()->data( left, static_cast< int >( QgsMapLayerModel::CustomRole::Empty ) ).toBool() )
     return true;
-  else if ( sourceModel()->data( right, QgsMapLayerModel::EmptyRole ).toBool() )
+  else if ( sourceModel()->data( right, static_cast< int >( QgsMapLayerModel::CustomRole::Empty ) ).toBool() )
     return false;
 
   // additional rows are always last
-  const bool leftAdditional = sourceModel()->data( left, QgsMapLayerModel::AdditionalRole ).toBool();
-  const bool rightAdditional = sourceModel()->data( right, QgsMapLayerModel::AdditionalRole ).toBool();
+  const bool leftAdditional = sourceModel()->data( left, static_cast< int >( QgsMapLayerModel::CustomRole::Additional ) ).toBool();
+  const bool rightAdditional = sourceModel()->data( right, static_cast< int >( QgsMapLayerModel::CustomRole::Additional ) ).toBool();
 
   if ( leftAdditional && !rightAdditional )
     return false;
