@@ -17,7 +17,7 @@
 #define QGSOPTIONAL_H
 
 #include "qgis_core.h"
-
+#include "qgis_sip.h"
 
 /**
  * \ingroup core
@@ -30,7 +30,6 @@
  * \note For Python you need to use implementations for specific template classes
  * \note Not available in Python bindings (although SIP file is present for specific implementations).
  *
- * \since QGIS 3.0
  */
 template<typename T>
 class CORE_EXPORT QgsOptional
@@ -66,7 +65,6 @@ class CORE_EXPORT QgsOptional
      * This will compare the enabled flag and call the == operator
      * of the contained class.
      *
-     * \since QGIS 3.0
      */
     bool operator== ( const QgsOptional<T> &other ) const
     {
@@ -76,7 +74,7 @@ class CORE_EXPORT QgsOptional
     /**
      * Boolean operator. Will return TRUE if this optional is enabled.
      */
-    operator bool() const
+    explicit operator bool() const SIP_SKIP
     {
       return mEnabled;
     }
@@ -84,7 +82,6 @@ class CORE_EXPORT QgsOptional
     /**
      * Check if this optional is enabled
      *
-     * \since QGIS 3.0
      */
     bool enabled() const
     {
@@ -94,7 +91,6 @@ class CORE_EXPORT QgsOptional
     /**
      * Set if this optional is enabled
      *
-     * \since QGIS 3.0
      */
     void setEnabled( bool enabled )
     {
@@ -104,7 +100,6 @@ class CORE_EXPORT QgsOptional
     /**
      * Access the payload data
      *
-     * \since QGIS 3.0
      */
     const T *operator->() const
     {
@@ -114,7 +109,6 @@ class CORE_EXPORT QgsOptional
     /**
      * Access the payload data
      *
-     * \since QGIS 3.0
      */
     T data() const
     {
@@ -124,7 +118,6 @@ class CORE_EXPORT QgsOptional
     /**
      * Set the payload data
      *
-     * \since QGIS 3.0
      */
     void setData( const T &data )
     {
