@@ -162,9 +162,7 @@ class CORE_EXPORT QgsRuleBasedRenderer : public QgsFeatureRenderer
               const QString &label = QString(), const QString &description = QString(), bool elseRule = false );
         ~Rule();
 
-        //! Rules cannot be copied
         Rule( const Rule &rh ) = delete;
-        //! Rules cannot be copied
         Rule &operator=( const Rule &rh ) = delete;
 
         /**
@@ -188,7 +186,6 @@ class CORE_EXPORT QgsRuleBasedRenderer : public QgsFeatureRenderer
         //! \note available in Python bindings as symbol2
         QgsSymbolList symbols( const QgsRenderContext &context = QgsRenderContext() ) const;
 
-        //! \since QGIS 2.6
         QgsLegendSymbolList legendSymbolItems( int currentLevel = -1 ) const;
 
         /**
@@ -219,7 +216,6 @@ class CORE_EXPORT QgsRuleBasedRenderer : public QgsFeatureRenderer
          * A scale of 0 indicates no maximum scale visibility.
          * \see minimumScale()
          * \see setMaximumScale()
-         * \since QGIS 3.0
         */
         double maximumScale() const { return mMaximumScale; }
 
@@ -229,7 +225,6 @@ class CORE_EXPORT QgsRuleBasedRenderer : public QgsFeatureRenderer
          * A scale of 0 indicates no minimum scale visibility.
          * \see maximumScale()
          * \see setMinimumScale()
-         * \since QGIS 3.0
         */
         double minimumScale() const { return mMinimumScale; }
 
@@ -261,13 +256,11 @@ class CORE_EXPORT QgsRuleBasedRenderer : public QgsFeatureRenderer
 
         /**
          * Unique rule identifier (for identification of rule within renderer)
-         * \since QGIS 2.6
          */
         QString ruleKey() const { return mRuleKey; }
 
         /**
          * Override the assigned rule key (should be used just internally by rule-based renderer)
-         * \since QGIS 2.6
          */
         void setRuleKey( const QString &key ) { mRuleKey = key; }
 
@@ -366,7 +359,6 @@ class CORE_EXPORT QgsRuleBasedRenderer : public QgsFeatureRenderer
 
         /**
          * Returns which legend keys match the feature
-         * \since QGIS 2.14
          */
         QSet< QString > legendKeysForFeature( const QgsFeature &feature, QgsRenderContext *context = nullptr );
 
@@ -439,7 +431,6 @@ class CORE_EXPORT QgsRuleBasedRenderer : public QgsFeatureRenderer
 
         /**
          * Try to find a rule given its unique key
-         * \since QGIS 2.6
          */
         QgsRuleBasedRenderer::Rule *findRuleByKey( const QString &key );
 
@@ -516,6 +507,7 @@ class CORE_EXPORT QgsRuleBasedRenderer : public QgsFeatureRenderer
     //! Returns symbol for current feature. Should not be used individually: there could be more symbols for a feature
     QgsSymbol *symbolForFeature( const QgsFeature &feature, QgsRenderContext &context ) const override;
 
+    Qgis::FeatureRendererFlags flags() const override;
     bool renderFeature( const QgsFeature &feature, QgsRenderContext &context, int layer = -1, bool selected = false, bool drawVertexMarker = false ) override SIP_THROW( QgsCsException );
 
     void startRender( QgsRenderContext &context, const QgsFields &fields ) override;
@@ -574,7 +566,6 @@ class CORE_EXPORT QgsRuleBasedRenderer : public QgsFeatureRenderer
      * Since QGIS 3.20, the optional \a layer parameter is required for conversions of some renderer types.
      *
      * \returns a new renderer if the conversion was possible, otherwise NULLPTR.
-     * \since QGIS 2.5
      */
     static QgsRuleBasedRenderer *convertFromRenderer( const QgsFeatureRenderer *renderer, QgsVectorLayer *layer = nullptr ) SIP_FACTORY;
 
