@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgstiledscenelayer.h"
+#include "moc_qgstiledscenelayer.cpp"
 #include "qgsthreadingutils.h"
 #include "qgsmaplayerfactory.h"
 #include "qgspainting.h"
@@ -40,10 +41,10 @@ QgsTiledSceneLayer::QgsTiledSceneLayer( const QString &uri,
   if ( !uri.isEmpty() && !provider.isEmpty() )
   {
     const QgsDataProvider::ProviderOptions providerOptions { options.transformContext };
-    QgsDataProvider::ReadFlags providerFlags = QgsDataProvider::ReadFlags();
+    Qgis::DataProviderReadFlags providerFlags;
     if ( options.loadDefaultStyle )
     {
-      providerFlags |= QgsDataProvider::FlagLoadDefaultStyle;
+      providerFlags |= Qgis::DataProviderReadFlag::LoadDefaultStyle;
     }
     setDataSource( uri, baseName, provider, providerOptions, providerFlags );
   }
@@ -172,7 +173,7 @@ bool QgsTiledSceneLayer::readXml( const QDomNode &layerNode, QgsReadWriteContext
   if ( !( mReadFlags & QgsMapLayer::FlagDontResolveLayers ) )
   {
     const QgsDataProvider::ProviderOptions providerOptions { context.transformContext() };
-    QgsDataProvider::ReadFlags flags = providerReadFlags( layerNode, mReadFlags );
+    Qgis::DataProviderReadFlags flags = providerReadFlags( layerNode, mReadFlags );
     // read extent
     if ( mReadFlags & QgsMapLayer::FlagReadExtentFromXml )
     {
@@ -365,7 +366,7 @@ void QgsTiledSceneLayer::setTransformContext( const QgsCoordinateTransformContex
 }
 
 void QgsTiledSceneLayer::setDataSourcePrivate( const QString &dataSource, const QString &baseName, const QString &provider,
-    const QgsDataProvider::ProviderOptions &options, QgsDataProvider::ReadFlags flags )
+    const QgsDataProvider::ProviderOptions &options, Qgis::DataProviderReadFlags flags )
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
@@ -405,13 +406,13 @@ void QgsTiledSceneLayer::setDataSourcePrivate( const QString &dataSource, const
 
   // Load initial extent, crs and renderer
   setCrs( mDataProvider->crs() );
-  if ( !( flags & QgsDataProvider::SkipGetExtent ) )
+  if ( !( flags & Qgis::DataProviderReadFlag::SkipGetExtent ) )
   {
     setExtent( mDataProvider->extent() );
   }
 
   bool loadDefaultStyleFlag = false;
-  if ( flags & QgsDataProvider::FlagLoadDefaultStyle )
+  if ( flags & Qgis::DataProviderReadFlag::LoadDefaultStyle )
   {
     loadDefaultStyleFlag = true;
   }
@@ -512,6 +513,8 @@ QString QgsTiledSceneLayer::htmlMetadata() const
   myMetadata += htmlFormatter.historySectionHtml( );
   myMetadata += QLatin1String( "<br><br>\n" );
 
+  myMetadata += customPropertyHtmlMetadata();
+
   myMetadata += QLatin1String( "\n</body>\n</html>\n" );
   return myMetadata;
 }
