@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgsattributetypedialog.h"
+#include "moc_qgsattributetypedialog.cpp"
 #include "qgsproject.h"
 #include "qgslogger.h"
 #include "qgsfieldformatterregistry.h"
@@ -59,10 +60,9 @@ QgsAttributeTypeDialog::QgsAttributeTypeDialog( QgsVectorLayer *vl, int fieldIdx
       item->setFlags( item->flags() & ~Qt::ItemIsEnabled );
   }
 
-  connect( mWidgetTypeComboBox, static_cast< void ( QComboBox::* )( int )>( &QComboBox::currentIndexChanged ), this, &QgsAttributeTypeDialog::onCurrentWidgetChanged );
+  connect( mWidgetTypeComboBox, static_cast<void ( QComboBox::* )( int )>( &QComboBox::currentIndexChanged ), this, &QgsAttributeTypeDialog::onCurrentWidgetChanged );
 
-  if ( vl->fields().fieldOrigin( fieldIdx ) == QgsFields::OriginJoin ||
-       vl->fields().fieldOrigin( fieldIdx ) == QgsFields::OriginExpression )
+  if ( vl->fields().fieldOrigin( fieldIdx ) == Qgis::FieldOrigin::Join || vl->fields().fieldOrigin( fieldIdx ) == Qgis::FieldOrigin::Expression || vl->fields().field( fieldIdx ).isReadOnly() )
   {
     isFieldEditableCheckBox->setEnabled( false );
   }
@@ -71,29 +71,25 @@ QgsAttributeTypeDialog::QgsAttributeTypeDialog( QgsVectorLayer *vl, int fieldIdx
   mExpressionWidget->setLayer( mLayer );
 
   mEditableExpressionButton->registerExpressionContextGenerator( this );
-  mEditableExpressionButton->init( QgsEditFormConfig::DataDefinedProperty::Editable, mDataDefinedProperties.property( QgsEditFormConfig::DataDefinedProperty::Editable ), vl->editFormConfig().propertyDefinitions(), vl );
+  mEditableExpressionButton->init( static_cast<int>( QgsEditFormConfig::DataDefinedProperty::Editable ), mDataDefinedProperties.property( QgsEditFormConfig::DataDefinedProperty::Editable ), vl->editFormConfig().propertyDefinitions(), vl );
   mEditableExpressionButton->registerLinkedWidget( isFieldEditableCheckBox );
-  connect( mEditableExpressionButton, &QgsPropertyOverrideButton::changed, this, [ = ]
-  {
+  connect( mEditableExpressionButton, &QgsPropertyOverrideButton::changed, this, [=] {
     mDataDefinedProperties.setProperty( QgsEditFormConfig::DataDefinedProperty::Editable, mEditableExpressionButton->toProperty() );
   } );
 
   mAliasExpressionButton->registerExpressionContextGenerator( this );
-  mAliasExpressionButton->init( QgsEditFormConfig::DataDefinedProperty::Alias, mDataDefinedProperties.property( QgsEditFormConfig::DataDefinedProperty::Alias ), vl->editFormConfig().propertyDefinitions(), vl );
-  connect( mAliasExpressionButton, &QgsPropertyOverrideButton::changed, this, [ = ]
-  {
+  mAliasExpressionButton->init( static_cast<int>( QgsEditFormConfig::DataDefinedProperty::Alias ), mDataDefinedProperties.property( QgsEditFormConfig::DataDefinedProperty::Alias ), vl->editFormConfig().propertyDefinitions(), vl );
+  connect( mAliasExpressionButton, &QgsPropertyOverrideButton::changed, this, [=] {
     mDataDefinedProperties.setProperty( QgsEditFormConfig::DataDefinedProperty::Alias, mAliasExpressionButton->toProperty() );
   } );
 
   connect( mExpressionWidget, &QgsExpressionLineEdit::expressionChanged, this, &QgsAttributeTypeDialog::defaultExpressionChanged );
-  connect( mUniqueCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( mUniqueCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mCheckBoxEnforceUnique->setEnabled( checked );
     if ( !checked )
       mCheckBoxEnforceUnique->setChecked( false );
   } );
-  connect( notNullCheckBox, &QCheckBox::toggled, this, [ = ]( bool checked )
-  {
+  connect( notNullCheckBox, &QCheckBox::toggled, this, [=]( bool checked ) {
     mCheckBoxEnforceNotNull->setEnabled( checked );
     if ( !checked )
       mCheckBoxEnforceNotNull->setChecked( false );
@@ -124,6 +120,12 @@ QgsAttributeTypeDialog::QgsAttributeTypeDialog( QgsVectorLayer *vl, int fieldIdx
 
   connect( mSplitPolicyComboBox, qOverload<int>( &QComboBox::currentIndexChanged ), this, &QgsAttributeTypeDialog::updateSplitPolicyLabel );
   updateSplitPolicyLabel();
+
+  mDuplicatePolicyComboBox->addItem( tr( "Duplicate Value" ), QVariant::fromValue( Qgis::FieldDuplicatePolicy::Duplicate ) );
+  mDuplicatePolicyComboBox->addItem( tr( "Use Default Value" ), QVariant::fromValue( Qgis::FieldDuplicatePolicy::DefaultValue ) );
+  mDuplicatePolicyComboBox->addItem( tr( "Remove Value" ), QVariant::fromValue( Qgis::FieldDuplicatePolicy::UnsetField ) );
+  connect( mDuplicatePolicyComboBox, qOverload<int>( &QComboBox::currentIndexChanged ), this, &QgsAttributeTypeDialog::updateDuplicatePolicyLabel );
+  updateDuplicatePolicyLabel();
 }
 
 QgsAttributeTypeDialog::~QgsAttributeTypeDialog()
@@ -175,7 +177,6 @@ const QVariantMap QgsAttributeTypeDialog::editorWidgetConfig()
 
 void QgsAttributeTypeDialog::setEditorWidgetType( const QString &type )
 {
-
   mWidgetTypeComboBox->setCurrentIndex( mWidgetTypeComboBox->findData( type ) );
 
   if ( mEditorConfigWidgets.contains( type ) && mEditorConfigWidgets.value( type ) /* may be a null pointer */ )
@@ -342,11 +343,12 @@ QgsExpressionContext QgsAttributeTypeDialog::createExpressionContext() const
 {
   QgsExpressionContext context;
   context
-      << QgsExpressionContextUtils::globalScope()
-      << QgsExpressionContextUtils::projectScope( QgsProject::instance() )
-      << QgsExpressionContextUtils::layerScope( mLayer )
-      << QgsExpressionContextUtils::formScope( )
-      << QgsExpressionContextUtils::mapToolCaptureScope( QList<QgsPointLocator::Match>() );
+    << QgsExpressionContextUtils::globalScope()
+    << QgsExpressionContextUtils::projectScope( QgsProject::instance() )
+    << QgsExpressionContextUtils::layerScope( mLayer )
+    << QgsExpressionContextUtils::formScope()
+    << QgsExpressionContextUtils::parentFormScope( QgsFeature() )
+    << QgsExpressionContextUtils::mapToolCaptureScope( QList<QgsPointLocator::Match>() );
 
   return context;
 }
@@ -372,7 +374,7 @@ void QgsAttributeTypeDialog::setApplyDefaultValueOnUpdate( bool applyDefaultValu
 
 Qgis::FieldDomainSplitPolicy QgsAttributeTypeDialog::splitPolicy() const
 {
-  return mSplitPolicyComboBox->currentData().value< Qgis::FieldDomainSplitPolicy >();
+  return mSplitPolicyComboBox->currentData().value<Qgis::FieldDomainSplitPolicy>();
 }
 
 void QgsAttributeTypeDialog::setSplitPolicy( Qgis::FieldDomainSplitPolicy policy )
@@ -381,6 +383,17 @@ void QgsAttributeTypeDialog::setSplitPolicy( Qgis::FieldDomainSplitPolicy policy
   updateSplitPolicyLabel();
 }
 
+Qgis::FieldDuplicatePolicy QgsAttributeTypeDialog::duplicatePolicy() const
+{
+  return mDuplicatePolicyComboBox->currentData().value<Qgis::FieldDuplicatePolicy>();
+}
+
+void QgsAttributeTypeDialog::setDuplicatePolicy( Qgis::FieldDuplicatePolicy policy )
+{
+  mDuplicatePolicyComboBox->setCurrentIndex( mDuplicatePolicyComboBox->findData( QVariant::fromValue( policy ) ) );
+  updateSplitPolicyLabel();
+}
+
 QString QgsAttributeTypeDialog::constraintExpression() const
 {
   return constraintExpressionWidget->asExpression();
@@ -477,7 +490,7 @@ void QgsAttributeTypeDialog::defaultExpressionChanged()
 void QgsAttributeTypeDialog::updateSplitPolicyLabel()
 {
   QString helperText;
-  switch ( mSplitPolicyComboBox->currentData().value< Qgis::FieldDomainSplitPolicy >() )
+  switch ( mSplitPolicyComboBox->currentData().value<Qgis::FieldDomainSplitPolicy>() )
   {
     case Qgis::FieldDomainSplitPolicy::DefaultValue:
       helperText = tr( "Resets the field by recalculating its default value." );
@@ -498,6 +511,26 @@ void QgsAttributeTypeDialog::updateSplitPolicyLabel()
   mSplitPolicyDescriptionLabel->setText( QStringLiteral( "<i>%1</i>" ).arg( helperText ) );
 }
 
+void QgsAttributeTypeDialog::updateDuplicatePolicyLabel()
+{
+  QString helperText;
+  switch ( mDuplicatePolicyComboBox->currentData().value<Qgis::FieldDuplicatePolicy>() )
+  {
+    case Qgis::FieldDuplicatePolicy::DefaultValue:
+      helperText = tr( "Resets the field by recalculating its default value." );
+      break;
+
+    case Qgis::FieldDuplicatePolicy::Duplicate:
+      helperText = tr( "Copies the current field value without change." );
+      break;
+
+    case Qgis::FieldDuplicatePolicy::UnsetField:
+      helperText = tr( "Clears the field to an unset state." );
+      break;
+  }
+  mDuplicatePolicyDescriptionLabel->setText( QStringLiteral( "<i>%1</i>" ).arg( helperText ) );
+}
+
 QStandardItem *QgsAttributeTypeDialog::currentItem() const
 {
   QStandardItemModel *widgetTypeModel = qobject_cast<QStandardItemModel *>( mWidgetTypeComboBox->model() );
