@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsrelationwidgetwrapper.h"
+#include "moc_qgsrelationwidgetwrapper.cpp"
 
 #include "qgsrelationeditorwidget.h"
 #include "qgsattributeeditorcontext.h"
@@ -75,22 +76,19 @@ void QgsRelationWidgetWrapper::setVisible( bool visible )
 
 void QgsRelationWidgetWrapper::aboutToSave()
 {
-  if ( !mRelation.isValid() || !widget() || !widget()->isVisible() || mRelation.referencingLayer() ==  mRelation.referencedLayer() || ( mNmRelation.isValid() && mNmRelation.referencedLayer() ==  mRelation.referencedLayer() ) )
+  if ( !mRelation.isValid() || !widget() || !widget()->isVisible() || mRelation.referencingLayer() == mRelation.referencedLayer() || ( mNmRelation.isValid() && mNmRelation.referencedLayer() == mRelation.referencedLayer() ) )
     return;
 
   // If the layer is already saved before, return
   const QgsAttributeEditorContext *ctx = &context();
   do
   {
-    if ( ctx->relation().isValid() && ( ctx->relation().referencedLayer() == mRelation.referencingLayer()
-                                        || ( mNmRelation.isValid() && ctx->relation().referencedLayer() == mNmRelation.referencedLayer() ) )
-       )
+    if ( ctx->relation().isValid() && ( ctx->relation().referencedLayer() == mRelation.referencingLayer() || ( mNmRelation.isValid() && ctx->relation().referencedLayer() == mNmRelation.referencedLayer() ) ) )
     {
       return;
     }
     ctx = ctx->parentContext();
-  }
-  while ( ctx );
+  } while ( ctx );
 
   // Calling isModified() will emit a beforeModifiedCheck()
   // signal that will make the embedded form to send any
@@ -162,7 +160,7 @@ void QgsRelationWidgetWrapper::initWidget( QWidget *editor )
   if ( !w )
   {
     w = QgsGui::relationWidgetRegistry()->create( mRelationEditorId, widgetConfig(), editor );
-    if ( ! editor->layout() )
+    if ( !editor->layout() )
     {
       editor->setLayout( new QVBoxLayout( editor ) );
     }
@@ -200,8 +198,7 @@ void QgsRelationWidgetWrapper::initWidget( QWidget *editor )
       break;
     }
     ctx = ctx->parentContext();
-  }
-  while ( ctx );
+  } while ( ctx );
 
   w->setEditorContext( myContext );
   w->setRelations( mRelation, mNmRelation );
@@ -237,7 +234,7 @@ bool QgsRelationWidgetWrapper::showSaveChildEditsButton() const
 
 void QgsRelationWidgetWrapper::setVisibleButtons( const QgsAttributeEditorRelation::Buttons &buttons )
 {
-  if ( ! mWidget )
+  if ( !mWidget )
     return;
   QVariantMap config = mWidget->config();
   config.insert( "buttons", qgsFlagValueToKeys( buttons ) );
