@@ -18,6 +18,7 @@
 
 #include "qgsapplication.h"
 #include "qgselevationprofilecanvas.h"
+#include "moc_qgselevationprofilecanvas.cpp"
 #include "qgsmaplayerlistutils_p.h"
 #include "qgsplotcanvasitem.h"
 #include "qgsprofilerequest.h"
@@ -37,6 +38,7 @@
 #include "qgsscreenhelper.h"
 #include "qgsfillsymbol.h"
 #include "qgslinesymbol.h"
+#include "qgsprofilesourceregistry.h"
 
 #include <QWheelEvent>
 #include <QTimer>
@@ -46,7 +48,6 @@
 class QgsElevationProfilePlotItem : public Qgs2DPlot, public QgsPlotCanvasItem
 {
   public:
-
     QgsElevationProfilePlotItem( QgsElevationProfileCanvas *canvas )
       : QgsPlotCanvasItem( canvas )
     {
@@ -112,6 +113,45 @@ class QgsElevationProfilePlotItem : public Qgs2DPlot, public QgsPlotCanvasItem
         case Qgis::DistanceUnit::Centimeters:
         case Qgis::DistanceUnit::Millimeters:
         case Qgis::DistanceUnit::Inches:
+        case Qgis::DistanceUnit::ChainsInternational:
+        case Qgis::DistanceUnit::ChainsBritishBenoit1895A:
+        case Qgis::DistanceUnit::ChainsBritishBenoit1895B:
+        case Qgis::DistanceUnit::ChainsBritishSears1922Truncated:
+        case Qgis::DistanceUnit::ChainsBritishSears1922:
+        case Qgis::DistanceUnit::ChainsClarkes:
+        case Qgis::DistanceUnit::ChainsUSSurvey:
+        case Qgis::DistanceUnit::FeetBritish1865:
+        case Qgis::DistanceUnit::FeetBritish1936:
+        case Qgis::DistanceUnit::FeetBritishBenoit1895A:
+        case Qgis::DistanceUnit::FeetBritishBenoit1895B:
+        case Qgis::DistanceUnit::FeetBritishSears1922Truncated:
+        case Qgis::DistanceUnit::FeetBritishSears1922:
+        case Qgis::DistanceUnit::FeetClarkes:
+        case Qgis::DistanceUnit::FeetGoldCoast:
+        case Qgis::DistanceUnit::FeetIndian:
+        case Qgis::DistanceUnit::FeetIndian1937:
+        case Qgis::DistanceUnit::FeetIndian1962:
+        case Qgis::DistanceUnit::FeetIndian1975:
+        case Qgis::DistanceUnit::FeetUSSurvey:
+        case Qgis::DistanceUnit::LinksInternational:
+        case Qgis::DistanceUnit::LinksBritishBenoit1895A:
+        case Qgis::DistanceUnit::LinksBritishBenoit1895B:
+        case Qgis::DistanceUnit::LinksBritishSears1922Truncated:
+        case Qgis::DistanceUnit::LinksBritishSears1922:
+        case Qgis::DistanceUnit::LinksClarkes:
+        case Qgis::DistanceUnit::LinksUSSurvey:
+        case Qgis::DistanceUnit::YardsBritishBenoit1895A:
+        case Qgis::DistanceUnit::YardsBritishBenoit1895B:
+        case Qgis::DistanceUnit::YardsBritishSears1922Truncated:
+        case Qgis::DistanceUnit::YardsBritishSears1922:
+        case Qgis::DistanceUnit::YardsClarkes:
+        case Qgis::DistanceUnit::YardsIndian:
+        case Qgis::DistanceUnit::YardsIndian1937:
+        case Qgis::DistanceUnit::YardsIndian1962:
+        case Qgis::DistanceUnit::YardsIndian1975:
+        case Qgis::DistanceUnit::MilesUSSurvey:
+        case Qgis::DistanceUnit::Fathoms:
+        case Qgis::DistanceUnit::MetersGermanLegal:
           return QStringLiteral( " %1" ).arg( QgsUnitTypes::toAbbreviatedString( mDistanceUnit ) );
 
         case Qgis::DistanceUnit::Degrees:
@@ -157,7 +197,7 @@ class QgsElevationProfilePlotItem : public Qgs2DPlot, public QgsPlotCanvasItem
 
     QgsPointXY plotPointToCanvasPoint( const QgsProfilePoint &point )
     {
-      if ( point.distance() < xMinimum() * mXScaleFactor || point.distance() > xMaximum()* mXScaleFactor || point.elevation() < yMinimum() || point.elevation() > yMaximum() )
+      if ( point.distance() < xMinimum() * mXScaleFactor || point.distance() > xMaximum() * mXScaleFactor || point.elevation() < yMinimum() || point.elevation() > yMaximum() )
         return QgsPointXY();
 
       const QRectF area = plotArea();
@@ -187,13 +227,11 @@ class QgsElevationProfilePlotItem : public Qgs2DPlot, public QgsPlotCanvasItem
         }
         else
         {
-          plot = mRenderer->renderToImage( plotArea.width() * pixelRatio,
-                                           plotArea.height() * pixelRatio, xMinimum() * mXScaleFactor, xMaximum() * mXScaleFactor, yMinimum(), yMaximum(), source, pixelRatio );
+          plot = mRenderer->renderToImage( plotArea.width() * pixelRatio, plotArea.height() * pixelRatio, xMinimum() * mXScaleFactor, xMaximum() * mXScaleFactor, yMinimum(), yMaximum(), source, pixelRatio );
           plot.setDevicePixelRatio( pixelRatio );
           mCachedImages.insert( source, plot );
         }
-        rc.painter()->drawImage( QPointF( plotArea.left(),
-                                          plotArea.top() ), plot );
+        rc.painter()->drawImage( QPointF( plotArea.left(), plotArea.top() ), plot );
       }
     }
 
@@ -236,10 +274,9 @@ class QgsElevationProfilePlotItem : public Qgs2DPlot, public QgsPlotCanvasItem
     Qgis::DistanceUnit mDistanceUnit = Qgis::DistanceUnit::Unknown;
 
   private:
-
     QImage mImage;
 
-    QMap< QString, QImage > mCachedImages;
+    QMap<QString, QImage> mCachedImages;
 
     QRectF mRect;
     QRectF mPlotArea;
@@ -249,7 +286,6 @@ class QgsElevationProfilePlotItem : public Qgs2DPlot, public QgsPlotCanvasItem
 class QgsElevationProfileCrossHairsItem : public QgsPlotCanvasItem
 {
   public:
-
     QgsElevationProfileCrossHairsItem( QgsElevationProfileCanvas *canvas, QgsElevationProfilePlotItem *plotItem )
       : QgsPlotCanvasItem( canvas )
       , mPlotItem( plotItem )
@@ -278,7 +314,7 @@ class QgsElevationProfileCrossHairsItem : public QgsPlotCanvasItem
 
     void paint( QPainter *painter ) override
     {
-      const QgsPointXY crossHairPlotPoint  = mPlotItem->plotPointToCanvasPoint( mPoint );
+      const QgsPointXY crossHairPlotPoint = mPlotItem->plotPointToCanvasPoint( mPoint );
       if ( crossHairPlotPoint.isEmpty() )
         return;
 
@@ -367,7 +403,6 @@ class QgsElevationProfileCrossHairsItem : public QgsPlotCanvasItem
     }
 
   private:
-
     QRectF mRect;
     QgsProfilePoint mPoint;
     QgsElevationProfilePlotItem *mPlotItem = nullptr;
@@ -399,7 +434,6 @@ QgsElevationProfileCanvas::QgsElevationProfileCanvas( QWidget *parent )
   mDeferredRedrawTimer->setSingleShot( true );
   mDeferredRedrawTimer->stop();
   connect( mDeferredRedrawTimer, &QTimer::timeout, this, &QgsElevationProfileCanvas::startDeferredRedraw );
-
 }
 
 QgsElevationProfileCanvas::~QgsElevationProfileCanvas()
@@ -430,7 +464,7 @@ void QgsElevationProfileCanvas::panContentsBy( double dx, double dy )
   const double dyPercent = dy / mPlotItem->plotArea().height();
 
   // these look backwards, but we are dragging the paper, not the view!
-  const double dxPlot = - dxPercent * ( mPlotItem->xMaximum() - mPlotItem->xMinimum() );
+  const double dxPlot = -dxPercent * ( mPlotItem->xMaximum() - mPlotItem->xMinimum() );
   const double dyPlot = dyPercent * ( mPlotItem->yMaximum() - mPlotItem->yMinimum() );
 
   // no need to handle axis scale lock here, we aren't changing scales
@@ -486,7 +520,7 @@ QgsProfileSnapContext QgsElevationProfileCanvas::snapContext() const
   context.maximumPointDistanceDelta = 4 * xToleranceInPlotUnits;
   context.maximumPointElevationDelta = 4 * yToleranceInPlotUnits;
   context.displayRatioElevationVsDistance = ( ( mPlotItem->yMaximum() - mPlotItem->yMinimum() ) / ( mPlotItem->plotArea().height() ) )
-      / ( ( mPlotItem->xMaximum() - mPlotItem->xMinimum() ) * mPlotItem->mXScaleFactor / ( mPlotItem->plotArea().width() ) );
+                                            / ( ( mPlotItem->xMaximum() - mPlotItem->xMinimum() ) * mPlotItem->mXScaleFactor / ( mPlotItem->plotArea().width() ) );
 
   return context;
 }
@@ -503,7 +537,7 @@ QgsProfileIdentifyContext QgsElevationProfileCanvas::identifyContext() const
   context.maximumPointDistanceDelta = 4 * xToleranceInPlotUnits;
   context.maximumPointElevationDelta = 4 * yToleranceInPlotUnits;
   context.displayRatioElevationVsDistance = ( ( mPlotItem->yMaximum() - mPlotItem->yMinimum() ) / ( mPlotItem->plotArea().height() ) )
-      / ( ( mPlotItem->xMaximum() - mPlotItem->xMinimum() ) * mPlotItem->mXScaleFactor / ( mPlotItem->plotArea().width() ) );
+                                            / ( ( mPlotItem->xMaximum() - mPlotItem->xMinimum() ) * mPlotItem->mXScaleFactor / ( mPlotItem->plotArea().width() ) );
 
   context.project = mProject;
 
@@ -529,7 +563,7 @@ void QgsElevationProfileCanvas::setupLayerConnections( QgsMapLayer *layer, bool
   {
     case Qgis::LayerType::Vector:
     {
-      QgsVectorLayer *vl = qobject_cast< QgsVectorLayer * >( layer );
+      QgsVectorLayer *vl = qobject_cast<QgsVectorLayer *>( layer );
       if ( isDisconnect )
       {
         disconnect( vl, &QgsVectorLayer::featureAdded, this, &QgsElevationProfileCanvas::regenerateResultsForLayer );
@@ -824,13 +858,7 @@ void QgsElevationProfileCanvas::refresh()
   if ( !mProject || !profileCurve() )
     return;
 
-  if ( mCurrentJob )
-  {
-    mPlotItem->setRenderer( nullptr );
-    disconnect( mCurrentJob, &QgsProfilePlotRenderer::generationFinished, this, &QgsElevationProfileCanvas::generationFinished );
-    mCurrentJob->deleteLater();
-    mCurrentJob = nullptr;
-  }
+  cancelJobs();
 
   QgsProfileRequest request( profileCurve()->clone() );
   request.setCrs( mCrs );
@@ -842,12 +870,15 @@ void QgsElevationProfileCanvas::refresh()
   context.appendScope( QgsExpressionContextUtils::projectScope( mProject ) );
   request.setExpressionContext( context );
 
-  const QList< QgsMapLayer * > layersToGenerate = layers();
-  QList< QgsAbstractProfileSource * > sources;
-  sources.reserve( layersToGenerate .size() );
+  const QList<QgsMapLayer *> layersToGenerate = layers();
+  QList<QgsAbstractProfileSource *> sources;
+  const QList<QgsAbstractProfileSource *> registrySources = QgsApplication::profileSourceRegistry()->profileSources();
+  sources.reserve( layersToGenerate.size() + registrySources.size() );
+
+  sources << registrySources;
   for ( QgsMapLayer *layer : layersToGenerate )
   {
-    if ( QgsAbstractProfileSource *source = dynamic_cast< QgsAbstractProfileSource * >( layer ) )
+    if ( QgsAbstractProfileSource *source = dynamic_cast<QgsAbstractProfileSource *>( layer ) )
       sources.append( source );
   }
 
@@ -907,13 +938,13 @@ void QgsElevationProfileCanvas::onLayerProfileGenerationPropertyChanged()
   if ( !mCurrentJob || mCurrentJob->isActive() )
     return;
 
-  QgsMapLayerElevationProperties *properties = qobject_cast< QgsMapLayerElevationProperties * >( sender() );
+  QgsMapLayerElevationProperties *properties = qobject_cast<QgsMapLayerElevationProperties *>( sender() );
   if ( !properties )
     return;
 
-  if ( QgsMapLayer *layer = qobject_cast< QgsMapLayer * >( properties->parent() ) )
+  if ( QgsMapLayer *layer = qobject_cast<QgsMapLayer *>( properties->parent() ) )
   {
-    if ( QgsAbstractProfileSource *source = dynamic_cast< QgsAbstractProfileSource * >( layer ) )
+    if ( QgsAbstractProfileSource *source = dynamic_cast<QgsAbstractProfileSource *>( layer ) )
     {
       if ( mCurrentJob->invalidateResults( source ) )
         scheduleDeferredRegeneration();
@@ -927,13 +958,13 @@ void QgsElevationProfileCanvas::onLayerProfileRendererPropertyChanged()
   if ( !mCurrentJob || mCurrentJob->isActive() )
     return;
 
-  QgsMapLayerElevationProperties *properties = qobject_cast< QgsMapLayerElevationProperties * >( sender() );
+  QgsMapLayerElevationProperties *properties = qobject_cast<QgsMapLayerElevationProperties *>( sender() );
   if ( !properties )
     return;
 
-  if ( QgsMapLayer *layer = qobject_cast< QgsMapLayer * >( properties->parent() ) )
+  if ( QgsMapLayer *layer = qobject_cast<QgsMapLayer *>( properties->parent() ) )
   {
-    if ( QgsAbstractProfileSource *source = dynamic_cast< QgsAbstractProfileSource * >( layer ) )
+    if ( QgsAbstractProfileSource *source = dynamic_cast<QgsAbstractProfileSource *>( layer ) )
     {
       mCurrentJob->replaceSource( source );
     }
@@ -944,9 +975,12 @@ void QgsElevationProfileCanvas::onLayerProfileRendererPropertyChanged()
 
 void QgsElevationProfileCanvas::regenerateResultsForLayer()
 {
-  if ( QgsMapLayer *layer = qobject_cast< QgsMapLayer * >( sender() ) )
+  if ( !mCurrentJob )
+    return;
+
+  if ( QgsMapLayer *layer = qobject_cast<QgsMapLayer *>( sender() ) )
   {
-    if ( QgsAbstractProfileSource *source = dynamic_cast< QgsAbstractProfileSource * >( layer ) )
+    if ( QgsAbstractProfileSource *source = dynamic_cast<QgsAbstractProfileSource *>( layer ) )
     {
       if ( mCurrentJob->invalidateResults( source ) )
         scheduleDeferredRegeneration();
@@ -1014,11 +1048,9 @@ void QgsElevationProfileCanvas::refineResults()
 
     // for similar reasons we round the minimum distance off to multiples of the maximum error in map units
     const double distanceMin = std::floor( ( mPlotItem->xMinimum() * mPlotItem->mXScaleFactor - plotDistanceRange * 0.05 ) / context.maximumErrorMapUnits() ) * context.maximumErrorMapUnits();
-    context.setDistanceRange( QgsDoubleRange( std::max( 0.0, distanceMin ),
-                              mPlotItem->xMaximum() * mPlotItem->mXScaleFactor + plotDistanceRange * 0.05 ) );
+    context.setDistanceRange( QgsDoubleRange( std::max( 0.0, distanceMin ), mPlotItem->xMaximum() * mPlotItem->mXScaleFactor + plotDistanceRange * 0.05 ) );
 
-    context.setElevationRange( QgsDoubleRange( mPlotItem->yMinimum() - plotElevationRange * 0.05,
-                               mPlotItem->yMaximum() + plotElevationRange * 0.05 ) );
+    context.setElevationRange( QgsDoubleRange( mPlotItem->yMinimum() - plotElevationRange * 0.05, mPlotItem->yMaximum() + plotElevationRange * 0.05 ) );
     mCurrentJob->setContext( context );
   }
   scheduleDeferredRegeneration();
@@ -1035,17 +1067,17 @@ void QgsElevationProfileCanvas::updateChartFromPalette()
     mPlotItem->yAxis().setTextFormat( textFormat );
   }
   {
-    std::unique_ptr< QgsFillSymbol > chartFill( mPlotItem->chartBackgroundSymbol()->clone() );
+    std::unique_ptr<QgsFillSymbol> chartFill( mPlotItem->chartBackgroundSymbol()->clone() );
     chartFill->setColor( chartPalette.color( QPalette::ColorGroup::Active, QPalette::ColorRole::Window ) );
     mPlotItem->setChartBackgroundSymbol( chartFill.release() );
   }
   {
-    std::unique_ptr< QgsFillSymbol > chartBorder( mPlotItem->chartBorderSymbol()->clone() );
+    std::unique_ptr<QgsFillSymbol> chartBorder( mPlotItem->chartBorderSymbol()->clone() );
     chartBorder->setColor( chartPalette.color( QPalette::ColorGroup::Active, QPalette::ColorRole::Text ) );
     mPlotItem->setChartBorderSymbol( chartBorder.release() );
   }
   {
-    std::unique_ptr< QgsLineSymbol > chartMajorSymbol( mPlotItem->xAxis().gridMajorSymbol()->clone() );
+    std::unique_ptr<QgsLineSymbol> chartMajorSymbol( mPlotItem->xAxis().gridMajorSymbol()->clone() );
     QColor c = chartPalette.color( QPalette::ColorGroup::Active, QPalette::ColorRole::Text );
     c.setAlpha( 150 );
     chartMajorSymbol->setColor( c );
@@ -1053,7 +1085,7 @@ void QgsElevationProfileCanvas::updateChartFromPalette()
     mPlotItem->yAxis().setGridMajorSymbol( chartMajorSymbol.release() );
   }
   {
-    std::unique_ptr< QgsLineSymbol > chartMinorSymbol( mPlotItem->xAxis().gridMinorSymbol()->clone() );
+    std::unique_ptr<QgsLineSymbol> chartMinorSymbol( mPlotItem->xAxis().gridMinorSymbol()->clone() );
     QColor c = chartPalette.color( QPalette::ColorGroup::Active, QPalette::ColorRole::Text );
     c.setAlpha( 50 );
     chartMinorSymbol->setColor( c );
@@ -1116,11 +1148,10 @@ void QgsElevationProfileCanvas::setLayers( const QList<QgsMapLayer *> &layers )
 
   // filter list, removing null layers and invalid layers
   auto filteredList = layers;
-  filteredList.erase( std::remove_if( filteredList.begin(), filteredList.end(),
-                                      []( QgsMapLayer * layer )
-  {
-    return !layer || !layer->isValid();
-  } ), filteredList.end() );
+  filteredList.erase( std::remove_if( filteredList.begin(), filteredList.end(), []( QgsMapLayer *layer ) {
+                        return !layer || !layer->isValid();
+                      } ),
+                      filteredList.end() );
 
   mLayers = _qgis_listRawToQPointer( filteredList );
   for ( QgsMapLayer *layer : std::as_const( mLayers ) )
@@ -1181,7 +1212,7 @@ QgsPoint QgsElevationProfileCanvas::toMapCoordinates( const QgsPointXY &point )
   const double distanceAlongPlotPercent = dx / mPlotItem->plotArea().width();
   double distanceAlongCurveLength = distanceAlongPlotPercent * ( mPlotItem->xMaximum() - mPlotItem->xMinimum() ) * mPlotItem->mXScaleFactor + mPlotItem->xMinimum() * mPlotItem->mXScaleFactor;
 
-  std::unique_ptr< QgsPoint > mapXyPoint( mProfileCurve->interpolatePoint( distanceAlongCurveLength ) );
+  std::unique_ptr<QgsPoint> mapXyPoint( mProfileCurve->interpolatePoint( distanceAlongCurveLength ) );
   if ( !mapXyPoint )
     return QgsPoint();
 
@@ -1308,7 +1339,6 @@ const Qgs2DPlot &QgsElevationProfileCanvas::plot() const
 class QgsElevationProfilePlot : public Qgs2DPlot
 {
   public:
-
     QgsElevationProfilePlot( QgsProfilePlotRenderer *renderer )
       : mRenderer( renderer )
     {
@@ -1327,7 +1357,6 @@ class QgsElevationProfilePlot : public Qgs2DPlot
     double mXScale = 1;
 
   private:
-
     QgsProfilePlotRenderer *mRenderer = nullptr;
 };
 ///@endcond PRIVATE
@@ -1391,7 +1420,7 @@ QVector<QgsProfileIdentifyResults> QgsElevationProfileCanvas::identify( const QR
 void QgsElevationProfileCanvas::clear()
 {
   setProfileCurve( nullptr );
-  mPlotItem->setRenderer( nullptr );
+  cancelJobs();
   mPlotItem->updatePlot();
 }
 
