@@ -41,16 +41,14 @@ class QgsLayoutItemBaseWidget;
  * the components related to the GUI behavior of a layout item.
  *
  * \note In C++ you can use QgsLayoutItemGuiMetadata convenience class.
- * \since QGIS 3.0
  */
 class GUI_EXPORT QgsLayoutItemAbstractGuiMetadata
 {
   public:
-
     //! Flags for controlling how a items behave in the GUI
-    enum Flag
+    enum Flag SIP_ENUM_BASETYPE( IntFlag )
     {
-      FlagNoCreationTools = 1 << 1,  //!< Do not show item creation tools for the item type
+      FlagNoCreationTools = 1 << 1, //!< Do not show item creation tools for the item type
     };
     Q_DECLARE_FLAGS( Flags, Flag )
 
@@ -63,7 +61,7 @@ class GUI_EXPORT QgsLayoutItemAbstractGuiMetadata
      *
      * If \a isNodeBased is TRUE, then the corresponding item is a node based item.
      */
-    QgsLayoutItemAbstractGuiMetadata( int type, const QString &visibleName, const QString &groupId = QString(), bool isNodeBased = false, Flags flags = nullptr )
+    QgsLayoutItemAbstractGuiMetadata( int type, const QString &visibleName, const QString &groupId = QString(), bool isNodeBased = false, Flags flags = QgsLayoutItemAbstractGuiMetadata::Flags() )
       : mType( type )
       , mGroupId( groupId )
       , mIsNodeBased( isNodeBased )
@@ -103,29 +101,48 @@ class GUI_EXPORT QgsLayoutItemAbstractGuiMetadata
      */
     virtual QIcon creationIcon() const { return QgsApplication::getThemeIcon( QStringLiteral( "/mActionAddBasicRectangle.svg" ) ); }
 
+    /*
+     * IMPORTANT: While it seems like /Factory/ would be the correct annotations here, that's not
+     * the case.
+     * As per Phil Thomson's advice on https://www.riverbankcomputing.com/pipermail/pyqt/2017-July/039450.html:
+     *
+     * "
+     * /Factory/ is used when the instance returned is guaranteed to be new to Python.
+     * In this case it isn't because it has already been seen when being returned by QgsProcessingAlgorithm::createInstance()
+     * (However for a different sub-class implemented in C++ then it would be the first time it was seen
+     * by Python so the /Factory/ on create() would be correct.)
+     *
+     * You might try using /TransferBack/ on create() instead - that might be the best compromise.
+     * "
+     */
+
     /**
      * Creates a configuration widget for an \a item of this type. Can return NULLPTR if no configuration GUI is required.
      */
-    virtual QgsLayoutItemBaseWidget *createItemWidget( QgsLayoutItem *item ) SIP_FACTORY { Q_UNUSED( item ) return nullptr; }
+    virtual QgsLayoutItemBaseWidget *createItemWidget( QgsLayoutItem *item ) SIP_TRANSFERBACK
+    {
+      Q_UNUSED( item )
+      return nullptr;
+    }
 
     /**
      * Creates a rubber band for use when creating layout items of this type. Can return NULLPTR if no rubber band
      * should be created. The default behavior is to create a rectangular rubber band.
      * \see createNodeRubberBand()
      */
-    virtual QgsLayoutViewRubberBand *createRubberBand( QgsLayoutView *view ) SIP_FACTORY;
+    virtual QgsLayoutViewRubberBand *createRubberBand( QgsLayoutView *view ) SIP_TRANSFERBACK;
 
     /**
      * Creates a rubber band for use when creating layout node based items of this type. Can return NULLPTR if no rubber band
      * should be created. The default behavior is to return NULLPTR.
      * \see createRubberBand()
      */
-    virtual QAbstractGraphicsShapeItem *createNodeRubberBand( QgsLayoutView *view ) SIP_FACTORY;
+    virtual QAbstractGraphicsShapeItem *createNodeRubberBand( QgsLayoutView *view ) SIP_TRANSFERBACK;
 
     /**
      * Creates an instance of the corresponding item type.
      */
-    virtual QgsLayoutItem *createItem( QgsLayout *layout ) SIP_FACTORY;
+    virtual QgsLayoutItem *createItem( QgsLayout *layout ) SIP_TRANSFERBACK;
 
     /**
      * Called when a newly created item of the associated type has been added to a layout.
@@ -136,13 +153,11 @@ class GUI_EXPORT QgsLayoutItemAbstractGuiMetadata
     virtual void newItemAddedToLayout( QgsLayoutItem *item );
 
   private:
-
     int mType = -1;
     QString mGroupId;
     bool mIsNodeBased = false;
     QString mName;
     Flags mFlags;
-
 };
 
 //! Layout item configuration widget creation function
@@ -155,20 +170,18 @@ typedef std::function<QgsLayoutViewRubberBand *( QgsLayoutView * )> QgsLayoutIte
 typedef std::function<QAbstractGraphicsShapeItem *( QgsLayoutView * )> QgsLayoutNodeItemRubberBandFunc SIP_SKIP;
 
 //! Layout item added to layout callback
-typedef std::function<void ( QgsLayoutItem * )> QgsLayoutItemAddedToLayoutFunc SIP_SKIP;
+typedef std::function<void( QgsLayoutItem *, const QVariantMap & )> QgsLayoutItemAddedToLayoutFunc SIP_SKIP;
 
 #ifndef SIP_RUN
 
 /**
  * \ingroup gui
- * Convenience metadata class that uses static functions to handle layout item GUI behavior.
+ * \brief Convenience metadata class that uses static functions to handle layout item GUI behavior.
  * \note not available in Python bindings
- * \since QGIS 3.0
  */
 class GUI_EXPORT QgsLayoutItemGuiMetadata : public QgsLayoutItemAbstractGuiMetadata
 {
   public:
-
     /**
      * Constructor for QgsLayoutItemGuiMetadata with the specified class \a type
      * and \a creationIcon, and function pointers for the various
@@ -180,12 +193,7 @@ class GUI_EXPORT QgsLayoutItemGuiMetadata : public QgsLayoutItemAbstractGuiMetad
      *
      * If \a isNodeBased is TRUE, then the corresponding item is a node based item.
      */
-    QgsLayoutItemGuiMetadata( int type, const QString &visibleName, const QIcon &creationIcon,
-                              const QgsLayoutItemWidgetFunc &pfWidget = nullptr,
-                              const QgsLayoutItemRubberBandFunc &pfRubberBand = nullptr, const QString &groupId = QString(),
-                              bool isNodeBased = false,
-                              QgsLayoutItemAbstractGuiMetadata::Flags flags = nullptr,
-                              const QgsLayoutItemCreateFunc &pfCreateFunc = nullptr )
+    QgsLayoutItemGuiMetadata( int type, const QString &visibleName, const QIcon &creationIcon, const QgsLayoutItemWidgetFunc &pfWidget = nullptr, const QgsLayoutItemRubberBandFunc &pfRubberBand = nullptr, const QString &groupId = QString(), bool isNodeBased = false, QgsLayoutItemAbstractGuiMetadata::Flags flags = QgsLayoutItemAbstractGuiMetadata::Flags(), const QgsLayoutItemCreateFunc &pfCreateFunc = nullptr )
       : QgsLayoutItemAbstractGuiMetadata( type, visibleName, groupId, isNodeBased, flags )
       , mIcon( creationIcon )
       , mWidgetFunc( pfWidget )
@@ -257,9 +265,23 @@ class GUI_EXPORT QgsLayoutItemGuiMetadata : public QgsLayoutItemAbstractGuiMetad
     QgsLayoutItemBaseWidget *createItemWidget( QgsLayoutItem *item ) override { return mWidgetFunc ? mWidgetFunc( item ) : nullptr; }
     QgsLayoutViewRubberBand *createRubberBand( QgsLayoutView *view ) override { return mRubberBandFunc ? mRubberBandFunc( view ) : nullptr; }
     QAbstractGraphicsShapeItem *createNodeRubberBand( QgsLayoutView *view ) override { return mNodeRubberBandFunc ? mNodeRubberBandFunc( view ) : nullptr; }
+
     QgsLayoutItem *createItem( QgsLayout *layout ) override;
     void newItemAddedToLayout( QgsLayoutItem *item ) override;
 
+    /**
+     * Called when a newly created item of the associated type has been added to a layout.
+     *
+     * This is only called for additions which result from GUI operations - i.e. it is not
+     * called for items added from templates.
+     *
+     * The \a properties map will be filled with any custom properties which were specified during
+     * the item creation.
+     *
+     * \since QGIS 3.18
+     */
+    void newItemAddedToLayout( QgsLayoutItem *item, const QVariantMap &properties );
+
   protected:
     QIcon mIcon;
     QgsLayoutItemWidgetFunc mWidgetFunc = nullptr;
@@ -267,7 +289,6 @@ class GUI_EXPORT QgsLayoutItemGuiMetadata : public QgsLayoutItemAbstractGuiMetad
     QgsLayoutNodeItemRubberBandFunc mNodeRubberBandFunc = nullptr;
     QgsLayoutItemCreateFunc mCreateFunc = nullptr;
     QgsLayoutItemAddedToLayoutFunc mAddedToLayoutFunc = nullptr;
-
 };
 
 #endif
@@ -282,12 +303,10 @@ class GUI_EXPORT QgsLayoutItemGuiMetadata : public QgsLayoutItemAbstractGuiMetad
  * For instance, the various basic shape creation tools would use QgsLayoutItemGuiGroup
  * to display grouped within designer dialogs.
  *
- * \since QGIS 3.0
  */
 class GUI_EXPORT QgsLayoutItemGuiGroup
 {
   public:
-
     /**
      * Constructor for QgsLayoutItemGuiGroup.
      */
@@ -311,7 +330,6 @@ class GUI_EXPORT QgsLayoutItemGuiGroup
      * Icon for group.
      */
     QIcon icon;
-
 };
 
 
@@ -326,14 +344,12 @@ class GUI_EXPORT QgsLayoutItemGuiGroup
  * This acts as a companion to QgsLayoutItemRegistry, handling only
  * the components related to the GUI behavior of layout items.
  *
- * \since QGIS 3.0
  */
 class GUI_EXPORT QgsLayoutItemGuiRegistry : public QObject
 {
     Q_OBJECT
 
   public:
-
     /**
      * Creates a new empty item GUI registry.
      *
@@ -344,9 +360,7 @@ class GUI_EXPORT QgsLayoutItemGuiRegistry : public QObject
 
     ~QgsLayoutItemGuiRegistry() override;
 
-    //! QgsLayoutItemGuiRegistry cannot be copied.
     QgsLayoutItemGuiRegistry( const QgsLayoutItemGuiRegistry &rh ) = delete;
-    //! QgsLayoutItemGuiRegistry cannot be copied.
     QgsLayoutItemGuiRegistry &operator=( const QgsLayoutItemGuiRegistry &rh ) = delete;
 
     /**
@@ -355,6 +369,18 @@ class GUI_EXPORT QgsLayoutItemGuiRegistry : public QObject
      */
     QgsLayoutItemAbstractGuiMetadata *itemMetadata( int metadataId ) const;
 
+    /**
+     * Returns the GUI item metadata ID which corresponds to the specified layout item \a type.
+     *
+     * In the case that multiple GUI metadata classes exist for a single layout item \a type then
+     * only the first encountered GUI metadata ID will be returned.
+     *
+     * Returns -1 if no matching metadata is found in the GUI registry.
+     *
+     * \since QGIS 3.18
+     */
+    int metadataIdForItemType( int type ) const;
+
     /**
      * Registers the gui metadata for a new layout item type. Takes ownership of the metadata instance.
      */
@@ -377,23 +403,56 @@ class GUI_EXPORT QgsLayoutItemGuiRegistry : public QObject
      */
     const QgsLayoutItemGuiGroup &itemGroup( const QString &id );
 
+    /*
+     * IMPORTANT: While it seems like /Factory/ would be the correct annotations here, that's not
+     * the case.
+     * As per Phil Thomson's advice on https://www.riverbankcomputing.com/pipermail/pyqt/2017-July/039450.html:
+     *
+     * "
+     * /Factory/ is used when the instance returned is guaranteed to be new to Python.
+     * In this case it isn't because it has already been seen when being returned by QgsProcessingAlgorithm::createInstance()
+     * (However for a different sub-class implemented in C++ then it would be the first time it was seen
+     * by Python so the /Factory/ on create() would be correct.)
+     *
+     * You might try using /TransferBack/ on create() instead - that might be the best compromise.
+     * "
+     */
+
     /**
      * Creates a new instance of a layout item given the item metadata \a metadataId, target \a layout.
      */
-    QgsLayoutItem *createItem( int metadataId, QgsLayout *layout ) const SIP_FACTORY;
+    QgsLayoutItem *createItem( int metadataId, QgsLayout *layout ) const SIP_TRANSFERBACK;
 
     /**
      * Called when a newly created item of the associated metadata \a metadataId has been added to a layout.
      *
      * This is only called for additions which result from GUI operations - i.e. it is not
      * called for items added from templates.
+     *
+     * Since QGIS 3.18 the optional \a properties argument can be used to pass custom properties to the
+     * QgsLayoutItemGuiMetadata::newItemAddedToLayout() function.
+     */
+    void newItemAddedToLayout( int metadataId, QgsLayoutItem *item, const QVariantMap &properties = QVariantMap() );
+
+    /*
+     * IMPORTANT: While it seems like /Factory/ would be the correct annotations here, that's not
+     * the case.
+     * As per Phil Thomson's advice on https://www.riverbankcomputing.com/pipermail/pyqt/2017-July/039450.html:
+     *
+     * "
+     * /Factory/ is used when the instance returned is guaranteed to be new to Python.
+     * In this case it isn't because it has already been seen when being returned by QgsProcessingAlgorithm::createInstance()
+     * (However for a different sub-class implemented in C++ then it would be the first time it was seen
+     * by Python so the /Factory/ on create() would be correct.)
+     *
+     * You might try using /TransferBack/ on create() instead - that might be the best compromise.
+     * "
      */
-    void newItemAddedToLayout( int metadataId, QgsLayoutItem *item );
 
     /**
      * Creates a new instance of a layout item configuration widget for the specified \a item.
      */
-    QgsLayoutItemBaseWidget *createItemWidget( QgsLayoutItem *item ) const SIP_FACTORY;
+    QgsLayoutItemBaseWidget *createItemWidget( QgsLayoutItem *item ) const SIP_TRANSFERBACK;
 
     /**
      * Creates a new rubber band item for the specified item \a metadataId and destination \a view.
@@ -413,7 +472,7 @@ class GUI_EXPORT QgsLayoutItemGuiRegistry : public QObject
     /**
      * Returns a list of available item metadata ids handled by the registry.
      */
-    QList< int > itemMetadataIds() const;
+    QList<int> itemMetadataIds() const;
 
   signals:
 
@@ -428,13 +487,9 @@ class GUI_EXPORT QgsLayoutItemGuiRegistry : public QObject
     QgsLayoutItemGuiRegistry( const QgsLayoutItemGuiRegistry &rh );
 #endif
 
-    QMap< int, QgsLayoutItemAbstractGuiMetadata *> mMetadata;
-
-    QMap< QString, QgsLayoutItemGuiGroup > mItemGroups;
+    QMap<int, QgsLayoutItemAbstractGuiMetadata *> mMetadata;
 
+    QMap<QString, QgsLayoutItemGuiGroup> mItemGroups;
 };
 
 #endif //QGSLAYOUTITEMGUIREGISTRY_H
-
-
-
