@@ -16,13 +16,15 @@
  ***************************************************************************/
 
 #include "qgslayoutlabelwidget.h"
+#include "moc_qgslayoutlabelwidget.cpp"
 #include "qgslayoutitemlabel.h"
 #include "qgslayout.h"
 #include "qgsexpressionbuilderdialog.h"
-#include "qgsguiutils.h"
 #include "qgslayoutitemmap.h"
 #include "qgsvectorlayer.h"
 #include "qgsprojoperation.h"
+#include "qgslayoutreportcontext.h"
+#include "qgsexpressionfinder.h"
 
 #include <QColorDialog>
 #include <QFontDialog>
@@ -40,27 +42,25 @@ QgsLayoutLabelWidget::QgsLayoutLabelWidget( QgsLayoutItemLabel *label )
   connect( mHtmlCheckBox, &QCheckBox::stateChanged, this, &QgsLayoutLabelWidget::mHtmlCheckBox_stateChanged );
   connect( mTextEdit, &QPlainTextEdit::textChanged, this, &QgsLayoutLabelWidget::mTextEdit_textChanged );
   connect( mInsertExpressionButton, &QPushButton::clicked, this, &QgsLayoutLabelWidget::mInsertExpressionButton_clicked );
-  connect( mMarginXDoubleSpinBox, static_cast < void ( QDoubleSpinBox::* )( double ) > ( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutLabelWidget::mMarginXDoubleSpinBox_valueChanged );
-  connect( mMarginYDoubleSpinBox, static_cast < void ( QDoubleSpinBox::* )( double ) > ( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutLabelWidget::mMarginYDoubleSpinBox_valueChanged );
-  connect( mFontColorButton, &QgsColorButton::colorChanged, this, &QgsLayoutLabelWidget::mFontColorButton_colorChanged );
-  connect( mCenterRadioButton, &QRadioButton::clicked, this, &QgsLayoutLabelWidget::mCenterRadioButton_clicked );
-  connect( mLeftRadioButton, &QRadioButton::clicked, this, &QgsLayoutLabelWidget::mLeftRadioButton_clicked );
-  connect( mRightRadioButton, &QRadioButton::clicked, this, &QgsLayoutLabelWidget::mRightRadioButton_clicked );
-  connect( mTopRadioButton, &QRadioButton::clicked, this, &QgsLayoutLabelWidget::mTopRadioButton_clicked );
-  connect( mBottomRadioButton, &QRadioButton::clicked, this, &QgsLayoutLabelWidget::mBottomRadioButton_clicked );
-  connect( mMiddleRadioButton, &QRadioButton::clicked, this, &QgsLayoutLabelWidget::mMiddleRadioButton_clicked );
+  connect( mMarginXDoubleSpinBox, static_cast<void ( QDoubleSpinBox::* )( double )>( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutLabelWidget::mMarginXDoubleSpinBox_valueChanged );
+  connect( mMarginYDoubleSpinBox, static_cast<void ( QDoubleSpinBox::* )( double )>( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutLabelWidget::mMarginYDoubleSpinBox_valueChanged );
+
+  mHAlignmentComboBox->setAvailableAlignments( Qt::AlignLeft | Qt::AlignHCenter | Qt::AlignRight | Qt::AlignJustify );
+  mVAlignmentComboBox->setAvailableAlignments( Qt::AlignTop | Qt::AlignVCenter | Qt::AlignBottom );
+
+  connect( mHAlignmentComboBox, &QgsAlignmentComboBox::changed, this, &QgsLayoutLabelWidget::horizontalAlignmentChanged );
+  connect( mVAlignmentComboBox, &QgsAlignmentComboBox::changed, this, &QgsLayoutLabelWidget::verticalAlignmentChanged );
+
   setPanelTitle( tr( "Label Properties" ) );
 
-  mFontButton->setMode( QgsFontButton::ModeQFont );
+  mFontButton->setMode( QgsFontButton::ModeTextRenderer );
+  mFontButton->setDialogTitle( tr( "Label Font" ) );
+  mFontButton->registerExpressionContextGenerator( this );
 
   //add widget for general composer item properties
   mItemPropertiesWidget = new QgsLayoutItemPropertiesWidget( this, label );
   mainLayout->addWidget( mItemPropertiesWidget );
 
-  mFontColorButton->setColorDialogTitle( tr( "Select Font Color" ) );
-  mFontColorButton->setContext( QStringLiteral( "composer" ) );
-  mFontColorButton->setAllowOpacity( true );
-
   mMarginXDoubleSpinBox->setClearValue( 0.0 );
   mMarginYDoubleSpinBox->setClearValue( 0.0 );
 
@@ -68,21 +68,18 @@ QgsLayoutLabelWidget::QgsLayoutLabelWidget( QgsLayoutItemLabel *label )
   connect( mLabel, &QgsLayoutObject::changed, this, &QgsLayoutLabelWidget::setGuiElementValues );
 
   connect( mFontButton, &QgsFontButton::changed, this, &QgsLayoutLabelWidget::fontChanged );
-  connect( mJustifyRadioButton, &QRadioButton::clicked, this, &QgsLayoutLabelWidget::justifyClicked );
 
   mDynamicTextMenu = new QMenu( this );
   mDynamicTextButton->setMenu( mDynamicTextMenu );
 
-  connect( mDynamicTextMenu, &QMenu::aboutToShow, this, [ = ]
-  {
+  connect( mDynamicTextMenu, &QMenu::aboutToShow, this, [=] {
     mDynamicTextMenu->clear();
     if ( mLabel->layout() )
     {
       // we need to rebuild this on each show, as the content varies depending on other available items...
-      buildInsertDynamicTextMenu( mLabel->layout(), mDynamicTextMenu, [ = ]( const QString & expression )
-      {
+      buildInsertDynamicTextMenu( mLabel->layout(), mDynamicTextMenu, [=]( const QString &expression ) {
         mLabel->beginCommand( tr( "Insert dynamic text" ) );
-        mTextEdit->insertPlainText( "[%" + expression + "%]" );
+        mTextEdit->insertPlainText( "[%" + expression.trimmed() + "%]" );
         mLabel->endCommand();
       } );
     }
@@ -93,6 +90,12 @@ QgsLayoutLabelWidget::QgsLayoutLabelWidget( QgsLayoutItemLabel *label )
   expressionMenu->addAction( convertToStaticAction );
   connect( convertToStaticAction, &QAction::triggered, mLabel, &QgsLayoutItemLabel::convertToStaticText );
   mInsertExpressionButton->setMenu( expressionMenu );
+
+  mFontButton->setLayer( coverageLayer() );
+  if ( mLabel->layout() )
+  {
+    connect( &mLabel->layout()->reportContext(), &QgsLayoutReportContext::layerChanged, mFontButton, &QgsFontButton::setLayer );
+  }
 }
 
 void QgsLayoutLabelWidget::setMasterLayout( QgsMasterLayoutInterface *masterLayout )
@@ -101,21 +104,24 @@ void QgsLayoutLabelWidget::setMasterLayout( QgsMasterLayoutInterface *masterLayo
     mItemPropertiesWidget->setMasterLayout( masterLayout );
 }
 
-void QgsLayoutLabelWidget::buildInsertDynamicTextMenu( QgsLayout *layout, QMenu *menu, const std::function<void ( const QString & )> &callback )
+QgsExpressionContext QgsLayoutLabelWidget::createExpressionContext() const
+{
+  return mLabel->createExpressionContext();
+}
+
+void QgsLayoutLabelWidget::buildInsertDynamicTextMenu( QgsLayout *layout, QMenu *menu, const std::function<void( const QString & )> &callback )
 {
   Q_ASSERT( layout );
-  auto addExpression = [&callback]( QMenu * menu, const QString & name, const QString & expression )
-  {
+  auto addExpression = [&callback]( QMenu *menu, const QString &name, const QString &expression ) {
     QAction *action = new QAction( name, menu );
-    connect( action, &QAction::triggered, action, [callback, expression]
-    {
+    connect( action, &QAction::triggered, action, [callback, expression] {
       callback( expression );
     } );
     menu->addAction( action );
   };
 
   QMenu *dateMenu = new QMenu( tr( "Current Date" ), menu );
-  for ( const std::pair< QString, QString > &expression :
+  for ( const std::pair<QString, QString> &expression :
         {
           std::make_pair( tr( "ISO Format (%1)" ).arg( QDateTime::currentDateTime().toString( QStringLiteral( "yyyy-MM-dd" ) ) ), QStringLiteral( "format_date(now(), 'yyyy-MM-dd')" ) ),
           std::make_pair( tr( "Day/Month/Year (%1)" ).arg( QDateTime::currentDateTime().toString( QStringLiteral( "dd/MM/yyyy" ) ) ), QStringLiteral( "format_date(now(), 'dd/MM/yyyy')" ) ),
@@ -127,7 +133,7 @@ void QgsLayoutLabelWidget::buildInsertDynamicTextMenu( QgsLayout *layout, QMenu
   menu->addMenu( dateMenu );
 
   QMenu *mapsMenu = new QMenu( tr( "Map Properties" ), menu );
-  QList< QgsLayoutItemMap * > maps;
+  QList<QgsLayoutItemMap *> maps;
   layout->layoutItems( maps );
   for ( QgsLayoutItemMap *map : std::as_const( maps ) )
   {
@@ -136,22 +142,22 @@ void QgsLayoutLabelWidget::buildInsertDynamicTextMenu( QgsLayout *layout, QMenu
       continue;
 
     QMenu *mapMenu = new QMenu( map->displayName(), mapsMenu );
-    for ( const std::pair< QString, QString > &expression :
+    for ( const std::pair<QString, QString> &expression :
           {
-            std::make_pair( tr( "Scale (%1)" ).arg( map->scale() ), QStringLiteral( "item_variables('%1')['map_scale']" ).arg( map->id() ) ),
+            std::make_pair( tr( "Scale (%1)" ).arg( map->scale() ), QStringLiteral( "format_number(item_variables('%1')['map_scale'], places:=6, omit_group_separators:=true, trim_trailing_zeroes:=true)" ).arg( map->id() ) ),
             std::make_pair( tr( "Rotation (%1)" ).arg( map->rotation() ), QStringLiteral( "item_variables('%1')['map_rotation']" ).arg( map->id() ) ),
           } )
     {
       addExpression( mapMenu, expression.first, expression.second );
     }
     mapMenu->addSeparator();
-    for ( const std::pair< QString, QString > &expression :
+    for ( const std::pair<QString, QString> &expression :
           {
-            std::make_pair( tr( "CRS Identifier (%1)" ).arg( map->crs().authid() ),  QStringLiteral( "item_variables('%1')['map_crs']" ).arg( map->id() ) ),
-            std::make_pair( tr( "CRS Name (%1)" ).arg( map->crs().description() ),  QStringLiteral( "item_variables('%1')['map_crs_description']" ).arg( map->id() ) ),
-            std::make_pair( tr( "Ellipsoid Name (%1)" ).arg( map->crs().ellipsoidAcronym() ),  QStringLiteral( "item_variables('%1')['map_crs_ellipsoid']" ).arg( map->id() ) ),
-            std::make_pair( tr( "Units (%1)" ).arg( QgsUnitTypes::toString( map->crs().mapUnits() ) ),  QStringLiteral( "item_variables('%1')['map_units']" ).arg( map->id() ) ),
-            std::make_pair( tr( "Projection (%1)" ).arg( map->crs().operation().description() ),  QStringLiteral( "item_variables('%1')['map_crs_projection']" ).arg( map->id() ) ),
+            std::make_pair( tr( "CRS Identifier (%1)" ).arg( map->crs().authid() ), QStringLiteral( "item_variables('%1')['map_crs']" ).arg( map->id() ) ),
+            std::make_pair( tr( "CRS Name (%1)" ).arg( map->crs().description() ), QStringLiteral( "item_variables('%1')['map_crs_description']" ).arg( map->id() ) ),
+            std::make_pair( tr( "Ellipsoid Name (%1)" ).arg( map->crs().ellipsoidAcronym() ), QStringLiteral( "item_variables('%1')['map_crs_ellipsoid']" ).arg( map->id() ) ),
+            std::make_pair( tr( "Units (%1)" ).arg( QgsUnitTypes::toString( map->crs().mapUnits() ) ), QStringLiteral( "item_variables('%1')['map_units']" ).arg( map->id() ) ),
+            std::make_pair( tr( "Projection (%1)" ).arg( map->crs().operation().description() ), QStringLiteral( "item_variables('%1')['map_crs_projection']" ).arg( map->id() ) ),
           } )
     {
       addExpression( mapMenu, expression.first, expression.second );
@@ -160,22 +166,22 @@ void QgsLayoutLabelWidget::buildInsertDynamicTextMenu( QgsLayout *layout, QMenu
 
     const QgsRectangle mapExtent = map->extent();
     const QgsPointXY center = mapExtent.center();
-    for ( const std::pair< QString, QString > &expression :
+    for ( const std::pair<QString, QString> &expression :
           {
-            std::make_pair( tr( "Center (X) (%1)" ).arg( center.x() ),  QStringLiteral( "x(item_variables('%1')['map_extent_center'])" ).arg( map->id() ) ),
-            std::make_pair( tr( "Center (Y) (%1)" ).arg( center.y() ),  QStringLiteral( "y(item_variables('%1')['map_extent_center'])" ).arg( map->id() ) ),
-            std::make_pair( tr( "X Minimum (%1)" ).arg( mapExtent.xMinimum() ),  QStringLiteral( "x_min(item_variables('%1')['map_extent'])" ).arg( map->id() ) ),
-            std::make_pair( tr( "Y Minimum (%1)" ).arg( mapExtent.yMinimum() ),  QStringLiteral( "y_min(item_variables('%1')['map_extent'])" ).arg( map->id() ) ),
-            std::make_pair( tr( "X Maximum (%1)" ).arg( mapExtent.xMaximum() ),  QStringLiteral( "x_max(item_variables('%1')['map_extent'])" ).arg( map->id() ) ),
-            std::make_pair( tr( "Y Maximum (%1)" ).arg( mapExtent.yMaximum() ),  QStringLiteral( "y_max(item_variables('%1')['map_extent'])" ).arg( map->id() ) ),
+            std::make_pair( tr( "Center (X) (%1)" ).arg( center.x() ), QStringLiteral( "x(item_variables('%1')['map_extent_center'])" ).arg( map->id() ) ),
+            std::make_pair( tr( "Center (Y) (%1)" ).arg( center.y() ), QStringLiteral( "y(item_variables('%1')['map_extent_center'])" ).arg( map->id() ) ),
+            std::make_pair( tr( "X Minimum (%1)" ).arg( mapExtent.xMinimum() ), QStringLiteral( "x_min(item_variables('%1')['map_extent'])" ).arg( map->id() ) ),
+            std::make_pair( tr( "Y Minimum (%1)" ).arg( mapExtent.yMinimum() ), QStringLiteral( "y_min(item_variables('%1')['map_extent'])" ).arg( map->id() ) ),
+            std::make_pair( tr( "X Maximum (%1)" ).arg( mapExtent.xMaximum() ), QStringLiteral( "x_max(item_variables('%1')['map_extent'])" ).arg( map->id() ) ),
+            std::make_pair( tr( "Y Maximum (%1)" ).arg( mapExtent.yMaximum() ), QStringLiteral( "y_max(item_variables('%1')['map_extent'])" ).arg( map->id() ) ),
           } )
     {
       addExpression( mapMenu, expression.first, expression.second );
     }
     mapMenu->addSeparator();
-    for ( const std::pair< QString, QString > &expression :
+    for ( const std::pair<QString, QString> &expression :
           {
-            std::make_pair( tr( "Layer Credits" ),  QStringLiteral( "array_to_string(map_credits('%1'))" ).arg( map->id() ) ),
+            std::make_pair( tr( "Layer Credits" ), QStringLiteral( "array_to_string(map_credits('%1'))" ).arg( map->id() ) ),
           } )
     {
       addExpression( mapMenu, expression.first, expression.second );
@@ -199,17 +205,18 @@ void QgsLayoutLabelWidget::buildInsertDynamicTextMenu( QgsLayout *layout, QMenu
     menu->addSeparator();
   }
 
-  for ( const std::pair< QString, QString > &expression :
+  for ( const std::pair<QString, QString> &expression :
         {
           std::make_pair( tr( "Layout Name" ), QStringLiteral( "@layout_name" ) ),
           std::make_pair( tr( "Layout Page Number" ), QStringLiteral( "@layout_page" ) ),
-          std::make_pair( tr( "Layout Page Count" ), QStringLiteral( "@layout_numpages" ) )
+          std::make_pair( tr( "Layout Page Count" ), QStringLiteral( "@layout_numpages" ) ),
+          std::make_pair( tr( "Layer Credits" ), QStringLiteral( "array_to_string(map_credits())" ) )
         } )
   {
     addExpression( menu, expression.first, expression.second );
   }
   menu->addSeparator();
-  for ( const std::pair< QString, QString > &expression :
+  for ( const std::pair<QString, QString> &expression :
         {
           std::make_pair( tr( "Project Author" ), QStringLiteral( "@project_author" ) ),
           std::make_pair( tr( "Project Title" ), QStringLiteral( "@project_title" ) ),
@@ -219,7 +226,7 @@ void QgsLayoutLabelWidget::buildInsertDynamicTextMenu( QgsLayout *layout, QMenu
     addExpression( menu, expression.first, expression.second );
   }
   menu->addSeparator();
-  for ( const std::pair< QString, QString > &expression :
+  for ( const std::pair<QString, QString> &expression :
         {
           std::make_pair( tr( "Current User Name" ), QStringLiteral( "@user_full_name" ) ),
           std::make_pair( tr( "Current User Account" ), QStringLiteral( "@user_account_name" ) )
@@ -239,7 +246,7 @@ bool QgsLayoutLabelWidget::setNewItem( QgsLayoutItem *item )
     disconnect( mLabel, &QgsLayoutObject::changed, this, &QgsLayoutLabelWidget::setGuiElementValues );
   }
 
-  mLabel = qobject_cast< QgsLayoutItemLabel * >( item );
+  mLabel = qobject_cast<QgsLayoutItemLabel *>( item );
   mItemPropertiesWidget->setItem( mLabel );
 
   if ( mLabel )
@@ -257,9 +264,7 @@ void QgsLayoutLabelWidget::mHtmlCheckBox_stateChanged( int state )
   if ( mLabel )
   {
     mVerticalAlignementLabel->setDisabled( state );
-    mTopRadioButton->setDisabled( state );
-    mMiddleRadioButton->setDisabled( state );
-    mBottomRadioButton->setDisabled( state );
+    mVAlignmentComboBox->setDisabled( state );
 
     mLabel->beginCommand( tr( "Change Label Mode" ) );
     mLabel->blockSignals( true );
@@ -288,20 +293,8 @@ void QgsLayoutLabelWidget::fontChanged()
 {
   if ( mLabel )
   {
-    QFont newFont = mFontButton->currentFont();
     mLabel->beginCommand( tr( "Change Label Font" ), QgsLayoutItem::UndoLabelFont );
-    mLabel->setFont( newFont );
-    mLabel->update();
-    mLabel->endCommand();
-  }
-}
-
-void QgsLayoutLabelWidget::justifyClicked()
-{
-  if ( mLabel )
-  {
-    mLabel->beginCommand( tr( "Change Label Alignment" ) );
-    mLabel->setHAlign( Qt::AlignJustify );
+    mLabel->setTextFormat( mFontButton->textFormat() );
     mLabel->update();
     mLabel->endCommand();
   }
@@ -329,19 +322,6 @@ void QgsLayoutLabelWidget::mMarginYDoubleSpinBox_valueChanged( double d )
   }
 }
 
-void QgsLayoutLabelWidget::mFontColorButton_colorChanged( const QColor &newLabelColor )
-{
-  if ( !mLabel )
-  {
-    return;
-  }
-
-  mLabel->beginCommand( tr( "Change Label Color" ), QgsLayoutItem::UndoLabelFontColor );
-  mLabel->setFontColor( newLabelColor );
-  mLabel->update();
-  mLabel->endCommand();
-}
-
 void QgsLayoutLabelWidget::mInsertExpressionButton_clicked()
 {
   if ( !mLabel )
@@ -349,95 +329,44 @@ void QgsLayoutLabelWidget::mInsertExpressionButton_clicked()
     return;
   }
 
-  QString selText = mTextEdit->textCursor().selectedText();
-
-  // html editor replaces newlines with Paragraph Separator characters - see https://github.com/qgis/QGIS/issues/27568
-  selText = selText.replace( QChar( 0x2029 ), QChar( '\n' ) );
-
-  // edit the selected expression if there's one
-  if ( selText.startsWith( QLatin1String( "[%" ) ) && selText.endsWith( QLatin1String( "%]" ) ) )
-    selText = selText.mid( 2, selText.size() - 4 );
+  QString expression = QgsExpressionFinder::findAndSelectActiveExpression( mTextEdit );
 
   // use the atlas coverage layer, if any
   QgsVectorLayer *layer = coverageLayer();
 
   QgsExpressionContext context = mLabel->createExpressionContext();
-  QgsExpressionBuilderDialog exprDlg( layer, selText, this, QStringLiteral( "generic" ), context );
+  QgsExpressionBuilderDialog exprDlg( layer, expression, this, QStringLiteral( "generic" ), context );
 
   exprDlg.setWindowTitle( tr( "Insert Expression" ) );
   if ( exprDlg.exec() == QDialog::Accepted )
   {
-    QString expression = exprDlg.expressionText();
+    expression = exprDlg.expressionText();
     if ( !expression.isEmpty() )
     {
       mLabel->beginCommand( tr( "Insert expression" ) );
-      mTextEdit->insertPlainText( "[%" + expression + "%]" );
+      mTextEdit->insertPlainText( "[%" + expression.trimmed() + "%]" );
       mLabel->endCommand();
     }
   }
 }
 
-void QgsLayoutLabelWidget::mCenterRadioButton_clicked()
+void QgsLayoutLabelWidget::horizontalAlignmentChanged()
 {
   if ( mLabel )
   {
     mLabel->beginCommand( tr( "Change Label Alignment" ) );
-    mLabel->setHAlign( Qt::AlignHCenter );
+    mLabel->setHAlign( static_cast<Qt::AlignmentFlag>( static_cast<int>( mHAlignmentComboBox->currentAlignment() ) ) );
     mLabel->update();
     mLabel->endCommand();
   }
 }
 
-void QgsLayoutLabelWidget::mRightRadioButton_clicked()
+void QgsLayoutLabelWidget::verticalAlignmentChanged()
 {
   if ( mLabel )
   {
     mLabel->beginCommand( tr( "Change Label Alignment" ) );
-    mLabel->setHAlign( Qt::AlignRight );
-    mLabel->update();
-    mLabel->endCommand();
-  }
-}
-
-void QgsLayoutLabelWidget::mLeftRadioButton_clicked()
-{
-  if ( mLabel )
-  {
-    mLabel->beginCommand( tr( "Change Label Alignment" ) );
-    mLabel->setHAlign( Qt::AlignLeft );
-    mLabel->update();
-    mLabel->endCommand();
-  }
-}
-
-void QgsLayoutLabelWidget::mTopRadioButton_clicked()
-{
-  if ( mLabel )
-  {
-    mLabel->beginCommand( tr( "Change Label Alignment" ) );
-    mLabel->setVAlign( Qt::AlignTop );
-    mLabel->update();
-    mLabel->endCommand();
-  }
-}
-
-void QgsLayoutLabelWidget::mBottomRadioButton_clicked()
-{
-  if ( mLabel )
-  {
-    mLabel->beginCommand( tr( "Change Label Alignment" ) );
-    mLabel->setVAlign( Qt::AlignBottom );
-    mLabel->update();
-    mLabel->endCommand();
-  }
-}
-
-void QgsLayoutLabelWidget::mMiddleRadioButton_clicked()
-{
-  if ( mLabel )
-  {
-    mLabel->beginCommand( tr( "Change Label Alignment" ) );
-    mLabel->setVAlign( Qt::AlignVCenter );
+    mLabel->setVAlign( static_cast<Qt::AlignmentFlag>( static_cast<int>( mVAlignmentComboBox->currentAlignment() ) ) );
     mLabel->update();
     mLabel->endCommand();
   }
@@ -451,19 +380,13 @@ void QgsLayoutLabelWidget::setGuiElementValues()
   mMarginXDoubleSpinBox->setValue( mLabel->marginX() );
   mMarginYDoubleSpinBox->setValue( mLabel->marginY() );
   mHtmlCheckBox->setChecked( mLabel->mode() == QgsLayoutItemLabel::ModeHtml );
-  mTopRadioButton->setChecked( mLabel->vAlign() == Qt::AlignTop );
-  mMiddleRadioButton->setChecked( mLabel->vAlign() == Qt::AlignVCenter );
-  mBottomRadioButton->setChecked( mLabel->vAlign() == Qt::AlignBottom );
-  mLeftRadioButton->setChecked( mLabel->hAlign() == Qt::AlignLeft );
-  mJustifyRadioButton->setChecked( mLabel->hAlign() == Qt::AlignJustify );
-  mCenterRadioButton->setChecked( mLabel->hAlign() == Qt::AlignHCenter );
-  mRightRadioButton->setChecked( mLabel->hAlign() == Qt::AlignRight );
-  mFontColorButton->setColor( mLabel->fontColor() );
-  mFontButton->setCurrentFont( mLabel->font() );
+
+  mHAlignmentComboBox->setCurrentAlignment( mLabel->hAlign() );
+  mVAlignmentComboBox->setCurrentAlignment( mLabel->vAlign() );
+
+  mFontButton->setTextFormat( mLabel->textFormat() );
   mVerticalAlignementLabel->setDisabled( mLabel->mode() == QgsLayoutItemLabel::ModeHtml );
-  mTopRadioButton->setDisabled( mLabel->mode() == QgsLayoutItemLabel::ModeHtml );
-  mMiddleRadioButton->setDisabled( mLabel->mode() == QgsLayoutItemLabel::ModeHtml );
-  mBottomRadioButton->setDisabled( mLabel->mode() == QgsLayoutItemLabel::ModeHtml );
+  mVAlignmentComboBox->setDisabled( mLabel->mode() == QgsLayoutItemLabel::ModeHtml );
 
   blockAllSignals( false );
 }
@@ -474,13 +397,7 @@ void QgsLayoutLabelWidget::blockAllSignals( bool block )
   mHtmlCheckBox->blockSignals( block );
   mMarginXDoubleSpinBox->blockSignals( block );
   mMarginYDoubleSpinBox->blockSignals( block );
-  mTopRadioButton->blockSignals( block );
-  mMiddleRadioButton->blockSignals( block );
-  mBottomRadioButton->blockSignals( block );
-  mLeftRadioButton->blockSignals( block );
-  mCenterRadioButton->blockSignals( block );
-  mRightRadioButton->blockSignals( block );
-  mJustifyRadioButton->blockSignals( block );
-  mFontColorButton->blockSignals( block );
+  mHAlignmentComboBox->blockSignals( block );
+  mVAlignmentComboBox->blockSignals( block );
   mFontButton->blockSignals( block );
 }
