@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsmodelcomponentgraphicitem.h"
+#include "moc_qgsmodelcomponentgraphicitem.cpp"
 #include "qgsprocessingmodelcomponent.h"
 #include "qgsprocessingmodelparameter.h"
 #include "qgsprocessingmodelchildalgorithm.h"
@@ -27,6 +28,7 @@
 #include "qgsmodelviewtool.h"
 #include "qgsmodelviewmouseevent.h"
 #include "qgsmodelgroupboxdefinitionwidget.h"
+#include "qgsmessagelog.h"
 
 #include <QSvgRenderer>
 #include <QPicture>
@@ -97,7 +99,7 @@ QgsModelGraphicsView *QgsModelComponentGraphicItem::view()
   if ( scene()->views().isEmpty() )
     return nullptr;
 
-  return qobject_cast< QgsModelGraphicsView * >( scene()->views().first() );
+  return qobject_cast<QgsModelGraphicsView *>( scene()->views().first() );
 }
 
 QFont QgsModelComponentGraphicItem::font() const
@@ -266,12 +268,12 @@ QVariant QgsModelComponentGraphicItem::itemChange( QGraphicsItem::GraphicsItemCh
         if ( linkPointCount( Qt::TopEdge ) )
         {
           mExpandTopButton = new QgsModelDesignerFoldButtonGraphicItem( this, mComponent->linksCollapsed( Qt::TopEdge ), QPointF( 0, 0 ) );
-          connect( mExpandTopButton, &QgsModelDesignerFoldButtonGraphicItem::folded, this, [ = ]( bool folded ) { fold( Qt::TopEdge, folded ); } );
+          connect( mExpandTopButton, &QgsModelDesignerFoldButtonGraphicItem::folded, this, [=]( bool folded ) { fold( Qt::TopEdge, folded ); } );
         }
         if ( linkPointCount( Qt::BottomEdge ) )
         {
           mExpandBottomButton = new QgsModelDesignerFoldButtonGraphicItem( this, mComponent->linksCollapsed( Qt::BottomEdge ), QPointF( 0, 0 ) );
-          connect( mExpandBottomButton, &QgsModelDesignerFoldButtonGraphicItem::folded, this, [ = ]( bool folded ) { fold( Qt::BottomEdge, folded ); } );
+          connect( mExpandBottomButton, &QgsModelDesignerFoldButtonGraphicItem::folded, this, [=]( bool folded ) { fold( Qt::BottomEdge, folded ); } );
         }
         mInitialized = true;
         updateButtonPositions();
@@ -292,14 +294,9 @@ QRectF QgsModelComponentGraphicItem::boundingRect() const
   const int linksAbove = linkPointCount( Qt::TopEdge );
   const int linksBelow = linkPointCount( Qt::BottomEdge );
 
-  const double hUp = linksAbove == 0 ? 0 :
-                     fm.height() * 1.2 * ( ( mComponent->linksCollapsed( Qt::TopEdge ) ? 0 : linksAbove ) + 2 );
-  const double hDown = linksBelow == 0 ? 0 :
-                       fm.height() * 1.2 * ( ( mComponent->linksCollapsed( Qt::BottomEdge ) ? 0 : linksBelow ) + 2 );
-  return QRectF( -( itemSize().width() ) / 2 - RECT_PEN_SIZE,
-                 -( itemSize().height() ) / 2 - hUp - RECT_PEN_SIZE,
-                 itemSize().width() + 2 * RECT_PEN_SIZE,
-                 itemSize().height() + hDown + hUp + 2 * RECT_PEN_SIZE );
+  const double hUp = linksAbove == 0 ? 0 : fm.height() * 1.2 * ( ( mComponent->linksCollapsed( Qt::TopEdge ) ? 0 : linksAbove ) + 2 );
+  const double hDown = linksBelow == 0 ? 0 : fm.height() * 1.2 * ( ( mComponent->linksCollapsed( Qt::BottomEdge ) ? 0 : linksBelow ) + 2 );
+  return QRectF( -( itemSize().width() ) / 2 - RECT_PEN_SIZE, -( itemSize().height() ) / 2 - hUp - RECT_PEN_SIZE, itemSize().width() + 2 * RECT_PEN_SIZE, itemSize().height() + hDown + hUp + 2 * RECT_PEN_SIZE );
 }
 
 bool QgsModelComponentGraphicItem::contains( const QPointF &point ) const
@@ -348,7 +345,7 @@ void QgsModelComponentGraphicItem::paint( QPainter *painter, const QStyleOptionG
     foreColor = textColor( state() );
   }
 
-  QPen strokePen = QPen( stroke, 0 ) ; // 0 width "cosmetic" pen
+  QPen strokePen = QPen( stroke, 0 ); // 0 width "cosmetic" pen
   strokePen.setStyle( strokeStyle( state() ) );
   painter->setPen( strokePen );
   painter->setBrush( QBrush( color, Qt::SolidPattern ) );
@@ -372,8 +369,7 @@ void QgsModelComponentGraphicItem::paint( QPainter *painter, const QStyleOptionG
   }
   else
   {
-    const QRectF labelRect = QRectF( rect.left() + 21 + TEXT_MARGIN, rect.top() + TEXT_MARGIN,
-                                     rect.width() - 2 * TEXT_MARGIN - mButtonSize.width() - BUTTON_MARGIN - 21, rect.height() - 2 * TEXT_MARGIN );
+    const QRectF labelRect = QRectF( rect.left() + 21 + TEXT_MARGIN, rect.top() + TEXT_MARGIN, rect.width() - 2 * TEXT_MARGIN - mButtonSize.width() - BUTTON_MARGIN - 21, rect.height() - 2 * TEXT_MARGIN );
     text = label();
     painter->drawText( labelRect, Qt::TextWordWrap | Qt::AlignVCenter, text );
   }
@@ -436,16 +432,10 @@ QRectF QgsModelComponentGraphicItem::itemRect( bool storedRect ) const
 {
   if ( storedRect )
   {
-    return QRectF( mComponent->position().x() - ( mComponent->size().width() ) / 2.0,
-                   mComponent->position().y()  - ( mComponent->size().height() ) / 2.0,
-                   mComponent->size().width(),
-                   mComponent->size().height() );
+    return QRectF( mComponent->position().x() - ( mComponent->size().width() ) / 2.0, mComponent->position().y() - ( mComponent->size().height() ) / 2.0, mComponent->size().width(), mComponent->size().height() );
   }
   else
-    return QRectF( -( itemSize().width() ) / 2.0,
-                   -( itemSize().height() ) / 2.0,
-                   itemSize().width(),
-                   itemSize().height() );
+    return QRectF( -( itemSize().width() ) / 2.0, -( itemSize().height() ) / 2.0, itemSize().width(), itemSize().height() );
 }
 
 QString QgsModelComponentGraphicItem::truncatedTextForItem( const QString &text ) const
@@ -491,10 +481,8 @@ QPixmap QgsModelComponentGraphicItem::iconPixmap() const
 
 void QgsModelComponentGraphicItem::updateButtonPositions()
 {
-  mEditButton->setPosition( QPointF( itemSize().width() / 2.0 - mButtonSize.width() / 2.0 - BUTTON_MARGIN,
-                                     itemSize().height() / 2.0 - mButtonSize.height() / 2.0 - BUTTON_MARGIN ) );
-  mDeleteButton->setPosition( QPointF( itemSize().width() / 2.0 - mButtonSize.width() / 2.0 - BUTTON_MARGIN,
-                                       mButtonSize.height() / 2.0 - itemSize().height() / 2.0 + BUTTON_MARGIN ) );
+  mEditButton->setPosition( QPointF( itemSize().width() / 2.0 - mButtonSize.width() / 2.0 - BUTTON_MARGIN, itemSize().height() / 2.0 - mButtonSize.height() / 2.0 - BUTTON_MARGIN ) );
+  mDeleteButton->setPosition( QPointF( itemSize().width() / 2.0 - mButtonSize.width() / 2.0 - BUTTON_MARGIN, mButtonSize.height() / 2.0 - itemSize().height() / 2.0 + BUTTON_MARGIN ) );
 
   if ( mExpandTopButton )
   {
@@ -540,11 +528,11 @@ void QgsModelComponentGraphicItem::fold( Qt::Edge edge, bool folded )
   // also need to update the model's stored component
 
   // TODO - this is not so nice, consider moving this to model class
-  if ( QgsProcessingModelChildAlgorithm *child = dynamic_cast< QgsProcessingModelChildAlgorithm * >( mComponent.get() ) )
+  if ( QgsProcessingModelChildAlgorithm *child = dynamic_cast<QgsProcessingModelChildAlgorithm *>( mComponent.get() ) )
     mModel->childAlgorithm( child->childId() ).setLinksCollapsed( edge, folded );
-  else if ( QgsProcessingModelParameter *param = dynamic_cast< QgsProcessingModelParameter * >( mComponent.get() ) )
+  else if ( QgsProcessingModelParameter *param = dynamic_cast<QgsProcessingModelParameter *>( mComponent.get() ) )
     mModel->parameterComponent( param->parameterName() ).setLinksCollapsed( edge, folded );
-  else if ( QgsProcessingModelOutput *output = dynamic_cast< QgsProcessingModelOutput * >( mComponent.get() ) )
+  else if ( QgsProcessingModelOutput *output = dynamic_cast<QgsProcessingModelOutput *>( mComponent.get() ) )
     mModel->childAlgorithm( output->childId() ).modelOutput( output->name() ).setLinksCollapsed( edge, folded );
 
   prepareGeometryChange();
@@ -604,9 +592,7 @@ QPointF QgsModelComponentGraphicItem::linkPoint( Qt::Edge edge, int index, bool
         const double h = fm.height() * 1.2 * ( pointIndex + 1 ) + fm.height() / 2.0;
         const double y = h + itemSize().height() / 2.0 + 5;
         const double x = !mComponent->linksCollapsed( Qt::BottomEdge ) ? ( -itemSize().width() / 2 + 33 + w + 5 ) : 10;
-        return QPointF( incoming ? -itemSize().width() / 2 + offsetX
-                        :  x,
-                        y );
+        return QPointF( incoming ? -itemSize().width() / 2 + offsetX : x, y );
       }
       break;
     }
@@ -627,9 +613,7 @@ QPointF QgsModelComponentGraphicItem::linkPoint( Qt::Edge edge, int index, bool
         const double w = fm.boundingRect( text ).width();
         double h = -( fm.height() * 1.2 ) * ( paramIndex + 2 ) - fm.height() / 2.0 + 8;
         h = h - itemSize().height() / 2.0;
-        return QPointF( incoming ? -itemSize().width() / 2 + offsetX
-                        : ( !mComponent->linksCollapsed( Qt::TopEdge ) ? ( -itemSize().width() / 2 + 33 + w + 5 ) : 10 ),
-                        h );
+        return QPointF( incoming ? -itemSize().width() / 2 + offsetX : ( !mComponent->linksCollapsed( Qt::TopEdge ) ? ( -itemSize().width() / 2 + 33 + w + 5 ) : 10 ), h );
       }
       break;
     }
@@ -788,7 +772,7 @@ QPicture QgsModelParameterGraphicItem::iconPicture() const
 
 void QgsModelParameterGraphicItem::updateStoredComponentPosition( const QPointF &pos, const QSizeF &size )
 {
-  if ( QgsProcessingModelParameter *param = dynamic_cast< QgsProcessingModelParameter * >( component() ) )
+  if ( QgsProcessingModelParameter *param = dynamic_cast<QgsProcessingModelParameter *>( component() ) )
   {
     model()->parameterComponent( param->parameterName() ).setPosition( pos );
     model()->parameterComponent( param->parameterName() ).setSize( size );
@@ -797,7 +781,7 @@ void QgsModelParameterGraphicItem::updateStoredComponentPosition( const QPointF
 
 bool QgsModelParameterGraphicItem::canDeleteComponent()
 {
-  if ( const QgsProcessingModelParameter *param = dynamic_cast< const QgsProcessingModelParameter * >( component() ) )
+  if ( const QgsProcessingModelParameter *param = dynamic_cast<const QgsProcessingModelParameter *>( component() ) )
   {
     if ( model()->childAlgorithmsDependOnParameter( param->parameterName() ) )
     {
@@ -817,19 +801,17 @@ bool QgsModelParameterGraphicItem::canDeleteComponent()
 
 void QgsModelParameterGraphicItem::deleteComponent()
 {
-  if ( const QgsProcessingModelParameter *param = dynamic_cast< const QgsProcessingModelParameter * >( component() ) )
+  if ( const QgsProcessingModelParameter *param = dynamic_cast<const QgsProcessingModelParameter *>( component() ) )
   {
     if ( model()->childAlgorithmsDependOnParameter( param->parameterName() ) )
     {
-      QMessageBox::warning( nullptr, QObject::tr( "Could not remove input" ),
-                            QObject::tr( "Algorithms depend on the selected input.\n"
-                                         "Remove them before trying to remove it." ) );
+      QMessageBox::warning( nullptr, QObject::tr( "Could not remove input" ), QObject::tr( "Algorithms depend on the selected input.\n"
+                                                                                           "Remove them before trying to remove it." ) );
     }
     else if ( model()->otherParametersDependOnParameter( param->parameterName() ) )
     {
-      QMessageBox::warning( nullptr, QObject::tr( "Could not remove input" ),
-                            QObject::tr( "Other inputs depend on the selected input.\n"
-                                         "Remove them before trying to remove it." ) );
+      QMessageBox::warning( nullptr, QObject::tr( "Could not remove input" ), QObject::tr( "Other inputs depend on the selected input.\n"
+                                                                                           "Remove them before trying to remove it." ) );
     }
     else
     {
@@ -842,7 +824,6 @@ void QgsModelParameterGraphicItem::deleteComponent()
 }
 
 
-
 QgsModelChildAlgorithmGraphicItem::QgsModelChildAlgorithmGraphicItem( QgsProcessingModelChildAlgorithm *child, QgsProcessingModelAlgorithm *model, QGraphicsItem *parent )
   : QgsModelComponentGraphicItem( child, model, parent )
 {
@@ -869,6 +850,20 @@ QgsModelChildAlgorithmGraphicItem::QgsModelChildAlgorithmGraphicItem( QgsProcess
 void QgsModelChildAlgorithmGraphicItem::contextMenuEvent( QGraphicsSceneContextMenuEvent *event )
 {
   QMenu *popupmenu = new QMenu( event->widget() );
+
+  if ( isSelected() )
+  {
+    QAction *runSelectedStepsAction = popupmenu->addAction( QObject::tr( "Run Selected Steps…" ) );
+    runSelectedStepsAction->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "mActionRunSelected.svg" ) ) );
+    connect( runSelectedStepsAction, &QAction::triggered, this, &QgsModelChildAlgorithmGraphicItem::runSelected );
+  }
+
+  QAction *runFromHereAction = popupmenu->addAction( QObject::tr( "Run from Here…" ) );
+  runFromHereAction->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "mActionStart.svg" ) ) );
+  connect( runFromHereAction, &QAction::triggered, this, &QgsModelChildAlgorithmGraphicItem::runFromHere );
+
+  popupmenu->addSeparator();
+
   QAction *removeAction = popupmenu->addAction( QObject::tr( "Remove" ) );
   connect( removeAction, &QAction::triggered, this, &QgsModelChildAlgorithmGraphicItem::deleteComponent );
   QAction *editAction = popupmenu->addAction( QObject::tr( "Edit…" ) );
@@ -877,7 +872,7 @@ void QgsModelChildAlgorithmGraphicItem::contextMenuEvent( QGraphicsSceneContextM
   connect( editCommentAction, &QAction::triggered, this, &QgsModelParameterGraphicItem::editComment );
   popupmenu->addSeparator();
 
-  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast< const QgsProcessingModelChildAlgorithm * >( component() ) )
+  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast<const QgsProcessingModelChildAlgorithm *>( component() ) )
   {
     if ( !child->isActive() )
     {
@@ -889,6 +884,44 @@ void QgsModelChildAlgorithmGraphicItem::contextMenuEvent( QGraphicsSceneContextM
       QAction *deactivateAction = popupmenu->addAction( QObject::tr( "Deactivate" ) );
       connect( deactivateAction, &QAction::triggered, this, &QgsModelChildAlgorithmGraphicItem::deactivateAlgorithm );
     }
+
+    // only show the "View Output Layers" action for algorithms which create layers
+    if ( const QgsProcessingAlgorithm *algorithm = child->algorithm() )
+    {
+      const QList<const QgsProcessingParameterDefinition *> outputParams = algorithm->destinationParameterDefinitions();
+      if ( !outputParams.isEmpty() )
+      {
+        popupmenu->addSeparator();
+        QAction *viewOutputLayersAction = popupmenu->addAction( QObject::tr( "View Output Layers" ) );
+        viewOutputLayersAction->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "mActionShowSelectedLayers.svg" ) ) );
+        connect( viewOutputLayersAction, &QAction::triggered, this, &QgsModelChildAlgorithmGraphicItem::showPreviousResults );
+        // enable this action only when the child succeeded
+        switch ( mResults.executionStatus() )
+        {
+          case Qgis::ProcessingModelChildAlgorithmExecutionStatus::NotExecuted:
+          case Qgis::ProcessingModelChildAlgorithmExecutionStatus::Failed:
+            viewOutputLayersAction->setEnabled( false );
+            break;
+
+          case Qgis::ProcessingModelChildAlgorithmExecutionStatus::Success:
+            break;
+        }
+      }
+    }
+
+    QAction *viewLogAction = popupmenu->addAction( QObject::tr( "View Log…" ) );
+    connect( viewLogAction, &QAction::triggered, this, &QgsModelChildAlgorithmGraphicItem::showLog );
+    // enable this action even when the child failed
+    switch ( mResults.executionStatus() )
+    {
+      case Qgis::ProcessingModelChildAlgorithmExecutionStatus::NotExecuted:
+        viewLogAction->setEnabled( false );
+        break;
+
+      case Qgis::ProcessingModelChildAlgorithmExecutionStatus::Success:
+      case Qgis::ProcessingModelChildAlgorithmExecutionStatus::Failed:
+        break;
+    }
   }
 
   popupmenu->exec( event->screenPos() );
@@ -933,7 +966,7 @@ QColor QgsModelChildAlgorithmGraphicItem::strokeColor( QgsModelComponentGraphicI
 
 QColor QgsModelChildAlgorithmGraphicItem::textColor( QgsModelComponentGraphicItem::State ) const
 {
-  return mIsValid ? ( qgis::down_cast< const QgsProcessingModelChildAlgorithm * >( component() )->isActive() ? Qt::black : Qt::gray ) : QColor( 255, 255, 255 );
+  return mIsValid ? ( qgis::down_cast<const QgsProcessingModelChildAlgorithm *>( component() )->isActive() ? Qt::black : Qt::gray ) : QColor( 255, 255, 255 );
 }
 
 QPixmap QgsModelChildAlgorithmGraphicItem::iconPixmap() const
@@ -948,7 +981,7 @@ QPicture QgsModelChildAlgorithmGraphicItem::iconPicture() const
 
 int QgsModelChildAlgorithmGraphicItem::linkPointCount( Qt::Edge edge ) const
 {
-  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast< const QgsProcessingModelChildAlgorithm * >( component() ) )
+  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast<const QgsProcessingModelChildAlgorithm *>( component() ) )
   {
     if ( !child->algorithm() )
       return 0;
@@ -960,10 +993,10 @@ int QgsModelChildAlgorithmGraphicItem::linkPointCount( Qt::Edge edge ) const
       case Qt::TopEdge:
       {
         QgsProcessingParameterDefinitions params = child->algorithm()->parameterDefinitions();
-        params.erase( std::remove_if( params.begin(), params.end(), []( const QgsProcessingParameterDefinition * param )
-        {
-          return param->flags() & QgsProcessingParameterDefinition::FlagHidden || param->isDestination();
-        } ), params.end() );
+        params.erase( std::remove_if( params.begin(), params.end(), []( const QgsProcessingParameterDefinition *param ) {
+                        return param->flags() & Qgis::ProcessingParameterFlag::Hidden || param->isDestination();
+                      } ),
+                      params.end() );
         return params.size();
       }
 
@@ -980,11 +1013,13 @@ QString QgsModelChildAlgorithmGraphicItem::linkPointText( Qt::Edge edge, int ind
   if ( index < 0 )
     return QString();
 
-  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast< const QgsProcessingModelChildAlgorithm * >( component() ) )
+  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast<const QgsProcessingModelChildAlgorithm *>( component() ) )
   {
     if ( !child->algorithm() )
       return QString();
 
+    const QVariantMap inputs = mResults.inputs();
+    const QVariantMap outputs = mResults.outputs();
     switch ( edge )
     {
       case Qt::BottomEdge:
@@ -994,15 +1029,16 @@ QString QgsModelChildAlgorithmGraphicItem::linkPointText( Qt::Edge edge, int ind
           // something goes wrong and tried to link to an not existing output
           QgsMessageLog::logMessage(
             tr( "Cannot link output for child: %1" ).arg( child->algorithm()->name() ),
-            "QgsModelChildAlgorithmGraphicItem", Qgis::MessageLevel::Warning, true );
+            "QgsModelChildAlgorithmGraphicItem", Qgis::MessageLevel::Warning, true
+          );
           return QString();
         }
 
         const QgsProcessingOutputDefinition *output = child->algorithm()->outputDefinitions().at( index );
         QString title = output->description();
-        if ( mResults.contains( output->name() ) )
+        if ( outputs.contains( output->name() ) )
         {
-          title += QStringLiteral( ": %1" ).arg( mResults.value( output->name() ).toString() );
+          title += QStringLiteral( ": %1" ).arg( outputs.value( output->name() ).toString() );
         }
         return truncatedTextForItem( title );
       }
@@ -1010,23 +1046,24 @@ QString QgsModelChildAlgorithmGraphicItem::linkPointText( Qt::Edge edge, int ind
       case Qt::TopEdge:
       {
         QgsProcessingParameterDefinitions params = child->algorithm()->parameterDefinitions();
-        params.erase( std::remove_if( params.begin(), params.end(), []( const QgsProcessingParameterDefinition * param )
-        {
-          return param->flags() & QgsProcessingParameterDefinition::FlagHidden || param->isDestination();
-        } ), params.end() );
+        params.erase( std::remove_if( params.begin(), params.end(), []( const QgsProcessingParameterDefinition *param ) {
+                        return param->flags() & Qgis::ProcessingParameterFlag::Hidden || param->isDestination();
+                      } ),
+                      params.end() );
 
         if ( index >= params.length() )
         {
           // something goes wrong and tried to link to an not existing source parameter
           QgsMessageLog::logMessage(
             tr( "Cannot link source for child: %1" ).arg( child->algorithm()->name() ),
-            "QgsModelChildAlgorithmGraphicItem", Qgis::MessageLevel::Warning, true );
+            "QgsModelChildAlgorithmGraphicItem", Qgis::MessageLevel::Warning, true
+          );
           return QString();
         }
 
         QString title = params.at( index )->description();
-        if ( !mInputs.value( params.at( index )->name() ).toString().isEmpty() )
-          title +=  QStringLiteral( ": %1" ).arg( mInputs.value( params.at( index )->name() ).toString() );
+        if ( !inputs.value( params.at( index )->name() ).toString().isEmpty() )
+          title += QStringLiteral( ": %1" ).arg( inputs.value( params.at( index )->name() ).toString() );
         return truncatedTextForItem( title );
       }
 
@@ -1040,7 +1077,7 @@ QString QgsModelChildAlgorithmGraphicItem::linkPointText( Qt::Edge edge, int ind
 
 void QgsModelChildAlgorithmGraphicItem::updateStoredComponentPosition( const QPointF &pos, const QSizeF &size )
 {
-  if ( QgsProcessingModelChildAlgorithm *child = dynamic_cast< QgsProcessingModelChildAlgorithm * >( component() ) )
+  if ( QgsProcessingModelChildAlgorithm *child = dynamic_cast<QgsProcessingModelChildAlgorithm *>( component() ) )
   {
     model()->childAlgorithm( child->childId() ).setPosition( pos );
     model()->childAlgorithm( child->childId() ).setSize( size );
@@ -1049,14 +1086,14 @@ void QgsModelChildAlgorithmGraphicItem::updateStoredComponentPosition( const QPo
 
 bool QgsModelChildAlgorithmGraphicItem::canDeleteComponent()
 {
-  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast< const QgsProcessingModelChildAlgorithm * >( component() ) )
+  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast<const QgsProcessingModelChildAlgorithm *>( component() ) )
   {
     return model()->dependentChildAlgorithms( child->childId() ).empty();
   }
   return false;
 }
 
-void QgsModelChildAlgorithmGraphicItem::setResults( const QVariantMap &results )
+void QgsModelChildAlgorithmGraphicItem::setResults( const QgsProcessingModelChildAlgorithmResult &results )
 {
   if ( mResults == results )
     return;
@@ -1066,26 +1103,15 @@ void QgsModelChildAlgorithmGraphicItem::setResults( const QVariantMap &results )
   emit updateArrowPaths();
 }
 
-void QgsModelChildAlgorithmGraphicItem::setInputs( const QVariantMap &inputs )
-{
-  if ( mInputs == inputs )
-    return;
-
-  mInputs = inputs;
-  update();
-  emit updateArrowPaths();
-}
-
 void QgsModelChildAlgorithmGraphicItem::deleteComponent()
 {
-  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast< const QgsProcessingModelChildAlgorithm * >( component() ) )
+  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast<const QgsProcessingModelChildAlgorithm *>( component() ) )
   {
     emit aboutToChange( tr( "Remove %1" ).arg( child->algorithm() ? child->algorithm()->displayName() : tr( "Algorithm" ) ) );
     if ( !model()->removeChildAlgorithm( child->childId() ) )
     {
-      QMessageBox::warning( nullptr, QObject::tr( "Could not remove algorithm" ),
-                            QObject::tr( "Other algorithms depend on the selected one.\n"
-                                         "Remove them before trying to remove it." ) );
+      QMessageBox::warning( nullptr, QObject::tr( "Could not remove algorithm" ), QObject::tr( "Other algorithms depend on the selected one.\n"
+                                                                                               "Remove them before trying to remove it." ) );
     }
     else
     {
@@ -1097,7 +1123,7 @@ void QgsModelChildAlgorithmGraphicItem::deleteComponent()
 
 void QgsModelChildAlgorithmGraphicItem::deactivateAlgorithm()
 {
-  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast< const QgsProcessingModelChildAlgorithm * >( component() ) )
+  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast<const QgsProcessingModelChildAlgorithm *>( component() ) )
   {
     model()->deactivateChildAlgorithm( child->childId() );
     emit requestModelRepaint();
@@ -1106,7 +1132,7 @@ void QgsModelChildAlgorithmGraphicItem::deactivateAlgorithm()
 
 void QgsModelChildAlgorithmGraphicItem::activateAlgorithm()
 {
-  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast< const QgsProcessingModelChildAlgorithm * >( component() ) )
+  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast<const QgsProcessingModelChildAlgorithm *>( component() ) )
   {
     if ( model()->activateChildAlgorithm( child->childId() ) )
     {
@@ -1114,9 +1140,8 @@ void QgsModelChildAlgorithmGraphicItem::activateAlgorithm()
     }
     else
     {
-      QMessageBox::warning( nullptr, QObject::tr( "Could not activate algorithm" ),
-                            QObject::tr( "The selected algorithm depends on other currently non-active algorithms.\n"
-                                         "Activate them them before trying to activate it.." ) );
+      QMessageBox::warning( nullptr, QObject::tr( "Could not activate algorithm" ), QObject::tr( "The selected algorithm depends on other currently non-active algorithms.\n"
+                                                                                                 "Activate them them before trying to activate it.." ) );
     }
   }
 }
@@ -1175,7 +1200,7 @@ QPicture QgsModelOutputGraphicItem::iconPicture() const
 
 void QgsModelOutputGraphicItem::updateStoredComponentPosition( const QPointF &pos, const QSizeF &size )
 {
-  if ( QgsProcessingModelOutput *output = dynamic_cast< QgsProcessingModelOutput * >( component() ) )
+  if ( QgsProcessingModelOutput *output = dynamic_cast<QgsProcessingModelOutput *>( component() ) )
   {
     model()->childAlgorithm( output->childId() ).modelOutput( output->name() ).setPosition( pos );
     model()->childAlgorithm( output->childId() ).modelOutput( output->name() ).setSize( size );
@@ -1184,7 +1209,7 @@ void QgsModelOutputGraphicItem::updateStoredComponentPosition( const QPointF &po
 
 bool QgsModelOutputGraphicItem::canDeleteComponent()
 {
-  if ( dynamic_cast< const QgsProcessingModelOutput * >( component() ) )
+  if ( dynamic_cast<const QgsProcessingModelOutput *>( component() ) )
   {
     return true;
   }
@@ -1193,7 +1218,7 @@ bool QgsModelOutputGraphicItem::canDeleteComponent()
 
 void QgsModelOutputGraphicItem::deleteComponent()
 {
-  if ( const QgsProcessingModelOutput *output = dynamic_cast< const QgsProcessingModelOutput * >( component() ) )
+  if ( const QgsProcessingModelOutput *output = dynamic_cast<const QgsProcessingModelOutput *>( component() ) )
   {
     emit aboutToChange( tr( "Delete Output %1" ).arg( output->description() ) );
     model()->childAlgorithm( output->childId() ).removeModelOutput( output->name() );
@@ -1280,7 +1305,7 @@ Qt::Alignment QgsModelGroupBoxGraphicItem::titleAlignment() const
 
 void QgsModelGroupBoxGraphicItem::updateStoredComponentPosition( const QPointF &pos, const QSizeF &size )
 {
-  if ( QgsProcessingModelGroupBox *box = dynamic_cast< QgsProcessingModelGroupBox * >( component() ) )
+  if ( QgsProcessingModelGroupBox *box = dynamic_cast<QgsProcessingModelGroupBox *>( component() ) )
   {
     box->setPosition( pos );
     box->setSize( size );
@@ -1290,7 +1315,7 @@ void QgsModelGroupBoxGraphicItem::updateStoredComponentPosition( const QPointF &
 
 bool QgsModelGroupBoxGraphicItem::canDeleteComponent()
 {
-  if ( dynamic_cast< QgsProcessingModelGroupBox * >( component() ) )
+  if ( dynamic_cast<QgsProcessingModelGroupBox *>( component() ) )
   {
     return true;
   }
@@ -1299,7 +1324,7 @@ bool QgsModelGroupBoxGraphicItem::canDeleteComponent()
 
 void QgsModelGroupBoxGraphicItem::deleteComponent()
 {
-  if ( const QgsProcessingModelGroupBox *box = dynamic_cast< const QgsProcessingModelGroupBox * >( component() ) )
+  if ( const QgsProcessingModelGroupBox *box = dynamic_cast<const QgsProcessingModelGroupBox *>( component() ) )
   {
     emit aboutToChange( tr( "Delete Group Box" ) );
     model()->removeGroupBox( box->uuid() );
@@ -1310,7 +1335,7 @@ void QgsModelGroupBoxGraphicItem::deleteComponent()
 
 void QgsModelGroupBoxGraphicItem::editComponent()
 {
-  if ( const QgsProcessingModelGroupBox *box = dynamic_cast< const QgsProcessingModelGroupBox * >( component() ) )
+  if ( const QgsProcessingModelGroupBox *box = dynamic_cast<const QgsProcessingModelGroupBox *>( component() ) )
   {
     QgsModelGroupBoxDefinitionDialog dlg( *box, this->scene()->views().at( 0 ) );
 
@@ -1432,15 +1457,15 @@ void QgsModelCommentGraphicItem::editComponent()
 
 QgsProcessingModelComment *QgsModelCommentGraphicItem::modelComponent()
 {
-  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast< const QgsProcessingModelChildAlgorithm * >( mParentComponent.get() ) )
+  if ( const QgsProcessingModelChildAlgorithm *child = dynamic_cast<const QgsProcessingModelChildAlgorithm *>( mParentComponent.get() ) )
   {
     return model()->childAlgorithm( child->childId() ).comment();
   }
-  else if ( const QgsProcessingModelParameter *param = dynamic_cast< const QgsProcessingModelParameter * >( mParentComponent.get() ) )
+  else if ( const QgsProcessingModelParameter *param = dynamic_cast<const QgsProcessingModelParameter *>( mParentComponent.get() ) )
   {
     return model()->parameterComponent( param->parameterName() ).comment();
   }
-  else if ( const QgsProcessingModelOutput *output = dynamic_cast< const QgsProcessingModelOutput * >( mParentComponent.get() ) )
+  else if ( const QgsProcessingModelOutput *output = dynamic_cast<const QgsProcessingModelOutput *>( mParentComponent.get() ) )
   {
     return model()->childAlgorithm( output->childId() ).modelOutput( output->name() ).comment();
   }
