@@ -18,6 +18,7 @@
 
 #include "qgis.h"
 #include "qgis_gui.h"
+#include "qgsprocessingcontext.h"
 #include <QGraphicsObject>
 #include <QFont>
 #include <QPicture>
@@ -48,17 +49,16 @@ class GUI_EXPORT QgsModelComponentGraphicItem : public QGraphicsObject
     Q_OBJECT
 
   public:
-
     //! Available item states
     enum State
     {
-      Normal, //!< Normal state
+      Normal,   //!< Normal state
       Selected, //!< Item is selected
-      Hover, //!< Cursor is hovering over an deselected item
+      Hover,    //!< Cursor is hovering over an deselected item
     };
 
     //! Available flags
-    enum Flag
+    enum Flag SIP_ENUM_BASETYPE( IntFlag )
     {
       // For future API flexibility only and to avoid sip issues, remove when real entries are added to flags.
       Unused = 1 << 0, //!< Temporary unused entry
@@ -73,9 +73,7 @@ class GUI_EXPORT QgsModelComponentGraphicItem : public QGraphicsObject
      *
      * Ownership of \a component is transferred to the item.
      */
-    QgsModelComponentGraphicItem( QgsProcessingModelComponent *component SIP_TRANSFER,
-                                  QgsProcessingModelAlgorithm *model,
-                                  QGraphicsItem *parent SIP_TRANSFERTHIS );
+    QgsModelComponentGraphicItem( QgsProcessingModelComponent *component SIP_TRANSFER, QgsProcessingModelAlgorithm *model, QGraphicsItem *parent SIP_TRANSFERTHIS );
 
     ~QgsModelComponentGraphicItem() override;
 
@@ -299,7 +297,6 @@ class GUI_EXPORT QgsModelComponentGraphicItem : public QGraphicsObject
     virtual void editComponent() {}
 
   protected:
-
     /**
      * Truncates a \a text string so that it fits nicely within the item's width,
      * accounting for margins and interactive buttons.
@@ -352,14 +349,13 @@ class GUI_EXPORT QgsModelComponentGraphicItem : public QGraphicsObject
     void updateButtonPositions();
 
   private:
-
     QSizeF itemSize() const;
 
     void updateToolTip( const QPointF &pos );
 
     void fold( Qt::Edge edge, bool folded );
 
-    std::unique_ptr< QgsProcessingModelComponent > mComponent;
+    std::unique_ptr<QgsProcessingModelComponent> mComponent;
     QgsProcessingModelAlgorithm *mModel = nullptr;
 
     bool mInitialized = false;
@@ -384,9 +380,7 @@ class GUI_EXPORT QgsModelComponentGraphicItem : public QGraphicsObject
     QFont mFont;
 
     bool mIsHovering = false;
-    bool mIsMoving = false;
     QSizeF mTempSize;
-
 };
 Q_DECLARE_OPERATORS_FOR_FLAGS( QgsModelComponentGraphicItem::Flags )
 
@@ -401,7 +395,6 @@ class GUI_EXPORT QgsModelParameterGraphicItem : public QgsModelComponentGraphicI
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsModelParameterGraphicItem for the specified \a parameter, with the specified \a parent item.
      *
@@ -410,15 +403,12 @@ class GUI_EXPORT QgsModelParameterGraphicItem : public QgsModelComponentGraphicI
      *
      * Ownership of \a parameter is transferred to the item.
      */
-    QgsModelParameterGraphicItem( QgsProcessingModelParameter *parameter SIP_TRANSFER,
-                                  QgsProcessingModelAlgorithm *model,
-                                  QGraphicsItem *parent SIP_TRANSFERTHIS );
+    QgsModelParameterGraphicItem( QgsProcessingModelParameter *parameter SIP_TRANSFER, QgsProcessingModelAlgorithm *model, QGraphicsItem *parent SIP_TRANSFERTHIS );
 
     void contextMenuEvent( QGraphicsSceneContextMenuEvent *event ) override;
     bool canDeleteComponent() override;
 
   protected:
-
     QColor fillColor( State state ) const override;
     QColor strokeColor( State state ) const override;
     QColor textColor( State state ) const override;
@@ -431,7 +421,6 @@ class GUI_EXPORT QgsModelParameterGraphicItem : public QgsModelComponentGraphicI
 
   private:
     QPicture mPicture;
-
 };
 
 /**
@@ -445,7 +434,6 @@ class GUI_EXPORT QgsModelChildAlgorithmGraphicItem : public QgsModelComponentGra
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsModelChildAlgorithmGraphicItem for the specified \a child, with the specified \a parent item.
      *
@@ -454,24 +442,46 @@ class GUI_EXPORT QgsModelChildAlgorithmGraphicItem : public QgsModelComponentGra
      *
      * Ownership of \a child is transferred to the item.
      */
-    QgsModelChildAlgorithmGraphicItem( QgsProcessingModelChildAlgorithm *child SIP_TRANSFER,
-                                       QgsProcessingModelAlgorithm *model,
-                                       QGraphicsItem *parent SIP_TRANSFERTHIS );
+    QgsModelChildAlgorithmGraphicItem( QgsProcessingModelChildAlgorithm *child SIP_TRANSFER, QgsProcessingModelAlgorithm *model, QGraphicsItem *parent SIP_TRANSFERTHIS );
     void contextMenuEvent( QGraphicsSceneContextMenuEvent *event ) override;
     bool canDeleteComponent() override;
 
     /**
-     * Sets the results obtained for this child algorithm for the last model execution through the dialog.
+     * Sets the \a results obtained for this child algorithm for the last model execution through the dialog.
      */
-    void setResults( const QVariantMap &results );
+    void setResults( const QgsProcessingModelChildAlgorithmResult &results );
+
+  signals:
 
     /**
-     * Sets the inputs used for this child algorithm for the last model execution through the dialog.
+     * Emitted when the user opts to run the model from this child algorithm.
+     *
+     * \since QGIS 3.38
+    */
+    void runFromHere();
+
+    /**
+     * Emitted when the user opts to run selected steps from the model.
+     *
+     * \since QGIS 3.38
+    */
+    void runSelected();
+
+    /**
+     * Emitted when the user opts to view previous results from this child algorithm.
+     *
+     * \since QGIS 3.38
      */
-    void setInputs( const QVariantMap &inputs );
+    void showPreviousResults();
+
+    /**
+    * Emitted when the user opts to view the previous log from this child algorithm.
+    *
+    * \since QGIS 3.38
+    */
+    void showLog();
 
   protected:
-
     QColor fillColor( State state ) const override;
     QColor strokeColor( State state ) const override;
     QColor textColor( State state ) const override;
@@ -493,8 +503,7 @@ class GUI_EXPORT QgsModelChildAlgorithmGraphicItem : public QgsModelComponentGra
   private:
     QPicture mPicture;
     QPixmap mPixmap;
-    QVariantMap mResults;
-    QVariantMap mInputs;
+    QgsProcessingModelChildAlgorithmResult mResults;
     bool mIsValid = true;
 };
 
@@ -510,7 +519,6 @@ class GUI_EXPORT QgsModelOutputGraphicItem : public QgsModelComponentGraphicItem
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsModelOutputGraphicItem for the specified \a output, with the specified \a parent item.
      *
@@ -519,14 +527,11 @@ class GUI_EXPORT QgsModelOutputGraphicItem : public QgsModelComponentGraphicItem
      *
      * Ownership of \a output is transferred to the item.
      */
-    QgsModelOutputGraphicItem( QgsProcessingModelOutput *output SIP_TRANSFER,
-                               QgsProcessingModelAlgorithm *model,
-                               QGraphicsItem *parent SIP_TRANSFERTHIS );
+    QgsModelOutputGraphicItem( QgsProcessingModelOutput *output SIP_TRANSFER, QgsProcessingModelAlgorithm *model, QGraphicsItem *parent SIP_TRANSFERTHIS );
 
     bool canDeleteComponent() override;
 
   protected:
-
     QColor fillColor( State state ) const override;
     QColor strokeColor( State state ) const override;
     QColor textColor( State state ) const override;
@@ -538,12 +543,10 @@ class GUI_EXPORT QgsModelOutputGraphicItem : public QgsModelComponentGraphicItem
     void deleteComponent() override;
 
   private:
-
     QPicture mPicture;
 };
 
 
-
 /**
  * \ingroup gui
  * \brief A graphic item representing a model comment in the model designer.
@@ -555,7 +558,6 @@ class GUI_EXPORT QgsModelCommentGraphicItem : public QgsModelComponentGraphicIte
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsModelCommentGraphicItem for the specified \a comment, with the specified \a parent item.
      *
@@ -564,10 +566,7 @@ class GUI_EXPORT QgsModelCommentGraphicItem : public QgsModelComponentGraphicIte
      *
      * Ownership of \a output is transferred to the item.
      */
-    QgsModelCommentGraphicItem( QgsProcessingModelComment *comment SIP_TRANSFER,
-                                QgsModelComponentGraphicItem *parentItem,
-                                QgsProcessingModelAlgorithm *model,
-                                QGraphicsItem *parent SIP_TRANSFERTHIS );
+    QgsModelCommentGraphicItem( QgsProcessingModelComment *comment SIP_TRANSFER, QgsModelComponentGraphicItem *parentItem, QgsProcessingModelAlgorithm *model, QGraphicsItem *parent SIP_TRANSFERTHIS );
     ~QgsModelCommentGraphicItem() override;
     void contextMenuEvent( QGraphicsSceneContextMenuEvent *event ) override;
     bool canDeleteComponent() override;
@@ -578,7 +577,6 @@ class GUI_EXPORT QgsModelCommentGraphicItem : public QgsModelComponentGraphicIte
     QgsModelComponentGraphicItem *parentComponentItem() const;
 
   protected:
-
     QColor fillColor( State state ) const override;
     QColor strokeColor( State state ) const override;
     QColor textColor( State state ) const override;
@@ -589,14 +587,12 @@ class GUI_EXPORT QgsModelCommentGraphicItem : public QgsModelComponentGraphicIte
 
     void deleteComponent() override;
     void editComponent() override;
-  private:
 
+  private:
     QgsProcessingModelComment *modelComponent();
 
-    std::unique_ptr< QgsProcessingModelComponent > mParentComponent;
-    QPointer< QgsModelComponentGraphicItem > mParentItem;
-
-
+    std::unique_ptr<QgsProcessingModelComponent> mParentComponent;
+    QPointer<QgsModelComponentGraphicItem> mParentItem;
 };
 
 
@@ -611,7 +607,6 @@ class GUI_EXPORT QgsModelGroupBoxGraphicItem : public QgsModelComponentGraphicIt
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsModelGroupBoxGraphicItem for the specified group \a box, with the specified \a parent item.
      *
@@ -620,14 +615,12 @@ class GUI_EXPORT QgsModelGroupBoxGraphicItem : public QgsModelComponentGraphicIt
      *
      * Ownership of \a output is transferred to the item.
      */
-    QgsModelGroupBoxGraphicItem( QgsProcessingModelGroupBox *box SIP_TRANSFER,
-                                 QgsProcessingModelAlgorithm *model,
-                                 QGraphicsItem *parent SIP_TRANSFERTHIS );
+    QgsModelGroupBoxGraphicItem( QgsProcessingModelGroupBox *box SIP_TRANSFER, QgsProcessingModelAlgorithm *model, QGraphicsItem *parent SIP_TRANSFERTHIS );
     ~QgsModelGroupBoxGraphicItem() override;
     void contextMenuEvent( QGraphicsSceneContextMenuEvent *event ) override;
     bool canDeleteComponent() override;
-  protected:
 
+  protected:
     QColor fillColor( State state ) const override;
     QColor strokeColor( State state ) const override;
     QColor textColor( State state ) const override;
@@ -639,9 +632,8 @@ class GUI_EXPORT QgsModelGroupBoxGraphicItem : public QgsModelComponentGraphicIt
 
     void deleteComponent() override;
     void editComponent() override;
+
   private:
-
-
 };
 
 ///@endcond
