@@ -14,10 +14,12 @@
  ***************************************************************************/
 
 #include "qgsprocessingtoolboxmodel.h"
+#include "moc_qgsprocessingtoolboxmodel.cpp"
 #include "qgsapplication.h"
 #include "qgsvectorlayer.h"
 #include "qgsprocessingregistry.h"
 #include "qgsprocessingrecentalgorithmlog.h"
+#include "qgsprocessingfavoritealgorithmmanager.h"
 #include <functional>
 #include <QPalette>
 #include <QMimeData>
@@ -46,9 +48,9 @@ QgsProcessingToolboxModelGroupNode *QgsProcessingToolboxModelNode::getChildGroup
 {
   for ( QgsProcessingToolboxModelNode *node : std::as_const( mChildren ) )
   {
-    if ( node->nodeType() == NodeGroup )
+    if ( node->nodeType() == NodeType::Group )
     {
-      QgsProcessingToolboxModelGroupNode *groupNode = qobject_cast< QgsProcessingToolboxModelGroupNode * >( node );
+      QgsProcessingToolboxModelGroupNode *groupNode = qobject_cast<QgsProcessingToolboxModelGroupNode *>( node );
       if ( groupNode && groupNode->id() == groupId )
         return groupNode;
     }
@@ -115,16 +117,20 @@ const QgsProcessingAlgorithm *QgsProcessingToolboxModelAlgorithmNode::algorithm(
 // QgsProcessingToolboxModel
 //
 
-QgsProcessingToolboxModel::QgsProcessingToolboxModel( QObject *parent, QgsProcessingRegistry *registry, QgsProcessingRecentAlgorithmLog *recentLog )
+QgsProcessingToolboxModel::QgsProcessingToolboxModel( QObject *parent, QgsProcessingRegistry *registry, QgsProcessingRecentAlgorithmLog *recentLog, QgsProcessingFavoriteAlgorithmManager *favoriteManager )
   : QAbstractItemModel( parent )
   , mRegistry( registry ? registry : QgsApplication::processingRegistry() )
   , mRecentLog( recentLog )
-  , mRootNode( std::make_unique< QgsProcessingToolboxModelGroupNode >( QString(), QString() ) )
+  , mFavoriteManager( favoriteManager )
+  , mRootNode( std::make_unique<QgsProcessingToolboxModelGroupNode>( QString(), QString() ) )
 {
   rebuild();
 
   if ( mRecentLog )
-    connect( mRecentLog, &QgsProcessingRecentAlgorithmLog::changed, this, [ = ] { repopulateRecentAlgorithms(); } );
+    connect( mRecentLog, &QgsProcessingRecentAlgorithmLog::changed, this, [=] { repopulateRecentAlgorithms(); } );
+
+  if ( mFavoriteManager )
+    connect( mFavoriteManager, &QgsProcessingFavoriteAlgorithmManager::changed, this, [=] { repopulateFavoriteAlgorithms(); } );
 
   connect( mRegistry, &QgsProcessingRegistry::providerAdded, this, &QgsProcessingToolboxModel::rebuild );
   connect( mRegistry, &QgsProcessingRegistry::providerRemoved, this, &QgsProcessingToolboxModel::providerRemoved );
@@ -136,19 +142,29 @@ void QgsProcessingToolboxModel::rebuild()
 
   mRootNode->deleteChildren();
   mRecentNode = nullptr;
+  mFavoriteNode = nullptr;
 
   if ( mRecentLog )
   {
-    std::unique_ptr< QgsProcessingToolboxModelRecentNode > recentNode = std::make_unique< QgsProcessingToolboxModelRecentNode >();
+    std::unique_ptr<QgsProcessingToolboxModelRecentNode> recentNode = std::make_unique<QgsProcessingToolboxModelRecentNode>();
     // cppcheck-suppress danglingLifetime
     mRecentNode = recentNode.get();
     mRootNode->addChildNode( recentNode.release() );
     repopulateRecentAlgorithms( true );
   }
 
+  if ( mFavoriteManager )
+  {
+    std::unique_ptr<QgsProcessingToolboxModelFavoriteNode> favoriteNode = std::make_unique<QgsProcessingToolboxModelFavoriteNode>();
+    // cppcheck-suppress danglingLifetime
+    mFavoriteNode = favoriteNode.get();
+    mRootNode->addChildNode( favoriteNode.release() );
+    repopulateFavoriteAlgorithms( true );
+  }
+
   if ( mRegistry )
   {
-    const QList< QgsProcessingProvider * > providers = mRegistry->providers();
+    const QList<QgsProcessingProvider *> providers = mRegistry->providers();
     for ( QgsProcessingProvider *provider : providers )
     {
       addProvider( provider );
@@ -179,7 +195,7 @@ void QgsProcessingToolboxModel::repopulateRecentAlgorithms( bool resetting )
   }
 
   const QStringList recentAlgIds = mRecentLog->recentAlgorithmIds();
-  QList< const QgsProcessingAlgorithm * > recentAlgorithms;
+  QList<const QgsProcessingAlgorithm *> recentAlgorithms;
   recentAlgorithms.reserve( recentAlgIds.count() );
   for ( const QString &id : recentAlgIds )
   {
@@ -202,7 +218,7 @@ void QgsProcessingToolboxModel::repopulateRecentAlgorithms( bool resetting )
 
   for ( const QgsProcessingAlgorithm *algorithm : std::as_const( recentAlgorithms ) )
   {
-    std::unique_ptr< QgsProcessingToolboxModelAlgorithmNode > algorithmNode = std::make_unique< QgsProcessingToolboxModelAlgorithmNode >( algorithm );
+    std::unique_ptr<QgsProcessingToolboxModelAlgorithmNode> algorithmNode = std::make_unique<QgsProcessingToolboxModelAlgorithmNode>( algorithm );
     mRecentNode->addChildNode( algorithmNode.release() );
   }
 
@@ -213,6 +229,66 @@ void QgsProcessingToolboxModel::repopulateRecentAlgorithms( bool resetting )
   }
 }
 
+void QgsProcessingToolboxModel::repopulateFavoriteAlgorithms( bool resetting )
+{
+  if ( !mFavoriteNode || !mFavoriteManager )
+    return;
+
+  // favorite node should be under the Recent node if it is present or
+  // the first top-level item in the toolbox if Recent node is not present
+  int idx = ( mRecentNode && mRecentLog ) ? 1 : 0;
+
+  QModelIndex favoriteIndex = index( idx, 0 );
+  const int prevCount = rowCount( favoriteIndex );
+  if ( !resetting && prevCount > 0 )
+  {
+    beginRemoveRows( favoriteIndex, 0, prevCount - 1 );
+    mFavoriteNode->deleteChildren();
+    endRemoveRows();
+  }
+
+  if ( !mRegistry )
+  {
+    if ( !resetting )
+      emit favoriteAlgorithmAdded();
+    return;
+  }
+
+  const QStringList favoriteAlgIds = mFavoriteManager->favoriteAlgorithmIds();
+  QList<const QgsProcessingAlgorithm *> favoriteAlgorithms;
+  favoriteAlgorithms.reserve( favoriteAlgIds.count() );
+  for ( const QString &id : favoriteAlgIds )
+  {
+    const QgsProcessingAlgorithm *algorithm = mRegistry->algorithmById( id );
+    if ( algorithm )
+      favoriteAlgorithms << algorithm;
+  }
+
+  if ( favoriteAlgorithms.empty() )
+  {
+    if ( !resetting )
+      emit favoriteAlgorithmAdded();
+    return;
+  }
+
+  if ( !resetting )
+  {
+    beginInsertRows( favoriteIndex, 0, favoriteAlgorithms.count() - 1 );
+  }
+
+  for ( const QgsProcessingAlgorithm *algorithm : std::as_const( favoriteAlgorithms ) )
+  {
+    std::unique_ptr<QgsProcessingToolboxModelAlgorithmNode> algorithmNode = std::make_unique<QgsProcessingToolboxModelAlgorithmNode>( algorithm );
+    mFavoriteNode->addChildNode( algorithmNode.release() );
+  }
+
+  if ( !resetting )
+  {
+    endInsertRows();
+    emit favoriteAlgorithmAdded();
+  }
+}
+
 void QgsProcessingToolboxModel::providerAdded( const QString &id )
 {
   if ( !mRegistry )
@@ -277,7 +353,7 @@ void QgsProcessingToolboxModel::addProvider( QgsProcessingProvider *provider )
   QgsProcessingToolboxModelNode *parentNode = nullptr;
   if ( !isTopLevelProvider( provider->id() ) )
   {
-    std::unique_ptr< QgsProcessingToolboxModelProviderNode > node = std::make_unique< QgsProcessingToolboxModelProviderNode >( provider );
+    std::unique_ptr<QgsProcessingToolboxModelProviderNode> node = std::make_unique<QgsProcessingToolboxModelProviderNode>( provider );
     parentNode = node.get();
     mRootNode->addChildNode( node.release() );
   }
@@ -286,10 +362,10 @@ void QgsProcessingToolboxModel::addProvider( QgsProcessingProvider *provider )
     parentNode = mRootNode.get();
   }
 
-  const QList< const QgsProcessingAlgorithm * > algorithms = provider->algorithms();
+  const QList<const QgsProcessingAlgorithm *> algorithms = provider->algorithms();
   for ( const QgsProcessingAlgorithm *algorithm : algorithms )
   {
-    std::unique_ptr< QgsProcessingToolboxModelAlgorithmNode > algorithmNode = std::make_unique< QgsProcessingToolboxModelAlgorithmNode >( algorithm );
+    std::unique_ptr<QgsProcessingToolboxModelAlgorithmNode> algorithmNode = std::make_unique<QgsProcessingToolboxModelAlgorithmNode>( algorithm );
 
     const QString groupId = algorithm->groupId();
     if ( !groupId.isEmpty() )
@@ -315,20 +391,12 @@ void QgsProcessingToolboxModel::addProvider( QgsProcessingProvider *provider )
 
 bool QgsProcessingToolboxModel::isTopLevelProvider( const QString &providerId )
 {
-  return providerId == QLatin1String( "qgis" ) ||
-         providerId == QLatin1String( "native" ) ||
-         providerId == QLatin1String( "3d" ) ||
-         providerId == QLatin1String( "pdal" );
+  return providerId == QLatin1String( "qgis" ) || providerId == QLatin1String( "native" ) || providerId == QLatin1String( "3d" ) || providerId == QLatin1String( "pdal" );
 }
 
 QString QgsProcessingToolboxModel::toolTipForAlgorithm( const QgsProcessingAlgorithm *algorithm )
 {
-  return QStringLiteral( "<p><b>%1</b></p>%2<p>%3</p>%4" ).arg(
-           algorithm->displayName(),
-           !algorithm->shortDescription().isEmpty() ? QStringLiteral( "<p>%1</p>" ).arg( algorithm->shortDescription() ) : QString(),
-           QObject::tr( "Algorithm ID: ‘%1’" ).arg( QStringLiteral( "<i>%1</i>" ).arg( algorithm->id() ) ),
-           ( algorithm->flags() & QgsProcessingAlgorithm::FlagKnownIssues ) ? QStringLiteral( "<b style=\"color:red\">%1</b>" ).arg( QObject::tr( "Warning: Algorithm has known issues" ) ) : QString()
-         );
+  return QStringLiteral( "<p><b>%1</b></p>%2<p>%3</p>%4" ).arg( algorithm->displayName(), !algorithm->shortDescription().isEmpty() ? QStringLiteral( "<p>%1</p>" ).arg( algorithm->shortDescription() ) : QString(), QObject::tr( "Algorithm ID: ‘%1’" ).arg( QStringLiteral( "<i>%1</i>" ).arg( algorithm->id() ) ), ( algorithm->flags() & Qgis::ProcessingAlgorithmFlag::KnownIssues ) ? QStringLiteral( "<b style=\"color:red\">%1</b>" ).arg( QObject::tr( "Warning: Algorithm has known issues" ) ) : QString() );
 }
 
 Qt::ItemFlags QgsProcessingToolboxModel::flags( const QModelIndex &index ) const
@@ -344,20 +412,24 @@ QVariant QgsProcessingToolboxModel::data( const QModelIndex &index, int role ) c
   if ( !index.isValid() )
     return QVariant();
 
-  if ( role == RoleNodeType )
+  if ( role == static_cast<int>( CustomRole::NodeType ) )
   {
     if ( QgsProcessingToolboxModelNode *node = index2node( index ) )
-      return node->nodeType();
+      return static_cast<int>( node->nodeType() );
     else
       return QVariant();
   }
 
   bool isRecentNode = false;
   if ( QgsProcessingToolboxModelNode *node = index2node( index ) )
-    isRecentNode = node->nodeType() == QgsProcessingToolboxModelNode::NodeRecent;
+    isRecentNode = node->nodeType() == QgsProcessingToolboxModelNode::NodeType::Recent;
+
+  bool isFavoriteNode = false;
+  if ( QgsProcessingToolboxModelNode *node = index2node( index ) )
+    isFavoriteNode = node->nodeType() == QgsProcessingToolboxModelNode::NodeType::Favorite;
 
   QgsProcessingProvider *provider = providerForIndex( index );
-  QgsProcessingToolboxModelGroupNode *groupNode = qobject_cast< QgsProcessingToolboxModelGroupNode * >( index2node( index ) );
+  QgsProcessingToolboxModelGroupNode *groupNode = qobject_cast<QgsProcessingToolboxModelGroupNode *>( index2node( index ) );
   const QgsProcessingAlgorithm *algorithm = algorithmForIndex( index );
 
   switch ( role )
@@ -375,6 +447,8 @@ QVariant QgsProcessingToolboxModel::data( const QModelIndex &index, int role ) c
             return groupNode->name();
           else if ( isRecentNode )
             return tr( "Recently used" );
+          else if ( isFavoriteNode )
+            return tr( "Favorites" );
           else
             return QVariant();
 
@@ -398,7 +472,7 @@ QVariant QgsProcessingToolboxModel::data( const QModelIndex &index, int role ) c
 
     case Qt::ForegroundRole:
     {
-      if ( algorithm && algorithm->flags() & QgsProcessingAlgorithm::FlagKnownIssues )
+      if ( algorithm && algorithm->flags() & Qgis::ProcessingAlgorithmFlag::KnownIssues )
         return QBrush( QColor( Qt::red ) );
       else
         return QVariant();
@@ -414,12 +488,14 @@ QVariant QgsProcessingToolboxModel::data( const QModelIndex &index, int role ) c
             return provider->icon();
           else if ( algorithm )
           {
-            if ( algorithm->flags() & QgsProcessingAlgorithm::FlagKnownIssues )
+            if ( algorithm->flags() & Qgis::ProcessingAlgorithmFlag::KnownIssues )
               return QgsApplication::getThemeIcon( QStringLiteral( "mIconWarning.svg" ) );
             return algorithm->icon();
           }
           else if ( isRecentNode )
             return QgsApplication::getThemeIcon( QStringLiteral( "/mIconHistory.svg" ) );
+          else if ( isFavoriteNode )
+            return QgsApplication::getThemeIcon( QStringLiteral( "/mIconFavorites.svg" ) );
           else if ( !index.parent().isValid() )
             // top level groups get the QGIS icon
             return QgsApplication::getThemeIcon( QStringLiteral( "/providerQgis.svg" ) );
@@ -433,13 +509,13 @@ QVariant QgsProcessingToolboxModel::data( const QModelIndex &index, int role ) c
       break;
     }
 
-    case RoleAlgorithmFlags:
+    case static_cast<int>( CustomRole::AlgorithmFlags ):
       switch ( index.column() )
       {
         case 0:
         {
           if ( algorithm )
-            return static_cast< int >( algorithm->flags() );
+            return static_cast<int>( algorithm->flags() );
           else
             return QVariant();
         }
@@ -449,17 +525,17 @@ QVariant QgsProcessingToolboxModel::data( const QModelIndex &index, int role ) c
       }
       break;
 
-    case RoleProviderFlags:
+    case static_cast<int>( CustomRole::ProviderFlags ):
       switch ( index.column() )
       {
         case 0:
         {
           if ( provider )
-            return static_cast< int >( provider->flags() );
+            return static_cast<int>( provider->flags() );
           else if ( algorithm && algorithm->provider() )
-            return static_cast< int >( algorithm->provider()->flags() );
-          else if ( index.parent().data( RoleProviderFlags ).isValid() ) // group node
-            return static_cast< int >( index.parent().data( RoleProviderFlags ).toInt() );
+            return static_cast<int>( algorithm->provider()->flags() );
+          else if ( index.parent().data( static_cast<int>( CustomRole::ProviderFlags ) ).isValid() ) // group node
+            return static_cast<int>( index.parent().data( static_cast<int>( CustomRole::ProviderFlags ) ).toInt() );
           else
             return QVariant();
         }
@@ -469,7 +545,7 @@ QVariant QgsProcessingToolboxModel::data( const QModelIndex &index, int role ) c
       }
       break;
 
-    case RoleAlgorithmId:
+    case static_cast<int>( CustomRole::AlgorithmId ):
       switch ( index.column() )
       {
         case 0:
@@ -485,7 +561,7 @@ QVariant QgsProcessingToolboxModel::data( const QModelIndex &index, int role ) c
       }
       break;
 
-    case RoleAlgorithmName:
+    case static_cast<int>( CustomRole::AlgorithmName ):
       switch ( index.column() )
       {
         case 0:
@@ -501,7 +577,7 @@ QVariant QgsProcessingToolboxModel::data( const QModelIndex &index, int role ) c
       }
       break;
 
-    case RoleAlgorithmTags:
+    case static_cast<int>( CustomRole::AlgorithmTags ):
       switch ( index.column() )
       {
         case 0:
@@ -517,7 +593,7 @@ QVariant QgsProcessingToolboxModel::data( const QModelIndex &index, int role ) c
       }
       break;
 
-    case RoleAlgorithmShortDescription:
+    case static_cast<int>( CustomRole::AlgorithmShortDescription ):
       switch ( index.column() )
       {
         case 0:
@@ -536,7 +612,7 @@ QVariant QgsProcessingToolboxModel::data( const QModelIndex &index, int role ) c
     default:
       return QVariant();
   }
-#ifndef _MSC_VER  // avoid warning
+#ifndef _MSC_VER // avoid warning
   return QVariant();
 #endif
 }
@@ -590,7 +666,7 @@ QMimeData *QgsProcessingToolboxModel::mimeData( const QModelIndexList &indexes )
     QByteArray encodedData;
     QDataStream stream( &encodedData, QIODevice::WriteOnly | QIODevice::Truncate );
 
-    std::unique_ptr< QMimeData > mimeData = std::make_unique< QMimeData >();
+    std::unique_ptr<QMimeData> mimeData = std::make_unique<QMimeData>();
     const QgsProcessingAlgorithm *algorithm = algorithmForIndex( indexes.at( 0 ) );
     if ( algorithm )
     {
@@ -605,40 +681,39 @@ QMimeData *QgsProcessingToolboxModel::mimeData( const QModelIndexList &indexes )
 QgsProcessingProvider *QgsProcessingToolboxModel::providerForIndex( const QModelIndex &index ) const
 {
   QgsProcessingToolboxModelNode *n = index2node( index );
-  if ( !n || n->nodeType() != QgsProcessingToolboxModelNode::NodeProvider )
+  if ( !n || n->nodeType() != QgsProcessingToolboxModelNode::NodeType::Provider )
     return nullptr;
 
-  return qobject_cast< QgsProcessingToolboxModelProviderNode * >( n )->provider();
+  return qobject_cast<QgsProcessingToolboxModelProviderNode *>( n )->provider();
 }
 
 QString QgsProcessingToolboxModel::providerIdForIndex( const QModelIndex &index ) const
 {
   QgsProcessingToolboxModelNode *n = index2node( index );
-  if ( !n || n->nodeType() != QgsProcessingToolboxModelNode::NodeProvider )
+  if ( !n || n->nodeType() != QgsProcessingToolboxModelNode::NodeType::Provider )
     return nullptr;
 
-  return qobject_cast< QgsProcessingToolboxModelProviderNode * >( n )->providerId();
+  return qobject_cast<QgsProcessingToolboxModelProviderNode *>( n )->providerId();
 }
 
 const QgsProcessingAlgorithm *QgsProcessingToolboxModel::algorithmForIndex( const QModelIndex &index ) const
 {
   QgsProcessingToolboxModelNode *n = index2node( index );
-  if ( !n || n->nodeType() != QgsProcessingToolboxModelNode::NodeAlgorithm )
+  if ( !n || n->nodeType() != QgsProcessingToolboxModelNode::NodeType::Algorithm )
     return nullptr;
 
-  return qobject_cast< QgsProcessingToolboxModelAlgorithmNode * >( n )->algorithm();
+  return qobject_cast<QgsProcessingToolboxModelAlgorithmNode *>( n )->algorithm();
 }
 
 bool QgsProcessingToolboxModel::isAlgorithm( const QModelIndex &index ) const
 {
   QgsProcessingToolboxModelNode *n = index2node( index );
-  return ( n && n->nodeType() == QgsProcessingToolboxModelNode::NodeAlgorithm );
+  return ( n && n->nodeType() == QgsProcessingToolboxModelNode::NodeType::Algorithm );
 }
 
 QModelIndex QgsProcessingToolboxModel::indexForProvider( const QString &providerId ) const
 {
-  std::function< QModelIndex( const QModelIndex &parent, const QString &providerId ) > findIndex = [&]( const QModelIndex & parent, const QString & providerId )->QModelIndex
-  {
+  std::function<QModelIndex( const QModelIndex &parent, const QString &providerId )> findIndex = [&]( const QModelIndex &parent, const QString &providerId ) -> QModelIndex {
     for ( int row = 0; row < rowCount( parent ); ++row )
     {
       QModelIndex current = index( row, 0, parent );
@@ -662,7 +737,7 @@ QModelIndex QgsProcessingToolboxModel::indexOfParentTreeNode( QgsProcessingToolb
 
   QgsProcessingToolboxModelNode *grandParentNode = parentNode->parent();
   if ( !grandParentNode )
-    return QModelIndex();  // root node -> invalid index
+    return QModelIndex(); // root node -> invalid index
 
   int row = grandParentNode->children().indexOf( parentNode );
   Q_ASSERT( row >= 0 );
@@ -674,10 +749,9 @@ QModelIndex QgsProcessingToolboxModel::indexOfParentTreeNode( QgsProcessingToolb
 // QgsProcessingToolboxProxyModel
 //
 
-QgsProcessingToolboxProxyModel::QgsProcessingToolboxProxyModel( QObject *parent, QgsProcessingRegistry *registry,
-    QgsProcessingRecentAlgorithmLog *recentLog )
+QgsProcessingToolboxProxyModel::QgsProcessingToolboxProxyModel( QObject *parent, QgsProcessingRegistry *registry, QgsProcessingRecentAlgorithmLog *recentLog, QgsProcessingFavoriteAlgorithmManager *favoriteManager )
   : QSortFilterProxyModel( parent )
-  , mModel( new QgsProcessingToolboxModel( this, registry, recentLog ) )
+  , mModel( new QgsProcessingToolboxModel( this, registry, recentLog, favoriteManager ) )
 {
   setSourceModel( mModel );
   setDynamicSortFilter( true );
@@ -685,7 +759,8 @@ QgsProcessingToolboxProxyModel::QgsProcessingToolboxProxyModel( QObject *parent,
   setFilterCaseSensitivity( Qt::CaseInsensitive );
   sort( 0 );
 
-  connect( mModel, &QgsProcessingToolboxModel::recentAlgorithmAdded, this, [ = ] { invalidateFilter(); } );
+  connect( mModel, &QgsProcessingToolboxModel::recentAlgorithmAdded, this, [=] { invalidateFilter(); } );
+  connect( mModel, &QgsProcessingToolboxModel::favoriteAlgorithmAdded, this, [=] { invalidateFilter(); } );
 }
 
 QgsProcessingToolboxModel *QgsProcessingToolboxProxyModel::toolboxModel()
@@ -722,16 +797,16 @@ bool QgsProcessingToolboxProxyModel::filterAcceptsRow( int sourceRow, const QMod
   QModelIndex sourceIndex = mModel->index( sourceRow, 0, sourceParent );
   if ( mModel->isAlgorithm( sourceIndex ) )
   {
-    const bool hasKnownIssues = sourceModel()->data( sourceIndex, QgsProcessingToolboxModel::RoleAlgorithmFlags ).toInt() & QgsProcessingAlgorithm::FlagKnownIssues;
-    if ( hasKnownIssues && !( mFilters & FilterShowKnownIssues ) )
+    const bool hasKnownIssues = sourceModel()->data( sourceIndex, static_cast<int>( QgsProcessingToolboxModel::CustomRole::AlgorithmFlags ) ).toInt() & static_cast<int>( Qgis::ProcessingAlgorithmFlag::KnownIssues );
+    if ( hasKnownIssues && !( mFilters & Filter::ShowKnownIssues ) )
       return false;
 
     if ( !mFilterString.trimmed().isEmpty() )
     {
-      const QString algId = sourceModel()->data( sourceIndex, QgsProcessingToolboxModel::RoleAlgorithmId ).toString();
-      const QString algName = sourceModel()->data( sourceIndex, QgsProcessingToolboxModel::RoleAlgorithmName ).toString();
-      const QStringList algTags = sourceModel()->data( sourceIndex, QgsProcessingToolboxModel::RoleAlgorithmTags ).toStringList();
-      const QString shortDesc = sourceModel()->data( sourceIndex, QgsProcessingToolboxModel::RoleAlgorithmShortDescription ).toString();
+      const QString algId = sourceModel()->data( sourceIndex, static_cast<int>( QgsProcessingToolboxModel::CustomRole::AlgorithmId ) ).toString();
+      const QString algName = sourceModel()->data( sourceIndex, static_cast<int>( QgsProcessingToolboxModel::CustomRole::AlgorithmName ) ).toString();
+      const QStringList algTags = sourceModel()->data( sourceIndex, static_cast<int>( QgsProcessingToolboxModel::CustomRole::AlgorithmTags ) ).toStringList();
+      const QString shortDesc = sourceModel()->data( sourceIndex, static_cast<int>( QgsProcessingToolboxModel::CustomRole::AlgorithmShortDescription ) ).toString();
 
       QStringList parentText;
       QModelIndex parent = sourceIndex.parent();
@@ -768,9 +843,9 @@ bool QgsProcessingToolboxProxyModel::filterAcceptsRow( int sourceRow, const QMod
       }
     }
 
-    if ( mFilters & FilterInPlace )
+    if ( mFilters & Filter::InPlace )
     {
-      const bool supportsInPlace = sourceModel()->data( sourceIndex, QgsProcessingToolboxModel::RoleAlgorithmFlags ).toInt() & QgsProcessingAlgorithm::FlagSupportsInPlaceEdits;
+      const bool supportsInPlace = sourceModel()->data( sourceIndex, static_cast<int>( QgsProcessingToolboxModel::CustomRole::AlgorithmFlags ) ).toInt() & static_cast<int>( Qgis::ProcessingAlgorithmFlag::SupportsInPlaceEdits );
       if ( !supportsInPlace )
         return false;
 
@@ -780,14 +855,14 @@ bool QgsProcessingToolboxProxyModel::filterAcceptsRow( int sourceRow, const QMod
         return false;
       }
     }
-    if ( mFilters & FilterModeler )
+    if ( mFilters & Filter::Modeler )
     {
-      bool isHiddenFromModeler = sourceModel()->data( sourceIndex, QgsProcessingToolboxModel::RoleAlgorithmFlags ).toInt() & QgsProcessingAlgorithm::FlagHideFromModeler;
+      bool isHiddenFromModeler = sourceModel()->data( sourceIndex, static_cast<int>( QgsProcessingToolboxModel::CustomRole::AlgorithmFlags ) ).toInt() & static_cast<int>( Qgis::ProcessingAlgorithmFlag::HideFromModeler );
       return !isHiddenFromModeler;
     }
-    if ( mFilters & FilterToolbox )
+    if ( mFilters & Filter::Toolbox )
     {
-      bool isHiddenFromToolbox = sourceModel()->data( sourceIndex, QgsProcessingToolboxModel::RoleAlgorithmFlags ).toInt() & QgsProcessingAlgorithm::FlagHideFromToolbox;
+      bool isHiddenFromToolbox = sourceModel()->data( sourceIndex, static_cast<int>( QgsProcessingToolboxModel::CustomRole::AlgorithmFlags ) ).toInt() & static_cast<int>( Qgis::ProcessingAlgorithmFlag::HideFromToolbox );
       return !isHiddenFromToolbox;
     }
     return true;
@@ -810,20 +885,24 @@ bool QgsProcessingToolboxProxyModel::filterAcceptsRow( int sourceRow, const QMod
 
 bool QgsProcessingToolboxProxyModel::lessThan( const QModelIndex &left, const QModelIndex &right ) const
 {
-  QgsProcessingToolboxModelNode::NodeType leftType = static_cast< QgsProcessingToolboxModelNode::NodeType >( sourceModel()->data( left, QgsProcessingToolboxModel::RoleNodeType ).toInt() );
-  QgsProcessingToolboxModelNode::NodeType rightType = static_cast< QgsProcessingToolboxModelNode::NodeType >( sourceModel()->data( right, QgsProcessingToolboxModel::RoleNodeType ).toInt() );
+  QgsProcessingToolboxModelNode::NodeType leftType = static_cast<QgsProcessingToolboxModelNode::NodeType>( sourceModel()->data( left, static_cast<int>( QgsProcessingToolboxModel::CustomRole::NodeType ) ).toInt() );
+  QgsProcessingToolboxModelNode::NodeType rightType = static_cast<QgsProcessingToolboxModelNode::NodeType>( sourceModel()->data( right, static_cast<int>( QgsProcessingToolboxModel::CustomRole::NodeType ) ).toInt() );
 
-  if ( leftType == QgsProcessingToolboxModelNode::NodeRecent )
+  if ( leftType == QgsProcessingToolboxModelNode::NodeType::Recent )
     return true;
-  else if ( rightType == QgsProcessingToolboxModelNode::NodeRecent )
+  else if ( rightType == QgsProcessingToolboxModelNode::NodeType::Recent )
+    return false;
+  else if ( leftType == QgsProcessingToolboxModelNode::NodeType::Favorite )
+    return true;
+  else if ( rightType == QgsProcessingToolboxModelNode::NodeType::Favorite )
     return false;
   else if ( leftType != rightType )
   {
-    if ( leftType == QgsProcessingToolboxModelNode::NodeProvider )
+    if ( leftType == QgsProcessingToolboxModelNode::NodeType::Provider )
       return false;
-    else if ( rightType == QgsProcessingToolboxModelNode::NodeProvider )
+    else if ( rightType == QgsProcessingToolboxModelNode::NodeType::Provider )
       return true;
-    else if ( leftType == QgsProcessingToolboxModelNode::NodeGroup )
+    else if ( leftType == QgsProcessingToolboxModelNode::NodeType::Group )
       return false;
     else
       return true;
@@ -834,7 +913,7 @@ bool QgsProcessingToolboxProxyModel::lessThan( const QModelIndex &left, const QM
   QModelIndex parent = left.parent();
   while ( parent.isValid() )
   {
-    if ( mModel->data( parent, QgsProcessingToolboxModel::RoleNodeType ).toInt() == QgsProcessingToolboxModelNode::NodeRecent )
+    if ( mModel->data( parent, static_cast<int>( QgsProcessingToolboxModel::CustomRole::NodeType ) ).toInt() == static_cast<int>( QgsProcessingToolboxModelNode::NodeType::Recent ) )
     {
       isRecentNode = true;
       break;
@@ -846,7 +925,6 @@ bool QgsProcessingToolboxProxyModel::lessThan( const QModelIndex &left, const QM
     return left.row() < right.row();
   }
 
-
   // default mode is alphabetical order
   QString leftStr = sourceModel()->data( left ).toString();
   QString rightStr = sourceModel()->data( right ).toString();
@@ -858,8 +936,8 @@ QVariant QgsProcessingToolboxProxyModel::data( const QModelIndex &index, int rol
   if ( role == Qt::ForegroundRole && !mFilterString.isEmpty() )
   {
     QModelIndex sourceIndex = mapToSource( index );
-    const QVariant flags = sourceModel()->data( sourceIndex, QgsProcessingToolboxModel::RoleProviderFlags );
-    if ( flags.isValid() && flags.toInt() & QgsProcessingProvider::FlagDeemphasiseSearchResults )
+    const QVariant flags = sourceModel()->data( sourceIndex, static_cast<int>( QgsProcessingToolboxModel::CustomRole::ProviderFlags ) );
+    if ( flags.isValid() && flags.toInt() & static_cast<int>( Qgis::ProcessingProviderFlag::DeemphasiseSearchResults ) )
     {
       QBrush brush( qApp->palette().color( QPalette::Text ), Qt::SolidPattern );
       QColor fadedTextColor = brush.color();
