@@ -33,31 +33,27 @@ class QgsGeoPackageItemGuiProvider : public QObject, public QgsDataItemGuiProvid
     Q_OBJECT
 
   public:
-
     QgsGeoPackageItemGuiProvider() = default;
 
     QString name() override { return QStringLiteral( "geopackage_items" ); }
 
-    void populateContextMenu( QgsDataItem *item, QMenu *menu,
-                              const QList<QgsDataItem *> &selectedItems,
-                              QgsDataItemGuiContext context ) override;
+    void populateContextMenu( QgsDataItem *item, QMenu *menu, const QList<QgsDataItem *> &selectedItems, QgsDataItemGuiContext context ) override;
 
     bool rename( QgsDataItem *item, const QString &name, QgsDataItemGuiContext context ) override;
     bool deleteLayer( QgsLayerItem *layerItem, QgsDataItemGuiContext context ) override;
 
     bool acceptDrop( QgsDataItem *item, QgsDataItemGuiContext context ) override;
-    bool handleDrop( QgsDataItem *item, QgsDataItemGuiContext context,
-                     const QMimeData *data,
-                     Qt::DropAction action ) override;
+    bool handleDrop( QgsDataItem *item, QgsDataItemGuiContext context, const QMimeData *data, Qt::DropAction action ) override;
+
   private:
     bool handleDropGeopackage( QgsGeoPackageCollectionItem *item, const QMimeData *data, QgsDataItemGuiContext context );
     //! Compacts (VACUUM) a geopackage database
     void vacuumGeoPackageDbAction( const QString &path, const QString &name, QgsDataItemGuiContext context );
-    void createDatabase( const QPointer< QgsGeoPackageRootItem > &item );
+    void createDatabase( const QPointer<QgsGeoPackageRootItem> &item );
+    void createDatabaseAndLayer( const QPointer<QgsGeoPackageRootItem> &item );
 
   protected slots:
-    void renameVectorLayer( const QString &uri, const QString &key, const QStringList &tableNames,
-                            const QPointer< QgsDataItem > &item, QgsDataItemGuiContext context );
+    void renameVectorLayer( const QString &uri, const QString &key, const QStringList &tableNames, const QPointer<QgsDataItem> &item, QgsDataItemGuiContext context );
 };
 
 ///@endcond
