@@ -72,6 +72,13 @@ class QgsApplicationExitBlockerInterface;
 class QgsAbstractMapToolHandler;
 class QgsUserProfileManager;
 class QgsDataSourceManagerDialog;
+class Qgs3DMapCanvas SIP_EXTERNAL;
+
+#ifdef SIP_RUN
+//%ModuleHeaderCode
+class Qgs3DMapCanvas;
+//%End
+#endif
 
 /**
  * \ingroup gui
@@ -92,8 +99,6 @@ class GUI_EXPORT QgisInterface : public QObject
     Q_OBJECT
 
   public:
-
-    //! Constructor
     QgisInterface() = default;
 
     virtual QgsPluginManagerInterface *pluginManagerInterface() = 0;
@@ -112,8 +117,7 @@ class GUI_EXPORT QgisInterface : public QObject
      * \see removeCustomActionForLayerType()
      * \see addCustomActionForLayer()
      */
-    virtual void addCustomActionForLayerType( QAction *action, QString menu,
-        Qgis::LayerType type, bool allLayers ) = 0;
+    virtual void addCustomActionForLayerType( QAction *action, QString menu, Qgis::LayerType type, bool allLayers ) = 0;
 
     /**
      * Add action to context menu for a specific layer in the layer tree.
@@ -131,24 +135,41 @@ class GUI_EXPORT QgisInterface : public QObject
 
     /**
      * Returns a list of all map canvases open in the app.
-     * \since QGIS 3.0
      */
-    virtual QList< QgsMapCanvas * > mapCanvases() = 0;
+    virtual QList<QgsMapCanvas *> mapCanvases() = 0;
 
     /**
      * Create a new map canvas with the specified unique \a name.
      * \see closeMapCanvas()
-     * \since QGIS 3.0
      */
     virtual QgsMapCanvas *createNewMapCanvas( const QString &name ) = 0;
 
     /**
      * Closes the additional map canvas with matching \a name.
      * \see createNewMapCanvas()
-     * \since QGIS 3.0
      */
     virtual void closeMapCanvas( const QString &name ) = 0;
 
+    /**
+     * Returns a list of all 3D map canvases open in the app.
+     * \since QGIS 3.36
+     */
+    virtual QList<Qgs3DMapCanvas *> mapCanvases3D() = 0;
+
+    /**
+     * Create a new 3D map canvas with the specified unique \a name.
+     * \see closeMapCanvas3D()
+     * \since QGIS 3.36
+     */
+    virtual Qgs3DMapCanvas *createNewMapCanvas3D( const QString &name ) = 0;
+
+    /**
+     * Closes the additional map canvas with matching \a name.
+     * \see createNewMapCanvas3D()
+     * \since QGIS 3.36
+     */
+    virtual void closeMapCanvas3D( const QString &name ) = 0;
+
     /**
      * Returns the toolbar icon size. If \a dockedToolbar is TRUE, the icon size
      * for toolbars contained within docks is returned.
@@ -177,7 +198,6 @@ class GUI_EXPORT QgisInterface : public QObject
     /**
      * Returns a pointer to the layer tree canvas bridge
      *
-     * \since QGIS 2.12
      */
     virtual QgsLayerTreeMapCanvasBridge *layerTreeCanvasBridge() = 0;
 
@@ -189,7 +209,6 @@ class GUI_EXPORT QgisInterface : public QObject
 
     /**
      * Returns all currently open layout designers.
-     * \since QGIS 3.0
      */
     virtual QList<QgsLayoutDesignerInterface *> openLayoutDesigners() = 0;
 
@@ -202,7 +221,6 @@ class GUI_EXPORT QgisInterface : public QObject
 
     /**
      * Advanced digitizing dock widget
-     * \since QGIS 2.12
      */
     virtual QgsAdvancedDigitizingDockWidget *cadDockWidget() = 0;
 
@@ -283,7 +301,6 @@ class GUI_EXPORT QgisInterface : public QObject
 
     /**
      * Returns a reference to the main window "Add Layer" menu.
-     * \since QGIS 2.5
      */
     virtual QMenu *addLayerMenu() = 0;
 
@@ -327,6 +344,13 @@ class GUI_EXPORT QgisInterface : public QObject
      */
     virtual QMenu *webMenu() = 0;
 
+    /**
+     * Returns a reference to the main window "Mesh" menu.
+     *
+     * \since QGIS 3.34
+     */
+    virtual QMenu *meshMenu() = 0;
+
     /**
      * Returns a reference to the right most standard menu, which is
      * usually the last menu item before the "Help" menu.
@@ -390,7 +414,6 @@ class GUI_EXPORT QgisInterface : public QObject
 
     /**
      * Returns a reference to the main window "Shape Digitizing" toolbar.
-     * \since QGIS 3.0
      */
     virtual QToolBar *shapeDigitizeToolBar() = 0;
 
@@ -542,7 +565,7 @@ class GUI_EXPORT QgisInterface : public QObject
     /**
      *  Returns the native zoom to layer action. Call trigger() on it to zoom to the active layer.
      *
-     *  \deprecated Use actionZoomToLayers() instead.
+     *  \deprecated QGIS 3.40. Use actionZoomToLayers() instead.
      */
     Q_DECL_DEPRECATED virtual QAction *actionZoomToLayer() = 0 SIP_DEPRECATED;
 
@@ -607,7 +630,6 @@ class GUI_EXPORT QgisInterface : public QObject
 
     /**
      * Statistical summary action.
-     * \since QGIS 3.0
      */
     virtual QAction *actionOpenStatisticalSummary() = 0;
 
@@ -644,7 +666,6 @@ class GUI_EXPORT QgisInterface : public QObject
 
     /**
      * Returns the Hide Deselected Layers action.
-     * \since QGIS 3.0
      */
     virtual QAction *actionHideDeselectedLayers() = 0;
     virtual QAction *actionShowSelectedLayers() = 0;
@@ -669,99 +690,99 @@ class GUI_EXPORT QgisInterface : public QObject
 
     /**
      * Returns the native add circle from 2 points action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionCircle2Points() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionCircle2Points() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Returns the native add circle from 3 points action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionCircle3Points() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionCircle3Points() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Returns the native add circle from 3 tangents action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionCircle3Tangents() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionCircle3Tangents() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Returns the native add circle from 2 tangents and a point action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionCircle2TangentsPoint() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionCircle2TangentsPoint() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Returns the native add circle from center action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionCircleCenterPoint() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionCircleCenterPoint() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Returns the native add ellipse from center and 2 points action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionEllipseCenter2Points() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionEllipseCenter2Points() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Returns the native add ellipse from center and a point action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionEllipseCenterPoint() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionEllipseCenterPoint() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Returns the native add ellipse from an extent action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionEllipseExtent() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionEllipseExtent() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Returns the native add ellipse from foci action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionEllipseFoci() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionEllipseFoci() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Returns the native add rectangle from center and a point action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionRectangleCenterPoint() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionRectangleCenterPoint() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Returns the native add rectangle from extent action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionRectangleExtent() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionRectangleExtent() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Returns the native add rectangle from 3 points (distance from 2nd and 3rd points) action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionRectangle3PointsDistance() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionRectangle3PointsDistance() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Returns the native add rectangle from 3 points (distance from projected 3rd point on segment p1 and p2) action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionRectangle3PointsProjected() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionRectangle3PointsProjected() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Returns the native add regular polygon from 2 points action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionRegularPolygon2Points() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionRegularPolygon2Points() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Returns the native add regular polygon from center and a point action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionRegularPolygonCenterPoint() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionRegularPolygonCenterPoint() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Returns the native add regular polygon from center and a corner action. Call trigger() on it to set the map tool.
-     * \deprecated since QGIS 3.26 shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
+     * \deprecated QGIS 3.26. Shape digitizing is now part of the add feature tool. To enable the shape tool, use QgsMapToolCapture::setCurrentCaptureTechnique() and then QgsMapToolCapture::setCurrentShapeMapTool().
      */
-    Q_DECL_DEPRECATED virtual QAction *actionRegularPolygonCenterCorner() SIP_DEPRECATED {return actionAddFeature();}
+    Q_DECL_DEPRECATED virtual QAction *actionRegularPolygonCenterCorner() SIP_DEPRECATED { return actionAddFeature(); }
 
     /**
      * Access the vector layer tools instance.
@@ -779,7 +800,6 @@ class GUI_EXPORT QgisInterface : public QObject
      * Returns a pointer to the app's status bar interface. This should be
      * used for interacting and adding widgets and messages to the app's
      * status bar (do not use the native Qt statusBar() method).
-     * \since QGIS 3.0
      */
     virtual QgsStatusBar *statusBarIface() = 0;
 
@@ -790,7 +810,11 @@ class GUI_EXPORT QgisInterface : public QObject
      * \param categories an int as a flag value of QgsAppScreenShots::Categories
      * \since QGIS 3.4
      */
-    virtual void takeAppScreenShots( const QString &saveDirectory, const int categories = 0 ) {Q_UNUSED( saveDirectory ) Q_UNUSED( categories );}
+    virtual void takeAppScreenShots( const QString &saveDirectory, const int categories = 0 )
+    {
+      Q_UNUSED( saveDirectory )
+      Q_UNUSED( categories );
+    }
 
     /**
      * Returns the insertion point.
@@ -906,9 +930,8 @@ class GUI_EXPORT QgisInterface : public QObject
      * This calls reloadConnections in the main application and triggers a signal that is
      * forwarded to the GUI elements that needs to be updated (i.e. the source
      * select dialogs and the browser widgets)
-     * \since QGIS 3.0
      */
-    virtual void reloadConnections( ) = 0;
+    virtual void reloadConnections() = 0;
 
     /**
      * Set the active layer (layer gets selected in the legend)
@@ -918,13 +941,11 @@ class GUI_EXPORT QgisInterface : public QObject
 
     /**
      * Copy selected features from the layer to clipboard
-     * \since QGIS 3.0
      */
     virtual void copySelectionToClipboard( QgsMapLayer * ) = 0;
 
     /**
      * Paste features from clipboard to the layer
-     * \since QGIS 3.0
      */
     virtual void pasteFromClipboard( QgsMapLayer * ) = 0;
 
@@ -1013,7 +1034,6 @@ class GUI_EXPORT QgisInterface : public QObject
 
     /**
      * Add a toolbar
-     * \since QGIS 2.3
      */
     virtual void addToolBar( QToolBar *toolbar SIP_TRANSFER, Qt::ToolBarArea area = Qt::TopToolBarArea ) = 0;
 
@@ -1027,7 +1047,6 @@ class GUI_EXPORT QgisInterface : public QObject
 
     /**
      * Opens the layout manager dialog.
-     * \since QGIS 3.0
      */
     virtual void showLayoutManager() = 0;
 
@@ -1035,14 +1054,12 @@ class GUI_EXPORT QgisInterface : public QObject
      * Opens a new layout designer dialog for the specified \a layout, or
      * brings an already open designer window to the foreground if one
      * is already created for the layout.
-     * \since QGIS 3.0
      */
     virtual QgsLayoutDesignerInterface *openLayoutDesigner( QgsMasterLayoutInterface *layout ) = 0;
 
     /**
      * Opens the options dialog. The \a currentPage argument can be used to force
      * the dialog to open at a specific page.
-     * \since QGIS 3.0
      */
     virtual void showOptionsDialog( QWidget *parent = nullptr, const QString &currentPage = QString() ) = 0;
 
@@ -1205,7 +1222,6 @@ class GUI_EXPORT QgisInterface : public QObject
      *       be unregistered when plugin is unloaded.
      * \see QgsMapLayerConfigWidgetFactory
      * \see unregisterMapLayerConfigWidgetFactory()
-     * \since QGIS 2.16
      */
     virtual void registerMapLayerConfigWidgetFactory( QgsMapLayerConfigWidgetFactory *factory ) = 0;
 
@@ -1213,7 +1229,6 @@ class GUI_EXPORT QgisInterface : public QObject
      * Unregister a previously registered tab in the map layer properties dialog.
      * \see QgsMapLayerConfigWidgetFactory
      * \see registerMapLayerConfigWidgetFactory()
-     * \since QGIS 2.16
     */
     virtual void unregisterMapLayerConfigWidgetFactory( QgsMapLayerConfigWidgetFactory *factory ) = 0;
 
@@ -1223,7 +1238,6 @@ class GUI_EXPORT QgisInterface : public QObject
      *       be unregistered when plugin is unloaded.
      * \see QgsOptionsWidgetFactory
      * \see unregisterOptionsWidgetFactory()
-     * \since QGIS 3.0
      */
     virtual void registerOptionsWidgetFactory( QgsOptionsWidgetFactory *factory ) = 0;
 
@@ -1231,7 +1245,6 @@ class GUI_EXPORT QgisInterface : public QObject
      * Unregister a previously registered tab in the options dialog.
      * \see QgsOptionsWidgetFactory
      * \see registerOptionsWidgetFactory()
-     * \since QGIS 3.0
     */
     virtual void unregisterOptionsWidgetFactory( QgsOptionsWidgetFactory *factory ) = 0;
 
@@ -1315,7 +1328,6 @@ class GUI_EXPORT QgisInterface : public QObject
      *       be unregistered when plugin is unloaded.
      * \see QgsCustomDropHandler
      * \see unregisterCustomDropHandler()
-     * \since QGIS 3.0
      */
     virtual void registerCustomDropHandler( QgsCustomDropHandler *handler ) = 0;
 
@@ -1323,7 +1335,6 @@ class GUI_EXPORT QgisInterface : public QObject
      * Unregister a previously registered custom drop \a handler.
      * \see QgsCustomDropHandler
      * \see registerCustomDropHandler()
-     * \since QGIS 3.0
      */
     virtual void unregisterCustomDropHandler( QgsCustomDropHandler *handler ) = 0;
 
@@ -1351,7 +1362,6 @@ class GUI_EXPORT QgisInterface : public QObject
      *       be unregistered when plugin is unloaded.
      * \see QgsLayoutCustomDropHandler
      * \see unregisterCustomLayoutDropHandler()
-     * \since QGIS 3.0
      */
     virtual void registerCustomLayoutDropHandler( QgsLayoutCustomDropHandler *handler ) = 0;
 
@@ -1359,7 +1369,6 @@ class GUI_EXPORT QgisInterface : public QObject
      * Unregister a previously registered custom drop \a handler for layout windows.
      * \see QgsLayoutCustomDropHandler
      * \see registerCustomLayoutDropHandler()
-     * \since QGIS 3.0
      */
     virtual void unregisterCustomLayoutDropHandler( QgsLayoutCustomDropHandler *handler ) = 0;
 
@@ -1372,7 +1381,7 @@ class GUI_EXPORT QgisInterface : public QObject
      * \param url URL to open
      * \param useQgisDocDirectory If TRUE, the URL will be formed by concatenating
      * url to the QGIS documentation directory path (prefix/share/doc)
-     * \deprecated Use QDesktopServices instead
+     * \deprecated QGIS 3.40. Use QDesktopServices instead.
      */
 #ifndef Q_MOC_RUN
     Q_DECL_DEPRECATED
@@ -1427,7 +1436,6 @@ class GUI_EXPORT QgisInterface : public QObject
      * \warning Plugins which register filters to the locator bar must take care to correctly call
      * deregisterLocatorFilter() and deregister their filters upon plugin unload to avoid crashes.
      * \see deregisterLocatorFilter()
-     * \since QGIS 3.0
      */
     virtual void registerLocatorFilter( QgsLocatorFilter *filter SIP_TRANSFER ) = 0;
 
@@ -1439,7 +1447,6 @@ class GUI_EXPORT QgisInterface : public QObject
      * deregisterLocatorFilter() to deregister their filters upon plugin unload to avoid crashes.
      *
      * \see registerLocatorFilter()
-     * \since QGIS 3.0
      */
     virtual void deregisterLocatorFilter( QgsLocatorFilter *filter ) = 0;
 
@@ -1456,7 +1463,6 @@ class GUI_EXPORT QgisInterface : public QObject
       * Checks available datum transforms and ask user if several are available and none
       * is chosen. Dialog is shown only if global option is set accordingly.
       * \returns TRUE if a datum transform has been specifically chosen by user or only one is available.
-      * \since 3.0
       */
     virtual bool askForDatumTransform( QgsCoordinateReferenceSystem sourceCrs, QgsCoordinateReferenceSystem destinationCrs ) = 0;
 
@@ -1477,6 +1483,22 @@ class GUI_EXPORT QgisInterface : public QObject
      */
     virtual void setGpsPanelConnection( QgsGpsConnection *connection SIP_TRANSFER ) = 0;
 
+    /**
+     * Sets whether changes to the active layer should be temporarily
+     * blocked.
+     *
+     * This is a low-level method, designed to avoid unnecessary work when adding lots
+     * of layers at once. Clients which will be adding many layers may call blockActiveLayerChanges( TRUE ) upfront,
+     * add all the layers, and then follow up with a call to blockActiveLayerChanges( FALSE ). This will defer emitting
+     * the active layer changed signal until they've added all layers, and only emit the signal once for
+     * the final layer added.
+     *
+     * \warning This must be accompanied by a subsequent call with \a blocked as FALSE.
+     *
+     * \since QGIS 3.36
+     */
+    virtual void blockActiveLayerChanges( bool blocked ) = 0;
+
   signals:
 
     /**
@@ -1488,14 +1510,12 @@ class GUI_EXPORT QgisInterface : public QObject
     /**
      * Emitted when the current \a theme is changed so plugins
      * can change their tool button icons.
-     * \since QGIS 3.0
     */
     void currentThemeChanged( const QString &theme );
 
     /**
      * Emitted when a new layout \a designer has been opened.
      * \see layoutDesignerWillBeClosed()
-     * \since QGIS 3.0
      */
     void layoutDesignerOpened( QgsLayoutDesignerInterface *designer );
 
@@ -1504,7 +1524,6 @@ class GUI_EXPORT QgisInterface : public QObject
      * and deleted.
      * \see layoutDesignerClosed()
      * \see layoutDesignerOpened()
-     * \since QGIS 3.0
      */
     void layoutDesignerWillBeClosed( QgsLayoutDesignerInterface *designer );
 
@@ -1512,7 +1531,6 @@ class GUI_EXPORT QgisInterface : public QObject
      * Emitted after a layout designer window is closed.
      * \see layoutDesignerWillBeClosed()
      * \see layoutDesignerOpened()
-     * \since QGIS 3.0
      */
     void layoutDesignerClosed();
 
@@ -1541,10 +1559,8 @@ class GUI_EXPORT QgisInterface : public QObject
 
     /**
      * Emitted when a layer has been saved using save as.
-     * \since QGIS 2.7
      */
     void layerSavedAs( QgsMapLayer *l, const QString &path );
-
 };
 Q_NOWARN_DEPRECATED_POP
 
