@@ -24,6 +24,7 @@
 #include "ui_qgsadvanceddigitizingdockwidgetbase.h"
 #include "qgis_gui.h"
 #include "qgis_sip.h"
+#include "qgsadvanceddigitizingtools.h"
 #include "qgsdockwidget.h"
 #include "qgsmessagebaritem.h"
 #include "qgspointxy.h"
@@ -33,10 +34,12 @@
 
 class QgsAdvancedDigitizingCanvasItem;
 class QgsAdvancedDigitizingFloater;
+class QgsAdvancedDigitizingTool;
 class QgsMapCanvas;
 class QgsMapTool;
 class QgsMapToolAdvancedDigitizing;
 class QgsMapMouseEvent;
+class QgsUserInputWidget;
 
 /**
  * \ingroup gui
@@ -50,18 +53,17 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     Q_OBJECT
 
   public:
-
     /**
      * The CadCapacity enum defines the possible constraints to be set
      * depending on the number of points in the CAD point list (the list of points
      * currently digitized)
      */
-    enum CadCapacity
+    enum CadCapacity SIP_ENUM_BASETYPE( IntFlag )
     {
-      AbsoluteAngle = 1, //!< Azimuth
-      RelativeAngle = 2, //!< Also for parallel and perpendicular
+      AbsoluteAngle = 1,       //!< Azimuth
+      RelativeAngle = 2,       //!< Also for parallel and perpendicular
       RelativeCoordinates = 4, //!< This corresponds to distance and relative coordinates
-      Distance = 8, //!< Distance
+      Distance = 8,            //!< Distance
     };
     Q_DECLARE_FLAGS( CadCapacities, CadCapacity )
     Q_FLAG( CadCapacities )
@@ -73,7 +75,9 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      */
     enum WidgetSetMode
     {
-      ReturnPressed, FocusOut, TextEdited
+      ReturnPressed,
+      FocusOut,
+      TextEdited
     };
 
 
@@ -86,7 +90,6 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     class GUI_EXPORT CadConstraint
     {
       public:
-
         /**
          * The lock mode
          */
@@ -130,7 +133,6 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
          * Returns TRUE if a repeating lock is set for the constraint. Repeating locks are not
          * automatically cleared after a new point is added.
          * \see setRepeatingLock()
-         * \since QGIS 2.16
          */
         bool isRepeatingLock() const { return mRepeatingLock; }
 
@@ -159,7 +161,6 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
          * automatically cleared after a new point is added.
          * \param repeating set to TRUE to set the lock to repeat automatically
          * \see isRepeatingLock()
-         * \since QGIS 2.16
          */
         void setRepeatingLock( bool repeating );
 
@@ -250,8 +251,10 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      * Create an advanced digitizing dock widget
      * \param canvas The map canvas on which the widget operates
      * \param parent The parent
+     * \param userInputWidget The user input widget on which tools can add widget overlays on top of the map canvas (since QGIS 3.40)
      */
-    explicit QgsAdvancedDigitizingDockWidget( QgsMapCanvas *canvas, QWidget *parent = nullptr );
+    explicit QgsAdvancedDigitizingDockWidget( QgsMapCanvas *canvas, QWidget *parent = nullptr, QgsUserInputWidget *userInputWidget = nullptr );
+    ~QgsAdvancedDigitizingDockWidget();
 
     /**
      * Filter key events to e.g. toggle construction mode or adapt constraints
@@ -270,14 +273,39 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     /**
      * align to segment for between line constraint.
      * If between line constraints are used, this will determine the angle to be locked depending on the snapped segment.
-     * \since QGIS 3.0
      */
     bool alignToSegment( QgsMapMouseEvent *e, QgsAdvancedDigitizingDockWidget::CadConstraint::LockMode lockMode = QgsAdvancedDigitizingDockWidget::CadConstraint::HardLock );
 
+    /**
+     * Processes the canvas press \a event.
+     */
+    void processCanvasPressEvent( QgsMapMouseEvent *event );
+
+    /**
+     * Processes the canvas move \a event.
+     */
+    void processCanvasMoveEvent( QgsMapMouseEvent *event );
+
+    /**
+     * Processes the canvas release \a event.
+     */
+    void processCanvasReleaseEvent( QgsMapMouseEvent *event );
+
+    /**
+     * Sets an advanced digitizing tool which will take over digitizing until the tool is close.
+     * \since QGIS 3.40
+     */
+    void setTool( QgsAdvancedDigitizingTool *tool );
+
+    /**
+     * Returns the current advanced digitizing tool. Returns NULLPTR if not set.
+     * \since QGIS 3.40
+     */
+    QgsAdvancedDigitizingTool *tool() const;
+
     /**
      * unlock all constraints
      * \param releaseRepeatingLocks set to FALSE to preserve the lock for any constraints set to repeating lock mode
-     * \since QGIS 3.0
      */
     void releaseLocks( bool releaseRepeatingLocks = true );
 
@@ -295,7 +323,7 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      * Determines if Z or M will be enabled.
      * \since QGIS 3.22
      */
-    void switchZM( );
+    void switchZM();
 
     /**
      * Sets whether Z is enabled
@@ -309,16 +337,43 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      */
     void setEnabledM( bool enable );
 
-    //! construction mode is used to draw intermediate points. These points won't be given any further (i.e. to the map tools)
+    /**
+     * Returns whether the construction mode is activated. The construction mode is used to draw intermediate
+     * points that will not be part of a geometry being digitized.
+     */
     bool constructionMode() const { return mConstructionMode; }
 
+    /**
+     * Returns the vector layer within which construction guides are stored.
+     * \since QGIS 3.40
+     */
+    QgsVectorLayer *constructionGuidesLayer() const { return mConstructionGuidesLayer.get(); }
+
+    /**
+     * Returns whether the construction guides are visible.
+     * \since QGIS 3.40
+     */
+    bool showConstructionGuides() const;
+
+    /**
+     * Returns whether points should snap to construction guides.
+     * \since QGIS 3.40
+     */
+    bool snapToConstructionGuides() const;
+
+    /**
+     * Returns whether construction guides are being recorded.
+     * \since QGIS 3.40
+     */
+    bool recordConstructionGuides() const;
+
     /**
      * Returns the between line constraints which are used to place
      * perpendicular/parallel segments to snapped segments on the canvas
      */
-    Qgis::BetweenLineConstraint betweenLineConstraint() const  { return mBetweenLineConstraint; }
+    Qgis::BetweenLineConstraint betweenLineConstraint() const { return mBetweenLineConstraint; }
     //! Returns the \a CadConstraint on the angle
-    const CadConstraint *constraintAngle() const  { return mAngleConstraint.get(); }
+    const CadConstraint *constraintAngle() const { return mAngleConstraint.get(); }
     //! Returns the \a CadConstraint on the distance
     const CadConstraint *constraintDistance() const { return mDistanceConstraint.get(); }
     //! Returns the \a CadConstraint on the X coordinate
@@ -355,6 +410,12 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     //! Returns the Y value of the Y soft lock. The value is NaN is the constraint isn't magnetized to a line
     double softLockY() const { return mSoftLockY; }
 
+    /**
+     * Toggles the distance constraint.
+     * \since QGIS 3.40
+     */
+    void toggleConstraintDistance();
+
     /**
      * Returns the point locator match
      * \since QGIS 3.4
@@ -365,7 +426,7 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      * Returns the snap matches whose vertices have been locked
      * \since QGIS 3.26
      */
-    QList< QgsPointLocator::Match > lockedSnapVertices() const { return mLockedSnapVertices; }
+    QList<QgsPointLocator::Match> lockedSnapVertices() const { return mLockedSnapVertices; }
 
     /**
       * Removes all points from the locked snap vertex list
@@ -376,13 +437,11 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
 
     /**
      * Removes all points from the CAD point list
-     * \since QGIS 3.0
      */
     void clearPoints();
 
     /**
      * Adds point to the CAD point list
-     * \since QGIS 3.0
      */
     void addPoint( const QgsPointXY &point );
 
@@ -403,7 +462,6 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      *
      * Some map tools may find it useful to override list of CAD points that is otherwise
      * automatically populated when user clicks with left mouse button on map canvas.
-     * \since QGIS 3.0
      */
     void setPoints( const QList<QgsPointXY> &points );
 
@@ -414,7 +472,7 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      *
      * \since QGIS 3.22
      */
-    QgsPoint currentPointV2( bool *exists  = nullptr ) const;
+    QgsPoint currentPointV2( bool *exists = nullptr ) const;
 
     /**
      * Returns the last CAD point, in a map \a layer's coordinates.
@@ -427,9 +485,9 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      * The last point.
      * Helper for the CAD point list. The CAD point list is the list of points
      * currently digitized. It contains both  "normal" points and intermediate points (construction mode).
-     * \deprecated since QGIS 3.22. Use currentPointV2() instead.
+     * \deprecated QGIS 3.22. Use currentPointV2() instead.
      */
-    Q_DECL_DEPRECATED QgsPointXY currentPoint( bool *exists  = nullptr ) const SIP_DEPRECATED { return currentPointV2( exists ); };
+    Q_DECL_DEPRECATED QgsPointXY currentPoint( bool *exists = nullptr ) const SIP_DEPRECATED { return currentPointV2( exists ); };
 
     /**
      * The previous point.
@@ -442,7 +500,7 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      * The previous point.
      * Helper for the CAD point list. The CAD point list is the list of points
      * currently digitized. It contains both  "normal" points and intermediate points (construction mode).
-     * \deprecated since QGIS 3.22. Use previousPointV2() instead.
+     * \deprecated QGIS 3.22. Use previousPointV2() instead.
      */
     Q_DECL_DEPRECATED QgsPointXY previousPoint( bool *exists = nullptr ) const SIP_DEPRECATED { return previousPointV2( exists ); };
 
@@ -457,7 +515,7 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      * The penultimate point.
      * Helper for the CAD point list. The CAD point list is the list of points
      * currently digitized. It contains both  "normal" points and intermediate points (construction mode).
-     * \deprecated since QGIS 3.22. Use penultimatePointV2() instead.
+     * \deprecated QGIS 3.22. Use penultimatePointV2() instead.
      */
     Q_DECL_DEPRECATED QgsPointXY penultimatePoint( bool *exists = nullptr ) const SIP_DEPRECATED { return penultimatePointV2( exists ); };
 
@@ -494,7 +552,6 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
 
     /**
      * Updates canvas item that displays constraints on the ma
-     * \since QGIS 3.0
      */
     void updateCadPaintItem();
 
@@ -562,13 +619,13 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      * Convenient method to get the Z value from the line edit wiget
      * \since QGIS 3.22
      */
-    double getLineZ( ) const;
+    double getLineZ() const;
 
     /**
      * Convenient method to get the M value from the line edit wiget
      * \since QGIS 3.22
      */
-    double getLineM( ) const;
+    double getLineM() const;
 
     /**
      * Returns the capacities
@@ -610,7 +667,7 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      * when a constraint is toggled.
      *
      * \param point The last known digitizing point. Can be used to emulate a mouse event.
-     * \deprecated since QGIS 3.22. No longer used, will be removed in QGIS 4.0. Use pointChangedV2 instead.
+     * \deprecated QGIS 3.22. No longer used, will be removed in QGIS 4.0. Use pointChangedV2 instead.
      */
     Q_DECL_DEPRECATED void pointChanged( const QgsPointXY &point ) SIP_DEPRECATED;
 
@@ -964,7 +1021,6 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     void settingsButtonTriggered( QAction *action );
 
   private:
-
     /**
      * Returns the layer currently associated with the map tool using the dock widget.
      */
@@ -1021,7 +1077,6 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     //! Updates values of constraints that are not locked based on the current point
     void updateUnlockedConstraintValues( const QgsPoint &point );
 
-
     /**
      * Adds or removes the snap match if it is already in the locked snap queue or not.
      * \param snapMatch the snap match to add or remove.
@@ -1029,7 +1084,20 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      */
     void toggleLockedSnapVertex( const QgsPointLocator::Match &snapMatch, QgsPointLocator::Match previouslySnap );
 
+    /**
+     * Resets the vector layer and point locator objects handling construction guides.
+     */
+    void resetConstructionGuides();
+
+    /**
+     * Updates the construction guides layer CRS to match the map canvas' destination CRS
+     * and reproject pre-existing construction guides.
+     */
+    void updateConstructionGuidesCrs();
+
     QgsMapCanvas *mMapCanvas = nullptr;
+    QgsUserInputWidget *mUserInputWidget = nullptr;
+
     QgsAdvancedDigitizingCanvasItem *mCadPaintItem = nullptr;
     //! Snapping indicator
     std::unique_ptr<QgsSnapIndicator> mSnapIndicator;
@@ -1047,33 +1115,43 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     bool mConstructionMode = false;
 
     // constraints
-    std::unique_ptr< CadConstraint > mAngleConstraint;
-    std::unique_ptr< CadConstraint > mDistanceConstraint;
-    std::unique_ptr< CadConstraint > mXConstraint;
-    std::unique_ptr< CadConstraint > mYConstraint;
-    std::unique_ptr< CadConstraint > mZConstraint;
-    std::unique_ptr< CadConstraint > mMConstraint;
-    std::unique_ptr< CadConstraint > mLineExtensionConstraint;
-    std::unique_ptr< CadConstraint > mXyVertexConstraint;
+    std::unique_ptr<CadConstraint> mAngleConstraint;
+    std::unique_ptr<CadConstraint> mDistanceConstraint;
+    std::unique_ptr<CadConstraint> mXConstraint;
+    std::unique_ptr<CadConstraint> mYConstraint;
+    std::unique_ptr<CadConstraint> mZConstraint;
+    std::unique_ptr<CadConstraint> mMConstraint;
+    std::unique_ptr<CadConstraint> mLineExtensionConstraint;
+    std::unique_ptr<CadConstraint> mXyVertexConstraint;
     Qgis::BetweenLineConstraint mBetweenLineConstraint;
     double mCommonAngleConstraint; // if 0: do not snap to common angles
 
     //! Flag that controls whether snapping to features has priority over common angle
     bool mSnappingPrioritizeFeatures = false;
 
-    // point list and current snap point / segment
+    // Point list and current snap point / segment
     QList<QgsPoint> mCadPointList;
     QList<QgsPointXY> mSnappedSegment;
 
     bool mSessionActive = false;
 
-    // error message
+    // Construction path history
+    std::unique_ptr<QgsVectorLayer> mConstructionGuidesLayer;
+    QgsFeatureId mConstructionGuideId;
+    QgsLineString mConstructionGuideLine;
+    bool mDeferredUpdateConstructionGuidesCrs = false;
+
+    // Error message
     std::unique_ptr<QgsMessageBarItem> mErrorMessage;
 
     // UI
-    QMap< double, QAction *> mCommonAngleActions; // map the common angle actions with their angle values
-    QAction *mLineExtensionAction;
-    QAction *mXyVertexAction;
+    QMap<double, QAction *> mCommonAngleActions; // map the common angle actions with their angle values
+    QAction *mLineExtensionAction = nullptr;
+    QAction *mXyVertexAction = nullptr;
+    QAction *mRecordConstructionGuides = nullptr;
+    QAction *mShowConstructionGuides = nullptr;
+    QAction *mSnapToConstructionGuides = nullptr;
+    QAction *mClearConstructionGuides = nullptr;
 
     // Snap indicator
     QgsPointLocator::Match mSnapMatch;
@@ -1083,7 +1161,10 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     Qgis::LineExtensionSide mSoftLockLineExtension;
     double mSoftLockX;
     double mSoftLockY;
-    QQueue< QgsPointLocator::Match > mLockedSnapVertices;
+    QQueue<QgsPointLocator::Match> mLockedSnapVertices;
+
+    // Advanced digitizing tool
+    QPointer<QgsAdvancedDigitizingTool> mCurrentTool;
 
 #ifdef SIP_RUN
     //! event filter for line edits in the dock UI (angle/distance/x/y line edits)
@@ -1095,7 +1176,15 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     QMenu *mCommonAngleActionsMenu = nullptr;
     QMenu *mFloaterActionsMenu = nullptr;
 
+    /* Store whether the target layer supports Z and M, to avoid unnecessary checks
+     * when floater settings are changed */
+    bool mTargetLayerSupportsZ = false;
+    bool mTargetLayerSupportsM = false;
+
     static const QgsSettingsEntryBool *settingsCadSnappingPriorityPrioritizeFeature;
+    static const QgsSettingsEntryBool *settingsCadRecordConstructionGuides;
+    static const QgsSettingsEntryBool *settingsCadShowConstructionGuides;
+    static const QgsSettingsEntryBool *settingsCadSnapToConstructionGuides;
 
     friend class TestQgsAdvancedDigitizing;
     friend class TestQgsAdvancedDigitizingDockWidget;
