@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgscompoundcolorwidget.h"
+#include "moc_qgscompoundcolorwidget.cpp"
 #include "qgscolorscheme.h"
 #include "qgscolorschemeregistry.h"
 #include "qgssymbollayerutils.h"
@@ -22,6 +23,7 @@
 #include "qgsscreenhelper.h"
 #include "qgsguiutils.h"
 
+#include <QButtonGroup>
 #include <QHeaderView>
 #include <QPushButton>
 #include <QMenu>
@@ -41,18 +43,52 @@ QgsCompoundColorWidget::QgsCompoundColorWidget( QWidget *parent, const QColor &c
 
   mScreenHelper = new QgsScreenHelper( this );
 
-  connect( mHueRadio, &QRadioButton::toggled, this, &QgsCompoundColorWidget::mHueRadio_toggled );
-  connect( mSaturationRadio, &QRadioButton::toggled, this, &QgsCompoundColorWidget::mSaturationRadio_toggled );
-  connect( mValueRadio, &QRadioButton::toggled, this, &QgsCompoundColorWidget::mValueRadio_toggled );
-  connect( mRedRadio, &QRadioButton::toggled, this, &QgsCompoundColorWidget::mRedRadio_toggled );
-  connect( mGreenRadio, &QRadioButton::toggled, this, &QgsCompoundColorWidget::mGreenRadio_toggled );
-  connect( mBlueRadio, &QRadioButton::toggled, this, &QgsCompoundColorWidget::mBlueRadio_toggled );
+  mRgbRadios = {
+    { mHueRadio, QgsColorWidget::ColorComponent::Hue },
+    { mSaturationRadio, QgsColorWidget::ColorComponent::Saturation },
+    { mValueRadio, QgsColorWidget::ColorComponent::Value },
+    { mRedRadio, QgsColorWidget::ColorComponent::Red },
+    { mGreenRadio, QgsColorWidget::ColorComponent::Green },
+    { mBlueRadio, QgsColorWidget::ColorComponent::Blue }
+  };
+
+  mCmykRadios = {
+    { mCyanRadio, QgsColorWidget::ColorComponent::Cyan },
+    { mMagentaRadio, QgsColorWidget::ColorComponent::Magenta },
+    { mYellowRadio, QgsColorWidget::ColorComponent::Yellow },
+    { mBlackRadio, QgsColorWidget::ColorComponent::Black }
+  };
+
+  mRgbGroup = new QButtonGroup( this );
+  int i = 0;
+  for ( auto colorRadio : mRgbRadios )
+    mRgbGroup->addButton( colorRadio.first, i++ );
+
+  mCmykGroup = new QButtonGroup( this );
+  i = 0;
+  for ( auto colorRadio : mCmykRadios )
+    mCmykGroup->addButton( colorRadio.first, i++ );
+
+  connect( mRgbGroup, &QButtonGroup::idToggled, this, &QgsCompoundColorWidget::onColorButtonGroupToggled );
+  connect( mCmykGroup, &QButtonGroup::idToggled, this, &QgsCompoundColorWidget::onColorButtonGroupToggled );
   connect( mAddColorToSchemeButton, &QPushButton::clicked, this, &QgsCompoundColorWidget::mAddColorToSchemeButton_clicked );
   connect( mAddCustomColorButton, &QPushButton::clicked, this, &QgsCompoundColorWidget::mAddCustomColorButton_clicked );
   connect( mSampleButton, &QPushButton::clicked, this, &QgsCompoundColorWidget::mSampleButton_clicked );
   connect( mTabWidget, &QTabWidget::currentChanged, this, &QgsCompoundColorWidget::mTabWidget_currentChanged );
   connect( mActionShowInButtons, &QAction::toggled, this, &QgsCompoundColorWidget::mActionShowInButtons_toggled );
 
+  mColorModel->addItem( tr( "RGB" ), QColor::Spec::Rgb );
+  mColorModel->addItem( tr( "CMYK" ), QColor::Spec::Cmyk );
+  connect( mColorModel, static_cast<void ( QComboBox::* )( int )>( &QComboBox::currentIndexChanged ), this, [this]( int ) {
+    const QColor::Spec spec = static_cast<QColor::Spec>( mColorModel->currentData().toInt() );
+    if ( spec == QColor::Spec::Cmyk )
+      setColor( this->color().toCmyk() );
+    else
+      setColor( this->color().toRgb() );
+
+    updateComponent();
+  } );
+
   if ( widgetLayout == LayoutVertical )
   {
     // shuffle stuff around
@@ -69,7 +105,7 @@ QgsCompoundColorWidget::QgsCompoundColorWidget( QWidget *parent, const QColor &c
   const QgsSettings settings;
 
   mSchemeList->header()->hide();
-  mSchemeList->setColumnWidth( 0, static_cast< int >( Qgis::UI_SCALE_FACTOR * fontMetrics().horizontalAdvance( 'X' ) * 6 ) );
+  mSchemeList->setColumnWidth( 0, static_cast<int>( Qgis::UI_SCALE_FACTOR * fontMetrics().horizontalAdvance( 'X' ) * 6 ) );
 
   //get schemes with ShowInColorDialog set
   refreshSchemeComboBox();
@@ -112,7 +148,7 @@ QgsCompoundColorWidget::QgsCompoundColorWidget( QWidget *parent, const QColor &c
   mSchemeToolButton->setMenu( schemeMenu );
 
   connect( mSchemeComboBox, static_cast<void ( QComboBox::* )( int )>( &QComboBox::currentIndexChanged ), this, &QgsCompoundColorWidget::schemeIndexChanged );
-  connect( mSchemeList, &QgsColorSchemeList::colorSelected, this, &QgsCompoundColorWidget::setColor );
+  connect( mSchemeList, &QgsColorSchemeList::colorSelected, this, &QgsCompoundColorWidget::_setColor );
 
   mOldColorLabel->hide();
 
@@ -127,6 +163,10 @@ QgsCompoundColorWidget::QgsCompoundColorWidget( QWidget *parent, const QColor &c
   mSaturationSlider->setComponent( QgsColorWidget::Saturation );
   mValueSlider->setComponent( QgsColorWidget::Value );
   mAlphaSlider->setComponent( QgsColorWidget::Alpha );
+  mCyanSlider->setComponent( QgsColorWidget::Cyan );
+  mMagentaSlider->setComponent( QgsColorWidget::Magenta );
+  mYellowSlider->setComponent( QgsColorWidget::Yellow );
+  mBlackSlider->setComponent( QgsColorWidget::Black );
 
   mSwatchButton1->setShowMenu( false );
   mSwatchButton1->setBehavior( QgsColorButton::SignalOnly );
@@ -183,8 +223,8 @@ QgsCompoundColorWidget::QgsCompoundColorWidget( QWidget *parent, const QColor &c
   mSamplePreview->setColor( QColor() );
 
   // hidpi friendly sizes
-  const int swatchWidth = static_cast< int >( std::round( std::max( Qgis::UI_SCALE_FACTOR * 1.9 * mSwatchButton1->fontMetrics().height(), 38.0 ) ) );
-  const int swatchHeight = static_cast< int >( std::round( std::max( Qgis::UI_SCALE_FACTOR * 1.5 * mSwatchButton1->fontMetrics().height(), 30.0 ) ) );
+  const int swatchWidth = static_cast<int>( std::round( std::max( Qgis::UI_SCALE_FACTOR * 1.9 * mSwatchButton1->fontMetrics().height(), 38.0 ) ) );
+  const int swatchHeight = static_cast<int>( std::round( std::max( Qgis::UI_SCALE_FACTOR * 1.5 * mSwatchButton1->fontMetrics().height(), 30.0 ) ) );
   mSwatchButton1->setMinimumSize( swatchWidth, swatchHeight );
   mSwatchButton1->setMaximumSize( swatchWidth, swatchHeight );
   mSwatchButton2->setMinimumSize( swatchWidth, swatchHeight );
@@ -217,76 +257,63 @@ QgsCompoundColorWidget::QgsCompoundColorWidget( QWidget *parent, const QColor &c
   mSwatchButton15->setMaximumSize( swatchWidth, swatchHeight );
   mSwatchButton16->setMinimumSize( swatchWidth, swatchHeight );
   mSwatchButton16->setMaximumSize( swatchWidth, swatchHeight );
-  const int previewHeight = static_cast< int >( std::round( std::max( Qgis::UI_SCALE_FACTOR * 2.0 * mSwatchButton1->fontMetrics().height(), 40.0 ) ) );
+  const int previewHeight = static_cast<int>( std::round( std::max( Qgis::UI_SCALE_FACTOR * 2.0 * mSwatchButton1->fontMetrics().height(), 40.0 ) ) );
   mColorPreview->setMinimumSize( 0, previewHeight );
   mPreviewWidget->setMaximumHeight( previewHeight * 2 );
-  const int swatchAddSize = static_cast< int >( std::round( std::max( Qgis::UI_SCALE_FACTOR * 1.4 * mSwatchButton1->fontMetrics().height(), 28.0 ) ) );
+  const int swatchAddSize = static_cast<int>( std::round( std::max( Qgis::UI_SCALE_FACTOR * 1.4 * mSwatchButton1->fontMetrics().height(), 28.0 ) ) );
   mAddCustomColorButton->setMinimumWidth( swatchAddSize );
   mAddCustomColorButton->setMaximumWidth( swatchAddSize );
 
   const int iconSize = QgsGuiUtils::scaleIconSize( 16 );
   mTabWidget->setIconSize( QSize( iconSize, iconSize ) );
 
-  if ( color.isValid() )
-  {
-    setColor( color );
-  }
+  setColor( color );
+
+  // restore active Rgb/Cmyk component radio button
+  const int activeRgbRadio = settings.value( QStringLiteral( "Windows/ColorDialog/activeComponent" ), 2 ).toInt();
+  if ( QAbstractButton *rgbRadio = mRgbGroup->button( activeRgbRadio ) )
+    rgbRadio->setChecked( true );
+
+  const int activeCmykRadio = settings.value( QStringLiteral( "Windows/ColorDialog/activeCmykComponent" ), 0 ).toInt();
+  if ( QAbstractButton *cmykRadio = mCmykGroup->button( activeCmykRadio ) )
+    cmykRadio->setChecked( true );
 
-  //restore active component radio button
-  const int activeRadio = settings.value( QStringLiteral( "Windows/ColorDialog/activeComponent" ), 2 ).toInt();
-  switch ( activeRadio )
-  {
-    case 0:
-      mHueRadio->setChecked( true );
-      break;
-    case 1:
-      mSaturationRadio->setChecked( true );
-      break;
-    case 2:
-      mValueRadio->setChecked( true );
-      break;
-    case 3:
-      mRedRadio->setChecked( true );
-      break;
-    case 4:
-      mGreenRadio->setChecked( true );
-      break;
-    case 5:
-      mBlueRadio->setChecked( true );
-      break;
-  }
   const int currentTab = settings.value( QStringLiteral( "Windows/ColorDialog/activeTab" ), 0 ).toInt();
   mTabWidget->setCurrentIndex( currentTab );
 
   //setup connections
-  connect( mColorBox, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::setColor );
-  connect( mColorWheel, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::setColor );
-  connect( mColorText, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::setColor );
-  connect( mVerticalRamp, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::setColor );
-  connect( mRedSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::setColor );
-  connect( mGreenSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::setColor );
-  connect( mBlueSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::setColor );
-  connect( mHueSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::setColor );
-  connect( mValueSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::setColor );
-  connect( mSaturationSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::setColor );
-  connect( mAlphaSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::setColor );
-  connect( mColorPreview, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton1, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton2, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton3, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton4, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton5, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton6, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton7, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton8, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton9, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton10, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton11, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton12, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton13, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton14, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton15, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
-  connect( mSwatchButton16, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::setColor );
+  connect( mColorBox, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mColorWheel, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mColorText, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mVerticalRamp, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mRedSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mGreenSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mBlueSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mHueSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mValueSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mCyanSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mMagentaSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mYellowSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mBlackSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSaturationSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mAlphaSlider, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mColorPreview, &QgsColorWidget::colorChanged, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton1, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton2, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton3, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton4, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton5, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton6, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton7, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton8, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton9, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton10, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton11, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton12, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton13, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton14, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton15, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
+  connect( mSwatchButton16, &QgsColorButton::colorClicked, this, &QgsCompoundColorWidget::_setColor );
 }
 
 QgsCompoundColorWidget::~QgsCompoundColorWidget()
@@ -317,6 +344,11 @@ void QgsCompoundColorWidget::setAllowOpacity( const bool allowOpacity )
   }
 }
 
+void QgsCompoundColorWidget::setColorModelEditable( bool colorModelEditable )
+{
+  mColorModel->setVisible( colorModelEditable );
+}
+
 void QgsCompoundColorWidget::refreshSchemeComboBox()
 {
   mSchemeComboBox->blockSignals( true );
@@ -393,9 +425,7 @@ void QgsCompoundColorWidget::importPalette()
 
 bool QgsCompoundColorWidget::removeUserPalette( QgsUserColorScheme *scheme, QWidget *parent )
 {
-  if ( QMessageBox::question( parent, tr( "Remove Color Palette" ),
-                              tr( "Are you sure you want to remove %1?" ).arg( scheme->schemeName() ),
-                              QMessageBox::Yes | QMessageBox::No, QMessageBox::No ) != QMessageBox::Yes )
+  if ( QMessageBox::question( parent, tr( "Remove Color Palette" ), tr( "Are you sure you want to remove %1?" ).arg( scheme->schemeName() ), QMessageBox::Yes | QMessageBox::No, QMessageBox::No ) != QMessageBox::Yes )
   {
     //user canceled
     return false;
@@ -441,8 +471,7 @@ void QgsCompoundColorWidget::removePalette()
 QgsUserColorScheme *QgsCompoundColorWidget::createNewUserPalette( QWidget *parent )
 {
   bool ok = false;
-  const QString name = QInputDialog::getText( parent, tr( "Create New Palette" ), tr( "Enter a name for the new palette:" ),
-                       QLineEdit::Normal, tr( "New palette" ), &ok );
+  const QString name = QInputDialog::getText( parent, tr( "Create New Palette" ), tr( "Enter a name for the new palette:" ), QLineEdit::Normal, tr( "New palette" ), &ok );
 
   if ( !ok || name.isEmpty() )
   {
@@ -601,17 +630,14 @@ void QgsCompoundColorWidget::mTabWidget_currentChanged( int index )
 {
   //disable radio buttons if not using the first tab, as they have no meaning for other tabs
   const bool enabled = index == 0;
-  mRedRadio->setEnabled( enabled );
-  mBlueRadio->setEnabled( enabled );
-  mGreenRadio->setEnabled( enabled );
-  mHueRadio->setEnabled( enabled );
-  mSaturationRadio->setEnabled( enabled );
-  mValueRadio->setEnabled( enabled );
+  const QList<QRadioButton *> colorRadios { mHueRadio, mSaturationRadio, mValueRadio, mRedRadio, mGreenRadio, mBlueRadio, mCyanRadio, mMagentaRadio, mYellowRadio, mBlackRadio };
+  for ( QRadioButton *colorRadio : colorRadios )
+    colorRadio->setEnabled( enabled );
 }
 
 void QgsCompoundColorWidget::mActionShowInButtons_toggled( bool state )
 {
-  QgsUserColorScheme *scheme = dynamic_cast< QgsUserColorScheme * >( mSchemeList->scheme() );
+  QgsUserColorScheme *scheme = dynamic_cast<QgsUserColorScheme *>( mSchemeList->scheme() );
   if ( scheme )
   {
     scheme->setShowSchemeInMenu( state );
@@ -620,7 +646,7 @@ void QgsCompoundColorWidget::mActionShowInButtons_toggled( bool state )
 
 QScreen *QgsCompoundColorWidget::findScreenAt( QPoint pos )
 {
-  const QList< QScreen * > screens = QGuiApplication::screens();
+  const QList<QScreen *> screens = QGuiApplication::screens();
   for ( QScreen *screen : screens )
   {
     if ( screen->geometry().contains( pos ) )
@@ -641,21 +667,9 @@ void QgsCompoundColorWidget::saveSettings()
 
   QgsSettings settings;
 
-  //record active component
-  int activeRadio = 0;
-  if ( mHueRadio->isChecked() )
-    activeRadio = 0;
-  if ( mSaturationRadio->isChecked() )
-    activeRadio = 1;
-  if ( mValueRadio->isChecked() )
-    activeRadio = 2;
-  if ( mRedRadio->isChecked() )
-    activeRadio = 3;
-  if ( mGreenRadio->isChecked() )
-    activeRadio = 4;
-  if ( mBlueRadio->isChecked() )
-    activeRadio = 5;
-  settings.setValue( QStringLiteral( "Windows/ColorDialog/activeComponent" ), activeRadio );
+  // record active component
+  settings.setValue( QStringLiteral( "Windows/ColorDialog/activeComponent" ), mRgbGroup->checkedId() );
+  settings.setValue( QStringLiteral( "Windows/ColorDialog/activeCmykComponent" ), mCmykGroup->checkedId() );
 
   //record current scheme
   settings.setValue( QStringLiteral( "Windows/ColorDialog/activeScheme" ), mSchemeComboBox->currentIndex() );
@@ -707,6 +721,15 @@ void QgsCompoundColorWidget::stopPicking( QPoint eventPos, const bool takeSample
 }
 
 void QgsCompoundColorWidget::setColor( const QColor &color )
+{
+  const QColor::Spec colorSpec = color.spec() == QColor::Cmyk ? QColor::Cmyk : QColor::Rgb;
+  mColorModel->setCurrentIndex( mColorModel->findData( colorSpec ) );
+  mRGB->setVisible( colorSpec != QColor::Cmyk );
+  mCMYK->setVisible( colorSpec == QColor::Cmyk );
+  _setColor( color );
+}
+
+void QgsCompoundColorWidget::_setColor( const QColor &color )
 {
   if ( !color.isValid() )
   {
@@ -719,6 +742,12 @@ void QgsCompoundColorWidget::setColor( const QColor &color )
     //opacity disallowed, so don't permit transparent colors
     fixedColor.setAlpha( 255 );
   }
+
+  if ( mColorModel->currentIndex() && fixedColor.spec() != QColor::Cmyk )
+  {
+    fixedColor = fixedColor.toCmyk();
+  }
+
   const QList<QgsColorWidget *> colorWidgets = this->findChildren<QgsColorWidget *>();
   const auto constColorWidgets = colorWidgets;
   for ( QgsColorWidget *widget : constColorWidgets )
@@ -731,6 +760,8 @@ void QgsCompoundColorWidget::setColor( const QColor &color )
     widget->setColor( fixedColor );
     widget->blockSignals( false );
   }
+
+
   emit currentColorChanged( fixedColor );
 }
 
@@ -768,7 +799,7 @@ QColor QgsCompoundColorWidget::averageColor( const QImage &image ) const
   //scan through image and sum rgb components
   for ( int heightIndex = 0; heightIndex < image.height(); ++heightIndex )
   {
-    const QRgb *scanLine = reinterpret_cast< const QRgb * >( image.constScanLine( heightIndex ) );
+    const QRgb *scanLine = reinterpret_cast<const QRgb *>( image.constScanLine( heightIndex ) );
     for ( int widthIndex = 0; widthIndex < image.width(); ++widthIndex )
     {
       tmpRgb = scanLine[widthIndex];
@@ -791,18 +822,14 @@ QColor QgsCompoundColorWidget::sampleColor( QPoint point ) const
 {
   const int sampleRadius = mSpinBoxRadius->value() - 1;
   QScreen *screen = findScreenAt( point );
-  if ( ! screen )
+  if ( !screen )
   {
     return QColor();
   }
 
   const int x = point.x() - screen->geometry().left();
   const int y = point.y() - screen->geometry().top();
-  const QPixmap snappedPixmap = screen->grabWindow( 0,
-                                x - sampleRadius,
-                                y - sampleRadius,
-                                1 + sampleRadius * 2,
-                                1 + sampleRadius * 2 );
+  const QPixmap snappedPixmap = screen->grabWindow( 0, x - sampleRadius, y - sampleRadius, 1 + sampleRadius * 2, 1 + sampleRadius * 2 );
   const QImage snappedImage = snappedPixmap.toImage();
   //scan all pixels and take average color
   return averageColor( snappedImage );
@@ -850,58 +877,26 @@ void QgsCompoundColorWidget::keyPressEvent( QKeyEvent *e )
   stopPicking( QCursor::pos(), e->key() == Qt::Key_Space );
 }
 
-void QgsCompoundColorWidget::mHueRadio_toggled( bool checked )
+
+void QgsCompoundColorWidget::updateComponent()
 {
-  if ( checked )
+  const bool isCmyk = mColorModel->currentData().toInt() == QColor::Spec::Cmyk;
+  const auto radios = isCmyk ? mCmykRadios : mRgbRadios;
+  const QButtonGroup *group = isCmyk ? mCmykGroup : mRgbGroup;
+
+  const int id = group->checkedId();
+  if ( id >= 0 && id < radios.count() )
   {
-    mColorBox->setComponent( QgsColorWidget::Hue );
-    mVerticalRamp->setComponent( QgsColorWidget::Hue );
+    const QgsColorWidget::ColorComponent component = radios.at( group->checkedId() ).second;
+    mColorBox->setComponent( component );
+    mVerticalRamp->setComponent( component );
   }
 }
 
-void QgsCompoundColorWidget::mSaturationRadio_toggled( bool checked )
+void QgsCompoundColorWidget::onColorButtonGroupToggled( int, bool checked )
 {
   if ( checked )
-  {
-    mColorBox->setComponent( QgsColorWidget::Saturation );
-    mVerticalRamp->setComponent( QgsColorWidget::Saturation );
-  }
-}
-
-void QgsCompoundColorWidget::mValueRadio_toggled( bool checked )
-{
-  if ( checked )
-  {
-    mColorBox->setComponent( QgsColorWidget::Value );
-    mVerticalRamp->setComponent( QgsColorWidget::Value );
-  }
-}
-
-void QgsCompoundColorWidget::mRedRadio_toggled( bool checked )
-{
-  if ( checked )
-  {
-    mColorBox->setComponent( QgsColorWidget::Red );
-    mVerticalRamp->setComponent( QgsColorWidget::Red );
-  }
-}
-
-void QgsCompoundColorWidget::mGreenRadio_toggled( bool checked )
-{
-  if ( checked )
-  {
-    mColorBox->setComponent( QgsColorWidget::Green );
-    mVerticalRamp->setComponent( QgsColorWidget::Green );
-  }
-}
-
-void QgsCompoundColorWidget::mBlueRadio_toggled( bool checked )
-{
-  if ( checked )
-  {
-    mColorBox->setComponent( QgsColorWidget::Blue );
-    mVerticalRamp->setComponent( QgsColorWidget::Blue );
-  }
+    updateComponent();
 }
 
 void QgsCompoundColorWidget::mAddColorToSchemeButton_clicked()
@@ -919,7 +914,7 @@ void QgsCompoundColorWidget::updateActionsForCurrentScheme()
   mRemoveColorsFromSchemeButton->setEnabled( scheme->isEditable() );
 
   QgsUserColorScheme *userScheme = dynamic_cast<QgsUserColorScheme *>( scheme );
-  mActionRemovePalette->setEnabled( static_cast< bool >( userScheme ) );
+  mActionRemovePalette->setEnabled( static_cast<bool>( userScheme ) );
   if ( userScheme )
   {
     mActionShowInButtons->setEnabled( true );
