@@ -39,7 +39,6 @@ class GUI_EXPORT QgsScaleWidget : public QWidget
     Q_PROPERTY( bool minScale READ minScale WRITE setMinScale )
 
   public:
-
     /**
      * \brief QgsScaleWidget creates a combobox which lets the user select map scale from predefined list
      * and highlights nearest to current scale value
@@ -58,7 +57,7 @@ class GUI_EXPORT QgsScaleWidget : public QWidget
      * Returns whether a button to set the scale from map canvas is shown or not.
      * \see setShowCurrentScaleButton()
      */
-    bool showCurrentScaleButton() { return mShowCurrentScaleButton;}
+    bool showCurrentScaleButton() { return mShowCurrentScaleButton; }
 
     /**
      * Set the map \a canvas associated to the current button.
@@ -136,6 +135,16 @@ class GUI_EXPORT QgsScaleWidget : public QWidget
      */
     bool allowNull() const;
 
+    /**
+     * Sets the list of predefined \a scales to show in the widget. List elements
+     * are expected to be scale denominators, e.g. 1000.0 for a 1:1000 map.
+     *
+     * If \a scales is empty then the default user scale options will be used instead.
+     *
+     * \since QGIS 3.38
+    */
+    void setPredefinedScales( const QVector<double> &scales );
+
   public slots:
 
     /**
@@ -146,7 +155,7 @@ class GUI_EXPORT QgsScaleWidget : public QWidget
     void setScale( double scale );
 
     /**
-     * Sets the list of predefined \a scales to show in the combobox. List elements
+     * Sets the list of predefined \a scales to show in the widget. List elements
      * are expected to be valid scale strings, such as "1:1000000".
      */
     void updateScales( const QStringList &scales = QStringList() ) { mScaleComboBox->updateScales( scales ); }
