@@ -39,7 +39,6 @@ class QgsMapCanvas;
  * QgsMapUnitScale object.
  * \see QgsMapUnitScaleDialog
  * \see QgsUnitSelectionWidget
- * \since QGIS 3.0
 */
 class GUI_EXPORT QgsMapUnitScaleWidget : public QgsPanelWidget, private Ui::QgsMapUnitScaleWidgetBase
 {
@@ -47,7 +46,6 @@ class GUI_EXPORT QgsMapUnitScaleWidget : public QgsPanelWidget, private Ui::QgsM
     Q_PROPERTY( QgsMapUnitScale mapUnitScale READ mapUnitScale WRITE setMapUnitScale NOTIFY mapUnitScaleChanged )
 
   public:
-
     /**
      * Constructor for QgsMapUnitScaleWidget.
      * \param parent parent widget
@@ -92,9 +90,7 @@ class GUI_EXPORT QgsMapUnitScaleWidget : public QgsPanelWidget, private Ui::QgsM
     void settingsChanged();
 
   private:
-
     bool mBlockSignals = true;
-
 };
 
 /**
@@ -112,7 +108,6 @@ class GUI_EXPORT QgsMapUnitScaleDialog : public QDialog
     Q_PROPERTY( QgsMapUnitScale mapUnitScale READ getMapUnitScale WRITE setMapUnitScale )
 
   public:
-
     /**
      * Constructor for QgsMapUnitScaleDialog.
      * \param parent parent widget
@@ -138,7 +133,6 @@ class GUI_EXPORT QgsMapUnitScaleDialog : public QDialog
      * Sets the map canvas associated with the dialog. This allows the dialog to retrieve the current
      * map scale from the canvas.
      * \param canvas map canvas
-     * \since QGIS 2.12
      */
     void setMapCanvas( QgsMapCanvas *canvas );
 
@@ -148,17 +142,17 @@ class GUI_EXPORT QgsMapUnitScaleDialog : public QDialog
 
 
   private:
-
     QgsMapUnitScaleWidget *mWidget = nullptr;
-
 };
 
 /**
  * \class QgsUnitSelectionWidget
  * \ingroup gui
  * \brief A widget displaying a combobox allowing the user to choose between various display units,
- * such as millimeters or map unit. If the user chooses map units, a button appears allowing
- * adjustment of minimum and maximum scaling.
+ * such as millimeters or map units.
+ *
+ * If the user chooses map units, a button appears allowing adjustment of minimum and maximum scaling.
+ *
  * \see QgsMapUnitScaleWidget
  * \see QgsMapUnitScaleDialog
  */
@@ -167,7 +161,6 @@ class GUI_EXPORT QgsUnitSelectionWidget : public QWidget, private Ui::QgsUnitSel
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsUnitSelectionWidget.
      * \param parent parent widget
@@ -184,7 +177,6 @@ class GUI_EXPORT QgsUnitSelectionWidget : public QWidget, private Ui::QgsUnitSel
     /**
      * Sets the units which the user can choose from in the combobox. Clears any existing units.
      * \param units list of valid units
-     * \since QGIS 2.9
      */
     void setUnits( const QgsUnitTypes::RenderUnitList &units );
 
@@ -194,9 +186,8 @@ class GUI_EXPORT QgsUnitSelectionWidget : public QWidget, private Ui::QgsUnitSel
     /**
      * Returns the current predefined selected unit (if applicable).
      * \returns selected output unit, or QgsUnitTypes::RenderUnknownUnit if the widget was populated with custom unit types
-     * \since QGIS 2.9
      */
-    QgsUnitTypes::RenderUnit unit() const;
+    Qgis::RenderUnit unit() const;
 
     /**
      * Sets the selected unit index
@@ -209,7 +200,7 @@ class GUI_EXPORT QgsUnitSelectionWidget : public QWidget, private Ui::QgsUnitSel
      * Sets the selected unit
      * \param unit predefined unit to set as current
      */
-    void setUnit( QgsUnitTypes::RenderUnit unit );
+    void setUnit( Qgis::RenderUnit unit );
 
     //! Returns the map unit scale
     QgsMapUnitScale getMapUnitScale() const { return mMapUnitScale; }
@@ -221,7 +212,6 @@ class GUI_EXPORT QgsUnitSelectionWidget : public QWidget, private Ui::QgsUnitSel
      * Sets the map canvas associated with the widget. This allows the widget to retrieve the current
      * map scale from the canvas.
      * \param canvas map canvas
-     * \since QGIS 2.12
      */
     void setMapCanvas( QgsMapCanvas *canvas );
 
@@ -242,6 +232,10 @@ class GUI_EXPORT QgsUnitSelectionWidget : public QWidget, private Ui::QgsUnitSel
     void setShowMapScaleButton( bool show );
 
   signals:
+
+    /**
+     * Emitted when the selected unit is changed, or the definition of the map unit scale is changed.
+     */
     void changed();
 
   private slots:
@@ -254,7 +248,6 @@ class GUI_EXPORT QgsUnitSelectionWidget : public QWidget, private Ui::QgsUnitSel
     int mMapUnitIdx;
     QgsMapCanvas *mCanvas = nullptr;
     bool mShowMapScaleButton = true;
-
 };
 
 #endif // QGSUNITSELECTIONWIDGET_H
