@@ -21,7 +21,6 @@
 #include "ui_qgspointdisplacementrendererwidgetbase.h"
 #include "qgis_sip.h"
 #include "qgsrendererwidget.h"
-#include "qgsexpressioncontextgenerator.h"
 #include "qgis_gui.h"
 
 class QgsPointDisplacementRenderer;
@@ -30,7 +29,7 @@ class QgsPointDisplacementRenderer;
  * \ingroup gui
  * \class QgsPointDisplacementRendererWidget
  */
-class GUI_EXPORT QgsPointDisplacementRendererWidget: public QgsRendererWidget, public QgsExpressionContextGenerator, private Ui::QgsPointDisplacementRendererWidgetBase
+class GUI_EXPORT QgsPointDisplacementRendererWidget : public QgsRendererWidget, private Ui::QgsPointDisplacementRendererWidgetBase
 {
     Q_OBJECT
   public:
@@ -44,7 +43,7 @@ class GUI_EXPORT QgsPointDisplacementRendererWidget: public QgsRendererWidget, p
     QgsExpressionContext createExpressionContext() const override;
 
   private:
-    std::unique_ptr< QgsPointDisplacementRenderer > mRenderer;
+    std::unique_ptr<QgsPointDisplacementRenderer> mRenderer;
 
     void blockAllSignals( bool block );
     void setupBlankUi( const QString &layerName );
