@@ -17,6 +17,10 @@
 #include <QFileDialog>
 #include <QFileInfo>
 #include <QMessageBox>
+#include <QRegularExpression>
+#include <QRegularExpressionValidator>
+#include <QRegularExpressionMatch>
+
 #include "qgssettings.h"
 
 #include "qgis.h"
@@ -32,6 +36,7 @@
 #include "qgsgrassmodule.h"
 #include "qgsgrassmoduleinput.h"
 #include "qgsgrassmoduleparam.h"
+#include "moc_qgsgrassmoduleparam.cpp"
 #include "qgsgrassplugin.h"
 #include "qgsgrassprovider.h"
 
@@ -43,8 +48,7 @@ extern "C"
 #endif
 
 /********************** QgsGrassModuleParam *************************/
-QgsGrassModuleParam::QgsGrassModuleParam( QgsGrassModule *module, QString key,
-    QDomElement &qdesc, QDomElement &gdesc, QDomNode &gnode, bool direct )
+QgsGrassModuleParam::QgsGrassModuleParam( QgsGrassModule *module, QString key, QDomElement &qdesc, QDomElement &gdesc, QDomNode &gnode, bool direct )
   : mModule( module )
   , mKey( key )
   , mMultiple( false )
@@ -196,9 +200,7 @@ QList<QDomNode> QgsGrassModuleParam::nodesByType( QDomElement descDomElement, ST
 
 /***************** QgsGrassModuleGroupBoxItem *********************/
 
-QgsGrassModuleGroupBoxItem::QgsGrassModuleGroupBoxItem( QgsGrassModule *module, QString key,
-    QDomElement &qdesc, QDomElement &gdesc, QDomNode &gnode,
-    bool direct, QWidget *parent )
+QgsGrassModuleGroupBoxItem::QgsGrassModuleGroupBoxItem( QgsGrassModule *module, QString key, QDomElement &qdesc, QDomElement &gdesc, QDomNode &gnode, bool direct, QWidget *parent )
   : QGroupBox( parent )
   , QgsGrassModuleParam( module, key, qdesc, gdesc, gnode, direct )
 {
@@ -222,9 +224,7 @@ void QgsGrassModuleGroupBoxItem::adjustTitle()
 
 /***************** QgsGrassModuleMultiParam *********************/
 
-QgsGrassModuleMultiParam::QgsGrassModuleMultiParam( QgsGrassModule *module, QString key,
-    QDomElement &qdesc, QDomElement &gdesc, QDomNode &gnode,
-    bool direct, QWidget *parent )
+QgsGrassModuleMultiParam::QgsGrassModuleMultiParam( QgsGrassModule *module, QString key, QDomElement &qdesc, QDomElement &gdesc, QDomNode &gnode, bool direct, QWidget *parent )
   : QgsGrassModuleGroupBoxItem( module, key, qdesc, gdesc, gnode, direct, parent )
 {
   adjustTitle();
@@ -236,7 +236,6 @@ QgsGrassModuleMultiParam::QgsGrassModuleMultiParam( QgsGrassModule *module, QStr
   mParamsLayout = new QVBoxLayout();
 
   mLayout->insertLayout( -1, mParamsLayout );
-
 }
 
 void QgsGrassModuleMultiParam::showAddRemoveButtons()
@@ -259,9 +258,7 @@ void QgsGrassModuleMultiParam::showAddRemoveButtons()
 
 /********************** QgsGrassModuleOption *************************/
 
-QgsGrassModuleOption::QgsGrassModuleOption( QgsGrassModule *module, QString key,
-    QDomElement &qdesc, QDomElement &gdesc, QDomNode &gnode,
-    bool direct, QWidget *parent )
+QgsGrassModuleOption::QgsGrassModuleOption( QgsGrassModule *module, QString key, QDomElement &qdesc, QDomElement &gdesc, QDomNode &gnode, bool direct, QWidget *parent )
   : QgsGrassModuleMultiParam( module, key, qdesc, gdesc, gnode, direct, parent )
   , mControlType( NoControl )
   , mValueType( String )
@@ -334,11 +331,7 @@ QgsGrassModuleOption::QgsGrassModuleOption( QgsGrassModule *module, QString key,
       }
 
       // List of values to be excluded
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-      QStringList exclude = qdesc.attribute( QStringLiteral( "exclude" ) ).split( ',', QString::SkipEmptyParts );
-#else
       QStringList exclude = qdesc.attribute( QStringLiteral( "exclude" ) ).split( ',', Qt::SkipEmptyParts );
-#endif
 
       QDomNode valueNode = valuesElem.firstChild();
 
@@ -348,7 +341,6 @@ QgsGrassModuleOption::QgsGrassModuleOption( QgsGrassModule *module, QString key,
 
         if ( !valueElem.isNull() && valueElem.tagName() == QLatin1String( "value" ) )
         {
-
           QDomNode n = valueNode.namedItem( QStringLiteral( "name" ) );
           if ( !n.isNull() )
           {
@@ -502,7 +494,6 @@ QgsGrassModuleOption::QgsGrassModuleOption( QgsGrassModule *module, QString key,
 
 void QgsGrassModuleOption::addRow()
 {
-
   // TODO make the widget growing with new lines. HOW???!!!
   QLineEdit *lineEdit = new QLineEdit( this );
   mLineEdits << lineEdit;
@@ -534,7 +525,7 @@ void QgsGrassModuleOption::addRow()
   }
   else if ( mIsOutput )
   {
-    QRegExp rx;
+    QRegularExpression rx;
     if ( mOutputType == Vector )
     {
       rx.setPattern( QStringLiteral( "[A-Za-z_][A-Za-z0-9_]+" ) );
@@ -543,7 +534,7 @@ void QgsGrassModuleOption::addRow()
     {
       rx.setPattern( QStringLiteral( "[A-Za-z0-9_.]+" ) );
     }
-    mValidator = new QRegExpValidator( rx, this );
+    mValidator = new QRegularExpressionValidator( rx, this );
 
     lineEdit->setValidator( mValidator );
   }
@@ -566,7 +557,6 @@ void QgsGrassModuleOption::addRow()
 
 void QgsGrassModuleOption::removeRow()
 {
-
   if ( mLineEdits.size() < 2 )
   {
     return;
@@ -589,13 +579,12 @@ void QgsGrassModuleOption::browse( bool checked )
       fileName = fileName + ".tif";
     }
     mLineEdits.at( 0 )->setText( fileName );
-    settings.setValue( QStringLiteral( "GRASS/lastDirectOutputDir" ),  QFileInfo( fileName ).absolutePath() );
+    settings.setValue( QStringLiteral( "GRASS/lastDirectOutputDir" ), QFileInfo( fileName ).absolutePath() );
   }
 }
 
 QString QgsGrassModuleOption::outputExists()
 {
-
   if ( !mIsOutput )
     return QString();
 
@@ -670,22 +659,24 @@ bool QgsGrassModuleOption::checkVersion( const QString &version_min, const QStri
 
   bool minOk = true;
   bool maxOk = true;
-  QRegExp rxVersionMajor( "(\\d+)" );
-  QRegExp rxVersion( "(\\d+)\\.(\\d+)" );
+  const thread_local QRegularExpression rxVersionMajor( "^(\\d+)$" );
+  const thread_local QRegularExpression rxVersion( "^(\\d+)\\.(\\d+)$" );
   if ( !version_min.isEmpty() )
   {
-    if ( rxVersion.exactMatch( version_min ) )
+    const QRegularExpressionMatch versionMatch = rxVersion.match( version_min );
+    const QRegularExpressionMatch versionMajorMatch = rxVersionMajor.match( version_min );
+    if ( versionMatch.hasMatch() )
     {
-      int versionMajorMin = rxVersion.cap( 1 ).toInt();
-      int versionMinorMin = rxVersion.cap( 2 ).toInt();
+      int versionMajorMin = versionMatch.captured( 1 ).toInt();
+      int versionMinorMin = versionMatch.captured( 2 ).toInt();
       if ( QgsGrass::versionMajor() < versionMajorMin || ( QgsGrass::versionMajor() == versionMajorMin && QgsGrass::versionMinor() < versionMinorMin ) )
       {
         minOk = false;
       }
     }
-    else if ( rxVersionMajor.exactMatch( version_min ) )
+    else if ( versionMajorMatch.hasMatch() )
     {
-      int versionMajorMin = rxVersionMajor.cap( 1 ).toInt();
+      int versionMajorMin = versionMajorMatch.captured( 1 ).toInt();
       if ( QgsGrass::versionMajor() < versionMajorMin )
       {
         minOk = false;
@@ -699,18 +690,21 @@ bool QgsGrassModuleOption::checkVersion( const QString &version_min, const QStri
 
   if ( !version_max.isEmpty() )
   {
-    if ( rxVersion.exactMatch( version_max ) )
+    const QRegularExpressionMatch versionMatch = rxVersion.match( version_max );
+    const QRegularExpressionMatch versionMajorMatch = rxVersionMajor.match( version_max );
+
+    if ( versionMatch.hasMatch() )
     {
-      int versionMajorMax = rxVersion.cap( 1 ).toInt();
-      int versionMinorMax = rxVersion.cap( 2 ).toInt();
+      int versionMajorMax = versionMatch.captured( 1 ).toInt();
+      int versionMinorMax = versionMatch.captured( 2 ).toInt();
       if ( QgsGrass::versionMajor() > versionMajorMax || ( QgsGrass::versionMajor() == versionMajorMax && QgsGrass::versionMinor() > versionMinorMax ) )
       {
         maxOk = false;
       }
     }
-    else if ( rxVersionMajor.exactMatch( version_max ) )
+    else if ( versionMajorMatch.hasMatch() )
     {
-      int versionMajorMax = rxVersionMajor.cap( 1 ).toInt();
+      int versionMajorMax = versionMajorMatch.captured( 1 ).toInt();
       if ( QgsGrass::versionMajor() > versionMajorMax )
       {
         maxOk = false;
@@ -752,12 +746,9 @@ QString QgsGrassModuleOption::ready()
 }
 
 /***************** QgsGrassModuleFlag *********************/
-QgsGrassModuleFlag::QgsGrassModuleFlag( QgsGrassModule *module, QString key,
-                                        QDomElement &qdesc, QDomElement &gdesc, QDomNode &gnode,
-                                        bool direct, QWidget *parent )
+QgsGrassModuleFlag::QgsGrassModuleFlag( QgsGrassModule *module, QString key, QDomElement &qdesc, QDomElement &gdesc, QDomNode &gnode, bool direct, QWidget *parent )
   : QgsGrassModuleCheckBox( QString(), parent ), QgsGrassModuleParam( module, key, qdesc, gdesc, gnode, direct )
 {
-
   if ( mHidden )
     hide();
 
@@ -784,7 +775,8 @@ QStringList QgsGrassModuleFlag::options()
 
 QgsGrassModuleGdalInput::QgsGrassModuleGdalInput(
   QgsGrassModule *module, Type type, QString key, QDomElement &qdesc,
-  QDomElement &gdesc, QDomNode &gnode, bool direct, QWidget *parent )
+  QDomElement &gdesc, QDomNode &gnode, bool direct, QWidget *parent
+)
   : QgsGrassModuleGroupBoxItem( module, key, qdesc, gdesc, gnode, direct, parent )
   , mType( type )
 {
@@ -796,9 +788,8 @@ QgsGrassModuleGdalInput::QgsGrassModuleGdalInput(
 
   // Read "layeroption" is defined
   QString opt = qdesc.attribute( QStringLiteral( "layeroption" ) );
-  if ( ! opt.isNull() )
+  if ( !opt.isNull() )
   {
-
     QDomNode optNode = nodeByKey( gdesc, opt );
 
     if ( optNode.isNull() )
@@ -828,7 +819,7 @@ QgsGrassModuleGdalInput::QgsGrassModuleGdalInput(
 
   QVBoxLayout *l = new QVBoxLayout( this );
   mLayerComboBox = new QComboBox();
-  mLayerComboBox->setSizePolicy( QSizePolicy::Expanding, QSizePolicy:: Preferred );
+  mLayerComboBox->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Preferred );
   l->addWidget( mLayerComboBox );
 
   QLabel *lbl = new QLabel( tr( "Password" ) );
@@ -841,10 +832,8 @@ QgsGrassModuleGdalInput::QgsGrassModuleGdalInput(
 
   lbl->setBuddy( mLayerPassword );
 
-  connect( QgsProject::instance(), &QgsProject::layersAdded,
-           this, &QgsGrassModuleGdalInput::updateQgisLayers );
-  connect( QgsProject::instance(), &QgsProject::layersRemoved,
-           this, &QgsGrassModuleGdalInput::updateQgisLayers );
+  connect( QgsProject::instance(), &QgsProject::layersAdded, this, &QgsGrassModuleGdalInput::updateQgisLayers );
+  connect( QgsProject::instance(), &QgsProject::layersRemoved, this, &QgsGrassModuleGdalInput::updateQgisLayers );
 
   // Fill in QGIS layers
   updateQgisLayers();
@@ -852,7 +841,6 @@ QgsGrassModuleGdalInput::QgsGrassModuleGdalInput(
 
 void QgsGrassModuleGdalInput::updateQgisLayers()
 {
-
   QString current = mLayerComboBox->currentText();
   mLayerComboBox->clear();
   mUri.clear();
@@ -870,14 +858,13 @@ void QgsGrassModuleGdalInput::updateQgisLayers()
 
   for ( QgsMapLayer *layer : QgsProject::instance()->mapLayers().values() )
   {
-    if ( !layer ) continue;
+    if ( !layer )
+      continue;
 
     if ( mType == Ogr && layer->type() == Qgis::LayerType::Vector )
     {
       QgsVectorLayer *vector = qobject_cast<QgsVectorLayer *>( layer );
-      if ( !vector ||
-           ( vector->providerType() != QLatin1String( "ogr" ) && vector->providerType() != QLatin1String( "postgres" ) )
-         )
+      if ( !vector || ( vector->providerType() != QLatin1String( "ogr" ) && vector->providerType() != QLatin1String( "postgres" ) ) )
         continue;
 
       QgsDataProvider *provider = vector->dataProvider();
@@ -1007,7 +994,6 @@ QStringList QgsGrassModuleGdalInput::options()
 
 QString QgsGrassModuleGdalInput::ready()
 {
-
   QString error;
 
   QgsDebugMsgLevel( QString( "count = %1" ).arg( mLayerComboBox->count() ), 3 );
@@ -1024,8 +1010,7 @@ void QgsGrassModuleGdalInput::changed( int i )
 }
 
 /***************** QgsGrassModuleField *********************/
-QgsGrassModuleField::QgsGrassModuleField( QgsGrassModule *module, QString key,
-    QDomElement &qdesc, QDomElement &gdesc, QDomNode &gnode, bool direct, QWidget *parent )
+QgsGrassModuleField::QgsGrassModuleField( QgsGrassModule *module, QString key, QDomElement &qdesc, QDomElement &gdesc, QDomNode &gnode, bool direct, QWidget *parent )
   : QgsGrassModuleOption( module, key, qdesc, gdesc, gnode, direct, parent )
 {
   // Validator is disabled to also allow entering of expressions
@@ -1043,7 +1028,8 @@ QgsGrassModuleField::QgsGrassModuleField( QgsGrassModule *module, QString key,
 QgsGrassModuleVectorField::QgsGrassModuleVectorField(
   QgsGrassModule *module, QgsGrassModuleStandardOptions *options,
   QString key, QDomElement &qdesc,
-  QDomElement &gdesc, QDomNode &gnode, bool direct, QWidget *parent )
+  QDomElement &gdesc, QDomNode &gnode, bool direct, QWidget *parent
+)
   : QgsGrassModuleMultiParam( module, key, qdesc, gdesc, gnode, direct, parent )
   , mModuleStandardOptions( options )
 {
@@ -1095,7 +1081,6 @@ void QgsGrassModuleVectorField::addRow()
 
 void QgsGrassModuleVectorField::removeRow()
 {
-
   if ( mComboBoxList.size() < 2 )
   {
     return;
@@ -1106,13 +1091,12 @@ void QgsGrassModuleVectorField::removeRow()
 
 void QgsGrassModuleVectorField::updateFields()
 {
-
   for ( QComboBox *comboBox : mComboBoxList )
   {
     QString current = comboBox->currentText();
     comboBox->clear();
 
-    if ( mLayerInput == nullptr )
+    if ( !mLayerInput )
     {
       continue;
     }
@@ -1123,7 +1107,7 @@ void QgsGrassModuleVectorField::updateFields()
       if ( mType.contains( field.typeName() ) )
       {
         comboBox->addItem( field.name() );
-        QgsDebugMsgLevel( "current = " +  current + " field = " + field.name(), 3 );
+        QgsDebugMsgLevel( "current = " + current + " field = " + field.name(), 3 );
         if ( field.name() == current )
         {
           comboBox->setCurrentIndex( index );
@@ -1161,7 +1145,8 @@ QStringList QgsGrassModuleVectorField::options()
 QgsGrassModuleSelection::QgsGrassModuleSelection(
   QgsGrassModule *module, QgsGrassModuleStandardOptions *options,
   QString key, QDomElement &qdesc,
-  QDomElement &gdesc, QDomNode &gnode, bool direct, QWidget *parent )
+  QDomElement &gdesc, QDomNode &gnode, bool direct, QWidget *parent
+)
   : QgsGrassModuleGroupBoxItem( module, key, qdesc, gdesc, gnode, direct, parent )
   , mModuleStandardOptions( options )
 {
@@ -1205,7 +1190,6 @@ QgsGrassModuleSelection::QgsGrassModuleSelection(
 
 void QgsGrassModuleSelection::onLayerChanged()
 {
-
   if ( !mLayerInput )
   {
     return;
@@ -1262,7 +1246,7 @@ void QgsGrassModuleSelection::onLayerChanged()
     {
       if ( mLayerInput->currentLayer() )
       {
-        mModeComboBox->addItem( tr( "Add to canvas layer" ) + " " +  mLayerInput->currentMap() + " " + layerCode, AddLayer );
+        mModeComboBox->addItem( tr( "Add to canvas layer" ) + " " + mLayerInput->currentMap() + " " + layerCode, AddLayer );
         QgsGrassObject grassObject = mLayerInput->currentLayer()->grassObject();
         QString uri = grassObject.mapsetPath() + "/" + grassObject.name() + "/" + layerCode;
         QgsDebugMsgLevel( "uri = " + uri, 3 );
@@ -1397,7 +1381,8 @@ QStringList QgsGrassModuleSelection::options()
 QgsGrassModuleFile::QgsGrassModuleFile(
   QgsGrassModule *module,
   QString key, QDomElement &qdesc,
-  QDomElement &gdesc, QDomNode &gnode, bool direct, QWidget *parent )
+  QDomElement &gdesc, QDomNode &gnode, bool direct, QWidget *parent
+)
   : QgsGrassModuleGroupBoxItem( module, key, qdesc, gdesc, gnode, direct, parent )
   , mType( Old )
 {
@@ -1431,8 +1416,7 @@ QgsGrassModuleFile::QgsGrassModuleFile(
   l->addWidget( mLineEdit );
   l->addWidget( mBrowseButton );
 
-  connect( mBrowseButton, &QAbstractButton::clicked,
-           this, &QgsGrassModuleFile::browse );
+  connect( mBrowseButton, &QAbstractButton::clicked, this, &QgsGrassModuleFile::browse );
 }
 
 QStringList QgsGrassModuleFile::options()
@@ -1560,4 +1544,3 @@ void QgsGrassModuleCheckBox::adjustText()
     QWidget::setToolTip( tt );
   }
 }
-
