@@ -16,6 +16,7 @@
 
 #include "qgis.h"
 #include "qgsgrassregion.h"
+#include "moc_qgsgrassregion.cpp"
 #include "qgsgrass.h"
 
 #include "qgisinterface.h"
@@ -184,12 +185,9 @@ void QgsGrassRegionEdit::setSrcRegion( const QgsRectangle &rect )
   mSrcRectangle = rect;
 }
 
-QgsGrassRegion::QgsGrassRegion( QgisInterface *iface,
-                                QWidget *parent, Qt::WindowFlags f )
+QgsGrassRegion::QgsGrassRegion( QgisInterface *iface, QWidget *parent, Qt::WindowFlags f )
   : QWidget( parent, f )
   , QgsGrassRegionBase()
-  , mX( 0 )
-  , mY( 0 )
   , mUpdatingGui( false )
 {
   QgsDebugMsgLevel( "QgsGrassRegion()", 3 );
@@ -207,8 +205,8 @@ QgsGrassRegion::QgsGrassRegion( QgisInterface *iface,
   mUpdatingGui = false;
 
   // Set input validators
-  QDoubleValidator *dv = new QDoubleValidator( nullptr );
-  QIntValidator *iv = new QIntValidator( nullptr );
+  QDoubleValidator *dv = new QDoubleValidator( this );
+  QIntValidator *iv = new QIntValidator( this );
 
   mNorth->setValidator( dv );
   mSouth->setValidator( dv );
@@ -220,13 +218,13 @@ QgsGrassRegion::QgsGrassRegion( QgisInterface *iface,
   mCols->setValidator( iv );
 
   // Group radio buttons
-  mRadioGroup = new QButtonGroup();
+  mRadioGroup = new QButtonGroup( this );
   mRadioGroup->addButton( mResRadio );
   mRadioGroup->addButton( mRowsColsRadio );
   mResRadio->setChecked( true );
   radioChanged();
 
-  connect( mRadioGroup, static_cast<void ( QButtonGroup::* )( int )>( &QButtonGroup::buttonClicked ), this, &QgsGrassRegion::radioChanged );
+  connect( mRadioGroup, qOverload<QAbstractButton *>( &QButtonGroup::buttonClicked ), this, &QgsGrassRegion::radioChanged );
 
   // Connect entries
   connect( mNorth, &QLineEdit::editingFinished, this, &QgsGrassRegion::northChanged );
@@ -442,7 +440,6 @@ void QgsGrassRegion::adjust()
 
 void QgsGrassRegion::radioChanged()
 {
-
   bool res = !mRowsColsRadio->isChecked();
 
   mEWResLabel->setEnabled( res );
@@ -516,5 +513,3 @@ void QgsGrassRegion::buttonClicked( QAbstractButton *button )
   // Better to keep the tool selected until another tool is chosen?
   mCanvas->unsetMapTool( mRegionEdit );
 }
-
-
