@@ -34,7 +34,7 @@
 #include <getopt.h>
 #endif
 
-#ifdef Q_OS_MACX
+#ifdef Q_OS_MACOS
 #include <ApplicationServices/ApplicationServices.h>
 #if MAC_OS_X_VERSION_MAX_ALLOWED < 1050
 typedef SInt32 SRefCon;
@@ -49,9 +49,8 @@ typedef SInt32 SRefCon;
 #undef QgsDebugError
 #undef QgsDebugMsgLevel
 #define QgsDebugCall
-#define QgsDebugError(str)
-#define QgsDebugMsgLevel(str, level)
-
+#define QgsDebugError( str )
+#define QgsDebugMsgLevel( str, level )
 
 
 /////////////////////////////////////////////////////////////////
@@ -69,13 +68,13 @@ static QStringList sFileList;
 
 int main( int argc, char *argv[] )
 {
-#ifdef Q_OS_WIN  // Windows
+#ifdef Q_OS_WIN // Windows
 #ifdef _MSC_VER
   _set_fmode( _O_BINARY );
-#else //MinGW
+#else  //MinGW
   _fmode = _O_BINARY;
-#endif  // _MSC_VER
-#endif  // Q_OS_WIN
+#endif // _MSC_VER
+#endif // Q_OS_WIN
 
   // a shortcut -- let's see if we are being called without any arguments, or just the usage/version argument.
   // If so, let's skip the startup cost of a QCoreApplication/QgsApplication
@@ -106,7 +105,7 @@ int main( int argc, char *argv[] )
 
   if ( argc == 1 || hasHelpArgument )
   {
-    QgsProcessingExec::showUsage( QString( argv[ 0 ] ) );
+    QgsProcessingExec::showUsage( QString( argv[0] ) );
     return 0;
   }
   else if ( hasVersionArgument )
@@ -121,30 +120,37 @@ int main( int argc, char *argv[] )
   // It will use QString::fromLocal8Bit( argv ) under Unix and GetCommandLine() under Windows.
   QStringList args = QCoreApplication::arguments();
 
+  QgsProcessingExec::Flags flags;
+
   const int jsonIndex = args.indexOf( QLatin1String( "--json" ) );
-  bool useJson = false;
   if ( jsonIndex >= 0 )
   {
-    useJson = true;
+    flags |= QgsProcessingExec::Flag::UseJson;
     args.removeAt( jsonIndex );
   }
 
   const int verboseIndex = args.indexOf( QLatin1String( "--verbose" ) );
-  QgsProcessingContext::LogLevel logLevel = QgsProcessingContext::DefaultLevel;
+  Qgis::ProcessingLogLevel logLevel = Qgis::ProcessingLogLevel::DefaultLevel;
   if ( verboseIndex >= 0 )
   {
-    logLevel = QgsProcessingContext::Verbose;
+    logLevel = Qgis::ProcessingLogLevel::Verbose;
     args.removeAt( verboseIndex );
   }
 
   const int noPythonIndex = args.indexOf( QLatin1String( "--no-python" ) );
-  bool skipPython = false;
   if ( noPythonIndex >= 0 )
   {
-    skipPython = true;
+    flags |= QgsProcessingExec::Flag::SkipPython;
     args.removeAt( noPythonIndex );
   }
 
+  const int skipLoadingPluginsIndex = args.indexOf( QLatin1String( "--skip-loading-plugins" ) );
+  if ( skipLoadingPluginsIndex >= 0 )
+  {
+    flags |= QgsProcessingExec::Flag::SkipLoadingPlugins;
+    args.removeAt( skipLoadingPluginsIndex );
+  }
+
   const QString command = args.value( 1 );
   if ( args.size() == 1 || command == QLatin1String( "--help" ) || command == QLatin1String( "-h" ) )
   {
@@ -177,9 +183,8 @@ int main( int argc, char *argv[] )
 
   QgsProcessingExec exec;
   int res = 0;
-  QTimer::singleShot( 0, &app, [&exec, args, useJson, logLevel, skipPython, &res]
-  {
-    res = exec.run( args, useJson, logLevel, skipPython );
+  QTimer::singleShot( 0, &app, [&exec, args, logLevel, flags, &res] {
+    res = exec.run( args, logLevel, flags );
     QgsApplication::exitQgis();
     QCoreApplication::exit( res );
   } );
