@@ -83,7 +83,6 @@ QgsGpsExtended::QgsGpsExtended()
   , yMax( -std::numeric_limits<double>::max() )
   , number( std::numeric_limits<int>::max() )
 {
-
 }
 
 
@@ -97,8 +96,7 @@ void QgsGpsExtended::writeXml( QTextStream &stream )
 
 void QgsWaypoint::writeXml( QTextStream &stream )
 {
-  stream << "<wpt lat=\"" << QString::number( lat, 'f', OUTPUT_PRECISION ) <<
-         "\" lon=\"" << QString::number( lon, 'f', OUTPUT_PRECISION ) << "\">\n";
+  stream << "<wpt lat=\"" << QString::number( lat, 'f', OUTPUT_PRECISION ) << "\" lon=\"" << QString::number( lon, 'f', OUTPUT_PRECISION ) << "\">\n";
   QgsGpsPoint::writeXml( stream );
   stream << "</wpt>\n";
 }
@@ -128,10 +126,7 @@ void QgsTrack::writeXml( QTextStream &stream )
     stream << "<trkseg>\n";
     for ( int j = 0; j < segments.at( i ).points.size(); ++j )
     {
-      stream << "<trkpt lat=\"" <<
-             QString::number( segments.at( i ).points.at( j ).lat, 'f', OUTPUT_PRECISION ) <<
-             "\" lon=\"" << QString::number( segments.at( i ).points.at( j ).lon, 'f', OUTPUT_PRECISION ) <<
-             "\">\n";
+      stream << "<trkpt lat=\"" << QString::number( segments.at( i ).points.at( j ).lat, 'f', OUTPUT_PRECISION ) << "\" lon=\"" << QString::number( segments.at( i ).points.at( j ).lon, 'f', OUTPUT_PRECISION ) << "\">\n";
       segments[i].points[j].writeXml( stream );
       stream << "</trkpt>\n";
     }
@@ -232,8 +227,7 @@ QgsGpsData::TrackIterator QgsGpsData::tracksEnd()
 }
 
 
-QgsGpsData::WaypointIterator QgsGpsData::addWaypoint( double lat, double lon,
-    const QString &name, double ele )
+QgsGpsData::WaypointIterator QgsGpsData::addWaypoint( double lat, double lon, const QString &name, double ele )
 {
   QgsWaypoint wpt;
   wpt.lat = lat;
@@ -359,7 +353,7 @@ void QgsGpsData::removeTracks( const QgsFeatureIds &ids )
 
 void QgsGpsData::writeXml( QTextStream &stream )
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
   stream.setCodec( QTextCodec::codecForName( "UTF8" ) );
 #endif
   stream << "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
@@ -390,7 +384,7 @@ QgsGpsData *QgsGpsData::getData( const QString &fileName )
       return nullptr;
     }
     QgsGpsData *data = new QgsGpsData;
-    QgsDebugMsg( "Loading file " + fileName );
+    QgsDebugMsgLevel( "Loading file " + fileName, 2 );
     QgsGPXHandler handler( *data );
     bool failed = false;
 
@@ -410,13 +404,13 @@ QgsGpsData *QgsGpsData::getData( const QString &fileName )
       if ( !XML_Parse( p, buffer, readBytes, atEnd ) )
       {
         QgsLogger::warning( QObject::tr( "Parse error at line %1 : %2" )
-                            .arg( XML_GetCurrentLineNumber( p ) )
-                            .arg( XML_ErrorString( XML_GetErrorCode( p ) ) ) );
+                              .arg( XML_GetCurrentLineNumber( p ) )
+                              .arg( XML_ErrorString( XML_GetErrorCode( p ) ) ) );
         failed = true;
         break;
       }
     }
-    delete [] buffer;
+    delete[] buffer;
     XML_ParserFree( p );
     if ( failed )
       return nullptr;
@@ -427,13 +421,13 @@ QgsGpsData *QgsGpsData::getData( const QString &fileName )
   }
   else
   {
-    QgsDebugMsg( fileName + " is already loaded" );
+    QgsDebugError( fileName + " is already loaded" );
   }
 
   // return a pointer and increase the reference count for that file name
   const DataMap::iterator iter = sDataObjects.find( fileName );
   ++( iter.value().second );
-  return ( QgsGpsData * )( iter.value().first );
+  return ( QgsGpsData * ) ( iter.value().first );
 }
 
 
@@ -446,10 +440,10 @@ void QgsGpsData::releaseData( const QString &fileName )
   const DataMap::iterator iter = sDataObjects.find( fileName );
   if ( iter != sDataObjects.end() )
   {
-    QgsDebugMsg( "unrefing " + fileName );
+    QgsDebugMsgLevel( "unrefing " + fileName, 2 );
     if ( --( iter.value().second ) == 0 )
     {
-      QgsDebugMsg( "No one's using " + fileName + ", I'll erase it" );
+      QgsDebugMsgLevel( "No one's using " + fileName + ", I'll erase it", 2 );
       delete iter.value().first;
       sDataObjects.erase( iter );
     }
@@ -459,7 +453,6 @@ void QgsGpsData::releaseData( const QString &fileName )
 
 bool QgsGPXHandler::startElement( const XML_Char *qName, const XML_Char **attr )
 {
-
   if ( !std::strcmp( qName, "gpx" ) )
   {
     parseModes.push( ParsingDocument );
@@ -496,9 +489,7 @@ bool QgsGPXHandler::startElement( const XML_Char *qName, const XML_Char **attr )
   // common properties
   else if ( !std::strcmp( qName, "name" ) )
   {
-    if ( parseModes.top() == ParsingWaypoint ||
-         parseModes.top() == ParsingRoute ||
-         parseModes.top() == ParsingTrack )
+    if ( parseModes.top() == ParsingWaypoint || parseModes.top() == ParsingRoute || parseModes.top() == ParsingTrack )
     {
       mString = &mObj->name;
       mCharBuffer.clear();
@@ -509,9 +500,7 @@ bool QgsGPXHandler::startElement( const XML_Char *qName, const XML_Char **attr )
   }
   else if ( !std::strcmp( qName, "cmt" ) )
   {
-    if ( parseModes.top() == ParsingWaypoint ||
-         parseModes.top() == ParsingRoute ||
-         parseModes.top() == ParsingTrack )
+    if ( parseModes.top() == ParsingWaypoint || parseModes.top() == ParsingRoute || parseModes.top() == ParsingTrack )
     {
       mString = &mObj->cmt;
       mCharBuffer.clear();
@@ -522,9 +511,7 @@ bool QgsGPXHandler::startElement( const XML_Char *qName, const XML_Char **attr )
   }
   else if ( !std::strcmp( qName, "desc" ) )
   {
-    if ( parseModes.top() == ParsingWaypoint ||
-         parseModes.top() == ParsingRoute ||
-         parseModes.top() == ParsingTrack )
+    if ( parseModes.top() == ParsingWaypoint || parseModes.top() == ParsingRoute || parseModes.top() == ParsingTrack )
     {
       mString = &mObj->desc;
       mCharBuffer.clear();
@@ -535,9 +522,7 @@ bool QgsGPXHandler::startElement( const XML_Char *qName, const XML_Char **attr )
   }
   else if ( !std::strcmp( qName, "src" ) )
   {
-    if ( parseModes.top() == ParsingWaypoint ||
-         parseModes.top() == ParsingRoute ||
-         parseModes.top() == ParsingTrack )
+    if ( parseModes.top() == ParsingWaypoint || parseModes.top() == ParsingRoute || parseModes.top() == ParsingTrack )
     {
       mString = &mObj->src;
       mCharBuffer.clear();
@@ -548,9 +533,7 @@ bool QgsGPXHandler::startElement( const XML_Char *qName, const XML_Char **attr )
   }
   else if ( !std::strcmp( qName, "url" ) )
   {
-    if ( parseModes.top() == ParsingWaypoint ||
-         parseModes.top() == ParsingRoute ||
-         parseModes.top() == ParsingTrack )
+    if ( parseModes.top() == ParsingWaypoint || parseModes.top() == ParsingRoute || parseModes.top() == ParsingTrack )
     {
       mString = &mObj->url;
       mCharBuffer.clear();
@@ -561,9 +544,7 @@ bool QgsGPXHandler::startElement( const XML_Char *qName, const XML_Char **attr )
   }
   else if ( !std::strcmp( qName, "urlname" ) )
   {
-    if ( parseModes.top() == ParsingWaypoint ||
-         parseModes.top() == ParsingRoute ||
-         parseModes.top() == ParsingTrack )
+    if ( parseModes.top() == ParsingWaypoint || parseModes.top() == ParsingRoute || parseModes.top() == ParsingTrack )
     {
       mString = &mObj->urlname;
       mCharBuffer.clear();
@@ -585,6 +566,17 @@ bool QgsGPXHandler::startElement( const XML_Char *qName, const XML_Char **attr )
     else
       parseModes.push( ParsingUnknown );
   }
+  else if ( !std::strcmp( qName, "time" ) )
+  {
+    if ( parseModes.top() == ParsingWaypoint )
+    {
+      mDateTime = &mWpt.time;
+      mCharBuffer.clear();
+      parseModes.push( ParsingDateTime );
+    }
+    else
+      parseModes.push( ParsingUnknown );
+  }
   else if ( !std::strcmp( qName, "sym" ) )
   {
     if ( parseModes.top() == ParsingWaypoint )
@@ -734,8 +726,12 @@ bool QgsGPXHandler::endElement( const std::string &qName )
     *mString = mCharBuffer;
     mCharBuffer.clear();
   }
+  else if ( parseModes.top() == ParsingDateTime )
+  {
+    *mDateTime = QDateTime::fromString( mCharBuffer, Qt::ISODateWithMs );
+    mCharBuffer.clear();
+  }
   parseModes.pop();
 
   return true;
 }
-
