@@ -62,7 +62,8 @@ class QgsHanaFeatureIterator : public QgsAbstractFeatureIteratorFromSource<QgsHa
     QgsHanaFeatureIterator(
       QgsHanaFeatureSource *source,
       bool ownSource,
-      const QgsFeatureRequest &request );
+      const QgsFeatureRequest &request
+    );
 
     ~QgsHanaFeatureIterator() override;
 
@@ -77,7 +78,7 @@ class QgsHanaFeatureIterator : public QgsAbstractFeatureIteratorFromSource<QgsHa
     bool prepareOrderBy( const QList<QgsFeatureRequest::OrderByClause> &orderBys ) override;
 
     QString buildSqlQuery( const QgsFeatureRequest &request );
-    QVariantList buildSqlQueryParameters( ) const;
+    QVariantList buildSqlQueryParameters() const;
     QString getBBOXFilter() const;
     QgsRectangle getFilterRect() const;
 
@@ -89,7 +90,7 @@ class QgsHanaFeatureIterator : public QgsAbstractFeatureIteratorFromSource<QgsHa
     QVariantList mSqlQueryParams;
     QgsRectangle mFilterRect;
     QgsGeometry mDistanceWithinGeom;
-    std::unique_ptr< QgsGeometryEngine > mDistanceWithinEngine;
+    std::unique_ptr<QgsGeometryEngine> mDistanceWithinEngine;
     QgsAttributeList mAttributesToFetch;
     QgsCoordinateTransform mTransform;
     bool mHasAttributes = false;
