@@ -19,6 +19,7 @@
 #include "qgshanadriver.h"
 #include "qgshanaconnection.h"
 #include "qgshananewconnection.h"
+#include "moc_qgshananewconnection.cpp"
 #include "qgshanasettings.h"
 #include "qgssettings.h"
 
@@ -36,12 +37,13 @@ namespace
   {
     return ( input.isEmpty() || QString( input ).replace( ' ', QString() ).isEmpty() );
   }
-}
+} // namespace
 
 QgsHanaNewConnection::QgsHanaNewConnection(
   QWidget *parent,
   const QString &connName,
-  Qt::WindowFlags fl )
+  Qt::WindowFlags fl
+)
   : QDialog( parent, fl )
   , mOriginalConnName( connName )
 {
@@ -108,8 +110,7 @@ void QgsHanaNewConnection::accept()
 {
   if ( isStringEmpty( txtName->text() ) )
   {
-    QMessageBox::warning( this,
-                          tr( "Save Connection" ), tr( "Connection name cannot be empty." ), QMessageBox::Ok );
+    QMessageBox::warning( this, tr( "Save Connection" ), tr( "Connection name cannot be empty." ), QMessageBox::Ok );
     return;
   }
 
@@ -118,15 +119,13 @@ void QgsHanaNewConnection::accept()
     case QgsHanaConnectionType::HostPort:
       if ( isStringEmpty( txtDriver->text() ) )
       {
-        QMessageBox::warning( this,
-                              tr( "Save Connection" ), tr( "Driver field cannot be empty." ), QMessageBox::Ok );
+        QMessageBox::warning( this, tr( "Save Connection" ), tr( "Driver field cannot be empty." ), QMessageBox::Ok );
         return;
       }
 
       if ( isStringEmpty( txtHost->text() ) )
       {
-        QMessageBox::warning( this,
-                              tr( "Save Connection" ), tr( "Host field cannot be empty." ), QMessageBox::Ok );
+        QMessageBox::warning( this, tr( "Save Connection" ), tr( "Host field cannot be empty." ), QMessageBox::Ok );
         return;
       }
 
@@ -134,8 +133,7 @@ void QgsHanaNewConnection::accept()
       {
         if ( isStringEmpty( txtTenantDatabaseName->text() ) )
         {
-          QMessageBox::warning( this,
-                                tr( "Save Connection" ), tr( "Tenant database name cannot be empty." ), QMessageBox::Ok );
+          QMessageBox::warning( this, tr( "Save Connection" ), tr( "Tenant database name cannot be empty." ), QMessageBox::Ok );
           return;
         }
       }
@@ -143,8 +141,7 @@ void QgsHanaNewConnection::accept()
     case QgsHanaConnectionType::Dsn:
       if ( cmbDsn->count() == 0 )
       {
-        QMessageBox::warning( this,
-                              tr( "Save Connection" ), tr( "DSN field cannot be empty." ), QMessageBox::Ok );
+        QMessageBox::warning( this, tr( "Save Connection" ), tr( "DSN field cannot be empty." ), QMessageBox::Ok );
         return;
       }
 
@@ -155,24 +152,20 @@ void QgsHanaNewConnection::accept()
   QgsHanaSettings::setSelectedConnection( connName );
   const bool hasAuthConfigID = !mAuthSettings->configId().isEmpty();
 
-  if ( !hasAuthConfigID && mAuthSettings->storePasswordIsChecked() &&
-       QMessageBox::question( this,
-                              tr( "Saving Passwords" ),
-                              tr( "WARNING: You have opted to save your password. It will be stored in unsecured "
-                                  "plain text in your project files and in your home directory (Unix-like OS) or user profile (Windows). "
-                                  "If you want to avoid this, press Cancel and either:\n\na) Don't save a password in the connection "
-                                  "settings — it will be requested interactively when needed;\nb) Use the Configuration tab to add your "
-                                  "credentials in an HTTP Basic Authentication method and store them in an encrypted database." ),
-                              QMessageBox::Ok | QMessageBox::Cancel ) == QMessageBox::Cancel )
+  if ( !hasAuthConfigID && mAuthSettings->storePasswordIsChecked() && QMessageBox::question( this, tr( "Saving Passwords" ), tr( "WARNING: You have opted to save your password. It will be stored in unsecured "
+                                                                                                                                 "plain text in your project files and in your home directory (Unix-like OS) or user profile (Windows). "
+                                                                                                                                 "If you want to avoid this, press Cancel and either:\n\na) Don't save a password in the connection "
+                                                                                                                                 "settings — it will be requested interactively when needed;\nb) Use the Configuration tab to add your "
+                                                                                                                                 "credentials in an HTTP Basic Authentication method and store them in an encrypted database." ),
+                                                                                             QMessageBox::Ok | QMessageBox::Cancel )
+                                                                        == QMessageBox::Cancel )
   {
     return;
   }
 
   QgsHanaSettings settings( connName, true );
   // warn if entry was renamed to an existing connection
-  if ( ( !mOriginalConnName.isNull() && mOriginalConnName.compare( connName, Qt::CaseInsensitive ) != 0 ) &&
-       QMessageBox::question( this, tr( "Save Connection" ), tr( "Should the existing connection %1 be overwritten?" ).arg( connName ),
-                              QMessageBox::Ok | QMessageBox::Cancel ) == QMessageBox::Cancel )
+  if ( ( !mOriginalConnName.isNull() && mOriginalConnName.compare( connName, Qt::CaseInsensitive ) != 0 ) && QMessageBox::question( this, tr( "Save Connection" ), tr( "Should the existing connection %1 be overwritten?" ).arg( connName ), QMessageBox::Ok | QMessageBox::Cancel ) == QMessageBox::Cancel )
   {
     return;
   }
@@ -183,9 +176,9 @@ void QgsHanaNewConnection::accept()
 
   readSettingsFromControls( settings );
   if ( !mAuthSettings->storeUsernameIsChecked() )
-    settings.setUserName( QString( ) );
+    settings.setUserName( QString() );
   if ( !( mAuthSettings->storePasswordIsChecked() && !hasAuthConfigID ) )
-    settings.setPassword( QString( ) );
+    settings.setPassword( QString() );
   settings.setSaveUserName( mAuthSettings->storeUsernameIsChecked() );
   settings.setSavePassword( mAuthSettings->storePasswordIsChecked() && !hasAuthConfigID );
 
@@ -298,6 +291,7 @@ void QgsHanaNewConnection::readSettingsFromControls( QgsHanaSettings &settings )
   settings.setSavePassword( mAuthSettings->storePasswordIsChecked() );
   settings.setUserTablesOnly( chkUserTablesOnly->isChecked() );
   settings.setAllowGeometrylessTables( chkAllowGeometrylessTables->isChecked() );
+  settings.setUseEstimatedMetadata( chkUseEstimatedMetadata->isChecked() );
   settings.setEnableSsl( chkEnableSSL->isChecked() );
   settings.setSslCryptoProvider( cbxCryptoProvider->currentData().toString() );
   settings.setSslKeyStore( txtKeyStore->text() );
@@ -351,6 +345,7 @@ void QgsHanaNewConnection::updateControlsFromSettings( const QgsHanaSettings &se
   txtSchema->setText( settings.schema() );
   chkUserTablesOnly->setChecked( settings.userTablesOnly() );
   chkAllowGeometrylessTables->setChecked( settings.allowGeometrylessTables() );
+  chkUseEstimatedMetadata->setChecked( settings.useEstimatedMetadata() );
 
   if ( settings.saveUserName() )
   {
@@ -393,8 +388,7 @@ void QgsHanaNewConnection::resizeEvent( QResizeEvent * )
 
 void QgsHanaNewConnection::resizeWidgets()
 {
-  auto resizeLayout = []( QLayout * layout )
-  {
+  auto resizeLayout = []( QLayout *layout ) {
     QWidget *widget = layout->parentWidget();
     widget->adjustSize();
     widget->resize( widget->parentWidget()->width(), widget->height() );
@@ -423,8 +417,7 @@ void QgsHanaNewConnection::testConnection()
     case QgsHanaConnectionType::HostPort:
       if ( txtHost->text().isEmpty() )
         warningMsg = tr( "Host name has not been specified." );
-      else if ( rbtnMultipleContainers->isChecked() && rbtnTenantDatabase->isChecked() &&
-                txtTenantDatabaseName->text().isEmpty() )
+      else if ( rbtnMultipleContainers->isChecked() && rbtnTenantDatabase->isChecked() && txtTenantDatabaseName->text().isEmpty() )
         warningMsg = tr( "Database has not been specified." );
       else if ( txtIdentifier->text().isEmpty() )
         warningMsg = tr( "Identifier has not been specified." );
@@ -437,7 +430,7 @@ void QgsHanaNewConnection::testConnection()
         {
           if ( !QgsHanaDriver::isInstalled( driver ) )
           {
-#if defined(Q_OS_WIN)
+#if defined( Q_OS_WIN )
             warningMsg = tr( "Driver with name '%1' is not installed." ).arg( driver );
 #else
             if ( !QgsHanaDriver::isValidPath( driver ) )
@@ -495,7 +488,7 @@ QString QgsHanaNewConnection::getDatabaseName() const
       return QStringLiteral( "SYSTEMDB" );
   }
   else
-    return QString( );
+    return QString();
 }
 
 void QgsHanaNewConnection::showHelp()
