@@ -38,7 +38,6 @@ class QgsMdalProvider : public QgsMeshDataProvider
     Q_OBJECT
 
   public:
-
     static const QString MDAL_PROVIDER_KEY;
     static const QString MDAL_PROVIDER_DESCRIPTION;
 
@@ -48,7 +47,7 @@ class QgsMdalProvider : public QgsMeshDataProvider
      * \param uri file name
      * \param options generic provider options
      */
-    QgsMdalProvider( const QString &uri, const QgsDataProvider::ProviderOptions &providerOptions, QgsDataProvider::ReadFlags flags = QgsDataProvider::ReadFlags() );
+    QgsMdalProvider( const QString &uri, const QgsDataProvider::ProviderOptions &providerOptions, Qgis::DataProviderReadFlags flags = Qgis::DataProviderReadFlags() );
     ~QgsMdalProvider() override;
 
     bool isValid() const override;
@@ -66,10 +65,10 @@ class QgsMdalProvider : public QgsMeshDataProvider
     QStringList extraDatasets() const override;
 
     int datasetGroupCount() const override;
-    int datasetCount( int groupIndex ) const override;
+    int datasetCount( int groupIndex ) const override final;
 
-    QgsMeshDatasetGroupMetadata datasetGroupMetadata( int groupIndex ) const override;
-    QgsMeshDatasetMetadata datasetMetadata( QgsMeshDatasetIndex index ) const override;
+    QgsMeshDatasetGroupMetadata datasetGroupMetadata( int groupIndex ) const override final;
+    QgsMeshDatasetMetadata datasetMetadata( QgsMeshDatasetIndex index ) const override final;
     QgsMeshDatasetValue datasetValue( QgsMeshDatasetIndex index, int valueIndex ) const override;
     QgsMeshDataBlock datasetValues( QgsMeshDatasetIndex index, int valueIndex, int count ) const override;
     QgsMesh3DDataBlock dataset3dValues( QgsMeshDatasetIndex index, int faceIndex, int count ) const override;
@@ -81,19 +80,9 @@ class QgsMdalProvider : public QgsMeshDataProvider
 
     QgsMeshDriverMetadata driverMetadata() const override;
 
-    bool persistDatasetGroup( const QString &outputFilePath,
-                              const QString &outputDriver,
-                              const QgsMeshDatasetGroupMetadata &meta,
-                              const QVector<QgsMeshDataBlock> &datasetValues,
-                              const QVector<QgsMeshDataBlock> &datasetActive,
-                              const QVector<double> &times
-                            ) override;
+    bool persistDatasetGroup( const QString &outputFilePath, const QString &outputDriver, const QgsMeshDatasetGroupMetadata &meta, const QVector<QgsMeshDataBlock> &datasetValues, const QVector<QgsMeshDataBlock> &datasetActive, const QVector<double> &times ) override;
 
-    bool persistDatasetGroup( const QString &outputFilePath,
-                              const QString &outputDriver,
-                              QgsMeshDatasetSourceInterface *source,
-                              int datasetGroupIndex
-                            ) override;
+    bool persistDatasetGroup( const QString &outputFilePath, const QString &outputDriver, QgsMeshDatasetSourceInterface *source, int datasetGroupIndex ) override;
 
     bool saveMeshFrame( const QgsMesh &mesh ) override;
 
@@ -122,9 +111,9 @@ class QgsMdalProvider : public QgsMeshDataProvider
     static void fileMeshExtensions( QStringList &fileMeshExtensions, QStringList &fileMeshDatasetExtensions );
 
   private:
-    QVector<QgsMeshVertex> vertices( ) const;
-    QVector<QgsMeshEdge> edges( ) const;
-    QVector<QgsMeshFace> faces( ) const;
+    QVector<QgsMeshVertex> vertices() const;
+    QVector<QgsMeshEdge> edges() const;
+    QVector<QgsMeshFace> faces() const;
     void loadData();
     void addGroupToTemporalCapabilities( int indexGroup );
     MDAL_MeshH mMeshH = nullptr;
@@ -132,6 +121,7 @@ class QgsMdalProvider : public QgsMeshDataProvider
     QgsCoordinateReferenceSystem mCrs;
     QStringList mSubLayersUris;
     QString mDriverName;
+    QMap<QString, QString> mMeshMetadata;
 
     /**
      * Closes and reloads dataset
@@ -139,7 +129,7 @@ class QgsMdalProvider : public QgsMeshDataProvider
     void reloadProviderData() override;
 };
 
-class QgsMdalProviderMetadata: public QgsProviderMetadata
+class QgsMdalProviderMetadata : public QgsProviderMetadata
 {
     Q_OBJECT
   public:
@@ -147,22 +137,17 @@ class QgsMdalProviderMetadata: public QgsProviderMetadata
     QIcon icon() const override;
     QString filters( Qgis::FileFilterType type ) override;
     QList<QgsMeshDriverMetadata> meshDriversMetadata() override;
-    QgsMdalProvider *createProvider( const QString &uri, const QgsDataProvider::ProviderOptions &options, QgsDataProvider::ReadFlags flags = QgsDataProvider::ReadFlags() ) override;
-    bool createMeshData( const QgsMesh &mesh,
-                         const QString &fileName,
-                         const QString &driverName,
-                         const QgsCoordinateReferenceSystem &crs ) const override;
-    bool createMeshData( const QgsMesh &mesh,
-                         const QString &uri,
-                         const QgsCoordinateReferenceSystem &crs ) const override;
+    QgsMdalProvider *createProvider( const QString &uri, const QgsDataProvider::ProviderOptions &options, Qgis::DataProviderReadFlags flags = Qgis::DataProviderReadFlags() ) override;
+    bool createMeshData( const QgsMesh &mesh, const QString &fileName, const QString &driverName, const QgsCoordinateReferenceSystem &crs, const QMap<QString, QString> &metadata = QMap<QString, QString>() ) const override;
+    bool createMeshData( const QgsMesh &mesh, const QString &uri, const QgsCoordinateReferenceSystem &crs, const QMap<QString, QString> &metadata = QMap<QString, QString>() ) const override;
     QVariantMap decodeUri( const QString &uri ) const override;
     QString encodeUri( const QVariantMap &parts ) const override;
     QString absoluteToRelativeUri( const QString &uri, const QgsReadWriteContext &context ) const override;
     QString relativeToAbsoluteUri( const QString &uri, const QgsReadWriteContext &context ) const override;
     ProviderCapabilities providerCapabilities() const override;
     QgsProviderMetadata::ProviderMetadataCapabilities capabilities() const override;
-    QList< QgsProviderSublayerDetails > querySublayers( const QString &uri, Qgis::SublayerQueryFlags flags = Qgis::SublayerQueryFlags(), QgsFeedback *feedback = nullptr ) const override;
-    QList< Qgis::LayerType > supportedLayerTypes() const override;
+    QList<QgsProviderSublayerDetails> querySublayers( const QString &uri, Qgis::SublayerQueryFlags flags = Qgis::SublayerQueryFlags(), QgsFeedback *feedback = nullptr ) const override;
+    QList<Qgis::LayerType> supportedLayerTypes() const override;
 };
 
 #endif //QGSMDALPROVIDER_H
