@@ -17,12 +17,14 @@
 
 #include <QMainWindow>
 
-#include "qgsdataitem.h"
+#include "qgsconnectionsitem.h"
+#include "qgsdatacollectionitem.h"
 #include "qgsdataitemprovider.h"
+#include "qgsdatabaseschemaitem.h"
+#include "qgslayeritem.h"
 
 #include "qgspostgresconn.h"
 #include "qgsmimedatautils.h"
-#include "qgsvectorlayerexporter.h"
 #include "qgswkbtypes.h"
 
 class QgsPGRootItem;
@@ -30,7 +32,7 @@ class QgsPGConnectionItem;
 class QgsPGSchemaItem;
 class QgsPGLayerItem;
 
-class QgsPGRootItem : public QgsDataCollectionItem
+class QgsPGRootItem : public QgsConnectionsRootItem
 {
     Q_OBJECT
   public:
@@ -40,16 +42,8 @@ class QgsPGRootItem : public QgsDataCollectionItem
 
     QVariant sortKey() const override { return 3; }
 
-#ifdef HAVE_GUI
-    QWidget *paramWidget() override;
-#endif
-
-    static QMainWindow *sMainWindow;
-
   public slots:
-#ifdef HAVE_GUI
     void onConnectionsChanged();
-#endif
 };
 
 class QgsPGConnectionItem : public QgsDataCollectionItem
@@ -61,6 +55,7 @@ class QgsPGConnectionItem : public QgsDataCollectionItem
     QVector<QgsDataItem *> createChildren() override;
     bool equal( const QgsDataItem *other ) override;
 
+    using QgsDataCollectionItem::handleDrop;
     bool handleDrop( const QMimeData *data, const QString &toSchema );
 
   signals:
@@ -70,10 +65,9 @@ class QgsPGConnectionItem : public QgsDataCollectionItem
 
     // refresh specified schema or all schemas if schema name is empty
     void refreshSchema( const QString &schema );
-
 };
 
-class QgsPGSchemaItem : public QgsDataCollectionItem
+class QgsPGSchemaItem : public QgsDatabaseSchemaItem
 {
     Q_OBJECT
   public:
@@ -87,6 +81,10 @@ class QgsPGSchemaItem : public QgsDataCollectionItem
     QgsPGLayerItem *createLayer( QgsPostgresLayerProperty layerProperty );
 
     QString mConnectionName;
+
+    // QgsDataItem interface
+  public:
+    bool layerCollection() const override;
 };
 
 class QgsPGLayerItem : public QgsLayerItem
@@ -94,7 +92,7 @@ class QgsPGLayerItem : public QgsLayerItem
     Q_OBJECT
 
   public:
-    QgsPGLayerItem( QgsDataItem *parent, const QString &name, const QString &path, QgsLayerItem::LayerType layerType, const QgsPostgresLayerProperty &layerProperties );
+    QgsPGLayerItem( QgsDataItem *parent, const QString &name, const QString &path, Qgis::BrowserLayerType layerType, const QgsPostgresLayerProperty &layerProperties );
 
     QString createUri();
 
@@ -102,17 +100,22 @@ class QgsPGLayerItem : public QgsLayerItem
 
     const QgsPostgresLayerProperty &layerInfo() const { return mLayerProperty; }
 
+    QVector<QgsDataItem *> createChildren() override;
+
   private:
     QgsPostgresLayerProperty mLayerProperty;
 };
 
+
 //! Provider for Postgres data item
 class QgsPostgresDataItemProvider : public QgsDataItemProvider
 {
   public:
     QString name() override;
 
-    int capabilities() const override;
+    QString dataProviderKey() const override;
+
+    Qgis::DataItemProviderCapabilities capabilities() const override;
 
     QgsDataItem *createDataItem( const QString &pathIn, QgsDataItem *parentItem ) override;
 };
