@@ -29,19 +29,19 @@
 namespace
 {
 
-// Build a key entry from name and version
+  // Build a key entry from name and version
   QString makeServiceKey( const QString &name, const QString &version )
   {
     return QString( "%1_%2" ).arg( name, version );
   }
 
-// Compare two version strings:
-// The strings are split into dot separated segment
-// Each segment are compared up to the shortest number of segment of the
-// lists. Remaining segments are dropped.
-// If both segments can be interpreted as numbers the are compared as numbers, otherwise
-// They are compared lexicographically.
-// Return true if v1 is greater than v2
+  // Compare two version strings:
+  // The strings are split into dot separated segment
+  // Each segment are compared up to the shortest number of segment of the
+  // lists. Remaining segments are dropped.
+  // If both segments can be interpreted as numbers the are compared as numbers, otherwise
+  // They are compared lexicographically.
+  // Return true if v1 is greater than v2
   bool isVersionGreater( const QString &v1, const QString &v2 )
   {
     QStringList l1 = v1.split( '.' );
@@ -76,7 +76,7 @@ namespace
     return false;
   }
 
-// Check that two versions are c
+  // Check that two versions are c
 
 
 } // namespace
@@ -104,35 +104,31 @@ QgsService *QgsServiceRegistry::getService( const QString &name, const QString &
     else
     {
       // Return the default version
-      QgsMessageLog::logMessage( QString( "Service %1 %2 not found, returning default" ).arg( name, version ),
-                                 QStringLiteral( "Server" ), Qgis::MessageLevel::Warning );
+      QgsMessageLog::logMessage( QString( "Service %1 %2 not found, returning default" ).arg( name, version ), QStringLiteral( "Server" ), Qgis::MessageLevel::Warning );
       service = mServices[v->second].get();
     }
   }
   else
   {
-    QgsMessageLog::logMessage( QString( "Service %1 is not registered" ).arg( name ),
-                               QStringLiteral( "Server" ), Qgis::MessageLevel::Critical );
+    QgsMessageLog::logMessage( QString( "Service %1 is not registered" ).arg( name ), QStringLiteral( "Server" ), Qgis::MessageLevel::Critical );
   }
   return service;
 }
 
 void QgsServiceRegistry::registerService( QgsService *service )
 {
-  const QString name    = service->name();
+  const QString name = service->name();
   const QString version = service->version();
 
   // Test if service is already registered
   const QString key = makeServiceKey( name, version );
   if ( mServices.constFind( key ) != mServices.constEnd() )
   {
-    QgsMessageLog::logMessage( QStringLiteral( "Error Service %1 %2 is already registered" ).arg( name, version ),
-                               QStringLiteral( "Server" ), Qgis::MessageLevel::Critical );
+    QgsMessageLog::logMessage( QStringLiteral( "Error Service %1 %2 is already registered" ).arg( name, version ), QStringLiteral( "Server" ), Qgis::MessageLevel::Critical );
     return;
   }
 
-  QgsMessageLog::logMessage( QStringLiteral( "Adding service %1 %2" ).arg( name, version ),
-                             QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
+  QgsMessageLog::logMessage( QStringLiteral( "Adding service %1 %2" ).arg( name, version ), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
   mServices.insert( key, std::shared_ptr<QgsService>( service ) );
 
   // Check the default version
@@ -160,12 +156,10 @@ void QgsServiceRegistry::registerService( QgsService *service )
     // Insert the service as the default one
     mVersions.insert( name, VersionTable::mapped_type( version, key ) );
   }*/
-
 }
 
 int QgsServiceRegistry::unregisterApi( const QString &name, const QString &version )
 {
-
   // Check that we have an API of that name
   int removed = 0;
   const VersionTable::const_iterator v = mApiVersions.constFind( name );
@@ -179,8 +173,7 @@ int QgsServiceRegistry::unregisterApi( const QString &name, const QString &versi
       {
         if ( ( *it )->name() == name )
         {
-          QgsMessageLog::logMessage( QString( "Unregistering API %1 %2" ).arg( name, ( *it )->version() ),
-                                     QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
+          QgsMessageLog::logMessage( QString( "Unregistering API %1 %2" ).arg( name, ( *it )->version() ), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
           it = mApis.erase( it );
           ++removed;
         }
@@ -198,8 +191,7 @@ int QgsServiceRegistry::unregisterApi( const QString &name, const QString &versi
       const ApiTable::iterator found = mApis.find( key );
       if ( found != mApis.end() )
       {
-        QgsMessageLog::logMessage( QString( "Unregistering API %1 %2" ).arg( name, version ),
-                                   QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
+        QgsMessageLog::logMessage( QString( "Unregistering API %1 %2" ).arg( name, version ), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
         mApis.erase( found );
         removed = 1;
 
@@ -207,13 +199,11 @@ int QgsServiceRegistry::unregisterApi( const QString &name, const QString &versi
         // but with different version
         //
         QString maxVer;
-        const std::function < void ( const ApiTable::mapped_type & ) >
-        findGreaterVersion = [name, &maxVer]( const ApiTable::mapped_type & api )
-        {
-          if ( api->name() == name &&
-               ( maxVer.isEmpty() || isVersionGreater( api->version(), maxVer ) ) )
-            maxVer = api->version();
-        };
+        const std::function<void( const ApiTable::mapped_type & )>
+          findGreaterVersion = [name, &maxVer]( const ApiTable::mapped_type &api ) {
+            if ( api->name() == name && ( maxVer.isEmpty() || isVersionGreater( api->version(), maxVer ) ) )
+              maxVer = api->version();
+          };
 
         mApiVersions.remove( name );
 
@@ -234,13 +224,11 @@ QgsServerApi *QgsServiceRegistry::apiForRequest( const QgsServerRequest &request
 {
   for ( const auto &api : mApis )
   {
-    QgsMessageLog::logMessage( QStringLiteral( "Trying URL path: '%1' for '%2'" ).arg( request.url().path(), api->rootPath() ),
-                               QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
+    QgsMessageLog::logMessage( QStringLiteral( "Trying URL path: '%1' for '%2'" ).arg( request.url().path(), api->rootPath() ), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
     if ( api->accept( request.url() ) )
     {
       Q_ASSERT( !api->name().isEmpty() );
-      QgsMessageLog::logMessage( QStringLiteral( "API %1 accepts the URL path '%2' " ).arg( api->name(), request.url().path() ),
-                                 QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
+      QgsMessageLog::logMessage( QStringLiteral( "API %1 accepts the URL path '%2' " ).arg( api->name(), request.url().path() ), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
       return api.get();
     }
   }
@@ -265,15 +253,13 @@ QgsServerApi *QgsServiceRegistry::getApi( const QString &name, const QString &ve
     else
     {
       // Return the default version
-      QgsMessageLog::logMessage( QString( "API %1 %2 not found, returning default" ).arg( name, version ),
-                                 QStringLiteral( "Server" ), Qgis::MessageLevel::Warning );
+      QgsMessageLog::logMessage( QString( "API %1 %2 not found, returning default" ).arg( name, version ), QStringLiteral( "Server" ), Qgis::MessageLevel::Warning );
       api = mApis[v->second].get();
     }
   }
   else
   {
-    QgsMessageLog::logMessage( QString( "API %1 is not registered" ).arg( name ),
-                               QStringLiteral( "Server" ), Qgis::MessageLevel::Critical );
+    QgsMessageLog::logMessage( QString( "API %1 is not registered" ).arg( name ), QStringLiteral( "Server" ), Qgis::MessageLevel::Critical );
   }
   return api;
 }
@@ -293,8 +279,7 @@ int QgsServiceRegistry::unregisterService( const QString &name, const QString &v
       {
         if ( ( *it )->name() == name )
         {
-          QgsMessageLog::logMessage( QString( "Unregistering service %1 %2" ).arg( name, ( *it )->version() ),
-                                     QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
+          QgsMessageLog::logMessage( QString( "Unregistering service %1 %2" ).arg( name, ( *it )->version() ), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
           it = mServices.erase( it );
           ++removed;
         }
@@ -312,8 +297,7 @@ int QgsServiceRegistry::unregisterService( const QString &name, const QString &v
       const ServiceTable::iterator found = mServices.find( key );
       if ( found != mServices.end() )
       {
-        QgsMessageLog::logMessage( QString( "Unregistering service %1 %2" ).arg( name, version ),
-                                   QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
+        QgsMessageLog::logMessage( QString( "Unregistering service %1 %2" ).arg( name, version ), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
         mServices.erase( found );
         removed = 1;
 
@@ -321,13 +305,11 @@ int QgsServiceRegistry::unregisterService( const QString &name, const QString &v
         // but with different version
         //
         QString maxVer;
-        const std::function < void ( const ServiceTable::mapped_type & ) >
-        findGreaterVersion = [name, &maxVer]( const ServiceTable::mapped_type & service )
-        {
-          if ( service->name() == name &&
-               ( maxVer.isEmpty() || isVersionGreater( service->version(), maxVer ) ) )
-            maxVer = service->version();
-        };
+        const std::function<void( const ServiceTable::mapped_type & )>
+          findGreaterVersion = [name, &maxVer]( const ServiceTable::mapped_type &service ) {
+            if ( service->name() == name && ( maxVer.isEmpty() || isVersionGreater( service->version(), maxVer ) ) )
+              maxVer = service->version();
+          };
 
         mServiceVersions.remove( name );
 
@@ -360,7 +342,6 @@ void QgsServiceRegistry::cleanUp()
 
 bool QgsServiceRegistry::registerApi( QgsServerApi *api )
 {
-
   const QString name = api->name();
   const QString version = api->version();
 
@@ -368,8 +349,7 @@ bool QgsServiceRegistry::registerApi( QgsServerApi *api )
   const QString key = makeServiceKey( name, version );
   if ( mApis.constFind( key ) != mApis.constEnd() )
   {
-    QgsMessageLog::logMessage( QStringLiteral( "Error API %1 %2 is already registered" ).arg( name, version ),
-                               QStringLiteral( "Server" ), Qgis::MessageLevel::Critical );
+    QgsMessageLog::logMessage( QStringLiteral( "Error API %1 %2 is already registered" ).arg( name, version ), QStringLiteral( "Server" ), Qgis::MessageLevel::Critical );
     return false;
   }
 
