@@ -40,16 +40,13 @@ std::once_flag initDirWatcher;
 
 QMap<QString, QString> QgsLandingPageUtils::projects( const QgsServerSettings &settings )
 {
-
   static QString QGIS_SERVER_LANDING_PAGE_PROJECTS_DIRECTORIES;
   static QString QGIS_SERVER_LANDING_PAGE_PROJECTS_PG_CONNECTIONS;
 
   // Init directory watcher
   static QFileSystemWatcher dirWatcher;
-  std::call_once( initDirWatcher, [ = ]
-  {
-    QObject::connect( &dirWatcher, &QFileSystemWatcher::directoryChanged, qApp, [ = ]( const QString & path )
-    {
+  std::call_once( initDirWatcher, [=] {
+    QObject::connect( &dirWatcher, &QFileSystemWatcher::directoryChanged, qApp, [=]( const QString &path ) {
       QgsMessageLog::logMessage( QStringLiteral( "Directory '%1' has changed: project information cache cleared." ).arg( path ), QStringLiteral( "Landing Page" ), Qgis::MessageLevel::Info );
       AVAILABLE_PROJECTS.clear();
     } );
@@ -83,21 +80,20 @@ QMap<QString, QString> QgsLandingPageUtils::projects( const QgsServerSettings &s
     const auto cProjectDirs { projectDir.split( QStringLiteral( "||" ) ) };
     for ( const auto &path : cProjectDirs )
     {
-      if ( ! path.isEmpty() )
+      if ( !path.isEmpty() )
       {
         const QDir dir { path };
         if ( dir.exists() )
         {
           dirWatcher.addPath( dir.path() );
-          const auto constFiles { dir.entryList( ) };
+          const auto constFiles { dir.entryList() };
           for ( const auto &f : constFiles )
           {
-            if ( f.endsWith( QStringLiteral( ".qgs" ), Qt::CaseSensitivity::CaseInsensitive ) ||
-                 f.endsWith( QStringLiteral( ".qgz" ), Qt::CaseSensitivity::CaseInsensitive ) )
+            if ( f.endsWith( QStringLiteral( ".qgs" ), Qt::CaseSensitivity::CaseInsensitive ) || f.endsWith( QStringLiteral( ".qgz" ), Qt::CaseSensitivity::CaseInsensitive ) )
             {
               const QString fullPath { path + '/' + f };
               const auto projectHash { QCryptographicHash::hash( fullPath.toUtf8(), QCryptographicHash::Md5 ).toHex() };
-              AVAILABLE_PROJECTS[ projectHash ] = fullPath;
+              AVAILABLE_PROJECTS[projectHash] = fullPath;
               QgsMessageLog::logMessage( QStringLiteral( "Adding filesystem project '%1' with id '%2'" ).arg( QFileInfo( f ).fileName(), QString::fromUtf8( projectHash ) ), QStringLiteral( "Landing Page" ), Qgis::MessageLevel::Info );
             }
           }
@@ -121,16 +117,16 @@ QMap<QString, QString> QgsLandingPageUtils::projects( const QgsServerSettings &s
   const auto cPgConnections { pgConnections.split( QStringLiteral( "||" ) ) };
   for ( const auto &connectionString : cPgConnections )
   {
-    if ( ! connectionString.isEmpty() )
+    if ( !connectionString.isEmpty() )
     {
       const auto constProjects { storage->listProjects( connectionString ) };
-      if ( ! constProjects.isEmpty() )
+      if ( !constProjects.isEmpty() )
       {
         for ( const auto &projectName : constProjects )
         {
           const QString projectFullPath { connectionString + QStringLiteral( "&project=%1" ).arg( projectName ) };
           const auto projectHash { QCryptographicHash::hash( projectFullPath.toUtf8(), QCryptographicHash::Md5 ).toHex() };
-          AVAILABLE_PROJECTS[ projectHash ] = projectFullPath;
+          AVAILABLE_PROJECTS[projectHash] = projectFullPath;
           QgsMessageLog::logMessage( QStringLiteral( "Adding postgres project '%1' with id '%2'" ).arg( projectName, QString::fromUtf8( projectHash ) ), QStringLiteral( "Landing Page" ), Qgis::MessageLevel::Warning );
         }
       }
@@ -151,9 +147,8 @@ QMap<QString, QString> QgsLandingPageUtils::projects( const QgsServerSettings &s
 json QgsLandingPageUtils::projectInfo( const QString &projectUri, const QgsServerSettings *serverSettings, const QgsServerRequest &request )
 {
   // Helper for QStringList
-  auto jList = [ ]( const QStringList & l ) -> json
-  {
-    json a = json::array( );
+  auto jList = []( const QStringList &l ) -> json {
+    json a = json::array();
     for ( const auto &e : std::as_const( l ) )
     {
       a.push_back( e.toStdString() );
@@ -161,24 +156,21 @@ json QgsLandingPageUtils::projectInfo( const QString &projectUri, const QgsServe
     return a;
   };
 
-  auto jHash = [ ]( const QHash<QString, QString> &l ) -> json
-  {
+  auto jHash = []( const QHash<QString, QString> &l ) -> json {
     json a = json::object();
     const auto &constKeys { l.keys() };
     for ( const auto &k : constKeys )
     {
-      a[ k.toStdString() ] = l[ k ].toStdString();
+      a[k.toStdString()] = l[k].toStdString();
     }
     return a;
   };
 
-  auto jContactList = [ ]( const QgsAbstractMetadataBase::ContactList & contacts ) -> json
-  {
+  auto jContactList = []( const QgsAbstractMetadataBase::ContactList &contacts ) -> json {
     json jContacts = json::array();
     for ( const auto &c : contacts )
     {
-      json jContact
-      {
+      json jContact {
         { "name", c.name.toStdString() },
         { "role", c.role.toStdString() },
         { "voice", c.voice.toStdString() },
@@ -192,52 +184,50 @@ json QgsLandingPageUtils::projectInfo( const QString &projectUri, const QgsServe
       const auto &cAddresses { c.addresses };
       for ( const auto &a : cAddresses )
       {
-        jContact[ "addresses" ].push_back(
-        {
-          { "address", a.address.toStdString()},
-          { "type", a.type.toStdString() },
-          { "city", a.city.toStdString() },
-          { "country", a.country.toStdString() },
-          { "postalCode", a.postalCode.toStdString() },
-          { "administrativeArea", a.administrativeArea.toStdString() }
-        } );
+        jContact["addresses"].push_back(
+          { { "address", a.address.toStdString() },
+            { "type", a.type.toStdString() },
+            { "city", a.city.toStdString() },
+            { "country", a.country.toStdString() },
+            { "postalCode", a.postalCode.toStdString() },
+            { "administrativeArea", a.administrativeArea.toStdString() }
+          }
+        );
       }
       jContacts.push_back( jContact );
     }
     return jContacts;
   };
 
-  auto jLinksList = [ ]( const QgsAbstractMetadataBase::LinkList & links ) -> json
-  {
+  auto jLinksList = []( const QgsAbstractMetadataBase::LinkList &links ) -> json {
     json jLinks = json::array();
     for ( const auto &l : links )
     {
       jLinks.push_back(
-      {
-        { "name", l.name.toStdString() },
-        { "url", l.url.toStdString()},
-        { "description", l.description.toStdString()},
-        { "type", l.type.toStdString()},
-        { "mimeType", l.mimeType.toStdString()},
-        { "format", l.format.toStdString()},
-        { "size", l.size.toStdString()}
-      } );
+        { { "name", l.name.toStdString() },
+          { "url", l.url.toStdString() },
+          { "description", l.description.toStdString() },
+          { "type", l.type.toStdString() },
+          { "mimeType", l.mimeType.toStdString() },
+          { "format", l.format.toStdString() },
+          { "size", l.size.toStdString() }
+        }
+      );
     }
     return jLinks;
   };
 
   json info = json::object();
-  info[ "id" ] = QCryptographicHash::hash( projectUri.toUtf8(), QCryptographicHash::Md5 ).toHex();
+  info["id"] = QCryptographicHash::hash( projectUri.toUtf8(), QCryptographicHash::Md5 ).toHex();
 
   const QgsProject *p { QgsConfigCache::instance()->project( projectUri, serverSettings ) };
 
   if ( p )
   {
-
     // Initial extent for map display, in 4326 CRS.
     // Check view settings first, read map canvas extent from XML if it's not set
     const QgsProjectViewSettings *viewSettings { p->viewSettings() };
-    if ( viewSettings && ! viewSettings->defaultViewExtent().isEmpty() )
+    if ( viewSettings && !viewSettings->defaultViewExtent().isEmpty() )
     {
       QgsRectangle extent { viewSettings->defaultViewExtent() };
       // Need conversion?
@@ -246,28 +236,21 @@ json QgsLandingPageUtils::projectInfo( const QString &projectUri, const QgsServe
         QgsCoordinateTransform ct { p->crs(), QgsCoordinateReferenceSystem::fromEpsgId( 4326 ), p->transformContext() };
         extent = ct.transform( extent );
       }
-      info[ "initial_extent" ] = json::array( { extent.xMinimum(), extent.yMinimum(), extent.xMaximum(), extent.yMaximum() } );
+      info["initial_extent"] = json::array( { extent.xMinimum(), extent.yMinimum(), extent.xMaximum(), extent.yMaximum() } );
     }
     else
-      // Old projects do not have view extent information, we have no choice than
-      // re-read the project and extract the information from there
+    // Old projects do not have view extent information, we have no choice than
+    // re-read the project and extract the information from there
     {
       QgsProject temporaryProject( nullptr, Qgis::ProjectCapabilities() );
-      QObject::connect( &temporaryProject, &QgsProject::readProject, qApp, [ & ]( const QDomDocument & projectDoc )
-      {
+      QObject::connect( &temporaryProject, &QgsProject::readProject, qApp, [&]( const QDomDocument &projectDoc ) {
         const QDomNodeList canvasElements { projectDoc.elementsByTagName( QStringLiteral( "mapcanvas" ) ) };
-        if ( ! canvasElements.isEmpty() )
+        if ( !canvasElements.isEmpty() )
         {
           const QDomNode canvasElement { canvasElements.item( 0 ).firstChildElement( QStringLiteral( "extent" ) ) };
-          if ( !canvasElement.isNull() &&
-               !canvasElement.firstChildElement( QStringLiteral( "xmin" ) ).isNull() &&
-               !canvasElement.firstChildElement( QStringLiteral( "ymin" ) ).isNull() &&
-               !canvasElement.firstChildElement( QStringLiteral( "xmax" ) ).isNull() &&
-               !canvasElement.firstChildElement( QStringLiteral( "ymax" ) ).isNull()
-             )
+          if ( !canvasElement.isNull() && !canvasElement.firstChildElement( QStringLiteral( "xmin" ) ).isNull() && !canvasElement.firstChildElement( QStringLiteral( "ymin" ) ).isNull() && !canvasElement.firstChildElement( QStringLiteral( "xmax" ) ).isNull() && !canvasElement.firstChildElement( QStringLiteral( "ymax" ) ).isNull() )
           {
-            QgsRectangle extent
-            {
+            QgsRectangle extent {
               canvasElement.firstChildElement( QStringLiteral( "xmin" ) ).text().toDouble(),
               canvasElement.firstChildElement( QStringLiteral( "ymin" ) ).text().toDouble(),
               canvasElement.firstChildElement( QStringLiteral( "xmax" ) ).text().toDouble(),
@@ -279,14 +262,15 @@ json QgsLandingPageUtils::projectInfo( const QString &projectUri, const QgsServe
               QgsCoordinateTransform ct { temporaryProject.crs(), QgsCoordinateReferenceSystem::fromEpsgId( 4326 ), temporaryProject.transformContext() };
               extent = ct.transform( extent );
             }
-            info[ "initial_extent" ] = json::array( { extent.xMinimum(), extent.yMinimum(), extent.xMaximum(), extent.yMaximum() } );
+            info["initial_extent"] = json::array( { extent.xMinimum(), extent.yMinimum(), extent.xMaximum(), extent.yMaximum() } );
           }
         }
       } );
 
       QgsMessageLog::logMessage( QStringLiteral( "The project '%1' was saved with a version of QGIS which does not contain initial extent information. "
-                                 "For better performances consider re-saving the project with the latest version of QGIS." )
-                                 .arg( projectUri ), QStringLiteral( "Landing Page" ), Qgis::MessageLevel::Warning );
+                                                 "For better performances consider re-saving the project with the latest version of QGIS." )
+                                   .arg( projectUri ),
+                                 QStringLiteral( "Landing Page" ), Qgis::MessageLevel::Warning );
       temporaryProject.read( projectUri );
     }
 
@@ -302,17 +286,16 @@ json QgsLandingPageUtils::projectInfo( const QString &projectUri, const QgsServe
     info["description"] = description.toStdString();
     // CRS
     const QStringList wmsOutputCrsList { QgsServerProjectUtils::wmsOutputCrsList( *p ) };
-    const QString crs = wmsOutputCrsList.contains( QStringLiteral( "EPSG:4326" ) ) || wmsOutputCrsList.isEmpty() ?
-                        QStringLiteral( "EPSG:4326" ) : wmsOutputCrsList.first();
+    const QString crs = wmsOutputCrsList.contains( QStringLiteral( "EPSG:4326" ) ) || wmsOutputCrsList.isEmpty() ? QStringLiteral( "EPSG:4326" ) : wmsOutputCrsList.first();
     info["crs"] = crs.toStdString();
     // Typenames for WMS
     const bool useIds { QgsServerProjectUtils::wmsUseLayerIds( *p ) };
     QStringList typenames;
     const QStringList wmsRestrictedLayers { QgsServerProjectUtils::wmsRestrictedLayers( *p ) };
-    const auto constLayers { p->mapLayers().values( ) };
+    const auto constLayers { p->mapLayers().values() };
     for ( const auto &l : constLayers )
     {
-      if ( ! wmsRestrictedLayers.contains( l->name() ) )
+      if ( !wmsRestrictedLayers.contains( l->name() ) )
       {
         typenames.push_back( useIds ? l->id() : l->name() );
       }
@@ -326,7 +309,7 @@ json QgsLandingPageUtils::projectInfo( const QString &projectUri, const QgsServe
     {
       for ( const auto &l : constLayers )
       {
-        if ( ! wmsRestrictedLayers.contains( l->name() ) )
+        if ( !wmsRestrictedLayers.contains( l->name() ) )
         {
           QgsRectangle layerExtent { l->extent() };
           if ( l->crs() != targetCrs && targetCrs.isValid() )
@@ -345,7 +328,7 @@ json QgsLandingPageUtils::projectInfo( const QString &projectUri, const QgsServe
         }
       }
     }
-    else if ( ! extent.isNull() )
+    else if ( !extent.isNull() )
     {
       if ( targetCrs.isValid() && targetCrs != p->crs() )
       {
@@ -357,7 +340,7 @@ json QgsLandingPageUtils::projectInfo( const QString &projectUri, const QgsServe
     QgsRectangle geographicExtent { extent };
     if ( targetCrs.authid() != QLatin1String( "EPSG:4326" ) )
     {
-      QgsCoordinateTransform ct { targetCrs,  QgsCoordinateReferenceSystem::fromEpsgId( 4326 ), p->transformContext() };
+      QgsCoordinateTransform ct { targetCrs, QgsCoordinateReferenceSystem::fromEpsgId( 4326 ), p->transformContext() };
       geographicExtent = ct.transform( geographicExtent );
     }
     info["geographic_extent"] = json::array( { geographicExtent.xMinimum(), geographicExtent.yMinimum(), geographicExtent.xMaximum(), geographicExtent.yMaximum() } );
@@ -379,7 +362,7 @@ json QgsLandingPageUtils::projectInfo( const QString &projectUri, const QgsServe
     metadata["links"] = jLinksList( md.links() );
     // Contacts
     metadata["contacts"] = jContactList( md.contacts() );
-    info[ "metadata" ] = metadata;
+    info["metadata"] = metadata;
     // Capabilities
     json capabilities = json::object();
     capabilities["owsServiceCapabilities"] = QgsServerProjectUtils::owsServiceCapabilities( *p );
@@ -428,13 +411,13 @@ json QgsLandingPageUtils::projectInfo( const QString &projectUri, const QgsServe
     capabilities["wmsServiceUrl"] = QgsServerProjectUtils::wmsServiceUrl( *p, request, *serverSettings ).toStdString();
     capabilities["wmsTileBuffer"] = QgsServerProjectUtils::wmsTileBuffer( *p );
     capabilities["wmsUseLayerIds"] = QgsServerProjectUtils::wmsUseLayerIds( *p );
-    capabilities["wmtsServiceUrl" ] = QgsServerProjectUtils::wmtsServiceUrl( *p, request, *serverSettings ).toStdString();
+    capabilities["wmtsServiceUrl"] = QgsServerProjectUtils::wmtsServiceUrl( *p, request, *serverSettings ).toStdString();
     info["capabilities"] = capabilities;
     // WMS layers
-    info[ "wms_root_name" ] = QgsServerProjectUtils::wmsRootName( *p ).toStdString();
+    info["wms_root_name"] = QgsServerProjectUtils::wmsRootName( *p ).toStdString();
     if ( QgsServerProjectUtils::wmsRootName( *p ).isEmpty() )
     {
-      info[ "wms_root_name" ] = p->title().toStdString();
+      info["wms_root_name"] = p->title().toStdString();
     }
     json wmsLayers;
     // For convenience:
@@ -446,19 +429,18 @@ json QgsLandingPageUtils::projectInfo( const QString &projectUri, const QgsServe
     QStringList wmsLayersQueryable;
     for ( const auto &l : constLayers )
     {
-      if ( ! wmsRestrictedLayers.contains( l->name() ) )
+      if ( !wmsRestrictedLayers.contains( l->name() ) )
       {
-        json wmsLayer
-        {
+        json wmsLayer {
           { "name", l->name().toStdString() },
           { "id", l->id().toStdString() },
           { "crs", l->crs().authid().toStdString() },
-          { "type", l->type() ==  Qgis::LayerType::Vector ? "vector" : "raster" },
+          { "type", l->type() == Qgis::LayerType::Vector ? "vector" : "raster" },
         };
         if ( l->type() == Qgis::LayerType::Vector )
         {
           const QgsVectorLayer *vl = static_cast<const QgsVectorLayer *>( l );
-          wmsLayer[ "pk" ] = vl->primaryKeyAttributes();
+          wmsLayer["pk"] = vl->primaryKeyAttributes();
           int fieldIdx { 0 };
           json fieldsData;
           const QgsFields &cFields { vl->fields() };
@@ -470,16 +452,12 @@ json QgsLandingPageUtils::projectInfo( const QString &projectUri, const QgsServe
               continue;
             }
             const QgsFieldConstraints::Constraints constraints { field.constraints().constraints() };
-            const bool notNull = constraints & QgsFieldConstraints::Constraint::ConstraintNotNull &&
-                                 field.constraints().constraintStrength( QgsFieldConstraints::Constraint::ConstraintNotNull ) == QgsFieldConstraints::ConstraintStrength::ConstraintStrengthHard;
-            const bool unique = constraints & QgsFieldConstraints::Constraint::ConstraintUnique &&
-                                field.constraints().constraintStrength( QgsFieldConstraints::Constraint::ConstraintUnique ) == QgsFieldConstraints::ConstraintStrength::ConstraintStrengthHard;
-            const bool hasExpression = constraints & QgsFieldConstraints::Constraint::ConstraintExpression &&
-                                       field.constraints().constraintStrength( QgsFieldConstraints::Constraint::ConstraintExpression ) == QgsFieldConstraints::ConstraintStrength::ConstraintStrengthHard;
+            const bool notNull = constraints & QgsFieldConstraints::Constraint::ConstraintNotNull && field.constraints().constraintStrength( QgsFieldConstraints::Constraint::ConstraintNotNull ) == QgsFieldConstraints::ConstraintStrength::ConstraintStrengthHard;
+            const bool unique = constraints & QgsFieldConstraints::Constraint::ConstraintUnique && field.constraints().constraintStrength( QgsFieldConstraints::Constraint::ConstraintUnique ) == QgsFieldConstraints::ConstraintStrength::ConstraintStrengthHard;
+            const bool hasExpression = constraints & QgsFieldConstraints::Constraint::ConstraintExpression && field.constraints().constraintStrength( QgsFieldConstraints::Constraint::ConstraintExpression ) == QgsFieldConstraints::ConstraintStrength::ConstraintStrengthHard;
             const QString defaultValue = vl->dataProvider()->defaultValueClause( fieldIdx );
-            const bool isReadOnly = notNull && unique && ! defaultValue.isEmpty();
-            fieldsData[ field.name().toStdString() ] =
-            {
+            const bool isReadOnly = notNull && unique && !defaultValue.isEmpty();
+            fieldsData[field.name().toStdString()] = {
               { "type", field.typeName().toStdString() },
               { "label", field.alias().isEmpty() ? field.name().toStdString() : field.alias().toStdString() },
               { "precision", field.precision() },
@@ -494,16 +472,16 @@ json QgsLandingPageUtils::projectInfo( const QString &projectUri, const QgsServe
 
             ++fieldIdx;
           }
-          wmsLayer[ "fields" ] = fieldsData;
+          wmsLayer["fields"] = fieldsData;
         }
-        wmsLayer[ "extent" ] = { l->extent().xMinimum(), l->extent().yMinimum(), l->extent().xMaximum(), l->extent().yMaximum() };
+        wmsLayer["extent"] = { l->extent().xMinimum(), l->extent().yMinimum(), l->extent().xMaximum(), l->extent().yMaximum() };
 
         // Fill maps
-        const QString layerTitle { l->title().isEmpty() ? l->name() : l->title() };
-        const QString shortName { ! l->shortName().isEmpty() ? l->shortName() : l->name() };
+        const QString layerTitle { l->serverProperties()->title().isEmpty() ? l->name() : l->serverProperties()->title() };
+        const QString shortName { !l->serverProperties()->shortName().isEmpty() ? l->serverProperties()->shortName() : l->name() };
         const std::string layerIdentifier { useIds ? l->id().toStdString() : shortName.toStdString() };
-        wmsLayersTypenameIdMap[ layerIdentifier ] = l->id().toStdString();
-        wmsLayersTitleIdMap[ layerTitle.toStdString() ] = layerIdentifier;
+        wmsLayersTypenameIdMap[layerIdentifier] = l->id().toStdString();
+        wmsLayersTitleIdMap[layerTitle.toStdString()] = layerIdentifier;
 
         if ( l->flags() & QgsMapLayer::Searchable )
         {
@@ -517,54 +495,54 @@ json QgsLandingPageUtils::projectInfo( const QString &projectUri, const QgsServe
         // Layer metadata
         json layerMetadata;
         const auto &md { l->metadata() };
-        layerMetadata[ "abstract" ] = md.abstract( ).toStdString();
-        layerMetadata[ "categories" ] = jList( md.categories( ) );
-        layerMetadata[ "contacts" ] = jContactList( md.contacts() );
-        layerMetadata[ "encoding" ] = md.encoding( ).toStdString();
-        layerMetadata[ "fees" ] = md.fees( ).toStdString();
-        layerMetadata[ "history" ] = jList( md.history( ) );
-        layerMetadata[ "identifier" ] = md.identifier( ).toStdString();
-        layerMetadata[ "keywordVocabularies" ] = jList( md.keywordVocabularies( ) );
+        layerMetadata["abstract"] = md.abstract().toStdString();
+        layerMetadata["categories"] = jList( md.categories() );
+        layerMetadata["contacts"] = jContactList( md.contacts() );
+        layerMetadata["encoding"] = md.encoding().toStdString();
+        layerMetadata["fees"] = md.fees().toStdString();
+        layerMetadata["history"] = jList( md.history() );
+        layerMetadata["identifier"] = md.identifier().toStdString();
+        layerMetadata["keywordVocabularies"] = jList( md.keywordVocabularies() );
         // Keywords
         json jKeywords = json::object();
         const auto &cKw { md.keywords().keys() };
         const auto &cVals { md.keywords() };
         for ( const auto &k : cKw )
         {
-          jKeywords[ k.toStdString() ] = jList( cVals[ k ] );
+          jKeywords[k.toStdString()] = jList( cVals[k] );
         }
-        layerMetadata[ "keywords" ] = jKeywords;
-        layerMetadata[ "language" ] = md.language( ).toStdString();
-        layerMetadata[ "licenses" ] = jList( md.licenses( ) );
-        layerMetadata[ "links" ] = jLinksList( md.links( ) );
-        layerMetadata[ "parentIdentifier" ] = md.parentIdentifier( ).toStdString();
-        layerMetadata[ "rights" ] = jList( md.rights( ) );
-        layerMetadata[ "title" ] = md.title( ).toStdString();
-        layerMetadata[ "type" ] = md.type( ).toStdString();
-        layerMetadata[ "crs" ] = md.crs().authid().toStdString();
-        const auto cConstraints {  md.constraints() };
+        layerMetadata["keywords"] = jKeywords;
+        layerMetadata["language"] = md.language().toStdString();
+        layerMetadata["licenses"] = jList( md.licenses() );
+        layerMetadata["links"] = jLinksList( md.links() );
+        layerMetadata["parentIdentifier"] = md.parentIdentifier().toStdString();
+        layerMetadata["rights"] = jList( md.rights() );
+        layerMetadata["title"] = md.title().toStdString();
+        layerMetadata["type"] = md.type().toStdString();
+        layerMetadata["crs"] = md.crs().authid().toStdString();
+        const auto cConstraints { md.constraints() };
         json constraints = json::array();
         for ( const auto &c : cConstraints )
         {
           constraints.push_back(
-          {
-            { "type", c.type.toStdString() },
-            { "constraint", c.constraint.toStdString() },
-          } );
+            {
+              { "type", c.type.toStdString() },
+              { "constraint", c.constraint.toStdString() },
+            }
+          );
         }
-        layerMetadata[ "constraints" ] = constraints;
-        wmsLayer[ "metadata" ] = layerMetadata;
-        wmsLayers[ l->id().toStdString() ] = wmsLayer;
+        layerMetadata["constraints"] = constraints;
+        wmsLayer["metadata"] = layerMetadata;
+        wmsLayers[l->id().toStdString()] = wmsLayer;
       }
     }
 
-    info[ "wms_layers" ] = wmsLayers;
-    info[ "wms_layers_map" ] = wmsLayersTitleIdMap;
-    info[ "wms_layers_queryable" ] = jList( wmsLayersQueryable );
-    info[ "wms_layers_searchable" ] = jList( wmsLayersSearchable );
-    info[ "wms_layers_typename_id_map" ] = wmsLayersTypenameIdMap;
-    info[ "toc" ] = layerTree( *p, wmsLayersQueryable, wmsLayersSearchable, wmsRestrictedLayers );
-
+    info["wms_layers"] = wmsLayers;
+    info["wms_layers_map"] = wmsLayersTitleIdMap;
+    info["wms_layers_queryable"] = jList( wmsLayersQueryable );
+    info["wms_layers_searchable"] = jList( wmsLayersSearchable );
+    info["wms_layers_typename_id_map"] = wmsLayersTypenameIdMap;
+    info["toc"] = layerTree( *p, wmsLayersQueryable, wmsLayersSearchable, wmsRestrictedLayers );
   }
   else
   {
@@ -579,8 +557,7 @@ json QgsLandingPageUtils::layerTree( const QgsProject &project, const QStringLis
   const QStringList wfsLayerIds { QgsServerProjectUtils::wfsLayerIds( project ) };
 
 
-  std::function<json( const QgsLayerTreeNode *, const QString & )> harvest = [ & ]( const QgsLayerTreeNode * node, const QString & parentId ) -> json
-  {
+  std::function<json( const QgsLayerTreeNode *, const QString & )> harvest = [&]( const QgsLayerTreeNode *node, const QString &parentId ) -> json {
     const std::string nodeName { parentId.isEmpty() ? "root" : node->name().toStdString() };
     QString title { QString::fromStdString( nodeName ) };
     QString nodeIdentifier = title;
@@ -594,19 +571,19 @@ json QgsLandingPageUtils::layerTree( const QgsProject &project, const QStringLis
     {
       const QgsLayerTreeLayer *l { static_cast<const QgsLayerTreeLayer *>( node ) };
       if ( l->layer() && ( l->layer()->type() == Qgis::LayerType::Vector || l->layer()->type() == Qgis::LayerType::Raster )
-           && ! wmsRestrictedLayers.contains( l->name() ) )
+           && !wmsRestrictedLayers.contains( l->name() ) )
       {
-        rec[ "id" ] = l->layerId().toStdString();
+        rec["id"] = l->layerId().toStdString();
         nodeIdentifier = l->layerId();
-        rec[ "queryable" ] = wmsLayersQueryable.contains( l->layerId() );
-        rec[ "searchable" ] = wmsLayersSearchable.contains( l->layerId() );
-        rec[ "wfs_enabled" ] = wfsLayerIds.contains( l->layerId() );
-        const QString layerName { l->layer()->shortName().isEmpty() ? l->layer()->name() : l->layer()->shortName()};
-        rec[ "typename" ] = useIds ? l->layer()->id().toStdString() : layerName.toStdString();
+        rec["queryable"] = wmsLayersQueryable.contains( l->layerId() );
+        rec["searchable"] = wmsLayersSearchable.contains( l->layerId() );
+        rec["wfs_enabled"] = wfsLayerIds.contains( l->layerId() );
+        const QString layerName { l->layer()->serverProperties()->shortName().isEmpty() ? l->layer()->name() : l->layer()->serverProperties()->shortName() };
+        rec["typename"] = useIds ? l->layer()->id().toStdString() : layerName.toStdString();
         // Override title
-        if ( ! l->layer()->title().isEmpty() )
+        if ( !l->layer()->serverProperties()->title().isEmpty() )
         {
-          title = l->layer()->title();
+          title = l->layer()->serverProperties()->title();
         }
       }
       else
@@ -620,17 +597,17 @@ json QgsLandingPageUtils::layerTree( const QgsProject &project, const QStringLis
         rec["min_scale"] = l->layer()->minimumScale();
         rec["max_scale"] = l->layer()->maximumScale();
       }
-      rec[ "is_layer" ] = true;
-      rec[ "layer_type" ] = l->layer()->type() == Qgis::LayerType::Vector ? "vector" : "raster";
+      rec["is_layer"] = true;
+      rec["layer_type"] = l->layer()->type() == Qgis::LayerType::Vector ? "vector" : "raster";
     }
     else
     {
-      rec[ "is_layer" ] = false;
+      rec["is_layer"] = false;
     }
-    rec[ "title"] = title.toStdString();
+    rec["title"] = title.toStdString();
     const QString treeId = parentId.isEmpty() ? QStringLiteral( "root" ) : parentId + "." + nodeIdentifier;
-    rec[ "tree_id" ] = treeId.toStdString();
-    rec[ "tree_id_hash" ] = QCryptographicHash::hash( treeId.toUtf8(), QCryptographicHash::Md5 ).toHex().toStdString();
+    rec["tree_id"] = treeId.toStdString();
+    rec["tree_id_hash"] = QCryptographicHash::hash( treeId.toUtf8(), QCryptographicHash::Md5 ).toHex().toStdString();
 
     // Collect children
     json children = json::array();
@@ -638,12 +615,12 @@ json QgsLandingPageUtils::layerTree( const QgsProject &project, const QStringLis
     for ( const auto &c : cChildren )
     {
       const json harvested = harvest( c, treeId );
-      if ( ! harvested.is_null() )
+      if ( !harvested.is_null() )
       {
         children.push_back( harvested );
       }
     }
-    rec [ "children" ] = children;
+    rec["children"] = children;
 
     return rec;
   };
@@ -661,5 +638,3 @@ QString QgsLandingPageUtils::projectUriFromUrl( const QString &url, const QgsSer
   }
   return QString();
 };
-
-
