@@ -30,12 +30,10 @@ namespace QgsWms
    * \ingroup server
    * \class QgsWms::QgsMapRendererJobProxy
    * \brief Proxy for sequential or parallel map render job
-   * \since QGIS 3.0
    */
   class QgsMapRendererJobProxy
   {
     public:
-
       /**
        * Constructor for QgsMapRendererJobProxy. Does not take ownership of
        * \a featureFilterProvider.
@@ -44,17 +42,16 @@ namespace QgsWms
        * \param featureFilterProvider Features filtering
        */
       QgsMapRendererJobProxy(
-        bool parallelRendering
-        , int maxThreads
-        , QgsFeatureFilterProvider *featureFilterProvider
+        bool parallelRendering, int maxThreads, QgsFeatureFilterProvider *featureFilterProvider
       );
 
       /**
        * Sequential or parallel map rendering.
        * \param mapSettings Passed to MapRendererJob
        * \param image The resulting image
+       * \param feedback socket feedback (since QGIS 3.36)
        */
-      void render( const QgsMapSettings &mapSettings, QImage *image );
+      void render( const QgsMapSettings &mapSettings, QImage *image, const QgsFeedback *feedback );
 
       /**
        * Takes ownership of the painter used for rendering.
@@ -80,5 +77,5 @@ namespace QgsWms
   };
 
 
-}
+} // namespace QgsWms
 #endif
