@@ -27,12 +27,6 @@ namespace QgsWms
   /**
    * Output GetFeatureInfo response
    */
-  void writeGetFeatureInfo( QgsServerInterface *serverIface, const QgsProject *project,
-                            const QgsWmsRequest &request,
-                            QgsServerResponse &response );
+  void writeGetFeatureInfo( QgsServerInterface *serverIface, const QgsProject *project, const QgsWmsRequest &request, QgsServerResponse &response );
 
 } // namespace QgsWms
-
-
-
-
