@@ -37,8 +37,7 @@ namespace QgsWms
 
     if ( !xsdFileInfo.exists() )
     {
-      QgsMessageLog::logMessage( QStringLiteral( "Error, xsd file 'schemaExtension.xsd' does not exist" ),
-                                 QStringLiteral( "Server" ), Qgis::MessageLevel::Critical );
+      QgsMessageLog::logMessage( QStringLiteral( "Error, xsd file 'schemaExtension.xsd' does not exist" ), QStringLiteral( "Server" ), Qgis::MessageLevel::Critical );
     }
     else
     {
@@ -51,8 +50,7 @@ namespace QgsWms
       }
       else
       {
-        QgsMessageLog::logMessage( QStringLiteral( "Error, xsd file 'schemaExtension.xsd' not readable" ),
-                                   QStringLiteral( "Server" ), Qgis::MessageLevel::Critical );
+        QgsMessageLog::logMessage( QStringLiteral( "Error, xsd file 'schemaExtension.xsd' not readable" ), QStringLiteral( "Server" ), Qgis::MessageLevel::Critical );
       }
     }
     response.setHeader( QStringLiteral( "Content-Type" ), QStringLiteral( "text/xml; charset=utf-8" ) );
