@@ -34,10 +34,10 @@ class TestQgsGeoreferencer : public QObject
     TestQgsGeoreferencer();
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
-    void cleanupTestCase();// will be called after the last testfunction was executed.
-    void init() {} // will be called before each testfunction is executed.
-    void cleanup() {} // will be called after every testfunction.
+    void initTestCase();    // will be called before the first testfunction is executed.
+    void cleanupTestCase(); // will be called after the last testfunction was executed.
+    void init() {}          // will be called before each testfunction is executed.
+    void cleanup() {}       // will be called after every testfunction.
     void testGcpPoint();
     void testGeorefDataPoint();
     void testGcpList();
@@ -50,6 +50,7 @@ class TestQgsGeoreferencer : public QObject
     void testUpdateResiduals();
     void testListModel();
     void testListModelCrs();
+    void testListModelLocalization();
     void testGdalCommands();
     void testWorldFile();
 
@@ -67,6 +68,8 @@ void TestQgsGeoreferencer::initTestCase()
   QgsApplication::init();
   QgsApplication::initQgis();
   mQgisApp = new QgisApp();
+  // Set locale to ensure tests are consistent
+  QLocale::setDefault( QLocale( QStringLiteral( "en_US.UTF-8" ) ) );
 }
 
 //runs after all tests
@@ -96,16 +99,11 @@ void TestQgsGeoreferencer::testGcpPoint()
   QVERIFY( p.isEnabled() );
 
   // equality operator
-  QVERIFY( QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false )
-           == QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ) );
-  QVERIFY( QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false )
-           != QgsGcpPoint( QgsPointXY( 11, 22 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ) );
-  QVERIFY( QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false )
-           != QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 33, 44 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ) );
-  QVERIFY( QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false )
-           != QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:28356" ) ), false ) );
-  QVERIFY( QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false )
-           != QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), true ) );
+  QVERIFY( QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ) == QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ) );
+  QVERIFY( QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ) != QgsGcpPoint( QgsPointXY( 11, 22 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ) );
+  QVERIFY( QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ) != QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 33, 44 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ) );
+  QVERIFY( QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ) != QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:28356" ) ), false ) );
+  QVERIFY( QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ) != QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), true ) );
 
 
   // transform destination point
@@ -119,9 +117,7 @@ void TestQgsGeoreferencer::testGeorefDataPoint()
 {
   QgsMapCanvas c1;
   QgsMapCanvas c2;
-  QgsGeorefDataPoint p( &c1, &c2,
-                        QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ),
-                        false );
+  QgsGeorefDataPoint p( &c1, &c2, QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false );
 
   QCOMPARE( p.sourcePoint(), QgsPointXY( 1, 2 ) );
   p.setSourcePoint( QgsPointXY( 11, 22 ) );
@@ -137,10 +133,7 @@ void TestQgsGeoreferencer::testGeorefDataPoint()
   p.setEnabled( true );
   QVERIFY( p.isEnabled() );
 
-  QCOMPARE( p.point(), QgsGcpPoint( QgsPointXY( 11, 22 ),
-                                    QgsPointXY( 33, 44 ),
-                                    QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ),
-                                    true ) );
+  QCOMPARE( p.point(), QgsGcpPoint( QgsPointXY( 11, 22 ), QgsPointXY( 33, 44 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), true ) );
 
 
   // transform destination point
@@ -158,57 +151,30 @@ void TestQgsGeoreferencer::testGcpList()
 
   QgsMapCanvas c1;
   QgsMapCanvas c2;
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ),
-                                       false ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ) );
   QCOMPARE( list.countEnabledPoints(), 0 );
-  QCOMPARE( list.asPoints(),
-  {
-    QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false )
-  }
-          );
+  QCOMPARE( list.asPoints(), { QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ) } );
 
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 11, 22 ), QgsPointXY( 33, 44 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:28356" ) ),
-                                       true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 11, 22 ), QgsPointXY( 33, 44 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:28356" ) ), true ) );
   QCOMPARE( list.countEnabledPoints(), 1 );
-  QCOMPARE( list.asPoints(),
-            QList< QgsGcpPoint >(
-  {
-    QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ),
-    QgsGcpPoint( QgsPointXY( 11, 22 ), QgsPointXY( 33, 44 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:28356" ) ), true )
-  } ) );
+  QCOMPARE( list.asPoints(), QList<QgsGcpPoint>( { QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ), QgsGcpPoint( QgsPointXY( 11, 22 ), QgsPointXY( 33, 44 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:28356" ) ), true ) } ) );
 
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 111, 222 ), QgsPointXY( 333, 444 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:28356" ) ),
-                                       true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 111, 222 ), QgsPointXY( 333, 444 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:28356" ) ), true ) );
   QCOMPARE( list.countEnabledPoints(), 2 );
-  QCOMPARE( list.asPoints(),
-            QList< QgsGcpPoint >(
-  {
-    QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ),
-    QgsGcpPoint( QgsPointXY( 11, 22 ), QgsPointXY( 33, 44 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:28356" ) ), true ),
-    QgsGcpPoint( QgsPointXY( 111, 222 ), QgsPointXY( 333, 444 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:28356" ) ), true )
-  } ) );
+  QCOMPARE( list.asPoints(), QList<QgsGcpPoint>( { QgsGcpPoint( QgsPointXY( 1, 2 ), QgsPointXY( 3, 4 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), false ), QgsGcpPoint( QgsPointXY( 11, 22 ), QgsPointXY( 33, 44 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:28356" ) ), true ), QgsGcpPoint( QgsPointXY( 111, 222 ), QgsPointXY( 333, 444 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:28356" ) ), true ) } ) );
 
 
   qDeleteAll( list );
   list.clear();
 
   // create gcp vectors
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 111, 222 ), QgsPointXY( -30, 40 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ),
-                                       true ) );
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 11, 22 ), QgsPointXY( 16697923, -3503549 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ),
-                                       true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 111, 222 ), QgsPointXY( -30, 40 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ), true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 11, 22 ), QgsPointXY( 16697923, -3503549 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ), true ) );
   // disabled!
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 33, 44 ), QgsPointXY( 100, 200 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ),
-                                       false ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 33, 44 ), QgsPointXY( 100, 200 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ), false ) );
 
-  QVector< QgsPointXY > sourcePoints;
-  QVector< QgsPointXY > destinationPoints;
+  QVector<QgsPointXY> sourcePoints;
+  QVector<QgsPointXY> destinationPoints;
   list.createGCPVectors( sourcePoints, destinationPoints, QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ), QgsProject::instance()->transformContext() );
   QCOMPARE( sourcePoints.size(), 2 );
   QCOMPARE( sourcePoints.at( 0 ).x(), 111 );
@@ -221,7 +187,6 @@ void TestQgsGeoreferencer::testGcpList()
   QGSCOMPARENEAR( destinationPoints.at( 0 ).y(), 4865942, 10000 );
   QCOMPARE( destinationPoints.at( 1 ).x(), 16697923 );
   QCOMPARE( destinationPoints.at( 1 ).y(), -3503549 );
-
 }
 
 void TestQgsGeoreferencer::testSaveLoadGcps()
@@ -230,16 +195,10 @@ void TestQgsGeoreferencer::testSaveLoadGcps()
   QgsGCPList list;
   QgsMapCanvas c1;
   QgsMapCanvas c2;
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 111, 222 ), QgsPointXY( -30, 40 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ),
-                                       true ) );
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 11, 22 ), QgsPointXY( 16697923, -3503549 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ),
-                                       true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 111, 222 ), QgsPointXY( -30, 40 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ), true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 11, 22 ), QgsPointXY( 16697923, -3503549 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ), true ) );
   // disabled!
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 33, 44 ), QgsPointXY( 100, 200 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ),
-                                       false ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 33, 44 ), QgsPointXY( 100, 200 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ), false ) );
 
   QTemporaryDir dir;
   QVERIFY( dir.isValid() );
@@ -247,23 +206,16 @@ void TestQgsGeoreferencer::testSaveLoadGcps()
 
   QString error;
 
-  QVERIFY( list.saveGcps( tempFilename, QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ),
-                          QgsProject::instance()->transformContext(), error ) );
+  QVERIFY( list.saveGcps( tempFilename, QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ), QgsProject::instance()->transformContext(), error ) );
   QVERIFY( error.isEmpty() );
 
 
   // load
   QgsCoordinateReferenceSystem actualDestinationCrs;
-  QList<QgsGcpPoint> res = QgsGCPList::loadGcps( QStringLiteral( "not real" ),
-                           QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ),
-                           actualDestinationCrs,
-                           error );
+  QList<QgsGcpPoint> res = QgsGCPList::loadGcps( QStringLiteral( "not real" ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), actualDestinationCrs, error );
   QVERIFY( !error.isEmpty() );
 
-  res = QgsGCPList::loadGcps( tempFilename,
-                              QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ),
-                              actualDestinationCrs,
-                              error );
+  res = QgsGCPList::loadGcps( tempFilename, QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), actualDestinationCrs, error );
   QVERIFY( error.isEmpty() );
   QCOMPARE( res.size(), 3 );
   // should be loaded from txt
@@ -297,16 +249,10 @@ void TestQgsGeoreferencer::testSaveLoadGcpsNoCrs()
   QgsGCPList list;
   QgsMapCanvas c1;
   QgsMapCanvas c2;
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 111, 222 ), QgsPointXY( -30, 40 ), QgsCoordinateReferenceSystem(),
-                                       true ) );
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 11, 22 ), QgsPointXY( 34, -50 ), QgsCoordinateReferenceSystem(),
-                                       true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 111, 222 ), QgsPointXY( -30, 40 ), QgsCoordinateReferenceSystem(), true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 11, 22 ), QgsPointXY( 34, -50 ), QgsCoordinateReferenceSystem(), true ) );
   // disabled!
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 33, 44 ), QgsPointXY( 100, 200 ), QgsCoordinateReferenceSystem(),
-                                       false ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 33, 44 ), QgsPointXY( 100, 200 ), QgsCoordinateReferenceSystem(), false ) );
 
   QTemporaryDir dir;
   QVERIFY( dir.isValid() );
@@ -314,17 +260,13 @@ void TestQgsGeoreferencer::testSaveLoadGcpsNoCrs()
 
   QString error;
 
-  QVERIFY( list.saveGcps( tempFilename, QgsCoordinateReferenceSystem(),
-                          QgsProject::instance()->transformContext(), error ) );
+  QVERIFY( list.saveGcps( tempFilename, QgsCoordinateReferenceSystem(), QgsProject::instance()->transformContext(), error ) );
   QVERIFY( error.isEmpty() );
 
 
   // load
   QgsCoordinateReferenceSystem actualDestinationCrs;
-  QList<QgsGcpPoint> res = QgsGCPList::loadGcps( tempFilename,
-                           QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ),
-                           actualDestinationCrs,
-                           error );
+  QList<QgsGcpPoint> res = QgsGCPList::loadGcps( tempFilename, QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3111" ) ), actualDestinationCrs, error );
   QVERIFY( error.isEmpty() );
   QCOMPARE( res.size(), 3 );
   // should fallback to default CRS
@@ -358,10 +300,9 @@ void TestQgsGeoreferencer::testTransformClone()
   QgsGeorefTransform transform( QgsGcpTransformerInterface::TransformMethod::PolynomialOrder1 );
   transform.loadRaster( QStringLiteral( TEST_DATA_DIR ) + QStringLiteral( "/rgb256x256.png" ) );
 
-  QVERIFY( transform.updateParametersFromGcps( {QgsPointXY( 0, 0 ), QgsPointXY( 10, 0 ), QgsPointXY( 0, 30 ), QgsPointXY( 10, 30 )},
-  {QgsPointXY( 10, 5 ), QgsPointXY( 16, 5 ), QgsPointXY( 10, 8 ), QgsPointXY( 16, 8 )}, true ) );
+  QVERIFY( transform.updateParametersFromGcps( { QgsPointXY( 0, 0 ), QgsPointXY( 10, 0 ), QgsPointXY( 0, 30 ), QgsPointXY( 10, 30 ) }, { QgsPointXY( 10, 5 ), QgsPointXY( 16, 5 ), QgsPointXY( 10, 8 ), QgsPointXY( 16, 8 ) }, true ) );
 
-  std::unique_ptr< QgsGeorefTransform > cloned( dynamic_cast< QgsGeorefTransform * >( transform.clone() ) );
+  std::unique_ptr<QgsGeorefTransform> cloned( dynamic_cast<QgsGeorefTransform *>( transform.clone() ) );
   QCOMPARE( cloned->method(), QgsGcpTransformerInterface::TransformMethod::PolynomialOrder1 );
   QVERIFY( !cloned->hasExistingGeoreference() );
 
@@ -384,10 +325,9 @@ void TestQgsGeoreferencer::testTransformClone()
   QgsGeorefTransform transform2( QgsGcpTransformerInterface::TransformMethod::Linear );
   transform2.loadRaster( QStringLiteral( TEST_DATA_DIR ) + QStringLiteral( "/landsat.tif" ) );
 
-  QVERIFY( transform2.updateParametersFromGcps( {QgsPointXY( 783414, 3350122 ), QgsPointXY( 791344, 3349795 ), QgsPointXY( 783077, 334093 ), QgsPointXY( 791134, 3341401 )},
-  {QgsPointXY( 783414, 3350122 ), QgsPointXY( 791344, 3349795 ), QgsPointXY( 783077, 334093 ), QgsPointXY( 791134, 3341401 )}, true ) );
+  QVERIFY( transform2.updateParametersFromGcps( { QgsPointXY( 783414, 3350122 ), QgsPointXY( 791344, 3349795 ), QgsPointXY( 783077, 334093 ), QgsPointXY( 791134, 3341401 ) }, { QgsPointXY( 783414, 3350122 ), QgsPointXY( 791344, 3349795 ), QgsPointXY( 783077, 334093 ), QgsPointXY( 791134, 3341401 ) }, true ) );
 
-  cloned.reset( dynamic_cast< QgsGeorefTransform * >( transform2.clone() ) );
+  cloned.reset( dynamic_cast<QgsGeorefTransform *>( transform2.clone() ) );
   QCOMPARE( cloned->method(), QgsGcpTransformerInterface::TransformMethod::Linear );
   QVERIFY( cloned->hasExistingGeoreference() );
 
@@ -441,8 +381,7 @@ void TestQgsGeoreferencer::testTransformImageNoGeoference()
   QCOMPARE( rect.xMaximum(), 100.0 );
   QCOMPARE( rect.yMaximum(), 200.0 );
 
-  QVERIFY( transform.updateParametersFromGcps( {QgsPointXY( 0, 0 ), QgsPointXY( 10, 0 ), QgsPointXY( 0, 30 ), QgsPointXY( 10, 30 )},
-  {QgsPointXY( 10, 5 ), QgsPointXY( 16, 5 ), QgsPointXY( 10, 8 ), QgsPointXY( 16, 8 )}, true ) );
+  QVERIFY( transform.updateParametersFromGcps( { QgsPointXY( 0, 0 ), QgsPointXY( 10, 0 ), QgsPointXY( 0, 30 ), QgsPointXY( 10, 30 ) }, { QgsPointXY( 10, 5 ), QgsPointXY( 16, 5 ), QgsPointXY( 10, 8 ), QgsPointXY( 16, 8 ) }, true ) );
 
   QVERIFY( transform.transform( QgsPointXY( 0, 5 ), res, true ) );
   QCOMPARE( res.x(), 10 );
@@ -502,15 +441,15 @@ void TestQgsGeoreferencer::testTransformImageWithExistingGeoreference()
   QGSCOMPARENEAR( rect.xMinimum(), 781662.375, 0.1 );
   QGSCOMPARENEAR( rect.yMinimum(), 3350923.125, 0.1 );
   QGSCOMPARENEAR( rect.xMaximum(), 787362.375, 0.1 );
-  QGSCOMPARENEAR( rect.yMaximum(),  3362323.125, 0.1 );
+  QGSCOMPARENEAR( rect.yMaximum(), 3362323.125, 0.1 );
 
   QVector<QgsPointXY> pixelCoords = transform.mRasterChangeCoords.getPixelCoords(
-  {
-    QgsPointXY( 783414, 3350122 ),
-    QgsPointXY( 791344, 3349795 ),
-    QgsPointXY( 783077, 3340937 ),
-    QgsPointXY( 791134, 3341401 )
-  } ) ;
+    { QgsPointXY( 783414, 3350122 ),
+      QgsPointXY( 791344, 3349795 ),
+      QgsPointXY( 783077, 3340937 ),
+      QgsPointXY( 791134, 3341401 )
+    }
+  );
 
   QCOMPARE( pixelCoords.size(), 4 );
   QGSCOMPARENEAR( pixelCoords.at( 0 ).x(), 30.7302631579, 0.01 );
@@ -525,8 +464,7 @@ void TestQgsGeoreferencer::testTransformImageWithExistingGeoreference()
   QVERIFY( transform.hasExistingGeoreference() );
 
   // when calling updateParametersFromGcps the source list MUST be in source layer CRS, not pixels!
-  QVERIFY( transform.updateParametersFromGcps( {QgsPointXY( 783414, 3350122 ), QgsPointXY( 791344, 3349795 ), QgsPointXY( 783077, 334093 ), QgsPointXY( 791134, 3341401 )},
-  {QgsPointXY( 783414, 3350122 ), QgsPointXY( 791344, 3349795 ), QgsPointXY( 783077, 334093 ), QgsPointXY( 791134, 3341401 )}, true ) );
+  QVERIFY( transform.updateParametersFromGcps( { QgsPointXY( 783414, 3350122 ), QgsPointXY( 791344, 3349795 ), QgsPointXY( 783077, 334093 ), QgsPointXY( 791134, 3341401 ) }, { QgsPointXY( 783414, 3350122 ), QgsPointXY( 791344, 3349795 ), QgsPointXY( 783077, 334093 ), QgsPointXY( 791134, 3341401 ) }, true ) );
 
   QVERIFY( transform.transform( QgsPointXY( 30.7302631579, -14.0548245614 ), res, true ) );
   QGSCOMPARENEAR( res.x(), 783414, 1 );
@@ -543,8 +481,7 @@ void TestQgsGeoreferencer::testTransformImageWithExistingGeoreference()
   QGSCOMPARENEAR( res.y(), -167.0548245614, 0.1 );
 
   // with shift of 100, 200
-  QVERIFY( transform.updateParametersFromGcps( {QgsPointXY( 783414, 3350122 ), QgsPointXY( 791344, 3349795 ), QgsPointXY( 783077, 334093 ), QgsPointXY( 791134, 3341401 )},
-  {QgsPointXY( 783514, 3350322 ), QgsPointXY( 791444, 3349995 ), QgsPointXY( 783177, 334293 ), QgsPointXY( 791234, 3341601 )}, true ) );
+  QVERIFY( transform.updateParametersFromGcps( { QgsPointXY( 783414, 3350122 ), QgsPointXY( 791344, 3349795 ), QgsPointXY( 783077, 334093 ), QgsPointXY( 791134, 3341401 ) }, { QgsPointXY( 783514, 3350322 ), QgsPointXY( 791444, 3349995 ), QgsPointXY( 783177, 334293 ), QgsPointXY( 791234, 3341601 ) }, true ) );
 
   QVERIFY( transform.transform( QgsPointXY( 30.7302631579, -14.0548245614 ), res, true ) );
   QGSCOMPARENEAR( res.x(), 783514, 1 );
@@ -579,8 +516,8 @@ void TestQgsGeoreferencer::testRasterChangeCoords()
   QGSCOMPARENEAR( transform.toColumnLine( QgsPointXY( 781662.375, 3350923.125 ) ).y(), 0.0, 0.0001 );
   QGSCOMPARENEAR( transform.toColumnLine( QgsPointXY( 787362.375, 3350923.125 ) ).x(), 100.0, 0.0001 );
   QGSCOMPARENEAR( transform.toColumnLine( QgsPointXY( 787362.375, 3350923.125 ) ).y(), 0.0, 0.0001 );
-  QGSCOMPARENEAR( transform.toColumnLine( QgsPointXY( 787362.375,  3362323.125 ) ).x(), 100.0, 0.0001 );
-  QGSCOMPARENEAR( transform.toColumnLine( QgsPointXY( 787362.375,  3362323.125 ) ).y(), 200.0, 0.0001 );
+  QGSCOMPARENEAR( transform.toColumnLine( QgsPointXY( 787362.375, 3362323.125 ) ).x(), 100.0, 0.0001 );
+  QGSCOMPARENEAR( transform.toColumnLine( QgsPointXY( 787362.375, 3362323.125 ) ).y(), 200.0, 0.0001 );
 
   // load a raster with no georeferencing
   transform.loadRaster( QStringLiteral( TEST_DATA_DIR ) + QStringLiteral( "/rgb256x256.png" ) );
@@ -611,15 +548,9 @@ void TestQgsGeoreferencer::testUpdateResiduals()
   QgsGCPList list;
   QgsMapCanvas c1;
   QgsMapCanvas c2;
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 781662.375, 3350923.125 ), QgsPointXY( -30, 40 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ),
-                                       true ) );
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 787362.375, 3350923.125 ), QgsPointXY( 16697923, -3503549 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ),
-                                       true ) );
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 787362.375, 3362323.125 ), QgsPointXY( -35, 42 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ),
-                                       true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 781662.375, 3350923.125 ), QgsPointXY( -30, 40 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ), true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 787362.375, 3350923.125 ), QgsPointXY( 16697923, -3503549 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ), true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 787362.375, 3362323.125 ), QgsPointXY( -35, 42 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ), true ) );
 
   list.updateResiduals( &transform, QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ), QgsProject::instance()->transformContext(), Qgis::RenderUnit::Pixels );
   QGSCOMPARENEAR( list.at( 0 )->residual().x(), 0, 0.00001 );
@@ -667,15 +598,9 @@ void TestQgsGeoreferencer::testListModel()
   QgsGCPList list;
   QgsMapCanvas c1;
   QgsMapCanvas c2;
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 781662.375, 3350923.125 ), QgsPointXY( -30, 40 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ),
-                                       true ) );
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 787362.375, 3350923.125 ), QgsPointXY( 16697923, -3503549 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ),
-                                       true ) );
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 787362.375, 3362323.125 ), QgsPointXY( -35, 42 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ),
-                                       true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 781662.375, 3350923.125 ), QgsPointXY( -30, 40 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ), true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 787362.375, 3350923.125 ), QgsPointXY( 16697923, -3503549 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ), true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 787362.375, 3362323.125 ), QgsPointXY( -35, 42 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ), true ) );
   QgsGeorefTransform transform( QgsGcpTransformerInterface::TransformMethod::Linear );
   transform.loadRaster( QStringLiteral( TEST_DATA_DIR ) + QStringLiteral( "/landsat.tif" ) );
   QVERIFY( transform.hasExistingGeoreference() );
@@ -690,8 +615,8 @@ void TestQgsGeoreferencer::testListModel()
 
   QCOMPARE( model.rowCount(), 3 );
   QCOMPARE( model.data( model.index( 0, 1 ) ).toString(), QStringLiteral( "0" ) );
-  QCOMPARE( model.data( model.index( 0, 2 ) ).toString(), QStringLiteral( "781662.38" ) );
-  QCOMPARE( model.data( model.index( 0, 3 ) ).toString(), QStringLiteral( "3350923.13" ) );
+  QCOMPARE( model.data( model.index( 0, 2 ) ).toString(), QStringLiteral( "781,662.38" ) );
+  QCOMPARE( model.data( model.index( 0, 3 ) ).toString(), QStringLiteral( "3,350,923.13" ) );
   QCOMPARE( model.data( model.index( 0, 4 ) ).toString(), QStringLiteral( "-30.000000" ) );
   QCOMPARE( model.data( model.index( 0, 5 ) ).toString(), QStringLiteral( "40.000000" ) );
   QCOMPARE( model.data( model.index( 0, 4 ), Qt::ToolTipRole ).toString(), QStringLiteral( "<b>-30.000000</b><br>EPSG:4326 - WGS 84" ) );
@@ -702,8 +627,8 @@ void TestQgsGeoreferencer::testListModel()
   QCOMPARE( model.data( model.index( 0, 8 ) ).toString(), QStringLiteral( "n/a" ) );
 
   QCOMPARE( model.data( model.index( 1, 1 ) ).toString(), QStringLiteral( "1" ) );
-  QCOMPARE( model.data( model.index( 1, 2 ) ).toString(), QStringLiteral( "787362.38" ) );
-  QCOMPARE( model.data( model.index( 1, 3 ) ).toString(), QStringLiteral( "3350923.13" ) );
+  QCOMPARE( model.data( model.index( 1, 2 ) ).toString(), QStringLiteral( "787,362.38" ) );
+  QCOMPARE( model.data( model.index( 1, 3 ) ).toString(), QStringLiteral( "3,350,923.13" ) );
   QCOMPARE( model.data( model.index( 1, 4 ) ).toString(), QStringLiteral( "149.999994" ) );
   QCOMPARE( model.data( model.index( 1, 5 ) ).toString(), QStringLiteral( "-29.999993" ) );
   // tooltip should show target CRS details for user clarification
@@ -714,8 +639,8 @@ void TestQgsGeoreferencer::testListModel()
   QCOMPARE( model.data( model.index( 1, 8 ) ).toString(), QStringLiteral( "n/a" ) );
 
   QCOMPARE( model.data( model.index( 2, 1 ) ).toString(), QStringLiteral( "2" ) );
-  QCOMPARE( model.data( model.index( 2, 2 ) ).toString(), QStringLiteral( "787362.38" ) );
-  QCOMPARE( model.data( model.index( 2, 3 ) ).toString(), QStringLiteral( "3362323.13" ) );
+  QCOMPARE( model.data( model.index( 2, 2 ) ).toString(), QStringLiteral( "787,362.38" ) );
+  QCOMPARE( model.data( model.index( 2, 3 ) ).toString(), QStringLiteral( "3,362,323.13" ) );
   QCOMPARE( model.data( model.index( 2, 4 ) ).toString(), QStringLiteral( "-35.000000" ) );
   QCOMPARE( model.data( model.index( 2, 5 ) ).toString(), QStringLiteral( "42.000000" ) );
   QCOMPARE( model.data( model.index( 2, 6 ) ).toString(), QStringLiteral( "n/a" ) );
@@ -745,19 +670,19 @@ void TestQgsGeoreferencer::testListModel()
   QVERIFY( !model.setData( model.index( 0, 8 ), 11 ) );
 
   QVERIFY( model.setData( model.index( 0, 2 ), 777777.77 ) );
-  QCOMPARE( model.data( model.index( 0, 2 ) ).toString(), QStringLiteral( "777777.77" ) );
+  QCOMPARE( model.data( model.index( 0, 2 ) ).toString(), QStringLiteral( "777,777.77" ) );
   QCOMPARE( list.at( 0 )->sourcePoint().x(), 777777.77 );
 
   QVERIFY( model.setData( model.index( 0, 3 ), 3333333.33 ) );
-  QCOMPARE( model.data( model.index( 0, 3 ) ).toString(), QStringLiteral( "3333333.33" ) );
+  QCOMPARE( model.data( model.index( 0, 3 ) ).toString(), QStringLiteral( "3,333,333.33" ) );
   QCOMPARE( list.at( 0 )->sourcePoint().y(), 3333333.33 );
 
   QVERIFY( model.setData( model.index( 0, 4 ), 1660000.77 ) );
-  QCOMPARE( model.data( model.index( 0, 4 ) ).toString(), QStringLiteral( "1660000.77" ) );
+  QCOMPARE( model.data( model.index( 0, 4 ) ).toString(), QStringLiteral( "1,660,000.77" ) );
   QCOMPARE( list.at( 0 )->destinationPoint().x(), 1660000.77 );
 
   QVERIFY( model.setData( model.index( 0, 5 ), 4433333.33 ) );
-  QCOMPARE( model.data( model.index( 0, 5 ) ).toString(), QStringLiteral( "4433333.33" ) );
+  QCOMPARE( model.data( model.index( 0, 5 ) ).toString(), QStringLiteral( "4,433,333.33" ) );
   QCOMPARE( list.at( 0 )->destinationPoint().y(), 4433333.33 );
 
   // disable point
@@ -776,15 +701,9 @@ void TestQgsGeoreferencer::testListModelCrs()
   QgsGCPList list;
   QgsMapCanvas c1;
   QgsMapCanvas c2;
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 781662.375, 3350923.125 ), QgsPointXY( -30, 40 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ),
-                                       true ) );
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 787362.375, 3350923.125 ), QgsPointXY( 16697923, -3503549 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ),
-                                       true ) );
-  list.append( new QgsGeorefDataPoint( &c1, &c2,
-                                       QgsPointXY( 787362.375, 3362323.125 ), QgsPointXY( 17697923, -3403549 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ),
-                                       true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 781662.375, 3350923.125 ), QgsPointXY( -30, 40 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ), true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 787362.375, 3350923.125 ), QgsPointXY( 16697923, -3503549 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ), true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 787362.375, 3362323.125 ), QgsPointXY( 17697923, -3403549 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ), true ) );
 
   QgsGCPListModel model;
   model.setGCPList( &list );
@@ -844,6 +763,47 @@ void TestQgsGeoreferencer::testListModelCrs()
   QCOMPARE( list.at( 2 )->destinationPointCrs().authid(), QStringLiteral( "EPSG:4326" ) );
 }
 
+void TestQgsGeoreferencer::testListModelLocalization()
+{
+  QgsGCPList list;
+  QgsMapCanvas c1;
+  QgsMapCanvas c2;
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 781662.375, 3350923.125 ), QgsPointXY( -30, 40 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ), true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 787362.375, 3350923.125 ), QgsPointXY( 16697923, -3503549 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ), true ) );
+  list.append( new QgsGeorefDataPoint( &c1, &c2, QgsPointXY( 787362.375, 3362323.125 ), QgsPointXY( 17697923, -3403549 ), QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) ), true ) );
+
+  QgsGCPListModel model;
+  model.setGCPList( &list );
+  model.setTargetCrs( QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ), QgsProject::instance()->transformContext() );
+
+  const QLocale defaultLocale = QLocale();
+
+  // Set locale to German
+  QLocale::setDefault( QLocale( QStringLiteral( "de_DE" ) ) );
+
+  // Check that the numbers are formatted correctly
+  QCOMPARE( model.data( model.index( 0, 4 ) ).toString(), QStringLiteral( "-30,000000" ) );
+  QCOMPARE( model.data( model.index( 0, 5 ) ).toString(), QStringLiteral( "40,000000" ) );
+  QCOMPARE( model.data( model.index( 1, 4 ) ).toString(), QStringLiteral( "149,999994" ) );
+  QCOMPARE( model.data( model.index( 1, 5 ) ).toString(), QStringLiteral( "-29,999993" ) );
+  QCOMPARE( model.data( model.index( 2, 4 ) ).toString(), QStringLiteral( "158,983147" ) );
+  QCOMPARE( model.data( model.index( 2, 5 ) ).toString(), QStringLiteral( "-29,218996" ) );
+
+  // Check that setData works with localized numbers
+  model.setData( model.index( 0, 4 ), QStringLiteral( "-31,123" ) );
+  QCOMPARE( QLocale().toDouble( model.data( model.index( 0, 4 ) ).toString() ), -31.123 );
+
+  model.setData( model.index( 0, 4 ), QStringLiteral( "1.123,1234" ) );
+  QCOMPARE( QLocale().toDouble( model.data( model.index( 0, 4 ) ).toString() ), 1123.1234 );
+
+  // Permissive check using C locale
+  model.setData( model.index( 0, 4 ), QStringLiteral( "123.4" ) );
+  QCOMPARE( QLocale().toDouble( model.data( model.index( 0, 4 ) ).toString() ), 123.4 );
+
+  // Revert locale to english
+  QLocale::setDefault( defaultLocale );
+}
+
 void TestQgsGeoreferencer::testGdalCommands()
 {
   QgsGeoreferencerMainWindow window;
@@ -856,25 +816,36 @@ void TestQgsGeoreferencer::testGdalCommands()
 
   QString command = window.generateGDALtranslateCommand();
   // gdal_translate command must use source pixels, not geographic coordinates
-  QCOMPARE( command, QStringLiteral( "gdal_translate -of GTiff -co TFW=YES -gcp 30.73 14.055 783414.001 3350122.002 -gcp 169.853 19.792 791344 33497952 -gcp 24.818 52926.844 783077 334093 -gcp 166.169 167.055 791134 3341401 \"%1\" \"%2\"" ).arg(
-              QStringLiteral( TEST_DATA_DIR ) + QStringLiteral( "/landsat.tif" ),
-              QDir::tempPath() + QStringLiteral( "/landsat.tif" ) ) );
+  QCOMPARE( command, QStringLiteral( "gdal_translate -of GTiff -co TFW=YES -gcp 30.73 14.055 783414.001 3350122.002 -gcp 169.853 19.792 791344 33497952 -gcp 24.818 52926.844 783077 334093 -gcp 166.169 167.055 791134 3341401 \"%1\" \"%2\"" ).arg( QStringLiteral( TEST_DATA_DIR ) + QStringLiteral( "/landsat.tif" ), QDir::tempPath() + QStringLiteral( "/landsat.tif" ) ) );
 
   command = window.generateGDALogr2ogrCommand();
-  QCOMPARE( command, QStringLiteral( "ogr2ogr -gcp 783414 3350122 783414.001 3350122.002 -gcp 791344 3349795 791344 33497952 -gcp 783077 334093 783077 334093 -gcp 791134 3341401 791134 3341401 -tps -t_srs EPSG:32633 \"\" \"%1\"" ).arg(
-              QStringLiteral( TEST_DATA_DIR ) + QStringLiteral( "/landsat.tif" ) ) );
+  QCOMPARE( command, QStringLiteral( "ogr2ogr -gcp 783414 3350122 783414.001 3350122.002 -gcp 791344 3349795 791344 33497952 -gcp 783077 334093 783077 334093 -gcp 791134 3341401 791134 3341401 -tps -t_srs EPSG:32633 \"\" \"%1\"" ).arg( QStringLiteral( TEST_DATA_DIR ) + QStringLiteral( "/landsat.tif" ) ) );
 
   window.mTargetCrs = QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) );
   command = window.generateGDALtranslateCommand();
   QgsDebugMsgLevel( command, 1 );
-  QCOMPARE( command, QStringLiteral( "gdal_translate -of GTiff -co TFW=YES -gcp 30.73 14.055 783414.00123457 3350122.00234568 -gcp 169.853 19.792 791344 33497952 -gcp 24.818 52926.844 783077 334093 -gcp 166.169 167.055 791134 3341401 \"%1\" \"%2\"" ).arg(
-              QStringLiteral( TEST_DATA_DIR ) + QStringLiteral( "/landsat.tif" ),
-              QDir::tempPath() + QStringLiteral( "/landsat.tif" ) ) );
+  QCOMPARE( command, QStringLiteral( "gdal_translate -of GTiff -co TFW=YES -gcp 30.73 14.055 783414.00123457 3350122.00234568 -gcp 169.853 19.792 791344 33497952 -gcp 24.818 52926.844 783077 334093 -gcp 166.169 167.055 791134 3341401 \"%1\" \"%2\"" ).arg( QStringLiteral( TEST_DATA_DIR ) + QStringLiteral( "/landsat.tif" ), QDir::tempPath() + QStringLiteral( "/landsat.tif" ) ) );
 
   command = window.generateGDALogr2ogrCommand();
   QgsDebugMsgLevel( command, 1 );
-  QCOMPARE( command, QStringLiteral( "ogr2ogr -gcp 783414 3350122 783414.00123457 3350122.00234568 -gcp 791344 3349795 791344 33497952 -gcp 783077 334093 783077 334093 -gcp 791134 3341401 791134 3341401 -tps -t_srs EPSG:4326 \"\" \"%1\"" ).arg(
-              QStringLiteral( TEST_DATA_DIR ) + QStringLiteral( "/landsat.tif" ) ) );
+  QCOMPARE( command, QStringLiteral( "ogr2ogr -gcp 783414 3350122 783414.00123457 3350122.00234568 -gcp 791344 3349795 791344 33497952 -gcp 783077 334093 783077 334093 -gcp 791134 3341401 791134 3341401 -tps -t_srs EPSG:4326 \"\" \"%1\"" ).arg( QStringLiteral( TEST_DATA_DIR ) + QStringLiteral( "/landsat.tif" ) ) );
+
+  const QLocale defaultLocale = QLocale();
+
+  // Set locale to German
+  QLocale::setDefault( QLocale( QStringLiteral( "de_DE" ) ) );
+
+  command = window.generateGDALtranslateCommand();
+  QgsDebugMsgLevel( command, 1 );
+  QCOMPARE( command, QStringLiteral( "gdal_translate -of GTiff -co TFW=YES -gcp 30.73 14.055 783414.00123457 3350122.00234568 -gcp 169.853 19.792 791344 33497952 -gcp 24.818 52926.844 783077 334093 -gcp 166.169 167.055 791134 3341401 \"%1\" \"%2\"" ).arg( QStringLiteral( TEST_DATA_DIR ) + QStringLiteral( "/landsat.tif" ), QDir::tempPath() + QStringLiteral( "/landsat.tif" ) ) );
+
+  command = window.generateGDALogr2ogrCommand();
+  QgsDebugMsgLevel( command, 1 );
+  QCOMPARE( command, QStringLiteral( "ogr2ogr -gcp 783414 3350122 783414.00123457 3350122.00234568 -gcp 791344 3349795 791344 33497952 -gcp 783077 334093 783077 334093 -gcp 791134 3341401 791134 3341401 -tps -t_srs EPSG:4326 \"\" \"%1\"" ).arg( QStringLiteral( TEST_DATA_DIR ) + QStringLiteral( "/landsat.tif" ) ) );
+
+
+  // Revert locale to english
+  QLocale::setDefault( defaultLocale );
 }
 
 void TestQgsGeoreferencer::testWorldFile()
