@@ -40,10 +40,10 @@ class TestQgsMapToolEditAnnotation : public QObject
     TestQgsMapToolEditAnnotation() = default;
 
   private slots:
-    void initTestCase(); // will be called before the first testfunction is executed.
+    void initTestCase();    // will be called before the first testfunction is executed.
     void cleanupTestCase(); // will be called after the last testfunction was executed.
-    void init(); // will be called before each testfunction is executed.
-    void cleanup(); // will be called after every testfunction.
+    void init();            // will be called before each testfunction is executed.
+    void cleanup();         // will be called after every testfunction.
 
     void testSelectItem();
     void testDeleteItem();
@@ -51,7 +51,6 @@ class TestQgsMapToolEditAnnotation : public QObject
     void testMoveNode();
     void testDeleteNode();
     void testAddNode();
-
 };
 
 void TestQgsMapToolEditAnnotation::initTestCase()
@@ -94,8 +93,8 @@ void TestQgsMapToolEditAnnotation::testSelectItem()
   item1->setZIndex( 1 );
   const QString i1id = layer->addItem( item1 );
 
-  QgsAnnotationPolygonItem *item2 = new QgsAnnotationPolygonItem( new QgsPolygon( new QgsLineString( QVector<QgsPoint> { QgsPoint( 1, 4 ), QgsPoint( 5, 4 ), QgsPoint( 5, 9 ), QgsPoint( 1, 9 ), QgsPoint( 1, 4 ) } ) ) );
-  item2->setZIndex( 2 );
+  QgsAnnotationPolygonItem *item2 = new QgsAnnotationPolygonItem( new QgsPolygon( new QgsLineString( QVector<QgsPoint> { QgsPoint( 1, 4 ), QgsPoint( 1.6, 4 ), QgsPoint( 1.6, 4.6 ), QgsPoint( 1, 4.6 ), QgsPoint( 1, 4 ) } ) ) );
+  item2->setZIndex( 0 );
   const QString i2id = layer->addItem( item2 );
 
   QgsAnnotationPolygonItem *item3 = new QgsAnnotationPolygonItem( new QgsPolygon( new QgsLineString( QVector<QgsPoint> { QgsPoint( 7, 1 ), QgsPoint( 8, 1 ), QgsPoint( 8, 2 ), QgsPoint( 7, 2 ), QgsPoint( 7, 1 ) } ) ) );
@@ -131,7 +130,7 @@ void TestQgsMapToolEditAnnotation::testSelectItem()
   QCOMPARE( spy.count(), 1 );
   QCOMPARE( spy.at( 0 ).at( 1 ).toString(), i1id );
 
-  // overlapping items, highest z order should be selected
+  // overlapping items, smallest area item should be selected
   utils.mouseMove( 1.5, 4.5 );
   utils.mouseClick( 1.5, 4.5, Qt::LeftButton, Qt::KeyboardModifiers(), true );
   QCOMPARE( spy.count(), 2 );
@@ -196,13 +195,13 @@ void TestQgsMapToolEditAnnotation::testDeleteItem()
   utils.mouseMove( 9, 9 );
   utils.mouseClick( 9, 9, Qt::LeftButton, Qt::KeyboardModifiers(), true );
   utils.keyClick( Qt::Key_Delete );
-  QCOMPARE( qgis::listToSet( layer->items().keys() ), QSet< QString >( { i1id, i2id, i3id } ) );
+  QCOMPARE( qgis::listToSet( layer->items().keys() ), QSet<QString>( { i1id, i2id, i3id } ) );
 
   // with selected item
   utils.mouseMove( 1.5, 1.5 );
   utils.mouseClick( 1.5, 1.5, Qt::LeftButton, Qt::KeyboardModifiers(), true );
   utils.keyClick( Qt::Key_Delete );
-  QCOMPARE( qgis::listToSet( layer->items().keys() ), QSet< QString >( { i2id, i3id } ) );
+  QCOMPARE( qgis::listToSet( layer->items().keys() ), QSet<QString>( { i2id, i3id } ) );
   while ( !canvas.isDrawing() )
   {
     QgsApplication::processEvents();
@@ -212,7 +211,7 @@ void TestQgsMapToolEditAnnotation::testDeleteItem()
   utils.mouseMove( 1.5, 4.5 );
   utils.mouseClick( 1.5, 4.5, Qt::LeftButton, Qt::KeyboardModifiers(), true );
   utils.keyClick( Qt::Key_Delete );
-  QCOMPARE( qgis::listToSet( layer->items().keys() ), QSet< QString >( { i3id } ) );
+  QCOMPARE( qgis::listToSet( layer->items().keys() ), QSet<QString>( { i3id } ) );
 }
 
 void TestQgsMapToolEditAnnotation::testMoveItem()
@@ -232,7 +231,7 @@ void TestQgsMapToolEditAnnotation::testMoveItem()
   QgsAnnotationPolygonItem *item1 = new QgsAnnotationPolygonItem( new QgsPolygon( new QgsLineString( QVector<QgsPoint> { QgsPoint( 1, 1 ), QgsPoint( 5, 1 ), QgsPoint( 5, 5 ), QgsPoint( 1, 5 ), QgsPoint( 1, 1 ) } ) ) );
   item1->setZIndex( 1 );
   const QString i1id = layer->addItem( item1 );
-  QCOMPARE( qgis::down_cast< QgsAnnotationPolygonItem * >( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((1 1, 5 1, 5 5, 1 5, 1 1))" ) );
+  QCOMPARE( qgis::down_cast<QgsAnnotationPolygonItem *>( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((1 1, 5 1, 5 5, 1 5, 1 1))" ) );
 
   layer->setCrs( QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ) );
 
@@ -273,7 +272,7 @@ void TestQgsMapToolEditAnnotation::testMoveItem()
   QCOMPARE( canvas.renderedItemResults()->renderedItems().size(), 1 );
 
   // check that item was moved
-  QCOMPARE( qgis::down_cast< QgsAnnotationPolygonItem * >( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((4 4, 8 4, 8 8, 4 8, 4 4))" ) );
+  QCOMPARE( qgis::down_cast<QgsAnnotationPolygonItem *>( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((4 4, 8 4, 8 8, 4 8, 4 4))" ) );
 
   // start a new move
   // click on item -- it should already be selected, so this will start a new move, not emit the itemSelected signal
@@ -291,7 +290,7 @@ void TestQgsMapToolEditAnnotation::testMoveItem()
   QCOMPARE( canvas.renderedItemResults()->renderedItems().size(), 1 );
 
   // check that item was moved
-  QCOMPARE( qgis::down_cast< QgsAnnotationPolygonItem * >( layer->item( i1id ) )->geometry()->asWkt( 1 ), QStringLiteral( "Polygon ((0.9 1, 4.9 1, 4.9 5, 0.9 5, 0.9 1))" ) );
+  QCOMPARE( qgis::down_cast<QgsAnnotationPolygonItem *>( layer->item( i1id ) )->geometry()->asWkt( 1 ), QStringLiteral( "Polygon ((0.9 1, 4.9 1, 4.9 5, 0.9 5, 0.9 1))" ) );
 
   // start a move then cancel it via right click
   utils.mouseMove( 1.6, 1.6 );
@@ -301,7 +300,7 @@ void TestQgsMapToolEditAnnotation::testMoveItem()
   utils.mouseMove( 4.5, 4.5 );
   utils.mouseClick( 4.5, 4.5, Qt::RightButton, Qt::KeyboardModifiers(), true );
   // check that item was NOT moved
-  QCOMPARE( qgis::down_cast< QgsAnnotationPolygonItem * >( layer->item( i1id ) )->geometry()->asWkt( 1 ), QStringLiteral( "Polygon ((0.9 1, 4.9 1, 4.9 5, 0.9 5, 0.9 1))" ) );
+  QCOMPARE( qgis::down_cast<QgsAnnotationPolygonItem *>( layer->item( i1id ) )->geometry()->asWkt( 1 ), QStringLiteral( "Polygon ((0.9 1, 4.9 1, 4.9 5, 0.9 5, 0.9 1))" ) );
 
   // cancel a move via escape key
   utils.mouseMove( 1.6, 1.6 );
@@ -314,7 +313,7 @@ void TestQgsMapToolEditAnnotation::testMoveItem()
   //... so next click is not "finish move", but "clear selection"
   utils.mouseClick( 4.5, 4.5, Qt::LeftButton, Qt::KeyboardModifiers(), true );
   // check that item was NOT moved
-  QCOMPARE( qgis::down_cast< QgsAnnotationPolygonItem * >( layer->item( i1id ) )->geometry()->asWkt( 1 ), QStringLiteral( "Polygon ((0.9 1, 4.9 1, 4.9 5, 0.9 5, 0.9 1))" ) );
+  QCOMPARE( qgis::down_cast<QgsAnnotationPolygonItem *>( layer->item( i1id ) )->geometry()->asWkt( 1 ), QStringLiteral( "Polygon ((0.9 1, 4.9 1, 4.9 5, 0.9 5, 0.9 1))" ) );
 }
 
 void TestQgsMapToolEditAnnotation::testMoveNode()
@@ -334,7 +333,7 @@ void TestQgsMapToolEditAnnotation::testMoveNode()
   QgsAnnotationPolygonItem *item1 = new QgsAnnotationPolygonItem( new QgsPolygon( new QgsLineString( QVector<QgsPoint> { QgsPoint( 1, 1 ), QgsPoint( 5, 1 ), QgsPoint( 5, 5 ), QgsPoint( 1, 5 ), QgsPoint( 1, 1 ) } ) ) );
   item1->setZIndex( 1 );
   const QString i1id = layer->addItem( item1 );
-  QCOMPARE( qgis::down_cast< QgsAnnotationPolygonItem * >( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((1 1, 5 1, 5 5, 1 5, 1 1))" ) );
+  QCOMPARE( qgis::down_cast<QgsAnnotationPolygonItem *>( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((1 1, 5 1, 5 5, 1 5, 1 1))" ) );
 
   layer->setCrs( QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ) );
 
@@ -376,7 +375,7 @@ void TestQgsMapToolEditAnnotation::testMoveNode()
   QCOMPARE( canvas.renderedItemResults()->renderedItems().size(), 1 );
 
   // check that item was moved
-  QCOMPARE( qgis::down_cast< QgsAnnotationPolygonItem * >( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((1 1, 5 1, 4.5 4.5, 1 5, 1 1))" ) );
+  QCOMPARE( qgis::down_cast<QgsAnnotationPolygonItem *>( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((1 1, 5 1, 4.5 4.5, 1 5, 1 1))" ) );
 
   // start a new move node
   // click on item -- it should already be selected, so this will start a new move, not emit the itemSelected signal
@@ -394,7 +393,7 @@ void TestQgsMapToolEditAnnotation::testMoveNode()
   QCOMPARE( canvas.renderedItemResults()->renderedItems().size(), 1 );
 
   // check that item was moved
-  QCOMPARE( qgis::down_cast< QgsAnnotationPolygonItem * >( layer->item( i1id ) )->geometry()->asWkt( 1 ), QStringLiteral( "Polygon ((1 1, 5.5 1.5, 4.5 4.5, 1 5, 1 1))" ) );
+  QCOMPARE( qgis::down_cast<QgsAnnotationPolygonItem *>( layer->item( i1id ) )->geometry()->asWkt( 1 ), QStringLiteral( "Polygon ((1 1, 5.5 1.5, 4.5 4.5, 1 5, 1 1))" ) );
 
   // start a move then cancel it via right click
   utils.mouseMove( 4.5, 4.5 );
@@ -404,7 +403,7 @@ void TestQgsMapToolEditAnnotation::testMoveNode()
   utils.mouseMove( 4.9, 4.9 );
   utils.mouseClick( 4.9, 4.9, Qt::RightButton, Qt::KeyboardModifiers(), true );
   // check that node was NOT moved
-  QCOMPARE( qgis::down_cast< QgsAnnotationPolygonItem * >( layer->item( i1id ) )->geometry()->asWkt( 1 ), QStringLiteral( "Polygon ((1 1, 5.5 1.5, 4.5 4.5, 1 5, 1 1))" ) );
+  QCOMPARE( qgis::down_cast<QgsAnnotationPolygonItem *>( layer->item( i1id ) )->geometry()->asWkt( 1 ), QStringLiteral( "Polygon ((1 1, 5.5 1.5, 4.5 4.5, 1 5, 1 1))" ) );
 
   // cancel a move via escape key
   utils.mouseMove( 4.5, 4.5 );
@@ -417,7 +416,7 @@ void TestQgsMapToolEditAnnotation::testMoveNode()
   //... so next click is not "finish move", but "clear selection"
   utils.mouseClick( 6.5, 6.5, Qt::LeftButton, Qt::KeyboardModifiers(), true );
   // check that node was NOT moved
-  QCOMPARE( qgis::down_cast< QgsAnnotationPolygonItem * >( layer->item( i1id ) )->geometry()->asWkt( 1 ), QStringLiteral( "Polygon ((1 1, 5.5 1.5, 4.5 4.5, 1 5, 1 1))" ) );
+  QCOMPARE( qgis::down_cast<QgsAnnotationPolygonItem *>( layer->item( i1id ) )->geometry()->asWkt( 1 ), QStringLiteral( "Polygon ((1 1, 5.5 1.5, 4.5 4.5, 1 5, 1 1))" ) );
 }
 
 void TestQgsMapToolEditAnnotation::testDeleteNode()
@@ -437,7 +436,7 @@ void TestQgsMapToolEditAnnotation::testDeleteNode()
   QgsAnnotationPolygonItem *item1 = new QgsAnnotationPolygonItem( new QgsPolygon( new QgsLineString( QVector<QgsPoint> { QgsPoint( 1, 1 ), QgsPoint( 5, 1 ), QgsPoint( 5, 5 ), QgsPoint( 1, 5 ), QgsPoint( 1, 1 ) } ) ) );
   item1->setZIndex( 1 );
   const QString i1id = layer->addItem( item1 );
-  QCOMPARE( qgis::down_cast< QgsAnnotationPolygonItem * >( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((1 1, 5 1, 5 5, 1 5, 1 1))" ) );
+  QCOMPARE( qgis::down_cast<QgsAnnotationPolygonItem *>( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((1 1, 5 1, 5 5, 1 5, 1 1))" ) );
 
   layer->setCrs( QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ) );
 
@@ -478,7 +477,7 @@ void TestQgsMapToolEditAnnotation::testDeleteNode()
   QCOMPARE( canvas.renderedItemResults()->renderedItems().size(), 1 );
 
   // check that node was deleted
-  QCOMPARE( qgis::down_cast< QgsAnnotationPolygonItem * >( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((1 1, 5 1, 1 5, 1 1))" ) );
+  QCOMPARE( qgis::down_cast<QgsAnnotationPolygonItem *>( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((1 1, 5 1, 1 5, 1 1))" ) );
 
   // start a new delete node
   // click on item -- it should already be selected, so this will start a new move, not emit the itemSelected signal
@@ -515,7 +514,7 @@ void TestQgsMapToolEditAnnotation::testAddNode()
   QgsAnnotationPolygonItem *item1 = new QgsAnnotationPolygonItem( new QgsPolygon( new QgsLineString( QVector<QgsPoint> { QgsPoint( 1, 1 ), QgsPoint( 5, 1 ), QgsPoint( 5, 5 ), QgsPoint( 1, 5 ), QgsPoint( 1, 1 ) } ) ) );
   item1->setZIndex( 1 );
   const QString i1id = layer->addItem( item1 );
-  QCOMPARE( qgis::down_cast< QgsAnnotationPolygonItem * >( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((1 1, 5 1, 5 5, 1 5, 1 1))" ) );
+  QCOMPARE( qgis::down_cast<QgsAnnotationPolygonItem *>( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((1 1, 5 1, 5 5, 1 5, 1 1))" ) );
 
   layer->setCrs( QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ) );
 
@@ -553,7 +552,7 @@ void TestQgsMapToolEditAnnotation::testAddNode()
   QCOMPARE( canvas.renderedItemResults()->renderedItems().size(), 1 );
 
   // check that node was added
-  QCOMPARE( qgis::down_cast< QgsAnnotationPolygonItem * >( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((1 1, 5 1, 5 3, 5 5, 1 5, 1 1))" ) );
+  QCOMPARE( qgis::down_cast<QgsAnnotationPolygonItem *>( layer->item( i1id ) )->geometry()->asWkt(), QStringLiteral( "Polygon ((1 1, 5 1, 5 3, 5 5, 1 5, 1 1))" ) );
 }
 
 
