@@ -16,6 +16,7 @@
 #include <QObject>
 #include <QString>
 #include <QStringList>
+#include <QMimeData>
 
 #include "qgspallabeling.h"
 #include "qgsfontutils.h"
@@ -43,6 +44,7 @@ class TestQgsPalLabeling : public QgsTest
 #if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
     void testPolygonWithEmptyRing();
 #endif
+    void testLabelSettingsToFromMime();
 };
 
 void TestQgsPalLabeling::cleanupTestCase()
@@ -315,5 +317,25 @@ void TestQgsPalLabeling::testPolygonWithEmptyRing()
 }
 #endif
 
+void TestQgsPalLabeling::testLabelSettingsToFromMime()
+{
+  QgsPalLayerSettings settings;
+
+  settings.fieldName = QStringLiteral( "'X'" );
+  settings.isExpression = true;
+  settings.placement = Qgis::LabelPlacement::OverPoint;
+
+  const QMimeData *md = settings.toMimeData();
+
+  bool ok = false;
+  QgsPalLayerSettings from_mime = QgsPalLayerSettings::fromMimeData( nullptr, &ok );
+  QVERIFY( !ok );
+  from_mime = QgsPalLayerSettings::fromMimeData( md, &ok );
+  QVERIFY( ok );
+  QCOMPARE( from_mime.fieldName, settings.fieldName );
+  QCOMPARE( from_mime.isExpression, settings.isExpression );
+  QCOMPARE( from_mime.placement, settings.placement );
+}
+
 QGSTEST_MAIN( TestQgsPalLabeling )
 #include "testqgspallabeling.moc"
