@@ -33,10 +33,10 @@ class TestQgsRasterIterator : public QObject
     TestQgsRasterIterator() = default;
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
-    void cleanupTestCase();// will be called after the last testfunction was executed.
-    void init() {} // will be called before each testfunction is executed.
-    void cleanup() {} // will be called after every testfunction.
+    void initTestCase();    // will be called before the first testfunction is executed.
+    void cleanupTestCase(); // will be called after the last testfunction was executed.
+    void init() {}          // will be called before each testfunction is executed.
+    void cleanup() {}       // will be called after every testfunction.
 
     void testBasic();
     void testNoBlock();
@@ -44,7 +44,6 @@ class TestQgsRasterIterator : public QObject
     void testPixelOverlap();
 
   private:
-
     QString mTestDataDir;
     QgsRasterLayer *mpRasterLayer = nullptr;
 };
@@ -94,7 +93,7 @@ void TestQgsRasterIterator::testBasic()
   int topLeftCol;
   int topLeftRow;
   QgsRectangle blockExtent;
-  std::unique_ptr< QgsRasterBlock > block;
+  std::unique_ptr<QgsRasterBlock> block;
 
   QVERIFY( it.readNextRasterPart( 1, nCols, nRows, block, topLeftCol, topLeftRow, &blockExtent ) );
   QCOMPARE( nCols, 3000 );
@@ -156,7 +155,7 @@ void TestQgsRasterIterator::testBasic()
   QCOMPARE( block->width(), 3000 );
   QCOMPARE( block->height(), 2500 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -171,7 +170,7 @@ void TestQgsRasterIterator::testBasic()
   QCOMPARE( block->width(), 3000 );
   QCOMPARE( block->height(), 2500 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -184,7 +183,7 @@ void TestQgsRasterIterator::testBasic()
   QCOMPARE( block->width(), 1200 );
   QCOMPARE( block->height(), 2500 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -199,7 +198,7 @@ void TestQgsRasterIterator::testBasic()
   QCOMPARE( block->width(), 3000 );
   QCOMPARE( block->height(), 450 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -212,7 +211,7 @@ void TestQgsRasterIterator::testBasic()
   QCOMPARE( block->width(), 3000 );
   QCOMPARE( block->height(), 450 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -227,7 +226,7 @@ void TestQgsRasterIterator::testBasic()
   QCOMPARE( block->width(), 1200 );
   QCOMPARE( block->height(), 450 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -298,7 +297,7 @@ void TestQgsRasterIterator::testNoBlock()
   QCOMPARE( topLeftCol, 0 );
   QCOMPARE( topLeftRow, 2500 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -308,7 +307,7 @@ void TestQgsRasterIterator::testNoBlock()
   QCOMPARE( topLeftCol, 3000 );
   QCOMPARE( topLeftRow, 2500 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -318,7 +317,7 @@ void TestQgsRasterIterator::testNoBlock()
   QCOMPARE( topLeftCol, 6000 );
   QCOMPARE( topLeftRow, 2500 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -328,7 +327,7 @@ void TestQgsRasterIterator::testNoBlock()
   QCOMPARE( topLeftCol, 0 );
   QCOMPARE( topLeftRow, 5000 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -338,7 +337,7 @@ void TestQgsRasterIterator::testNoBlock()
   QCOMPARE( topLeftCol, 3000 );
   QCOMPARE( topLeftRow, 5000 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -348,7 +347,7 @@ void TestQgsRasterIterator::testNoBlock()
   QCOMPARE( topLeftCol, 6000 );
   QCOMPARE( topLeftRow, 5000 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -371,9 +370,7 @@ void TestQgsRasterIterator::testSubRegion()
   int subRectTop = 0;
   int subRectLeft = 0;
   // sub region is whole of raster extent
-  QgsRectangle subRect = QgsRasterIterator::subRegion( provider->extent(), provider->xSize(), provider->ySize(),
-                         QgsRectangle( 497470, 7050585, 498190, 7051130 ),
-                         subRectWidth, subRectHeight, subRectLeft, subRectTop );
+  QgsRectangle subRect = QgsRasterIterator::subRegion( provider->extent(), provider->xSize(), provider->ySize(), QgsRectangle( 497470, 7050585, 498190, 7051130 ), subRectWidth, subRectHeight, subRectLeft, subRectTop );
   QCOMPARE( subRect.xMinimum(), 497470 );
   QCOMPARE( subRect.yMinimum(), 7050585 );
   QCOMPARE( subRect.xMaximum(), 498190 );
@@ -384,9 +381,7 @@ void TestQgsRasterIterator::testSubRegion()
   QCOMPARE( subRectTop, 0 );
 
   // sub region extends outside of raster extent, should be clipped back to raster extent
-  subRect = QgsRasterIterator::subRegion( provider->extent(), provider->xSize(), provider->ySize(),
-                                          QgsRectangle( 497370, 7050385, 498390, 7051330 ),
-                                          subRectWidth, subRectHeight, subRectLeft, subRectTop );
+  subRect = QgsRasterIterator::subRegion( provider->extent(), provider->xSize(), provider->ySize(), QgsRectangle( 497370, 7050385, 498390, 7051330 ), subRectWidth, subRectHeight, subRectLeft, subRectTop );
   QCOMPARE( subRect.xMinimum(), 497470 );
   QCOMPARE( subRect.yMinimum(), 7050585 );
   QCOMPARE( subRect.xMaximum(), 498190 );
@@ -397,9 +392,7 @@ void TestQgsRasterIterator::testSubRegion()
   QCOMPARE( subRectTop, 0 );
 
   // sub rect inside raster extent
-  subRect = QgsRasterIterator::subRegion( provider->extent(), provider->xSize(), provider->ySize(),
-                                          QgsRectangle( 497970.01, 7050985.05, 498030.95, 7051030.75 ),
-                                          subRectWidth, subRectHeight, subRectLeft, subRectTop );
+  subRect = QgsRasterIterator::subRegion( provider->extent(), provider->xSize(), provider->ySize(), QgsRectangle( 497970.01, 7050985.05, 498030.95, 7051030.75 ), subRectWidth, subRectHeight, subRectLeft, subRectTop );
   QCOMPARE( subRect.xMinimum(), 497970 );
   QCOMPARE( subRect.yMinimum(), 7050985.0 );
   QCOMPARE( subRect.xMaximum(), 498031 );
@@ -411,9 +404,7 @@ void TestQgsRasterIterator::testSubRegion()
   QCOMPARE( subRectTop, 992 );
 
   // sub rect JUST inside raster extent
-  subRect = QgsRasterIterator::subRegion( provider->extent(), provider->xSize(), provider->ySize(),
-                                          QgsRectangle( 497370.001, 7050385.001, 498389.99999, 7051329.9999 ),
-                                          subRectWidth, subRectHeight, subRectLeft, subRectTop );
+  subRect = QgsRasterIterator::subRegion( provider->extent(), provider->xSize(), provider->ySize(), QgsRectangle( 497370.001, 7050385.001, 498389.99999, 7051329.9999 ), subRectWidth, subRectHeight, subRectLeft, subRectTop );
   QCOMPARE( subRect.xMinimum(), 497470 );
   QCOMPARE( subRect.yMinimum(), 7050585 );
   QCOMPARE( subRect.xMaximum(), 498190 );
@@ -422,7 +413,6 @@ void TestQgsRasterIterator::testSubRegion()
   QCOMPARE( subRectHeight, 5450 );
   QCOMPARE( subRectLeft, 0 );
   QCOMPARE( subRectTop, 0 );
-
 }
 
 void TestQgsRasterIterator::testPixelOverlap()
@@ -451,7 +441,7 @@ void TestQgsRasterIterator::testPixelOverlap()
   int tileTopLeftRow;
 
   QgsRectangle blockExtent;
-  std::unique_ptr< QgsRasterBlock > block;
+  std::unique_ptr<QgsRasterBlock> block;
 
   QVERIFY( it.readNextRasterPart( 1, nCols, nRows, block, topLeftCol, topLeftRow, &blockExtent, &tileCols, &tileRows, &tileTopLeftCol, &tileTopLeftRow ) );
   QCOMPARE( nCols, 3020 );
@@ -529,7 +519,7 @@ void TestQgsRasterIterator::testPixelOverlap()
   QCOMPARE( block->width(), 3020 );
   QCOMPARE( block->height(), 2540 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -548,7 +538,7 @@ void TestQgsRasterIterator::testPixelOverlap()
   QCOMPARE( block->width(), 3040 );
   QCOMPARE( block->height(), 2540 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -565,7 +555,7 @@ void TestQgsRasterIterator::testPixelOverlap()
   QCOMPARE( block->width(), 1220 );
   QCOMPARE( block->height(), 2540 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -584,7 +574,7 @@ void TestQgsRasterIterator::testPixelOverlap()
   QCOMPARE( block->width(), 3020 );
   QCOMPARE( block->height(), 470 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -601,7 +591,7 @@ void TestQgsRasterIterator::testPixelOverlap()
   QCOMPARE( block->width(), 3040 );
   QCOMPARE( block->height(), 470 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
@@ -620,7 +610,7 @@ void TestQgsRasterIterator::testPixelOverlap()
   QCOMPARE( block->width(), 1220 );
   QCOMPARE( block->height(), 470 );
   QCOMPARE( blockExtent.xMinimum(), mpRasterLayer->extent().xMinimum() + topLeftCol * mpRasterLayer->rasterUnitsPerPixelX() );
-  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow )* mpRasterLayer->rasterUnitsPerPixelY() );
+  QCOMPARE( blockExtent.yMinimum(), mpRasterLayer->extent().yMaximum() - ( nRows + topLeftRow ) * mpRasterLayer->rasterUnitsPerPixelY() );
   QCOMPARE( blockExtent.width(), nCols * mpRasterLayer->rasterUnitsPerPixelX() );
   QCOMPARE( blockExtent.height(), nRows * mpRasterLayer->rasterUnitsPerPixelY() );
 
