@@ -31,11 +31,12 @@
 
 struct FilterExcludePoint : public QgsPointLocator::MatchFilter
 {
-  explicit FilterExcludePoint( const QgsPointXY &p ) : mPoint( p ) {}
+    explicit FilterExcludePoint( const QgsPointXY &p )
+      : mPoint( p ) {}
 
-  bool acceptMatch( const QgsPointLocator::Match &match ) override { return match.point() != mPoint; }
+    bool acceptMatch( const QgsPointLocator::Match &match ) override { return match.point() != mPoint; }
 
-  QgsPointXY mPoint;
+    QgsPointXY mPoint;
 };
 
 
@@ -83,7 +84,6 @@ class TestQgsSnappingUtils : public QObject
       mVL->dataProvider()->addFeatures( flist );
 
       QgsProject::instance()->addMapLayer( mVL );
-
     }
 
     void cleanupTestCase()
@@ -197,7 +197,7 @@ class TestQgsSnappingUtils : public QObject
       QCOMPARE( m5.point(), QgsPointXY( 0, 1 ) );
 
       //uncheck all and test that all nodes are unchecked
-      static_cast< QgsSymbolLegendNode * >( nodes.at( 0 ) )->uncheckAllItems();
+      static_cast<QgsSymbolLegendNode *>( nodes.at( 0 ) )->uncheckAllItems();
       for ( QgsLayerTreeModelLegendNode *ln : nodes )
       {
         QVERIFY( ln->data( Qt::CheckStateRole ) == Qt::Unchecked );
@@ -276,7 +276,7 @@ class TestQgsSnappingUtils : public QObject
       polyline1 << QgsPointXY( 0, 0 ) << QgsPointXY( 1, 1 );
       polyline2 << QgsPointXY( 1, 0 ) << QgsPointXY( 0, 1 );
       QgsFeature f1;
-      const QgsGeometry f1g = QgsGeometry::fromPolylineXY( polyline1 ) ;
+      const QgsGeometry f1g = QgsGeometry::fromPolylineXY( polyline1 );
       f1.setGeometry( f1g );
       QgsFeature f2;
       const QgsGeometry f2g = QgsGeometry::fromPolylineXY( polyline2 );
@@ -321,7 +321,7 @@ class TestQgsSnappingUtils : public QObject
       // testing with a layer with curve and Z
       std::unique_ptr<QgsVectorLayer> vCurveZ( new QgsVectorLayer( QStringLiteral( "CircularStringZ" ), QStringLiteral( "x" ), QStringLiteral( "memory" ) ) );
       QgsFeature f1;
-      const QgsGeometry f1g = QgsGeometry::fromWkt( "CircularStringZ (0 0 0, 5 5 5, 0 10 10)" ) ;
+      const QgsGeometry f1g = QgsGeometry::fromWkt( "CircularStringZ (0 0 0, 5 5 5, 0 10 10)" );
       f1.setGeometry( f1g );
       QgsFeature f2;
       const QgsGeometry f2g = QgsGeometry::fromWkt( "CircularStringZ (8 0 20, 5 3 30, 8 10 40)" );
@@ -371,7 +371,7 @@ class TestQgsSnappingUtils : public QObject
       f2.setGeometry( f2g );
 
       QgsFeatureList flist;
-      flist << f1 << f2 ;
+      flist << f1 << f2;
       vMulti->dataProvider()->addFeatures( flist );
 
       QVERIFY( vMulti->dataProvider()->featureCount() == 2 );
@@ -400,7 +400,6 @@ class TestQgsSnappingUtils : public QObject
       QVERIFY( m2.isValid() );
       QCOMPARE( m2.type(), QgsPointLocator::Vertex );
       QCOMPARE( m2.point(), QgsPointXY( 5.0, 2.5 ) );
-
     }
     void testSnapOnCentroidAndMiddleSegment()
     {
@@ -730,8 +729,8 @@ class TestQgsSnappingUtils : public QObject
       QVERIFY( m1.hasVertex() );
 
       snappingConfig.setScaleDependencyMode( QgsSnappingConfig::Global );
-      snappingConfig.setMinimumScale( 10000.0 );// 1/10000 scale
-      snappingConfig.setMaximumScale( 1000.0 );// 1/1000 scale
+      snappingConfig.setMinimumScale( 10000.0 ); // 1/10000 scale
+      snappingConfig.setMaximumScale( 1000.0 );  // 1/1000 scale
       u.setConfig( snappingConfig );
 
       //Global settings for scale limit, but scale outside min max range -> no snapping
@@ -822,6 +821,60 @@ class TestQgsSnappingUtils : public QObject
       QVERIFY( !m5.isValid() );
       QVERIFY( !m6.isValid() );
     }
+
+
+    void testLocatorsCleaning()
+    {
+      auto vl = std::make_unique<QgsVectorLayer>( QStringLiteral( "Polygon?field=fld:int" ), QStringLiteral( "x" ), QStringLiteral( "memory" ) );
+      const int idx = mVL->fields().indexFromName( QStringLiteral( "fld" ) );
+      QVERIFY( idx != -1 );
+      f1.initAttributes( 1 );
+      f2.initAttributes( 1 );
+
+      QgsPolygonXY polygon;
+      QgsPolylineXY polyline;
+      polyline << QgsPointXY( 0, 1 ) << QgsPointXY( 1, 0 ) << QgsPointXY( 1, 1 ) << QgsPointXY( 0, 1 );
+      polygon << polyline;
+      const QgsGeometry polygonGeom = QgsGeometry::fromPolygonXY( polygon );
+      f1.setGeometry( polygonGeom );
+      f1.setAttribute( idx, QVariant( 2 ) );
+      QgsFeatureList flist;
+      flist << f1;
+
+      vl->dataProvider()->addFeatures( flist );
+
+      QgsMapSettings mapSettings;
+      mapSettings.setOutputSize( QSize( 100, 100 ) );
+      mapSettings.setExtent( QgsRectangle( 0, 0, 1, 1 ) );
+      QVERIFY( mapSettings.hasValidSettings() );
+
+      QgsSnappingUtils u;
+      u.setMapSettings( mapSettings );
+      u.setCurrentLayer( vl.get() );
+
+      // first try with no snapping enabled
+      QgsSnappingConfig snappingConfig = u.config();
+      snappingConfig.setEnabled( false );
+      snappingConfig.setTolerance( 10 );
+      snappingConfig.setUnits( Qgis::MapToolUnit::Pixels );
+      snappingConfig.setMode( Qgis::SnappingMode::ActiveLayer );
+      snappingConfig.setEnabled( true );
+      snappingConfig.setTypeFlag( Qgis::SnappingType::Vertex );
+      u.setConfig( snappingConfig );
+
+      QCOMPARE( u.mLocators.count(), 0 );
+
+      const QgsPointLocator::Match m = u.snapToMap( QPoint( 100, 100 ) );
+      QVERIFY( m.isValid() );
+      QVERIFY( m.hasVertex() );
+      QCOMPARE( m.point(), QgsPointXY( 1, 0 ) );
+
+      QCOMPARE( u.mLocators.count(), 1 );
+
+      vl.reset();
+
+      QCOMPARE( u.mLocators.count(), 0 );
+    }
 };
 
 QGSTEST_MAIN( TestQgsSnappingUtils )
