@@ -23,12 +23,12 @@ import unittest
 from qgis.testing import start_app, QgisTestCase
 
 AUTHDBDIR = tempfile.mkdtemp()
-os.environ['QGIS_AUTH_DB_DIR_PATH'] = AUTHDBDIR
+os.environ["QGIS_AUTH_DB_DIR_PATH"] = AUTHDBDIR
 
 
-__author__ = 'Alessandro Pasotti'
-__date__ = '13/10/2020'
-__copyright__ = 'Copyright 2020, The QGIS Project'
+__author__ = "Alessandro Pasotti"
+__date__ = "13/10/2020"
+__copyright__ = "Copyright 2020, The QGIS Project"
 
 qgis_app = start_app()
 
@@ -38,13 +38,13 @@ class TestAuthManager(QgisTestCase):
     @classmethod
     def setUpAuth(cls, username, password):
         """Run before all tests and set up authentication"""
-        assert (cls.authm.setMasterPassword('masterpassword', True))
+        assert cls.authm.setMasterPassword("masterpassword", True)
         # Client side
         auth_config = QgsAuthMethodConfig("Basic")
-        auth_config.setConfig('username', username)
-        auth_config.setConfig('password', password)
-        auth_config.setName('test_basic_auth_config')
-        assert (cls.authm.storeAuthenticationConfig(auth_config)[0])
+        auth_config.setConfig("username", username)
+        auth_config.setConfig("password", password)
+        auth_config.setName("test_basic_auth_config")
+        assert cls.authm.storeAuthenticationConfig(auth_config)[0]
         assert auth_config.isValid()
         return auth_config
 
@@ -55,12 +55,11 @@ class TestAuthManager(QgisTestCase):
         cls.authm = QgsApplication.authManager()
         assert not cls.authm.isDisabled(), cls.authm.disabledMessage()
 
-        cls.mpass = 'pass'  # master password
+        cls.mpass = "pass"  # master password
 
-        db1 = QFileInfo(cls.authm.authenticationDatabasePath()
-                        ).canonicalFilePath()
-        db2 = QFileInfo(AUTHDBDIR + '/qgis-auth.db').canonicalFilePath()
-        msg = 'Auth db temp path does not match db path of manager'
+        db1 = QFileInfo(cls.authm.authenticationDatabasePath()).canonicalFilePath()
+        db2 = QFileInfo(AUTHDBDIR + "/qgis-auth.db").canonicalFilePath()
+        msg = "Auth db temp path does not match db path of manager"
         assert db1 == db2, msg
 
     def setUp(self):
@@ -75,24 +74,24 @@ class TestAuthManager(QgisTestCase):
         """Extracts and decode credentials from request Authorization header"""
 
         ac = self.setUpAuth(username, password)
-        req = QNetworkRequest(QUrl('http://none'))
+        req = QNetworkRequest(QUrl("http://none"))
         self.authm.updateNetworkRequest(req, ac.id())
-        auth = bytes(req.rawHeader(b'Authorization'))[6:]
+        auth = bytes(req.rawHeader(b"Authorization"))[6:]
         # Note that RFC7617 states clearly: User-ids containing colons cannot be encoded in user-pass strings
-        u, p = base64.b64decode(auth).split(b':')
-        return u.decode('utf8'), p.decode('utf8')
+        u, p = base64.b64decode(auth).split(b":")
+        return u.decode("utf8"), p.decode("utf8")
 
     def testHeaderEncoding(self):
         """Test credentials encoding"""
 
         for creds in (
-            ('username', 'password'),
-            ('username', r'pa%%word'),
-            ('username', r'èé'),
-            ('username', r'😁😂😍'),
+            ("username", "password"),
+            ("username", r"pa%%word"),
+            ("username", r"èé"),
+            ("username", r"😁😂😍"),
         ):
             self.assertEqual(self._get_decoded_credentials(*creds), creds)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
