@@ -5,11 +5,11 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = 'Nyall Dawson'
-__date__ = '08/11/2021'
-__copyright__ = 'Copyright 2021, The QGIS Project'
 
-import qgis  # NOQA
+__author__ = "Nyall Dawson"
+__date__ = "08/11/2021"
+__copyright__ = "Copyright 2021, The QGIS Project"
+
 
 from qgis.analysis import QgsGraph
 from qgis.core import QgsPointXY
@@ -241,7 +241,9 @@ class TestQgsGraph(QgisTestCase):
         self.assertEqual(graph.vertex(v1).incomingEdges(), [edge_2])
         self.assertFalse(graph.vertex(v1).outgoingEdges())
         self.assertFalse(graph.vertex(v2).incomingEdges())
-        self.assertCountEqual(graph.vertex(v2).outgoingEdges(), [edge_2, edge_3, edge_4])
+        self.assertCountEqual(
+            graph.vertex(v2).outgoingEdges(), [edge_2, edge_3, edge_4]
+        )
 
         with self.assertRaises(IndexError):
             graph.removeEdge(edge_1)
@@ -328,5 +330,5 @@ class TestQgsGraph(QgisTestCase):
         self.assertEqual(graph.findOppositeEdge(edge_5), -1)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
