@@ -5,6 +5,7 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
+
 __author__ = "Matthias Kuhn"
 __date__ = "8.11.2017"
 __copyright__ = "Copyright 2017, The QGIS Project"
@@ -13,7 +14,6 @@ import os
 import unittest
 from typing import Optional
 
-import qgis  # NOQA
 from qgis.PyQt.QtCore import QSize, Qt
 from qgis.PyQt.QtGui import QColor, QImage, QPainter
 from qgis.core import (
@@ -75,7 +75,7 @@ class TestQgsHighlight(QgisTestCase):
             highlight.setColor(highlight_color)
             highlight.setFillColor(highlight_color)
         else:
-            color = QColor(Qt.red)
+            color = QColor(Qt.GlobalColor.red)
             highlight.setColor(color)
             color.setAlpha(50)
             highlight.setFillColor(color)
@@ -83,8 +83,8 @@ class TestQgsHighlight(QgisTestCase):
         highlight.setWidth(2)
         highlight.show()
 
-        image = QImage(QSize(400, 400), QImage.Format_ARGB32)
-        image.fill(Qt.white)
+        image = QImage(QSize(400, 400), QImage.Format.Format_ARGB32)
+        image.fill(Qt.GlobalColor.white)
         painter = QPainter()
         painter.begin(image)
         canvas.render(painter)
@@ -117,9 +117,7 @@ class TestQgsHighlight(QgisTestCase):
         symbol.setOpacity(0.3)
         layer.setRenderer(QgsSingleSymbolRenderer(symbol))
         self.assertTrue(layer.isValid())
-        self.assertTrue(
-            self.run_test_for_layer(layer, "polygons", use_feature=False)
-        )
+        self.assertTrue(self.run_test_for_layer(layer, "polygons", use_feature=False))
         self.assertTrue(
             self.run_test_for_layer(
                 layer,
@@ -179,7 +177,7 @@ class TestQgsHighlight(QgisTestCase):
         buffer_layer = QgsGeometryGeneratorSymbolLayer.create(
             {"geometryModifier": "buffer($geometry, -0.4)"}
         )
-        buffer_layer.setSymbolType(QgsSymbol.Fill)
+        buffer_layer.setSymbolType(QgsSymbol.SymbolType.Fill)
         buffer_layer.setSubSymbol(sub_symbol)
         sym.changeSymbolLayer(0, buffer_layer)
         layer.setRenderer(QgsSingleSymbolRenderer(sym))
@@ -204,7 +202,7 @@ class TestQgsHighlight(QgisTestCase):
         self.assertTrue(feature.isValid())
 
         highlight = QgsHighlight(canvas, feature, layer)
-        color = QColor(Qt.red)
+        color = QColor(Qt.GlobalColor.red)
         highlight.setColor(color)
         color.setAlpha(50)
         highlight.setFillColor(color)
@@ -218,7 +216,7 @@ class TestQgsHighlight(QgisTestCase):
         )
 
     def canvas_image_check(self, name, reference_image, canvas):
-        image = QImage(canvas.size(), QImage.Format_ARGB32)
+        image = QImage(canvas.size(), QImage.Format.Format_ARGB32)
         painter = QPainter(image)
         canvas.render(painter)
         painter.end()
