@@ -5,18 +5,13 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = 'Nyall Dawson'
-__date__ = '18/10/2016'
-__copyright__ = 'Copyright 2016, The QGIS Project'
 
-import qgis  # NOQA switch sip api
+__author__ = "Nyall Dawson"
+__date__ = "18/10/2016"
+__copyright__ = "Copyright 2016, The QGIS Project"
+
 from qgis.PyQt import sip
-from qgis.PyQt.QtCore import (
-    QDate,
-    QDateTime,
-    QTime,
-    QModelIndex
-)
+from qgis.PyQt.QtCore import QDate, QDateTime, QTime, QModelIndex
 from qgis.PyQt.QtTest import QSignalSpy
 
 from qgis.core import Qgis
@@ -27,7 +22,7 @@ from qgis.gui import (
     QgsGui,
     QgsHistoryEntryNode,
     QgsHistoryEntryGroup,
-    QgsHistoryEntryModel
+    QgsHistoryEntryModel,
 )
 import unittest
 from qgis.testing import start_app, QgisTestCase
@@ -48,7 +43,7 @@ class TestEntryNode(QgsHistoryEntryGroup):
 class TestHistoryProvider(QgsAbstractHistoryProvider):
 
     def id(self) -> str:
-        return 'test_provider'
+        return "test_provider"
 
     def createNodeForEntry(self, entry, context):
         return TestEntryNode(entry.entry)
@@ -56,28 +51,28 @@ class TestHistoryProvider(QgsAbstractHistoryProvider):
     def updateNodeForEntry(self, node, entry, context):
         node.val = entry.entry
 
-        new_child_node = TestEntryNode('my child')
+        new_child_node = TestEntryNode("my child")
         node.addChild(new_child_node)
-        new_child_node = TestEntryNode('my child 2')
+        new_child_node = TestEntryNode("my child 2")
         node.addChild(new_child_node)
 
 
 class TestHistoryProvider2(QgsAbstractHistoryProvider):
 
     def id(self) -> str:
-        return 'test_provider2'
+        return "test_provider2"
 
 
 class TestNode(QgsHistoryEntryNode):
 
     def data(self, role):
-        return 'test'
+        return "test"
 
 
 class TestGroup(QgsHistoryEntryGroup):
 
     def data(self, role):
-        return 'test'
+        return "test"
 
 
 class TestQgsHistoryProviderRegistry(QgisTestCase):
@@ -95,24 +90,25 @@ class TestQgsHistoryProviderRegistry(QgisTestCase):
         entry = QgsHistoryEntry()
         self.assertFalse(entry.isValid())
 
-        entry = QgsHistoryEntry('my provider', QDateTime(2021, 1, 2, 3, 4, 5),
-                                {'somevar': 5})
+        entry = QgsHistoryEntry(
+            "my provider", QDateTime(2021, 1, 2, 3, 4, 5), {"somevar": 5}
+        )
         self.assertTrue(entry.isValid())
 
-        self.assertEqual(entry.providerId, 'my provider')
+        self.assertEqual(entry.providerId, "my provider")
         self.assertEqual(entry.timestamp, QDateTime(2021, 1, 2, 3, 4, 5))
-        self.assertEqual(entry.entry, {'somevar': 5})
+        self.assertEqual(entry.entry, {"somevar": 5})
 
-        self.assertEqual(str(entry),
-                         '<QgsHistoryEntry: my provider 2021-01-02T03:04:05>')
+        self.assertEqual(
+            str(entry), "<QgsHistoryEntry: my provider 2021-01-02T03:04:05>"
+        )
 
-        entry = QgsHistoryEntry({'somevar': 7})
+        entry = QgsHistoryEntry({"somevar": 7})
         self.assertTrue(entry.isValid())
 
         self.assertFalse(entry.providerId)
-        self.assertEqual(entry.timestamp.date(),
-                         QDateTime.currentDateTime().date())
-        self.assertEqual(entry.entry, {'somevar': 7})
+        self.assertEqual(entry.timestamp.date(), QDateTime.currentDateTime().date())
+        self.assertEqual(entry.entry, {"somevar": 7})
 
     def test_registry_providers(self):
         """
@@ -124,21 +120,20 @@ class TestQgsHistoryProviderRegistry(QgisTestCase):
         provider1 = TestHistoryProvider()
         provider2 = TestHistoryProvider2()
         self.assertTrue(reg.addProvider(provider1))
-        self.assertEqual(reg.providerIds(), ['test_provider'])
+        self.assertEqual(reg.providerIds(), ["test_provider"])
 
         # already registered
         self.assertFalse(reg.addProvider(provider1))
 
         self.assertTrue(reg.addProvider(provider2))
-        self.assertCountEqual(reg.providerIds(),
-                              ['test_provider', 'test_provider2'])
+        self.assertCountEqual(reg.providerIds(), ["test_provider", "test_provider2"])
 
-        self.assertFalse(reg.removeProvider('x'))
-        self.assertTrue(reg.removeProvider('test_provider'))
+        self.assertFalse(reg.removeProvider("x"))
+        self.assertTrue(reg.removeProvider("test_provider"))
 
         self.assertTrue(sip.isdeleted(provider1))
 
-        self.assertEqual(reg.providerIds(), ['test_provider2'])
+        self.assertEqual(reg.providerIds(), ["test_provider2"])
 
     def test_registry_entries(self):
         """
@@ -150,169 +145,189 @@ class TestQgsHistoryProviderRegistry(QgisTestCase):
         added_spy = QSignalSpy(reg.entryAdded)
         updated_spy = QSignalSpy(reg.entryUpdated)
 
-        id_1, ok = reg.addEntry('my provider',
-                                {'some var': 5, 'other_var': [1, 2, 3],
-                                 'final_var': {'a': 'b'}},
-                                QgsHistoryProviderRegistry.HistoryEntryOptions())
+        id_1, ok = reg.addEntry(
+            "my provider",
+            {"some var": 5, "other_var": [1, 2, 3], "final_var": {"a": "b"}},
+            QgsHistoryProviderRegistry.HistoryEntryOptions(),
+        )
         self.assertTrue(ok)
 
         self.assertEqual(len(added_spy), 1)
         self.assertEqual(added_spy[-1][0], id_1)
-        self.assertEqual(added_spy[-1][1].providerId, 'my provider')
+        self.assertEqual(added_spy[-1][1].providerId, "my provider")
         self.assertEqual(added_spy[-1][1].id, id_1)
-        self.assertEqual(added_spy[-1][1].entry,
-                         {'some var': 5, 'other_var': [1, 2, 3],
-                          'final_var': {'a': 'b'}})
+        self.assertEqual(
+            added_spy[-1][1].entry,
+            {"some var": 5, "other_var": [1, 2, 3], "final_var": {"a": "b"}},
+        )
 
-        id_2, ok = reg.addEntry('my provider 2', {'some var': 6},
-                                QgsHistoryProviderRegistry.HistoryEntryOptions())
+        id_2, ok = reg.addEntry(
+            "my provider 2",
+            {"some var": 6},
+            QgsHistoryProviderRegistry.HistoryEntryOptions(),
+        )
         self.assertTrue(ok)
         self.assertEqual(len(added_spy), 2)
         self.assertEqual(added_spy[-1][0], id_2)
-        self.assertEqual(added_spy[-1][1].providerId, 'my provider 2')
+        self.assertEqual(added_spy[-1][1].providerId, "my provider 2")
         self.assertEqual(added_spy[-1][1].id, id_2)
-        self.assertEqual(added_spy[-1][1].entry, {'some var': 6})
+        self.assertEqual(added_spy[-1][1].entry, {"some var": 6})
 
         self.assertEqual(len(reg.queryEntries()), 2)
-        self.assertEqual(reg.queryEntries()[0].providerId, 'my provider')
+        self.assertEqual(reg.queryEntries()[0].providerId, "my provider")
         self.assertEqual(reg.queryEntries()[0].id, id_1)
-        self.assertEqual(reg.queryEntries()[0].timestamp.date(),
-                         QDateTime.currentDateTime().date())
-        self.assertEqual(reg.queryEntries()[0].entry,
-                         {'some var': 5, 'other_var': [1, 2, 3],
-                          'final_var': {'a': 'b'}})
+        self.assertEqual(
+            reg.queryEntries()[0].timestamp.date(), QDateTime.currentDateTime().date()
+        )
+        self.assertEqual(
+            reg.queryEntries()[0].entry,
+            {"some var": 5, "other_var": [1, 2, 3], "final_var": {"a": "b"}},
+        )
 
-        self.assertEqual(reg.queryEntries()[1].providerId, 'my provider 2')
+        self.assertEqual(reg.queryEntries()[1].providerId, "my provider 2")
         self.assertEqual(reg.queryEntries()[1].id, id_2)
-        self.assertEqual(reg.queryEntries()[1].timestamp.date(),
-                         QDateTime.currentDateTime().date())
-        self.assertEqual(reg.queryEntries()[1].entry, {'some var': 6})
+        self.assertEqual(
+            reg.queryEntries()[1].timestamp.date(), QDateTime.currentDateTime().date()
+        )
+        self.assertEqual(reg.queryEntries()[1].entry, {"some var": 6})
 
         entry, ok = reg.entry(1111)
         self.assertFalse(ok)
         entry, ok = reg.entry(id_1)
         self.assertTrue(ok)
-        self.assertEqual(entry.providerId, 'my provider')
+        self.assertEqual(entry.providerId, "my provider")
         self.assertEqual(entry.id, id_1)
-        self.assertEqual(entry.timestamp.date(),
-                         QDateTime.currentDateTime().date())
-        self.assertEqual(entry.entry, {'some var': 5, 'other_var': [1, 2, 3],
-                                       'final_var': {'a': 'b'}})
+        self.assertEqual(entry.timestamp.date(), QDateTime.currentDateTime().date())
+        self.assertEqual(
+            entry.entry,
+            {"some var": 5, "other_var": [1, 2, 3], "final_var": {"a": "b"}},
+        )
         entry, ok = reg.entry(id_2)
         self.assertTrue(ok)
-        self.assertEqual(entry.providerId, 'my provider 2')
+        self.assertEqual(entry.providerId, "my provider 2")
         self.assertEqual(entry.id, id_2)
-        self.assertEqual(entry.timestamp.date(),
-                         QDateTime.currentDateTime().date())
-        self.assertEqual(entry.entry, {'some var': 6})
+        self.assertEqual(entry.timestamp.date(), QDateTime.currentDateTime().date())
+        self.assertEqual(entry.entry, {"some var": 6})
 
-        entry = QgsHistoryEntry('my provider 3',
-                                QDateTime(2021, 1, 2, 3, 4, 5), {'var': 7})
+        entry = QgsHistoryEntry(
+            "my provider 3", QDateTime(2021, 1, 2, 3, 4, 5), {"var": 7}
+        )
         id_3, ok = reg.addEntry(entry)
         self.assertTrue(ok)
         self.assertEqual(len(added_spy), 3)
         self.assertEqual(added_spy[-1][0], id_3)
-        self.assertEqual(added_spy[-1][1].providerId, 'my provider 3')
+        self.assertEqual(added_spy[-1][1].providerId, "my provider 3")
         self.assertEqual(added_spy[-1][1].id, id_3)
-        self.assertEqual(added_spy[-1][1].entry, {'var': 7})
+        self.assertEqual(added_spy[-1][1].entry, {"var": 7})
 
         self.assertEqual(len(reg.queryEntries()), 3)
-        self.assertEqual(reg.queryEntries()[0].providerId, 'my provider')
+        self.assertEqual(reg.queryEntries()[0].providerId, "my provider")
         self.assertEqual(reg.queryEntries()[0].id, id_1)
-        self.assertEqual(reg.queryEntries()[0].timestamp.date(),
-                         QDateTime.currentDateTime().date())
-        self.assertEqual(reg.queryEntries()[0].entry,
-                         {'some var': 5, 'other_var': [1, 2, 3],
-                          'final_var': {'a': 'b'}})
-        self.assertEqual(reg.queryEntries()[1].providerId, 'my provider 2')
+        self.assertEqual(
+            reg.queryEntries()[0].timestamp.date(), QDateTime.currentDateTime().date()
+        )
+        self.assertEqual(
+            reg.queryEntries()[0].entry,
+            {"some var": 5, "other_var": [1, 2, 3], "final_var": {"a": "b"}},
+        )
+        self.assertEqual(reg.queryEntries()[1].providerId, "my provider 2")
         self.assertEqual(reg.queryEntries()[1].id, id_2)
-        self.assertEqual(reg.queryEntries()[1].timestamp.date(),
-                         QDateTime.currentDateTime().date())
-        self.assertEqual(reg.queryEntries()[1].entry, {'some var': 6})
-        self.assertEqual(reg.queryEntries()[2].providerId, 'my provider 3')
+        self.assertEqual(
+            reg.queryEntries()[1].timestamp.date(), QDateTime.currentDateTime().date()
+        )
+        self.assertEqual(reg.queryEntries()[1].entry, {"some var": 6})
+        self.assertEqual(reg.queryEntries()[2].providerId, "my provider 3")
         self.assertEqual(reg.queryEntries()[2].id, id_3)
-        self.assertEqual(reg.queryEntries()[2].timestamp.date(),
-                         QDate(2021, 1, 2))
-        self.assertEqual(reg.queryEntries()[2].entry, {'var': 7})
+        self.assertEqual(reg.queryEntries()[2].timestamp.date(), QDate(2021, 1, 2))
+        self.assertEqual(reg.queryEntries()[2].entry, {"var": 7})
 
         # query by provider
-        entries = reg.queryEntries(providerId='my provider')
+        entries = reg.queryEntries(providerId="my provider")
         self.assertEqual(len(entries), 1)
-        self.assertEqual(entries[0].providerId, 'my provider')
+        self.assertEqual(entries[0].providerId, "my provider")
         self.assertEqual(entries[0].id, id_1)
-        self.assertEqual(entries[0].timestamp.date(),
-                         QDateTime.currentDateTime().date())
-        self.assertEqual(entries[0].entry,
-                         {'some var': 5, 'other_var': [1, 2, 3],
-                          'final_var': {'a': 'b'}})
+        self.assertEqual(
+            entries[0].timestamp.date(), QDateTime.currentDateTime().date()
+        )
+        self.assertEqual(
+            entries[0].entry,
+            {"some var": 5, "other_var": [1, 2, 3], "final_var": {"a": "b"}},
+        )
 
-        entries = reg.queryEntries(providerId='my provider 2')
+        entries = reg.queryEntries(providerId="my provider 2")
         self.assertEqual(len(entries), 1)
-        self.assertEqual(entries[0].providerId, 'my provider 2')
+        self.assertEqual(entries[0].providerId, "my provider 2")
         self.assertEqual(entries[0].id, id_2)
-        self.assertEqual(entries[0].timestamp.date(),
-                         QDateTime.currentDateTime().date())
-        self.assertEqual(entries[0].entry, {'some var': 6})
+        self.assertEqual(
+            entries[0].timestamp.date(), QDateTime.currentDateTime().date()
+        )
+        self.assertEqual(entries[0].entry, {"some var": 6})
 
         # query by date
-        entries = reg.queryEntries(start=QDateTime(3022, 1, 2, 3, 4,
-                                                   5))  # this test will break in 3022, sorry
+        entries = reg.queryEntries(
+            start=QDateTime(3022, 1, 2, 3, 4, 5)
+        )  # this test will break in 3022, sorry
         self.assertEqual(len(entries), 0)
         entries = reg.queryEntries(end=QDateTime(2020, 1, 2, 3, 4, 5))
         self.assertEqual(len(entries), 0)
 
         entries = reg.queryEntries(start=QDateTime(2021, 3, 2, 3, 4, 5))
         self.assertEqual(len(entries), 2)
-        self.assertCountEqual([e.providerId for e in entries],
-                              ['my provider', 'my provider 2'])
+        self.assertCountEqual(
+            [e.providerId for e in entries], ["my provider", "my provider 2"]
+        )
         entries = reg.queryEntries(end=QDateTime(2021, 3, 2, 3, 4, 5))
         self.assertEqual(len(entries), 1)
-        self.assertEqual(entries[0].providerId, 'my provider 3')
+        self.assertEqual(entries[0].providerId, "my provider 3")
 
         # update an entry
-        self.assertTrue(reg.updateEntry(id_1, {'new_props': 54}))
+        self.assertTrue(reg.updateEntry(id_1, {"new_props": 54}))
         self.assertEqual(len(updated_spy), 1)
         self.assertEqual(updated_spy[-1][0], id_1)
-        self.assertEqual(updated_spy[-1][1], {'new_props': 54})
+        self.assertEqual(updated_spy[-1][1], {"new_props": 54})
 
         entry, ok = reg.entry(id_1)
-        self.assertEqual(entry.providerId, 'my provider')
+        self.assertEqual(entry.providerId, "my provider")
         self.assertEqual(entry.id, id_1)
-        self.assertEqual(entry.timestamp.date(),
-                         QDateTime.currentDateTime().date())
-        self.assertEqual(entry.entry, {'new_props': 54})
+        self.assertEqual(entry.timestamp.date(), QDateTime.currentDateTime().date())
+        self.assertEqual(entry.entry, {"new_props": 54})
 
         clear_spy = QSignalSpy(reg.historyCleared)
-        self.assertTrue(
-            reg.clearHistory(Qgis.HistoryProviderBackend.LocalProfile))
+        self.assertTrue(reg.clearHistory(Qgis.HistoryProviderBackend.LocalProfile))
         self.assertEqual(len(clear_spy), 1)
 
         self.assertFalse(reg.queryEntries())
 
         # bulk add entries
-        self.assertTrue(reg.addEntries([
-            QgsHistoryEntry('my provider 4', QDateTime(2021, 1, 2, 3, 4, 5),
-                            {'var': 7}),
-            QgsHistoryEntry('my provider 5', QDateTime(2021, 1, 2, 3, 4, 5),
-                            {'var': 8})
-        ]))
+        self.assertTrue(
+            reg.addEntries(
+                [
+                    QgsHistoryEntry(
+                        "my provider 4", QDateTime(2021, 1, 2, 3, 4, 5), {"var": 7}
+                    ),
+                    QgsHistoryEntry(
+                        "my provider 5", QDateTime(2021, 1, 2, 3, 4, 5), {"var": 8}
+                    ),
+                ]
+            )
+        )
         self.assertEqual(len(reg.queryEntries()), 2)
 
         self.assertEqual(len(added_spy), 5)
-        self.assertEqual(added_spy[-2][1].providerId, 'my provider 4')
+        self.assertEqual(added_spy[-2][1].providerId, "my provider 4")
         self.assertEqual(added_spy[-2][1].id, 1)
-        self.assertEqual(added_spy[-2][1].entry, {'var': 7})
-        self.assertEqual(added_spy[-1][1].providerId, 'my provider 5')
+        self.assertEqual(added_spy[-2][1].entry, {"var": 7})
+        self.assertEqual(added_spy[-1][1].providerId, "my provider 5")
         self.assertEqual(added_spy[-1][1].id, 2)
-        self.assertEqual(added_spy[-1][1].entry, {'var': 8})
+        self.assertEqual(added_spy[-1][1].entry, {"var": 8})
 
-        self.assertEqual(reg.queryEntries()[0].providerId, 'my provider 4')
+        self.assertEqual(reg.queryEntries()[0].providerId, "my provider 4")
         self.assertEqual(reg.queryEntries()[0].id, 1)
-        self.assertEqual(reg.queryEntries()[0].entry, {'var': 7})
+        self.assertEqual(reg.queryEntries()[0].entry, {"var": 7})
 
-        self.assertEqual(reg.queryEntries()[1].providerId, 'my provider 5')
+        self.assertEqual(reg.queryEntries()[1].providerId, "my provider 5")
         self.assertEqual(reg.queryEntries()[1].id, 2)
-        self.assertEqual(reg.queryEntries()[1].entry, {'var': 8})
+        self.assertEqual(reg.queryEntries()[1].entry, {"var": 8})
 
     def test_nodes(self):
         node = TestNode()
@@ -389,109 +404,113 @@ class TestQgsHistoryProviderRegistry(QgisTestCase):
         registry = QgsHistoryProviderRegistry()
         provider = TestHistoryProvider()
         registry.addProvider(provider)
-        registry.addEntry(provider.id(), {'a': 1})
-        registry.addEntry(provider.id(), {'a': 2})
-        registry.addEntry(provider.id(), {'a': 3})
+        registry.addEntry(provider.id(), {"a": 1})
+        registry.addEntry(provider.id(), {"a": 2})
+        registry.addEntry(provider.id(), {"a": 3})
 
         model = QgsHistoryEntryModel(provider.id(), registry=registry)
         # find Today group
         self.assertEqual(model.rowCount(), 1)
         date_group_1_index = model.index(0, 0, QModelIndex())
-        self.assertEqual(model.data(date_group_1_index), 'Today')
+        self.assertEqual(model.data(date_group_1_index), "Today")
 
         self.assertEqual(model.rowCount(date_group_1_index), 3)
         entry_1_index = model.index(2, 0, date_group_1_index)
-        self.assertEqual(model.data(entry_1_index), {'a': 1})
+        self.assertEqual(model.data(entry_1_index), {"a": 1})
         entry_2_index = model.index(1, 0, date_group_1_index)
-        self.assertEqual(model.data(entry_2_index), {'a': 2})
+        self.assertEqual(model.data(entry_2_index), {"a": 2})
         entry_3_index = model.index(0, 0, date_group_1_index)
-        self.assertEqual(model.data(entry_3_index), {'a': 3})
+        self.assertEqual(model.data(entry_3_index), {"a": 3})
 
         # an entry from yesterday
         yesterday = QDateTime.currentDateTime().addDays(-1)
-        yesterday_entry = QgsHistoryEntry(provider.id(), yesterday, {'a': 4})
+        yesterday_entry = QgsHistoryEntry(provider.id(), yesterday, {"a": 4})
         registry.addEntry(yesterday_entry)
 
         self.assertEqual(model.rowCount(), 2)
         yesterday_index = model.index(1, 0, QModelIndex())
-        self.assertEqual(model.data(yesterday_index), 'Yesterday')
+        self.assertEqual(model.data(yesterday_index), "Yesterday")
 
         self.assertEqual(model.rowCount(yesterday_index), 1)
         entry_4_index = model.index(0, 0, yesterday_index)
-        self.assertEqual(model.data(entry_4_index), {'a': 4})
+        self.assertEqual(model.data(entry_4_index), {"a": 4})
 
         # another entry from yesterday
-        yesterday_entry2 = QgsHistoryEntry(provider.id(), yesterday, {'a': 5})
+        yesterday_entry2 = QgsHistoryEntry(provider.id(), yesterday, {"a": 5})
         registry.addEntry(yesterday_entry2)
 
-        self.assertEqual(model.data(yesterday_index), 'Yesterday')
+        self.assertEqual(model.data(yesterday_index), "Yesterday")
 
         self.assertEqual(model.rowCount(yesterday_index), 2)
-        self.assertEqual(model.data(entry_4_index), {'a': 4})
+        self.assertEqual(model.data(entry_4_index), {"a": 4})
         entry_5_index = model.index(0, 0, yesterday_index)
-        self.assertEqual(model.data(entry_5_index), {'a': 5})
-        self.assertEqual(model.data(entry_4_index), {'a': 4})
+        self.assertEqual(model.data(entry_5_index), {"a": 5})
+        self.assertEqual(model.data(entry_4_index), {"a": 4})
 
         # an entry from an earlier month
-        earlier_entry = QgsHistoryEntry(provider.id(), QDateTime(QDate(2020, 6, 3), QTime(12, 13, 14)), {'a': 6})
+        earlier_entry = QgsHistoryEntry(
+            provider.id(), QDateTime(QDate(2020, 6, 3), QTime(12, 13, 14)), {"a": 6}
+        )
         earlier_entry_id, _ = registry.addEntry(earlier_entry)
 
         self.assertEqual(model.rowCount(), 3)
         june2020_index = model.index(2, 0, QModelIndex())
-        self.assertEqual(model.data(date_group_1_index), 'Today')
-        self.assertEqual(model.data(yesterday_index), 'Yesterday')
-        self.assertEqual(model.data(june2020_index), 'June 2020')
+        self.assertEqual(model.data(date_group_1_index), "Today")
+        self.assertEqual(model.data(yesterday_index), "Yesterday")
+        self.assertEqual(model.data(june2020_index), "June 2020")
 
         self.assertEqual(model.rowCount(june2020_index), 1)
         entry_6_index = model.index(0, 0, june2020_index)
-        self.assertEqual(model.data(entry_6_index), {'a': 6})
+        self.assertEqual(model.data(entry_6_index), {"a": 6})
 
         # an entry from an earlier month which is later than the previous one
-        earlier_entry2 = QgsHistoryEntry(provider.id(), QDateTime(QDate(2020, 10, 3), QTime(12, 13, 14)), {'a': 7})
+        earlier_entry2 = QgsHistoryEntry(
+            provider.id(), QDateTime(QDate(2020, 10, 3), QTime(12, 13, 14)), {"a": 7}
+        )
         registry.addEntry(earlier_entry2)
 
         self.assertEqual(model.rowCount(), 4)
         october2020_index = model.index(2, 0, QModelIndex())
-        self.assertEqual(model.data(date_group_1_index), 'Today')
-        self.assertEqual(model.data(yesterday_index), 'Yesterday')
-        self.assertEqual(model.data(june2020_index), 'June 2020')
-        self.assertEqual(model.data(october2020_index), 'October 2020')
+        self.assertEqual(model.data(date_group_1_index), "Today")
+        self.assertEqual(model.data(yesterday_index), "Yesterday")
+        self.assertEqual(model.data(june2020_index), "June 2020")
+        self.assertEqual(model.data(october2020_index), "October 2020")
 
         self.assertEqual(model.rowCount(october2020_index), 1)
         entry_7_index = model.index(0, 0, october2020_index)
-        self.assertEqual(model.data(entry_7_index), {'a': 7})
+        self.assertEqual(model.data(entry_7_index), {"a": 7})
 
         # an entry from last week
         last_week = QDateTime.currentDateTime().addDays(-7)
-        last_week_entry = QgsHistoryEntry(provider.id(), last_week, {'a': 'last_week'})
+        last_week_entry = QgsHistoryEntry(provider.id(), last_week, {"a": "last_week"})
         registry.addEntry(last_week_entry)
 
         self.assertEqual(model.rowCount(), 5)
         last_week_index = model.index(2, 0, QModelIndex())
-        self.assertEqual(model.data(date_group_1_index), 'Today')
-        self.assertEqual(model.data(yesterday_index), 'Yesterday')
-        self.assertEqual(model.data(june2020_index), 'June 2020')
-        self.assertEqual(model.data(october2020_index), 'October 2020')
-        self.assertEqual(model.data(last_week_index), 'Last 7 days')
+        self.assertEqual(model.data(date_group_1_index), "Today")
+        self.assertEqual(model.data(yesterday_index), "Yesterday")
+        self.assertEqual(model.data(june2020_index), "June 2020")
+        self.assertEqual(model.data(october2020_index), "October 2020")
+        self.assertEqual(model.data(last_week_index), "Last 7 days")
 
         self.assertEqual(model.rowCount(last_week_index), 1)
         entry_last_week_index = model.index(0, 0, last_week_index)
-        self.assertEqual(model.data(entry_last_week_index), {'a': 'last_week'})
+        self.assertEqual(model.data(entry_last_week_index), {"a": "last_week"})
 
         # update an entry
-        registry.updateEntry(earlier_entry_id, {'a': 8})
+        registry.updateEntry(earlier_entry_id, {"a": 8})
         entry_6_index = model.index(0, 0, june2020_index)
-        self.assertEqual(model.data(entry_6_index), {'a': 8})
+        self.assertEqual(model.data(entry_6_index), {"a": 8})
         self.assertEqual(model.rowCount(entry_6_index), 2)
         entry_6a_index = model.index(0, 0, entry_6_index)
-        self.assertEqual(model.data(entry_6a_index), 'my child')
+        self.assertEqual(model.data(entry_6a_index), "my child")
         entry_6b_index = model.index(1, 0, entry_6_index)
-        self.assertEqual(model.data(entry_6b_index), 'my child 2')
+        self.assertEqual(model.data(entry_6b_index), "my child 2")
 
         # clear
         registry.clearHistory(Qgis.HistoryProviderBackend.LocalProfile)
         self.assertEqual(model.rowCount(), 0)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
