@@ -5,22 +5,15 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = '(C) 2017 by Nyall Dawson'
-__date__ = '17/01/2017'
-__copyright__ = 'Copyright 2017, The QGIS Project'
+
+__author__ = "(C) 2017 by Nyall Dawson"
+__date__ = "17/01/2017"
+__copyright__ = "Copyright 2017, The QGIS Project"
 
 import os
 
-import qgis  # NOQA
-from qgis.PyQt.QtCore import (
-    Qt,
-    QRectF
-)
-from qgis.PyQt.QtGui import (
-    QColor,
-    QPainter,
-    QImage
-)
+from qgis.PyQt.QtCore import Qt, QRectF
+from qgis.PyQt.QtGui import QColor, QPainter, QImage
 from qgis.PyQt.QtTest import QSignalSpy
 from qgis.core import (
     QgsLayout,
@@ -38,7 +31,7 @@ from qgis.core import (
     QgsFillSymbol,
     QgsSimpleFillSymbolLayer,
     QgsLayoutRenderContext,
-    QgsLayoutItemElevationProfile
+    QgsLayoutItemElevationProfile,
 )
 import unittest
 from qgis.testing import start_app, QgisTestCase
@@ -51,13 +44,13 @@ start_app()
 
 
 class LayoutItemTestCase:
-    '''
-        This is a collection of generic tests for QgsLayoutItem subclasses.
-        To make use of it, subclass it and set self.item_class to a QgsLayoutItem subclass you want to test.
-    '''
+    """
+    This is a collection of generic tests for QgsLayoutItem subclasses.
+    To make use of it, subclass it and set self.item_class to a QgsLayoutItem subclass you want to test.
+    """
 
     def make_item(self, layout):
-        if hasattr(self, 'item_class'):
+        if hasattr(self, "item_class"):
             return self.item_class(layout)
         else:
             return self.createItem(layout)
@@ -66,7 +59,7 @@ class LayoutItemTestCase:
         l = QgsLayout(QgsProject.instance())
         item = self.make_item(l)
         self.assertFalse(item.requiresRasterization())
-        item.setBlendMode(QPainter.CompositionMode_SourceIn)
+        item.setBlendMode(QPainter.CompositionMode.CompositionMode_SourceIn)
         self.assertTrue(item.requiresRasterization())
 
 
@@ -74,7 +67,7 @@ class TestQgsLayoutItem(QgisTestCase):
 
     @classmethod
     def control_path_prefix(cls):
-        return 'composer_effects'
+        return "composer_effects"
 
     def testDataDefinedFrameColor(self):
         layout = QgsLayout(QgsProject.instance())
@@ -86,9 +79,14 @@ class TestQgsLayoutItem(QgisTestCase):
         self.assertEqual(item.frameStrokeColor(), QColor(255, 0, 0))
         self.assertEqual(item.pen().color().name(), QColor(255, 0, 0).name())
 
-        item.dataDefinedProperties().setProperty(QgsLayoutObject.FrameColor, QgsProperty.fromExpression("'blue'"))
+        item.dataDefinedProperties().setProperty(
+            QgsLayoutObject.DataDefinedProperty.FrameColor,
+            QgsProperty.fromExpression("'blue'"),
+        )
         item.refreshDataDefinedProperty()
-        self.assertEqual(item.frameStrokeColor(), QColor(255, 0, 0))  # should not change
+        self.assertEqual(
+            item.frameStrokeColor(), QColor(255, 0, 0)
+        )  # should not change
         self.assertEqual(item.pen().color().name(), QColor(0, 0, 255).name())
 
     def testFrameWidth(self):
@@ -97,12 +95,22 @@ class TestQgsLayoutItem(QgisTestCase):
         item = QgsLayoutItemMap(layout)
         item.setFrameEnabled(True)
 
-        item.setFrameStrokeWidth(QgsLayoutMeasurement(10, QgsUnitTypes.LayoutMillimeters))
-        self.assertEqual(item.frameStrokeWidth(), QgsLayoutMeasurement(10, QgsUnitTypes.LayoutMillimeters))
+        item.setFrameStrokeWidth(
+            QgsLayoutMeasurement(10, QgsUnitTypes.LayoutUnit.LayoutMillimeters)
+        )
+        self.assertEqual(
+            item.frameStrokeWidth(),
+            QgsLayoutMeasurement(10, QgsUnitTypes.LayoutUnit.LayoutMillimeters),
+        )
         self.assertEqual(item.pen().width(), 10.0)
 
-        item.setFrameStrokeWidth(QgsLayoutMeasurement(10, QgsUnitTypes.LayoutCentimeters))
-        self.assertEqual(item.frameStrokeWidth(), QgsLayoutMeasurement(10, QgsUnitTypes.LayoutCentimeters))
+        item.setFrameStrokeWidth(
+            QgsLayoutMeasurement(10, QgsUnitTypes.LayoutUnit.LayoutCentimeters)
+        )
+        self.assertEqual(
+            item.frameStrokeWidth(),
+            QgsLayoutMeasurement(10, QgsUnitTypes.LayoutUnit.LayoutCentimeters),
+        )
         self.assertEqual(item.pen().width(), 100.0)
 
     def testDataDefinedBackgroundColor(self):
@@ -114,9 +122,14 @@ class TestQgsLayoutItem(QgisTestCase):
         self.assertEqual(item.backgroundColor(), QColor(255, 0, 0))
         self.assertEqual(item.brush().color().name(), QColor(255, 0, 0).name())
 
-        item.dataDefinedProperties().setProperty(QgsLayoutObject.BackgroundColor, QgsProperty.fromExpression("'blue'"))
+        item.dataDefinedProperties().setProperty(
+            QgsLayoutObject.DataDefinedProperty.BackgroundColor,
+            QgsProperty.fromExpression("'blue'"),
+        )
         item.refreshDataDefinedProperty()
-        self.assertEqual(item.backgroundColor(False), QColor(255, 0, 0))  # should not change
+        self.assertEqual(
+            item.backgroundColor(False), QColor(255, 0, 0)
+        )  # should not change
         self.assertEqual(item.backgroundColor(True).name(), item.brush().color().name())
         self.assertEqual(item.brush().color().name(), QColor(0, 0, 255).name())
 
@@ -154,64 +167,78 @@ class TestQgsLayoutItem(QgisTestCase):
         item.setFrameEnabled(False)
         self.assertEqual(item.estimatedFrameBleed(), 0)
 
-        item.setFrameStrokeWidth(QgsLayoutMeasurement(10, QgsUnitTypes.LayoutMillimeters))
+        item.setFrameStrokeWidth(
+            QgsLayoutMeasurement(10, QgsUnitTypes.LayoutUnit.LayoutMillimeters)
+        )
         item.setFrameEnabled(False)
         self.assertEqual(item.estimatedFrameBleed(), 0)
         item.setFrameEnabled(True)
         self.assertEqual(item.estimatedFrameBleed(), 5)  # only half bleeds out!
 
-        item.setFrameStrokeWidth(QgsLayoutMeasurement(10, QgsUnitTypes.LayoutCentimeters))
+        item.setFrameStrokeWidth(
+            QgsLayoutMeasurement(10, QgsUnitTypes.LayoutUnit.LayoutCentimeters)
+        )
         self.assertEqual(item.estimatedFrameBleed(), 50)  # only half bleeds out!
 
     def testRectWithFrame(self):
         layout = QgsLayout(QgsProject.instance())
         item = QgsLayoutItemMap(layout)
-        item.attemptMove(QgsLayoutPoint(6, 10, QgsUnitTypes.LayoutMillimeters))
-        item.attemptResize(QgsLayoutSize(18, 12, QgsUnitTypes.LayoutMillimeters))
+        item.attemptMove(
+            QgsLayoutPoint(6, 10, QgsUnitTypes.LayoutUnit.LayoutMillimeters)
+        )
+        item.attemptResize(
+            QgsLayoutSize(18, 12, QgsUnitTypes.LayoutUnit.LayoutMillimeters)
+        )
 
         item.setFrameEnabled(False)
         self.assertEqual(item.rectWithFrame(), QRectF(0, 0, 18, 12))
-        item.setFrameStrokeWidth(QgsLayoutMeasurement(10, QgsUnitTypes.LayoutMillimeters))
+        item.setFrameStrokeWidth(
+            QgsLayoutMeasurement(10, QgsUnitTypes.LayoutUnit.LayoutMillimeters)
+        )
         item.setFrameEnabled(False)
         self.assertEqual(item.rectWithFrame(), QRectF(0, 0, 18, 12))
         item.setFrameEnabled(True)
         self.assertEqual(item.rectWithFrame(), QRectF(-5.0, -5.0, 28.0, 22.0))
-        item.setFrameStrokeWidth(QgsLayoutMeasurement(10, QgsUnitTypes.LayoutCentimeters))
+        item.setFrameStrokeWidth(
+            QgsLayoutMeasurement(10, QgsUnitTypes.LayoutUnit.LayoutCentimeters)
+        )
         self.assertEqual(item.rectWithFrame(), QRectF(-50.0, -50.0, 118.0, 112.0))
 
     def testDisplayName(self):
         layout = QgsLayout(QgsProject.instance())
         item = QgsLayoutItemShape(layout)
-        self.assertEqual(item.displayName(), '<Rectangle>')
-        item.setId('a')
-        self.assertEqual(item.displayName(), 'a')
-        self.assertEqual(item.id(), 'a')
+        self.assertEqual(item.displayName(), "<Rectangle>")
+        item.setId("a")
+        self.assertEqual(item.displayName(), "a")
+        self.assertEqual(item.id(), "a")
 
     def testCasting(self):
         """
         Test that sip correctly casts stuff
         """
         p = QgsProject()
-        p.read(os.path.join(TEST_DATA_DIR, 'layouts', 'layout_casting.qgs'))
+        p.read(os.path.join(TEST_DATA_DIR, "layouts", "layout_casting.qgs"))
 
         layout = p.layoutManager().layouts()[0]
 
         # check a method which often fails casting
-        map = layout.itemById('map')
+        map = layout.itemById("map")
         self.assertIsInstance(map, QgsLayoutItemMap)
-        label = layout.itemById('label')
+        label = layout.itemById("label")
         self.assertIsInstance(label, QgsLayoutItemLabel)
 
         # another method -- sometimes this fails casting for different(?) reasons
         # make sure we start from a new project so sip hasn't remembered item instances
         p2 = QgsProject()
-        p2.read(os.path.join(TEST_DATA_DIR, 'layouts', 'layout_casting.qgs'))
+        p2.read(os.path.join(TEST_DATA_DIR, "layouts", "layout_casting.qgs"))
         layout = p2.layoutManager().layouts()[0]
 
         items = layout.items()
-        map2 = [i for i in items if isinstance(i, QgsLayoutItem) and i.id() == 'map'][0]
+        map2 = [i for i in items if isinstance(i, QgsLayoutItem) and i.id() == "map"][0]
         self.assertIsInstance(map2, QgsLayoutItemMap)
-        label2 = [i for i in items if isinstance(i, QgsLayoutItem) and i.id() == 'label'][0]
+        label2 = [
+            i for i in items if isinstance(i, QgsLayoutItem) and i.id() == "label"
+        ][0]
         self.assertIsInstance(label2, QgsLayoutItemLabel)
 
     def testContainsAdvancedEffectsAndRasterization(self):
@@ -225,11 +252,16 @@ class TestQgsLayoutItem(QgisTestCase):
         self.assertTrue(item.containsAdvancedEffects())
         # but not the WHOLE layout
         self.assertFalse(item.requiresRasterization())
-        item.dataDefinedProperties().setProperty(QgsLayoutObject.Opacity, QgsProperty.fromExpression('100'))
+        item.dataDefinedProperties().setProperty(
+            QgsLayoutObject.DataDefinedProperty.Opacity,
+            QgsProperty.fromExpression("100"),
+        )
         item.refresh()
         self.assertFalse(item.containsAdvancedEffects())
         self.assertFalse(item.requiresRasterization())
-        item.dataDefinedProperties().setProperty(QgsLayoutObject.Opacity, QgsProperty())
+        item.dataDefinedProperties().setProperty(
+            QgsLayoutObject.DataDefinedProperty.Opacity, QgsProperty()
+        )
         item.refresh()
         self.assertTrue(item.containsAdvancedEffects())
         self.assertFalse(item.requiresRasterization())
@@ -238,7 +270,7 @@ class TestQgsLayoutItem(QgisTestCase):
         self.assertFalse(item.requiresRasterization())
 
         # item blend mode is NOT an advanced effect -- rather it requires that the WHOLE layout be rasterized to achieve
-        item.setBlendMode(QPainter.CompositionMode_DestinationAtop)
+        item.setBlendMode(QPainter.CompositionMode.CompositionMode_DestinationAtop)
         self.assertFalse(item.containsAdvancedEffects())
         self.assertTrue(item.requiresRasterization())
 
@@ -253,47 +285,58 @@ class TestQgsLayoutItem(QgisTestCase):
         l.initializeDefaults()
         item1 = QgsLayoutItemShape(l)
         item1.attemptSetSceneRect(QRectF(20, 20, 150, 100))
-        item1.setShapeType(QgsLayoutItemShape.Rectangle)
+        item1.setShapeType(QgsLayoutItemShape.Shape.Rectangle)
         simple_fill = QgsSimpleFillSymbolLayer()
         fill_symbol = QgsFillSymbol()
         fill_symbol.changeSymbolLayer(0, simple_fill)
         simple_fill.setColor(QColor(255, 150, 0))
-        simple_fill.setStrokeColor(Qt.black)
+        simple_fill.setStrokeColor(Qt.GlobalColor.black)
         item1.setSymbol(fill_symbol)
 
         l.addLayoutItem(item1)
         item2 = QgsLayoutItemShape(l)
         item2.attemptSetSceneRect(QRectF(50, 50, 150, 100))
-        item2.setShapeType(QgsLayoutItemShape.Rectangle)
+        item2.setShapeType(QgsLayoutItemShape.Shape.Rectangle)
         l.addLayoutItem(item2)
         simple_fill = QgsSimpleFillSymbolLayer()
         fill_symbol = QgsFillSymbol()
         fill_symbol.changeSymbolLayer(0, simple_fill)
         simple_fill.setColor(QColor(0, 100, 150))
-        simple_fill.setStrokeColor(Qt.black)
+        simple_fill.setStrokeColor(Qt.GlobalColor.black)
         item2.setSymbol(fill_symbol)
 
-        item2.setBlendMode(QPainter.CompositionMode_Multiply)
+        item2.setBlendMode(QPainter.CompositionMode.CompositionMode_Multiply)
 
         page_item = l.pageCollection().page(0)
-        paper_rect = QRectF(page_item.pos().x(),
-                            page_item.pos().y(),
-                            page_item.rect().width(),
-                            page_item.rect().height())
+        paper_rect = QRectF(
+            page_item.pos().x(),
+            page_item.pos().y(),
+            page_item.rect().width(),
+            page_item.rect().height(),
+        )
 
-        im = QImage(1122, 794, QImage.Format_ARGB32)
-        im.fill(Qt.transparent)
+        im = QImage(1122, 794, QImage.Format.Format_ARGB32)
+        im.fill(Qt.GlobalColor.transparent)
         im.setDotsPerMeterX(int(300 / 25.4 * 1000))
         im.setDotsPerMeterY(int(300 / 25.4 * 1000))
         painter = QPainter(im)
-        painter.setRenderHint(QPainter.Antialiasing, True)
+        painter.setRenderHint(QPainter.RenderHint.Antialiasing, True)
 
-        l.render(painter, QRectF(0, 0, painter.device().width(), painter.device().height()), paper_rect)
+        l.render(
+            painter,
+            QRectF(0, 0, painter.device().width(), painter.device().height()),
+            paper_rect,
+        )
         painter.end()
 
-        self.assertTrue(self.image_check('blend_modes_preview_mode',
-                                         'composereffects_blend',
-                                         im, allowed_mismatch=0))
+        self.assertTrue(
+            self.image_check(
+                "blend_modes_preview_mode",
+                "composereffects_blend",
+                im,
+                allowed_mismatch=0,
+            )
+        )
 
     def test_blend_mode_rendering_export(self):
         """
@@ -305,34 +348,29 @@ class TestQgsLayoutItem(QgisTestCase):
         l.initializeDefaults()
         item1 = QgsLayoutItemShape(l)
         item1.attemptSetSceneRect(QRectF(20, 20, 150, 100))
-        item1.setShapeType(QgsLayoutItemShape.Rectangle)
+        item1.setShapeType(QgsLayoutItemShape.Shape.Rectangle)
         simple_fill = QgsSimpleFillSymbolLayer()
         fill_symbol = QgsFillSymbol()
         fill_symbol.changeSymbolLayer(0, simple_fill)
         simple_fill.setColor(QColor(255, 150, 0))
-        simple_fill.setStrokeColor(Qt.black)
+        simple_fill.setStrokeColor(Qt.GlobalColor.black)
         item1.setSymbol(fill_symbol)
 
         l.addLayoutItem(item1)
         item2 = QgsLayoutItemShape(l)
         item2.attemptSetSceneRect(QRectF(50, 50, 150, 100))
-        item2.setShapeType(QgsLayoutItemShape.Rectangle)
+        item2.setShapeType(QgsLayoutItemShape.Shape.Rectangle)
         l.addLayoutItem(item2)
         simple_fill = QgsSimpleFillSymbolLayer()
         fill_symbol = QgsFillSymbol()
         fill_symbol.changeSymbolLayer(0, simple_fill)
         simple_fill.setColor(QColor(0, 100, 150))
-        simple_fill.setStrokeColor(Qt.black)
+        simple_fill.setStrokeColor(Qt.GlobalColor.black)
         item2.setSymbol(fill_symbol)
 
-        item2.setBlendMode(QPainter.CompositionMode_Multiply)
+        item2.setBlendMode(QPainter.CompositionMode.CompositionMode_Multiply)
 
-        self.assertTrue(
-            self.render_layout_check(
-                "composereffects_blend",
-                l
-            )
-        )
+        self.assertTrue(self.render_layout_check("composereffects_blend", l))
 
     def test_blend_mode_rendering_export_no_advanced_effects(self):
         """
@@ -343,38 +381,37 @@ class TestQgsLayoutItem(QgisTestCase):
         """
         p = QgsProject()
         l = QgsLayout(p)
-        l.renderContext().setFlag(QgsLayoutRenderContext.FlagUseAdvancedEffects, False)
+        l.renderContext().setFlag(
+            QgsLayoutRenderContext.Flag.FlagUseAdvancedEffects, False
+        )
 
         l.initializeDefaults()
         item1 = QgsLayoutItemShape(l)
         item1.attemptSetSceneRect(QRectF(20, 20, 150, 100))
-        item1.setShapeType(QgsLayoutItemShape.Rectangle)
+        item1.setShapeType(QgsLayoutItemShape.Shape.Rectangle)
         simple_fill = QgsSimpleFillSymbolLayer()
         fill_symbol = QgsFillSymbol()
         fill_symbol.changeSymbolLayer(0, simple_fill)
         simple_fill.setColor(QColor(255, 150, 0))
-        simple_fill.setStrokeColor(Qt.black)
+        simple_fill.setStrokeColor(Qt.GlobalColor.black)
         item1.setSymbol(fill_symbol)
 
         l.addLayoutItem(item1)
         item2 = QgsLayoutItemShape(l)
         item2.attemptSetSceneRect(QRectF(50, 50, 150, 100))
-        item2.setShapeType(QgsLayoutItemShape.Rectangle)
+        item2.setShapeType(QgsLayoutItemShape.Shape.Rectangle)
         l.addLayoutItem(item2)
         simple_fill = QgsSimpleFillSymbolLayer()
         fill_symbol = QgsFillSymbol()
         fill_symbol.changeSymbolLayer(0, simple_fill)
         simple_fill.setColor(QColor(0, 100, 150))
-        simple_fill.setStrokeColor(Qt.black)
+        simple_fill.setStrokeColor(Qt.GlobalColor.black)
         item2.setSymbol(fill_symbol)
 
-        item2.setBlendMode(QPainter.CompositionMode_Multiply)
+        item2.setBlendMode(QPainter.CompositionMode.CompositionMode_Multiply)
 
         self.assertTrue(
-            self.render_layout_check(
-                "composereffects_blend_no_advanced_effects",
-                l
-            )
+            self.render_layout_check("composereffects_blend_no_advanced_effects", l)
         )
 
     def test_blend_mode_rendering_export_force_vector(self):
@@ -386,40 +423,39 @@ class TestQgsLayoutItem(QgisTestCase):
         """
         p = QgsProject()
         l = QgsLayout(p)
-        l.renderContext().setFlag(QgsLayoutRenderContext.FlagForceVectorOutput, True)
+        l.renderContext().setFlag(
+            QgsLayoutRenderContext.Flag.FlagForceVectorOutput, True
+        )
 
         l.initializeDefaults()
         item1 = QgsLayoutItemShape(l)
         item1.attemptSetSceneRect(QRectF(20, 20, 150, 100))
-        item1.setShapeType(QgsLayoutItemShape.Rectangle)
+        item1.setShapeType(QgsLayoutItemShape.Shape.Rectangle)
         simple_fill = QgsSimpleFillSymbolLayer()
         fill_symbol = QgsFillSymbol()
         fill_symbol.changeSymbolLayer(0, simple_fill)
         simple_fill.setColor(QColor(255, 150, 0))
-        simple_fill.setStrokeColor(Qt.black)
+        simple_fill.setStrokeColor(Qt.GlobalColor.black)
         item1.setSymbol(fill_symbol)
 
         l.addLayoutItem(item1)
         item2 = QgsLayoutItemShape(l)
         item2.attemptSetSceneRect(QRectF(50, 50, 150, 100))
-        item2.setShapeType(QgsLayoutItemShape.Rectangle)
+        item2.setShapeType(QgsLayoutItemShape.Shape.Rectangle)
         l.addLayoutItem(item2)
         simple_fill = QgsSimpleFillSymbolLayer()
         fill_symbol = QgsFillSymbol()
         fill_symbol.changeSymbolLayer(0, simple_fill)
         simple_fill.setColor(QColor(0, 100, 150))
-        simple_fill.setStrokeColor(Qt.black)
+        simple_fill.setStrokeColor(Qt.GlobalColor.black)
         item2.setSymbol(fill_symbol)
 
-        item2.setBlendMode(QPainter.CompositionMode_Multiply)
+        item2.setBlendMode(QPainter.CompositionMode.CompositionMode_Multiply)
 
         self.assertTrue(
-            self.render_layout_check(
-                "composereffects_blend_no_advanced_effects",
-                l
-            )
+            self.render_layout_check("composereffects_blend_no_advanced_effects", l)
         )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
