@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """QGIS Unit tests for QgsLayoutItemScaleBar.
 
 .. note:: This program is free software; you can redistribute it and/or modify
@@ -6,26 +5,27 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = '(C) 2017 by Nyall Dawson'
-__date__ = '23/10/2017'
-__copyright__ = 'Copyright 2017, The QGIS Project'
 
-import qgis  # NOQA
+__author__ = "(C) 2017 by Nyall Dawson"
+__date__ = "23/10/2017"
+__copyright__ = "Copyright 2017, The QGIS Project"
 
-from qgis.testing import start_app, unittest
 from qgis.core import QgsLayoutItemScaleBar
+import unittest
+from qgis.testing import start_app, QgisTestCase
 
 from test_qgslayoutitem import LayoutItemTestCase
 
 start_app()
 
 
-class TestQgsLayoutScaleBar(unittest.TestCase, LayoutItemTestCase):
+class TestQgsLayoutScaleBar(QgisTestCase, LayoutItemTestCase):
 
     @classmethod
     def setUpClass(cls):
+        super().setUpClass()
         cls.item_class = QgsLayoutItemScaleBar
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
