@@ -9,11 +9,11 @@ the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 """
-__author__ = 'René-Luc Dhont'
-__date__ = '21/06/2019'
-__copyright__ = 'Copyright 2019, The QGIS Project'
 
-import qgis  # NOQA switch sip api
+__author__ = "René-Luc Dhont"
+__date__ = "21/06/2019"
+__copyright__ = "Copyright 2019, The QGIS Project"
+
 from qgis.PyQt.QtCore import QVariant
 from qgis.PyQt.QtXml import QDomDocument
 from qgis.core import QgsField, QgsOgcUtils, QgsVectorLayer
@@ -29,12 +29,12 @@ class TestQgsOgcUtils(QgisTestCase):
         """
         Test expressionFromOgcFilter with Int type field
         """
-        vl = QgsVectorLayer('Point', 'vl', 'memory')
-        vl.dataProvider().addAttributes([QgsField('id', QVariant.Int)])
+        vl = QgsVectorLayer("Point", "vl", "memory")
+        vl.dataProvider().addAttributes([QgsField("id", QVariant.Int)])
         vl.updateFields()
 
         # Literals are Integer 1 and 3
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -47,15 +47,15 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > 1 AND id < 3')
+        self.assertEqual(e.expression(), "id > 1 AND id < 3")
 
         # Literals are Double 1.0 and 3.0
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -68,15 +68,15 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > 1 AND id < 3')
+        self.assertEqual(e.expression(), "id > 1 AND id < 3")
 
         # Literals are Double 1.5 and 3.5
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -89,15 +89,15 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > 2 AND id < 4')
+        self.assertEqual(e.expression(), "id > 2 AND id < 4")
 
         # Literals are Scientific notation 15e-01 and 35e-01
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -110,23 +110,23 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > 2 AND id < 4')
+        self.assertEqual(e.expression(), "id > 2 AND id < 4")
 
     def test_expressionFromOgcFilterWithLonglong(self):
         """
         Test expressionFromOgcFilter with LongLong type field
         """
-        vl = QgsVectorLayer('Point', 'vl', 'memory')
-        vl.dataProvider().addAttributes([QgsField('id', QVariant.LongLong)])
+        vl = QgsVectorLayer("Point", "vl", "memory")
+        vl.dataProvider().addAttributes([QgsField("id", QVariant.LongLong)])
         vl.updateFields()
 
         # Literals are Integer 1 and 3
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -139,14 +139,14 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > 1 AND id < 3')
+        self.assertEqual(e.expression(), "id > 1 AND id < 3")
         # Literals are Double 1.0 and 3.0
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -159,15 +159,15 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > 1 AND id < 3')
+        self.assertEqual(e.expression(), "id > 1 AND id < 3")
 
         # Literals are Double 1.5 and 3.5
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -180,15 +180,15 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > 2 AND id < 4')
+        self.assertEqual(e.expression(), "id > 2 AND id < 4")
 
         # Literals are Scientific notation 15e-01 and 35e-01
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -201,52 +201,52 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > 2 AND id < 4')
+        self.assertEqual(e.expression(), "id > 2 AND id < 4")
 
         # Literal is empty
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:PropertyIsEqualTo>
                 <ogc:PropertyName>id</ogc:PropertyName>
                 <ogc:Literal></ogc:Literal>
               </ogc:PropertyIsEqualTo>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id = \'\'')
+        self.assertEqual(e.expression(), "id = ''")
 
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:PropertyIsEqualTo>
                 <ogc:PropertyName>id</ogc:PropertyName>
                 <ogc:Literal/>
               </ogc:PropertyIsEqualTo>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id = \'\'')
+        self.assertEqual(e.expression(), "id = ''")
 
     def test_expressionFromOgcFilterWithDouble(self):
         """
         Test expressionFromOgcFilter with Double type field
         """
-        vl = QgsVectorLayer('Point', 'vl', 'memory')
-        vl.dataProvider().addAttributes([QgsField('id', QVariant.Double)])
+        vl = QgsVectorLayer("Point", "vl", "memory")
+        vl.dataProvider().addAttributes([QgsField("id", QVariant.Double)])
         vl.updateFields()
 
         # Literals are Integer 1 and 3
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -259,15 +259,15 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > 1 AND id < 3')
+        self.assertEqual(e.expression(), "id > 1 AND id < 3")
 
         # Literals are Double 1.0 and 3.0
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -280,15 +280,15 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > 1 AND id < 3')
+        self.assertEqual(e.expression(), "id > 1 AND id < 3")
 
         # Literals are Double 1.5 and 3.5
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -301,15 +301,15 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > 1.5 AND id < 3.5')
+        self.assertEqual(e.expression(), "id > 1.5 AND id < 3.5")
 
         # Literals are Scientific notation 15e-01 and 35e-01
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -322,52 +322,52 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > 1.5 AND id < 3.5')
+        self.assertEqual(e.expression(), "id > 1.5 AND id < 3.5")
 
         # Literal is empty
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:PropertyIsEqualTo>
                 <ogc:PropertyName>id</ogc:PropertyName>
                 <ogc:Literal></ogc:Literal>
               </ogc:PropertyIsEqualTo>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id = \'\'')
+        self.assertEqual(e.expression(), "id = ''")
 
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:PropertyIsEqualTo>
                 <ogc:PropertyName>id</ogc:PropertyName>
                 <ogc:Literal/>
               </ogc:PropertyIsEqualTo>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id = \'\'')
+        self.assertEqual(e.expression(), "id = ''")
 
     def test_expressionFromOgcFilterWithString(self):
         """
         Test expressionFromOgcFilter with String type field
         """
-        vl = QgsVectorLayer('Point', 'vl', 'memory')
-        vl.dataProvider().addAttributes([QgsField('id', QVariant.String)])
+        vl = QgsVectorLayer("Point", "vl", "memory")
+        vl.dataProvider().addAttributes([QgsField("id", QVariant.String)])
         vl.updateFields()
 
         # Literals are Integer 1 and 3
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -380,15 +380,15 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > \'1\' AND id < \'3\'')
+        self.assertEqual(e.expression(), "id > '1' AND id < '3'")
 
         # Literals are Double 1.0 and 3.0
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -401,15 +401,15 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > \'1.0\' AND id < \'3.0\'')
+        self.assertEqual(e.expression(), "id > '1.0' AND id < '3.0'")
 
         # Literals are Double 1.5 and 3.5
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -422,15 +422,15 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > \'1.5\' AND id < \'3.5\'')
+        self.assertEqual(e.expression(), "id > '1.5' AND id < '3.5'")
 
         # Literals are Scientific notation 15e-01 and 35e-01
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -443,52 +443,58 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id > \'15e-01\' AND id < \'35e-01\'')
+        self.assertEqual(e.expression(), "id > '15e-01' AND id < '35e-01'")
 
         # Literal is empty
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:PropertyIsEqualTo>
                 <ogc:PropertyName>id</ogc:PropertyName>
                 <ogc:Literal></ogc:Literal>
               </ogc:PropertyIsEqualTo>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id = \'\'')
+        self.assertEqual(e.expression(), "id = ''")
 
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:PropertyIsEqualTo>
                 <ogc:PropertyName>id</ogc:PropertyName>
                 <ogc:Literal/>
               </ogc:PropertyIsEqualTo>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'id = \'\'')
+        self.assertEqual(e.expression(), "id = ''")
 
     def test_expressionFromOgcFilterWithAndOrPropertyIsLike(self):
         """
         Test expressionFromOgcFilter with And, Or and PropertyIsLike with wildCard
         """
 
-        vl = QgsVectorLayer('Point', 'vl', 'memory')
-        vl.dataProvider().addAttributes([QgsField('id', QVariant.LongLong), QgsField('THEME', QVariant.String), QgsField('PROGRAMME', QVariant.String)])
+        vl = QgsVectorLayer("Point", "vl", "memory")
+        vl.dataProvider().addAttributes(
+            [
+                QgsField("id", QVariant.LongLong),
+                QgsField("THEME", QVariant.String),
+                QgsField("PROGRAMME", QVariant.String),
+            ]
+        )
         vl.updateFields()
 
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
             <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsLike escape="\\" wildCard="%" singleChar="_">
@@ -515,23 +521,26 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:Or>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), 'THEME LIKE \'%Phytoplancton total%\' AND (PROGRAMME ILIKE \'REPHY;%\' OR PROGRAMME ILIKE \'%;REPHY\' OR PROGRAMME ILIKE \'%;REPHY;%\' OR PROGRAMME ILIKE \'^REPHY$\')')
+        self.assertEqual(
+            e.expression(),
+            "THEME LIKE '%Phytoplancton total%' AND (PROGRAMME ILIKE 'REPHY;%' OR PROGRAMME ILIKE '%;REPHY' OR PROGRAMME ILIKE '%;REPHY;%' OR PROGRAMME ILIKE '^REPHY$')",
+        )
 
     def test_expressionFromOgcFilterWithDateTime(self):
         """
         Test expressionFromOgcFilter with Date/Time type field
         """
         # test with datetime type
-        vl = QgsVectorLayer('Point', 'vl', 'memory')
-        vl.dataProvider().addAttributes([QgsField('datetime', QVariant.DateTime)])
+        vl = QgsVectorLayer("Point", "vl", "memory")
+        vl.dataProvider().addAttributes([QgsField("datetime", QVariant.DateTime)])
         vl.updateFields()
 
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
         <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -544,19 +553,22 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
-        self.assertEqual(e.expression(), "datetime > '1998-07-12T00:00:00' AND datetime < '2018-07-15T00:00:00'")
+        self.assertEqual(
+            e.expression(),
+            "datetime > '1998-07-12T00:00:00' AND datetime < '2018-07-15T00:00:00'",
+        )
 
         # test with date type
-        vl = QgsVectorLayer('Point', 'vl', 'memory')
-        vl.dataProvider().addAttributes([QgsField('date', QVariant.Date)])
+        vl = QgsVectorLayer("Point", "vl", "memory")
+        vl.dataProvider().addAttributes([QgsField("date", QVariant.Date)])
         vl.updateFields()
 
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
         <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -569,19 +581,19 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
         self.assertEqual(e.expression(), "date > '1998-07-12' AND date < '2018-07-15'")
 
         # test with time type
-        vl = QgsVectorLayer('Point', 'vl', 'memory')
-        vl.dataProvider().addAttributes([QgsField('time', QVariant.Time)])
+        vl = QgsVectorLayer("Point", "vl", "memory")
+        vl.dataProvider().addAttributes([QgsField("time", QVariant.Time)])
         vl.updateFields()
 
-        f = '''<?xml version="1.0" encoding="UTF-8"?>
+        f = """<?xml version="1.0" encoding="UTF-8"?>
         <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
               <ogc:And>
                 <ogc:PropertyIsGreaterThan>
@@ -594,13 +606,13 @@ class TestQgsOgcUtils(QgisTestCase):
                 </ogc:PropertyIsLessThan>
               </ogc:And>
             </ogc:Filter>
-        '''
-        d = QDomDocument('filter')
+        """
+        d = QDomDocument("filter")
         d.setContent(f, True)
 
         e = QgsOgcUtils.expressionFromOgcFilter(d.documentElement(), vl)
         self.assertEqual(e.expression(), "time > '11:01:02' AND time < '12:03:04'")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
