@@ -8,9 +8,10 @@ the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 """
-__author__ = 'Paul Blottiere'
-__date__ = '26/12/2016'
-__copyright__ = 'Copyright 2016, The QGIS Project'
+
+__author__ = "Paul Blottiere"
+__date__ = "26/12/2016"
+__copyright__ = "Copyright 2016, The QGIS Project"
 
 import os
 
@@ -26,7 +27,7 @@ start_app()
 class TestQgsServerProjectUtils(unittest.TestCase):
 
     def setUp(self):
-        self.testdata_path = unitTestDataPath('qgis_server_project') + '/'
+        self.testdata_path = unitTestDataPath("qgis_server_project") + "/"
 
         self.prj = QgsProject()
         self.prjPath = os.path.join(self.testdata_path, "project.qgs")
@@ -44,9 +45,15 @@ class TestQgsServerProjectUtils(unittest.TestCase):
         self.assertEqual(QgsServerProjectUtils.wmsMaxHeight(self.prj), 500)
 
     def test_url(self):
-        self.assertEqual(QgsServerProjectUtils.wmsServiceUrl(self.prj), "my_wms_advertised_url")
-        self.assertEqual(QgsServerProjectUtils.wcsServiceUrl(self.prj), "my_wcs_advertised_url")
-        self.assertEqual(QgsServerProjectUtils.wfsServiceUrl(self.prj), "my_wfs_advertised_url")
+        self.assertEqual(
+            QgsServerProjectUtils.wmsServiceUrl(self.prj), "my_wms_advertised_url"
+        )
+        self.assertEqual(
+            QgsServerProjectUtils.wcsServiceUrl(self.prj), "my_wcs_advertised_url"
+        )
+        self.assertEqual(
+            QgsServerProjectUtils.wfsServiceUrl(self.prj), "my_wfs_advertised_url"
+        )
 
     def test_wmsuselayerids(self):
         self.assertEqual(QgsServerProjectUtils.wmsUseLayerIds(self.prj), False)
@@ -56,9 +63,9 @@ class TestQgsServerProjectUtils(unittest.TestCase):
         # retrieve entry from project
         result = QgsServerProjectUtils.wmsRestrictedLayers(self.prj)
         expected = []
-        expected.append('points')  # layer
-        expected.append('group1')  # local group
-        expected.append('groupEmbedded')  # embedded group
+        expected.append("points")  # layer
+        expected.append("group1")  # local group
+        expected.append("groupEmbedded")  # embedded group
 
         self.assertListEqual(sorted(expected), sorted(result))
 
@@ -67,9 +74,9 @@ class TestQgsServerProjectUtils(unittest.TestCase):
         result = QgsServerProjectUtils.wfsLayerIds(self.prj)
 
         expected = []
-        expected.append('multipoint20170309173637804')  # from embedded group
-        expected.append('points20170309173738552')  # local layer
-        expected.append('polys20170309173913723')  # from local group
+        expected.append("multipoint20170309173637804")  # from embedded group
+        expected.append("points20170309173738552")  # local layer
+        expected.append("polys20170309173913723")  # from local group
 
         self.assertEqual(expected, result)
 
@@ -78,20 +85,24 @@ class TestQgsServerProjectUtils(unittest.TestCase):
         result = QgsServerProjectUtils.wcsLayerIds(self.prj)
 
         expected = []
-        expected.append('landsat20170313142548073')
+        expected.append("landsat20170313142548073")
 
         self.assertEqual(expected, result)
 
-    @mock.patch.dict(os.environ, {"QGIS_SERVER_WFS_SERVICE_URL": "http://localhost:8080"})
+    @mock.patch.dict(
+        os.environ, {"QGIS_SERVER_WFS_SERVICE_URL": "http://localhost:8080"}
+    )
     def test_map_uppercase_replace(self):
         """Test issue GH #54533 MAP replacementin URL arg"""
 
         settings = QgsServerSettings()
-        self.assertIsNotNone(settings.serviceUrl('WFS'))
-        request = QgsBufferServerRequest('http://localhost:8080/?MaP=/mAp.qgs&SERVICE=WMS&REQUEST=GetMap')
-        service_url = QgsServerProjectUtils.serviceUrl('WFS', request, settings)
-        self.assertEqual(service_url, 'http://localhost:8080/?MAP=/mAp.qgs')
+        self.assertIsNotNone(settings.serviceUrl("WFS"))
+        request = QgsBufferServerRequest(
+            "http://localhost:8080/?MaP=/mAp.qgs&SERVICE=WMS&REQUEST=GetMap"
+        )
+        service_url = QgsServerProjectUtils.serviceUrl("WFS", request, settings)
+        self.assertEqual(service_url, "http://localhost:8080/?MAP=/mAp.qgs")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
