@@ -18,13 +18,12 @@ From build dir, run: ctest -R PyQgsSymbolLayer -V
 
 """
 
-__author__ = 'Massimo Endrighi'
-__date__ = 'October 2012'
-__copyright__ = '(C) 2012, Massimo Endrighi'
+__author__ = "Massimo Endrighi"
+__date__ = "October 2012"
+__copyright__ = "(C) 2012, Massimo Endrighi"
 
 import os
 
-import qgis  # NOQA
 import qgis.core
 from osgeo import ogr
 from qgis.PyQt.QtCore import (
@@ -81,7 +80,7 @@ from qgis.core import (
     QgsUnitTypes,
     QgsVectorFieldSymbolLayer,
     QgsVectorLayer,
-    QgsSymbolRenderContext
+    QgsSymbolRenderContext,
 )
 import unittest
 from qgis.testing import start_app, QgisTestCase
@@ -98,22 +97,21 @@ EXPECTED_TYPE = type(QObject)
 
 
 class TestQgsSymbolLayer(QgisTestCase):
-
     """
-     This class test the sip binding for QgsSymbolLayer descendants
-     Every class is tested using the createFromSld implementation
-     An exception is done for:
-     - QgsLinePatternFillSymbolLayer where createFromSld implementation
-         returns NULL
-     - QgsPointPatternFillSymbolLayer where createFromSld implementation
-         returns NULL
-     - QgsVectorFieldSymbolLayer where createFromSld implementation
-         returns NULL
-     """
+    This class test the sip binding for QgsSymbolLayer descendants
+    Every class is tested using the createFromSld implementation
+    An exception is done for:
+    - QgsLinePatternFillSymbolLayer where createFromSld implementation
+        returns NULL
+    - QgsPointPatternFillSymbolLayer where createFromSld implementation
+        returns NULL
+    - QgsVectorFieldSymbolLayer where createFromSld implementation
+        returns NULL
+    """
 
     @classmethod
     def control_path_prefix(cls):
-        return 'symbol_layer'
+        return "symbol_layer"
 
     def testBinding(self):
         """Test python bindings existence."""
@@ -283,7 +281,7 @@ class TestQgsSymbolLayer(QgisTestCase):
         assert EXPECTED_TYPE == mType, mMessage
 
     def testGettersSetters(self):
-        """ test base class getters/setters """
+        """test base class getters/setters"""
         layer = QgsSimpleFillSymbolLayer()
 
         layer.setEnabled(False)
@@ -300,7 +298,7 @@ class TestQgsSymbolLayer(QgisTestCase):
         self.assertEqual(layer.renderingPass(), 5)
 
     def testSaveRestore(self):
-        """ Test saving and restoring base symbol layer properties to xml"""
+        """Test saving and restoring base symbol layer properties to xml"""
 
         layer = QgsSimpleFillSymbolLayer()
         layer.setEnabled(False)
@@ -312,18 +310,22 @@ class TestQgsSymbolLayer(QgisTestCase):
         symbol.changeSymbolLayer(0, layer)
 
         doc = QDomDocument("testdoc")
-        elem = QgsSymbolLayerUtils.saveSymbol('test', symbol, doc, QgsReadWriteContext())
+        elem = QgsSymbolLayerUtils.saveSymbol(
+            "test", symbol, doc, QgsReadWriteContext()
+        )
 
         restored_symbol = QgsSymbolLayerUtils.loadSymbol(elem, QgsReadWriteContext())
         restored_layer = restored_symbol.symbolLayer(0)
         self.assertFalse(restored_layer.enabled())
         self.assertTrue(restored_layer.isLocked())
         self.assertEqual(restored_layer.renderingPass(), 5)
-        self.assertEqual(restored_layer.userFlags(),
-                         Qgis.SymbolLayerUserFlag.DisableSelectionRecoloring)
+        self.assertEqual(
+            restored_layer.userFlags(),
+            Qgis.SymbolLayerUserFlag.DisableSelectionRecoloring,
+        )
 
     def testClone(self):
-        """ test that base symbol layer properties are cloned with layer """
+        """test that base symbol layer properties are cloned with layer"""
 
         layer = QgsSimpleFillSymbolLayer()
         layer.setEnabled(False)
@@ -339,22 +341,24 @@ class TestQgsSymbolLayer(QgisTestCase):
         self.assertFalse(cloned_layer.enabled())
         self.assertTrue(cloned_layer.isLocked())
         self.assertEqual(cloned_layer.renderingPass(), 5)
-        self.assertEqual(cloned_layer.userFlags(),
-                         Qgis.SymbolLayerUserFlag.DisableSelectionRecoloring)
+        self.assertEqual(
+            cloned_layer.userFlags(),
+            Qgis.SymbolLayerUserFlag.DisableSelectionRecoloring,
+        )
 
     def testRenderFillLayerDisabled(self):
-        """ test that rendering a fill symbol with disabled layer works"""
+        """test that rendering a fill symbol with disabled layer works"""
         layer = QgsSimpleFillSymbolLayer()
         layer.setEnabled(False)
 
         symbol = QgsFillSymbol()
         symbol.changeSymbolLayer(0, layer)
 
-        image = QImage(200, 200, QImage.Format_RGB32)
+        image = QImage(200, 200, QImage.Format.Format_RGB32)
         painter = QPainter()
         ms = QgsMapSettings()
 
-        geom = QgsGeometry.fromWkt('Polygon ((0 0, 10 0, 10 10, 0 10, 0 0))')
+        geom = QgsGeometry.fromWkt("Polygon ((0 0, 10 0, 10 10, 0 10, 0 0))")
         f = QgsFeature()
         f.setGeometry(geom)
 
@@ -377,8 +381,7 @@ class TestQgsSymbolLayer(QgisTestCase):
         painter.end()
 
         self.assertTrue(
-            self.image_check('symbollayer_disabled',
-                             'symbollayer_disabled', image)
+            self.image_check("symbollayer_disabled", "symbollayer_disabled", image)
         )
 
     def testRenderFillLayerDataDefined(self):
@@ -386,13 +389,16 @@ class TestQgsSymbolLayer(QgisTestCase):
         Test that rendering a fill symbol with data defined enabled layer works
         """
 
-        polys_shp = os.path.join(TEST_DATA_DIR, 'polys.shp')
-        polys_layer = QgsVectorLayer(polys_shp, 'Polygons', 'ogr')
+        polys_shp = os.path.join(TEST_DATA_DIR, "polys.shp")
+        polys_layer = QgsVectorLayer(polys_shp, "Polygons", "ogr")
         QgsProject.instance().addMapLayer(polys_layer)
 
         layer = QgsSimpleFillSymbolLayer()
-        layer.setDataDefinedProperty(QgsSymbolLayer.PropertyLayerEnabled, QgsProperty.fromExpression("Name='Lake'"))
-        layer.setStrokeStyle(Qt.NoPen)
+        layer.setDataDefinedProperty(
+            QgsSymbolLayer.Property.PropertyLayerEnabled,
+            QgsProperty.fromExpression("Name='Lake'"),
+        )
+        layer.setStrokeStyle(Qt.PenStyle.NoPen)
         layer.setColor(QColor(100, 150, 150))
 
         symbol = QgsFillSymbol()
@@ -409,18 +415,16 @@ class TestQgsSymbolLayer(QgisTestCase):
         ctx = QgsRenderContext.fromMapSettings(ms)
         ctx.expressionContext().appendScope(polys_layer.createExpressionContextScope())
         # for symbol layer
-        self.assertCountEqual(layer.usedAttributes(ctx), {'Name'})
+        self.assertCountEqual(layer.usedAttributes(ctx), {"Name"})
         # for symbol
-        self.assertCountEqual(symbol.usedAttributes(ctx), {'Name'})
+        self.assertCountEqual(symbol.usedAttributes(ctx), {"Name"})
         # for symbol renderer
-        self.assertCountEqual(polys_layer.renderer().usedAttributes(ctx), {'Name'})
+        self.assertCountEqual(polys_layer.renderer().usedAttributes(ctx), {"Name"})
 
         # Test rendering
         self.assertTrue(
             self.render_map_settings_check(
-                'filllayer_ddenabled',
-                'filllayer_ddenabled',
-                ms
+                "filllayer_ddenabled", "filllayer_ddenabled", ms
             )
         )
 
@@ -436,11 +440,11 @@ class TestQgsSymbolLayer(QgisTestCase):
         symbol = QgsLineSymbol()
         symbol.changeSymbolLayer(0, layer)
 
-        image = QImage(200, 200, QImage.Format_RGB32)
+        image = QImage(200, 200, QImage.Format.Format_RGB32)
         painter = QPainter()
         ms = QgsMapSettings()
 
-        geom = QgsGeometry.fromWkt('LineString (0 0,3 4,4 3)')
+        geom = QgsGeometry.fromWkt("LineString (0 0,3 4,4 3)")
         f = QgsFeature()
         f.setGeometry(geom)
 
@@ -463,11 +467,7 @@ class TestQgsSymbolLayer(QgisTestCase):
         painter.end()
 
         self.assertTrue(
-            self.image_check(
-                'symbollayer_disabled',
-                'symbollayer_disabled',
-                image
-            )
+            self.image_check("symbollayer_disabled", "symbollayer_disabled", image)
         )
 
     def testRenderLineLayerDataDefined(self):
@@ -475,12 +475,15 @@ class TestQgsSymbolLayer(QgisTestCase):
         Test that rendering a line symbol with data defined enabled layer works
         """
 
-        lines_shp = os.path.join(TEST_DATA_DIR, 'lines.shp')
-        lines_layer = QgsVectorLayer(lines_shp, 'Lines', 'ogr')
+        lines_shp = os.path.join(TEST_DATA_DIR, "lines.shp")
+        lines_layer = QgsVectorLayer(lines_shp, "Lines", "ogr")
         QgsProject.instance().addMapLayer(lines_layer)
 
         layer = QgsSimpleLineSymbolLayer()
-        layer.setDataDefinedProperty(QgsSymbolLayer.PropertyLayerEnabled, QgsProperty.fromExpression("Name='Highway'"))
+        layer.setDataDefinedProperty(
+            QgsSymbolLayer.Property.PropertyLayerEnabled,
+            QgsProperty.fromExpression("Name='Highway'"),
+        )
         layer.setColor(QColor(100, 150, 150))
         layer.setWidth(5)
 
@@ -498,18 +501,16 @@ class TestQgsSymbolLayer(QgisTestCase):
         ctx = QgsRenderContext.fromMapSettings(ms)
         ctx.expressionContext().appendScope(lines_layer.createExpressionContextScope())
         # for symbol layer
-        self.assertCountEqual(layer.usedAttributes(ctx), {'Name'})
+        self.assertCountEqual(layer.usedAttributes(ctx), {"Name"})
         # for symbol
-        self.assertCountEqual(symbol.usedAttributes(ctx), {'Name'})
+        self.assertCountEqual(symbol.usedAttributes(ctx), {"Name"})
         # for symbol renderer
-        self.assertCountEqual(lines_layer.renderer().usedAttributes(ctx), {'Name'})
+        self.assertCountEqual(lines_layer.renderer().usedAttributes(ctx), {"Name"})
 
         # Test rendering
         self.assertTrue(
             self.render_map_settings_check(
-                'linelayer_ddenabled',
-                'linelayer_ddenabled',
-                ms
+                "linelayer_ddenabled", "linelayer_ddenabled", ms
             )
         )
 
@@ -525,11 +526,11 @@ class TestQgsSymbolLayer(QgisTestCase):
         symbol = QgsMarkerSymbol()
         symbol.changeSymbolLayer(0, layer)
 
-        image = QImage(200, 200, QImage.Format_RGB32)
+        image = QImage(200, 200, QImage.Format.Format_RGB32)
         painter = QPainter()
         ms = QgsMapSettings()
 
-        geom = QgsGeometry.fromWkt('Point (1 2)')
+        geom = QgsGeometry.fromWkt("Point (1 2)")
         f = QgsFeature()
         f.setGeometry(geom)
 
@@ -550,11 +551,7 @@ class TestQgsSymbolLayer(QgisTestCase):
         painter.end()
 
         self.assertTrue(
-            self.image_check(
-                'symbollayer_disabled',
-                'symbollayer_disabled',
-                image
-            )
+            self.image_check("symbollayer_disabled", "symbollayer_disabled", image)
         )
 
     def testRenderMarkerLayerDataDefined(self):
@@ -563,15 +560,18 @@ class TestQgsSymbolLayer(QgisTestCase):
         layer works
         """
 
-        points_shp = os.path.join(TEST_DATA_DIR, 'points.shp')
-        points_layer = QgsVectorLayer(points_shp, 'Points', 'ogr')
+        points_shp = os.path.join(TEST_DATA_DIR, "points.shp")
+        points_layer = QgsVectorLayer(points_shp, "Points", "ogr")
         QgsProject.instance().addMapLayer(points_layer)
 
         layer = QgsSimpleMarkerSymbolLayer()
-        layer.setDataDefinedProperty(QgsSymbolLayer.PropertyLayerEnabled, QgsProperty.fromExpression("Class='Biplane'"))
+        layer.setDataDefinedProperty(
+            QgsSymbolLayer.Property.PropertyLayerEnabled,
+            QgsProperty.fromExpression("Class='Biplane'"),
+        )
         layer.setColor(QColor(100, 150, 150))
         layer.setSize(5)
-        layer.setStrokeStyle(Qt.NoPen)
+        layer.setStrokeStyle(Qt.PenStyle.NoPen)
 
         symbol = QgsMarkerSymbol()
         symbol.changeSymbolLayer(0, layer)
@@ -587,18 +587,16 @@ class TestQgsSymbolLayer(QgisTestCase):
         ctx = QgsRenderContext.fromMapSettings(ms)
         ctx.expressionContext().appendScope(points_layer.createExpressionContextScope())
         # for symbol layer
-        self.assertCountEqual(layer.usedAttributes(ctx), {'Class'})
+        self.assertCountEqual(layer.usedAttributes(ctx), {"Class"})
         # for symbol
-        self.assertCountEqual(symbol.usedAttributes(ctx), {'Class'})
+        self.assertCountEqual(symbol.usedAttributes(ctx), {"Class"})
         # for symbol renderer
-        self.assertCountEqual(points_layer.renderer().usedAttributes(ctx), {'Class'})
+        self.assertCountEqual(points_layer.renderer().usedAttributes(ctx), {"Class"})
 
         # Test rendering
         self.assertTrue(
             self.render_map_settings_check(
-                'markerlayer_ddenabled',
-                'markerlayer_ddenabled',
-                ms
+                "markerlayer_ddenabled", "markerlayer_ddenabled", ms
             )
         )
         QgsProject.instance().removeMapLayer(points_layer)
@@ -607,33 +605,36 @@ class TestQgsSymbolLayer(QgisTestCase):
         """
         Create a new style from a .sld file and match test.
         """
-        mTestName = 'QgsSimpleFillSymbolLayer'
-        mFilePath = QDir.toNativeSeparators(f'{unitTestDataPath()}/symbol_layer/{mTestName}.sld')
+        mTestName = "QgsSimpleFillSymbolLayer"
+        mFilePath = QDir.toNativeSeparators(
+            f"{unitTestDataPath()}/symbol_layer/{mTestName}.sld"
+        )
 
         mDoc = QDomDocument(mTestName)
         mFile = QFile(mFilePath)
-        mFile.open(QIODevice.ReadOnly)
+        mFile.open(QIODevice.OpenModeFlag.ReadOnly)
         mDoc.setContent(mFile, True)
         mFile.close()
         mSymbolLayer = QgsSimpleFillSymbolLayer.createFromSld(
-            mDoc.elementsByTagName('PolygonSymbolizer').item(0).toElement())
+            mDoc.elementsByTagName("PolygonSymbolizer").item(0).toElement()
+        )
 
         mExpectedValue = type(QgsSimpleFillSymbolLayer())
         mValue = type(mSymbolLayer)
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = Qt.SolidPattern
+        mExpectedValue = Qt.BrushStyle.SolidPattern
         mValue = mSymbolLayer.brushStyle()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = '#ffaa7f'
+        mExpectedValue = "#ffaa7f"
         mValue = mSymbolLayer.strokeColor().name()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = Qt.DotLine
+        mExpectedValue = Qt.PenStyle.DotLine
         mValue = mSymbolLayer.strokeStyle()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
@@ -657,31 +658,31 @@ class TestQgsSymbolLayer(QgisTestCase):
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = QgsGradientFillSymbolLayer.Radial
+        mExpectedValue = QgsGradientFillSymbolLayer.GradientType.Radial
         mGradientLayer.setGradientType(mExpectedValue)
         mValue = mGradientLayer.gradientType()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = QgsGradientFillSymbolLayer.ColorRamp
+        mExpectedValue = QgsGradientFillSymbolLayer.GradientColorType.ColorRamp
         mGradientLayer.setGradientColorType(mExpectedValue)
         mValue = mGradientLayer.gradientColorType()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = QColor('#55aaff')
+        mExpectedValue = QColor("#55aaff")
         mGradientLayer.setColor2(mExpectedValue)
         mValue = mGradientLayer.color2()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = QgsGradientFillSymbolLayer.Viewport
+        mExpectedValue = QgsGradientFillSymbolLayer.GradientCoordinateMode.Viewport
         mGradientLayer.setCoordinateMode(mExpectedValue)
         mValue = mGradientLayer.coordinateMode()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = QgsGradientFillSymbolLayer.Reflect
+        mExpectedValue = QgsGradientFillSymbolLayer.GradientSpread.Reflect
         mGradientLayer.setGradientSpread(mExpectedValue)
         mValue = mGradientLayer.gradientSpread()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
@@ -723,7 +724,7 @@ class TestQgsSymbolLayer(QgisTestCase):
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = QgsUnitTypes.RenderMapUnits
+        mExpectedValue = QgsUnitTypes.RenderUnit.RenderMapUnits
         mGradientLayer.setOffsetUnit(mExpectedValue)
         mValue = mGradientLayer.offsetUnit()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
@@ -736,33 +737,36 @@ class TestQgsSymbolLayer(QgisTestCase):
         """
         Create a new style from a .sld file and match test
         """
-        mTestName = 'QgsCentroidFillSymbolLayer'
-        mFilePath = QDir.toNativeSeparators(f'{unitTestDataPath()}/symbol_layer/{mTestName}.sld')
+        mTestName = "QgsCentroidFillSymbolLayer"
+        mFilePath = QDir.toNativeSeparators(
+            f"{unitTestDataPath()}/symbol_layer/{mTestName}.sld"
+        )
 
         mDoc = QDomDocument(mTestName)
         mFile = QFile(mFilePath)
-        mFile.open(QIODevice.ReadOnly)
+        mFile.open(QIODevice.OpenModeFlag.ReadOnly)
         mDoc.setContent(mFile, True)
         mFile.close()
         mSymbolLayer = QgsCentroidFillSymbolLayer.createFromSld(
-            mDoc.elementsByTagName('PointSymbolizer').item(0).toElement())
+            mDoc.elementsByTagName("PointSymbolizer").item(0).toElement()
+        )
 
         mExpectedValue = type(QgsCentroidFillSymbolLayer())
         mValue = type(mSymbolLayer)
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = QgsSimpleMarkerSymbolLayerBase.Star
+        mExpectedValue = QgsSimpleMarkerSymbolLayerBase.Shape.Star
         mValue = mSymbolLayer.subSymbol().symbolLayer(0).shape()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = '#55aaff'
+        mExpectedValue = "#55aaff"
         mValue = mSymbolLayer.subSymbol().symbolLayer(0).color().name()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = '#00ff00'
+        mExpectedValue = "#00ff00"
         mValue = mSymbolLayer.subSymbol().symbolLayer(0).strokeColor().name()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
@@ -787,23 +791,26 @@ class TestQgsSymbolLayer(QgisTestCase):
         """
         Create a new style from a .sld file and match test
         """
-        mTestName = 'QgsLinePatternFillSymbolLayer'
-        mFilePath = QDir.toNativeSeparators(f'{unitTestDataPath()}/symbol_layer/{mTestName}.sld')
+        mTestName = "QgsLinePatternFillSymbolLayer"
+        mFilePath = QDir.toNativeSeparators(
+            f"{unitTestDataPath()}/symbol_layer/{mTestName}.sld"
+        )
 
         mDoc = QDomDocument(mTestName)
         mFile = QFile(mFilePath)
-        mFile.open(QIODevice.ReadOnly)
+        mFile.open(QIODevice.OpenModeFlag.ReadOnly)
         mDoc.setContent(mFile, True)
         mFile.close()
         mSymbolLayer = QgsLinePatternFillSymbolLayer.createFromSld(
-            mDoc.elementsByTagName('PolygonSymbolizer').item(0).toElement())
+            mDoc.elementsByTagName("PolygonSymbolizer").item(0).toElement()
+        )
 
         mExpectedValue = type(QgsLinePatternFillSymbolLayer())
         mValue = type(mSymbolLayer)
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = '#ff55ff'
+        mExpectedValue = "#ff55ff"
         mValue = mSymbolLayer.color().name()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
@@ -840,33 +847,36 @@ class TestQgsSymbolLayer(QgisTestCase):
         """
         # at the moment there is an empty createFromSld implementation
         # that return nulls
-        mTestName = 'QgsPointPatternFillSymbolLayer'
-        mFilePath = QDir.toNativeSeparators(f'{unitTestDataPath()}/symbol_layer/{mTestName}.sld')
+        mTestName = "QgsPointPatternFillSymbolLayer"
+        mFilePath = QDir.toNativeSeparators(
+            f"{unitTestDataPath()}/symbol_layer/{mTestName}.sld"
+        )
 
         mDoc = QDomDocument(mTestName)
         mFile = QFile(mFilePath)
-        mFile.open(QIODevice.ReadOnly)
+        mFile.open(QIODevice.OpenModeFlag.ReadOnly)
         mDoc.setContent(mFile, True)
         mFile.close()
         mSymbolLayer = QgsPointPatternFillSymbolLayer.createFromSld(
-            mDoc.elementsByTagName('PolygonSymbolizer').item(0).toElement())
+            mDoc.elementsByTagName("PolygonSymbolizer").item(0).toElement()
+        )
 
         mExpectedValue = type(QgsPointPatternFillSymbolLayer())
         mValue = type(mSymbolLayer)
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = QgsSimpleMarkerSymbolLayerBase.Triangle
+        mExpectedValue = QgsSimpleMarkerSymbolLayerBase.Shape.Triangle
         mValue = mSymbolLayer.subSymbol().symbolLayer(0).shape()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = '#ffaa00'
+        mExpectedValue = "#ffaa00"
         mValue = mSymbolLayer.subSymbol().symbolLayer(0).color().name()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = '#ff007f'
+        mExpectedValue = "#ff007f"
         mValue = mSymbolLayer.subSymbol().symbolLayer(0).strokeColor().name()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
@@ -905,23 +915,26 @@ class TestQgsSymbolLayer(QgisTestCase):
         """
         Create a new style from a .sld file and match test
         """
-        mTestName = 'QgsSVGFillSymbolLayer'
-        mFilePath = QDir.toNativeSeparators(f'{unitTestDataPath()}/symbol_layer/{mTestName}.sld')
+        mTestName = "QgsSVGFillSymbolLayer"
+        mFilePath = QDir.toNativeSeparators(
+            f"{unitTestDataPath()}/symbol_layer/{mTestName}.sld"
+        )
 
         mDoc = QDomDocument(mTestName)
         mFile = QFile(mFilePath)
-        mFile.open(QIODevice.ReadOnly)
+        mFile.open(QIODevice.OpenModeFlag.ReadOnly)
         mDoc.setContent(mFile, True)
         mFile.close()
         mSymbolLayer = QgsSVGFillSymbolLayer.createFromSld(
-            mDoc.elementsByTagName('PolygonSymbolizer').item(0).toElement())
+            mDoc.elementsByTagName("PolygonSymbolizer").item(0).toElement()
+        )
 
         mExpectedValue = type(QgsSVGFillSymbolLayer(""))
         mValue = type(mSymbolLayer)
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = 'accommodation_camping.svg'
+        mExpectedValue = "accommodation_camping.svg"
         mValue = os.path.basename(mSymbolLayer.svgFilePath())
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
@@ -938,38 +951,41 @@ class TestQgsSymbolLayer(QgisTestCase):
         """
         Create a new style from a .sld file and match test
         """
-        mTestName = 'QgsMarkerLineSymbolLayer'
-        mFilePath = QDir.toNativeSeparators(f'{unitTestDataPath()}/symbol_layer/{mTestName}.sld')
+        mTestName = "QgsMarkerLineSymbolLayer"
+        mFilePath = QDir.toNativeSeparators(
+            f"{unitTestDataPath()}/symbol_layer/{mTestName}.sld"
+        )
 
         mDoc = QDomDocument(mTestName)
         mFile = QFile(mFilePath)
-        mFile.open(QIODevice.ReadOnly)
+        mFile.open(QIODevice.OpenModeFlag.ReadOnly)
         mDoc.setContent(mFile, True)
         mFile.close()
         mSymbolLayer = QgsMarkerLineSymbolLayer.createFromSld(
-            mDoc.elementsByTagName('LineSymbolizer').item(0).toElement())
+            mDoc.elementsByTagName("LineSymbolizer").item(0).toElement()
+        )
 
         mExpectedValue = type(QgsMarkerLineSymbolLayer())
         mValue = type(mSymbolLayer)
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = QgsMarkerLineSymbolLayer.CentralPoint
+        mExpectedValue = QgsMarkerLineSymbolLayer.Placement.CentralPoint
         mValue = mSymbolLayer.placement()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = QgsSimpleMarkerSymbolLayerBase.Circle
+        mExpectedValue = QgsSimpleMarkerSymbolLayerBase.Shape.Circle
         mValue = mSymbolLayer.subSymbol().symbolLayer(0).shape()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = '#000000'
+        mExpectedValue = "#000000"
         mValue = mSymbolLayer.subSymbol().symbolLayer(0).strokeColor().name()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = '#ff0000'
+        mExpectedValue = "#ff0000"
         mValue = mSymbolLayer.subSymbol().symbolLayer(0).color().name()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
@@ -989,23 +1005,26 @@ class TestQgsSymbolLayer(QgisTestCase):
         """
         Create a new style from a .sld file and match test
         """
-        mTestName = 'QgsSimpleLineSymbolLayer'
-        mFilePath = QDir.toNativeSeparators(f'{unitTestDataPath()}/symbol_layer/{mTestName}.sld')
+        mTestName = "QgsSimpleLineSymbolLayer"
+        mFilePath = QDir.toNativeSeparators(
+            f"{unitTestDataPath()}/symbol_layer/{mTestName}.sld"
+        )
 
         mDoc = QDomDocument(mTestName)
         mFile = QFile(mFilePath)
-        mFile.open(QIODevice.ReadOnly)
+        mFile.open(QIODevice.OpenModeFlag.ReadOnly)
         mDoc.setContent(mFile, True)
         mFile.close()
         mSymbolLayer = QgsSimpleLineSymbolLayer.createFromSld(
-            mDoc.elementsByTagName('LineSymbolizer').item(0).toElement())
+            mDoc.elementsByTagName("LineSymbolizer").item(0).toElement()
+        )
 
         mExpectedValue = type(QgsSimpleLineSymbolLayer())
         mValue = type(mSymbolLayer)
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = '#aa007f'
+        mExpectedValue = "#aa007f"
         mValue = mSymbolLayer.color().name()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
@@ -1015,12 +1034,12 @@ class TestQgsSymbolLayer(QgisTestCase):
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = Qt.RoundCap
+        mExpectedValue = Qt.PenCapStyle.RoundCap
         mValue = mSymbolLayer.penCapStyle()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = Qt.MiterJoin
+        mExpectedValue = Qt.PenJoinStyle.MiterJoin
         mValue = mSymbolLayer.penJoinStyle()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
@@ -1042,33 +1061,36 @@ class TestQgsSymbolLayer(QgisTestCase):
         """
         Create a new style from a .sld file and match test
         """
-        mTestName = 'QgsEllipseSymbolLayer'
-        mFilePath = QDir.toNativeSeparators(f'{unitTestDataPath()}/symbol_layer/{mTestName}.sld')
+        mTestName = "QgsEllipseSymbolLayer"
+        mFilePath = QDir.toNativeSeparators(
+            f"{unitTestDataPath()}/symbol_layer/{mTestName}.sld"
+        )
 
         mDoc = QDomDocument(mTestName)
         mFile = QFile(mFilePath)
-        mFile.open(QIODevice.ReadOnly)
+        mFile.open(QIODevice.OpenModeFlag.ReadOnly)
         mDoc.setContent(mFile, True)
         mFile.close()
         mSymbolLayer = QgsEllipseSymbolLayer.createFromSld(
-            mDoc.elementsByTagName('PointSymbolizer').item(0).toElement())
+            mDoc.elementsByTagName("PointSymbolizer").item(0).toElement()
+        )
 
         mExpectedValue = type(QgsEllipseSymbolLayer())
         mValue = type(mSymbolLayer)
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = 'circle'
+        mExpectedValue = "circle"
         mValue = mSymbolLayer.symbolName()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = '#ffff7f'
+        mExpectedValue = "#ffff7f"
         mValue = mSymbolLayer.fillColor().name()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = '#aaaaff'
+        mExpectedValue = "#aaaaff"
         mValue = mSymbolLayer.strokeColor().name()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
@@ -1090,23 +1112,26 @@ class TestQgsSymbolLayer(QgisTestCase):
         """
         Create a new style from a .sld file and match test
         """
-        mTestName = 'QgsFontMarkerSymbolLayer'
-        mFilePath = QDir.toNativeSeparators(f'{unitTestDataPath()}/symbol_layer/{mTestName}.sld')
+        mTestName = "QgsFontMarkerSymbolLayer"
+        mFilePath = QDir.toNativeSeparators(
+            f"{unitTestDataPath()}/symbol_layer/{mTestName}.sld"
+        )
 
         mDoc = QDomDocument(mTestName)
         mFile = QFile(mFilePath)
-        mFile.open(QIODevice.ReadOnly)
+        mFile.open(QIODevice.OpenModeFlag.ReadOnly)
         mDoc.setContent(mFile, True)
         mFile.close()
         mSymbolLayer = QgsFontMarkerSymbolLayer.createFromSld(
-            mDoc.elementsByTagName('PointSymbolizer').item(0).toElement())
+            mDoc.elementsByTagName("PointSymbolizer").item(0).toElement()
+        )
 
         mExpectedValue = type(QgsFontMarkerSymbolLayer())
         mValue = type(mSymbolLayer)
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = 'Arial'
+        mExpectedValue = "Arial"
         mValue = mSymbolLayer.fontFamily()
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
@@ -1133,22 +1158,26 @@ class TestQgsSymbolLayer(QgisTestCase):
         """
         Create a new style from a .sld file and match test
         """
-        mTestName = 'QgsSvgMarkerSymbolLayer'
-        mFilePath = QDir.toNativeSeparators(f'{unitTestDataPath()}/symbol_layer/{mTestName}.sld')
+        mTestName = "QgsSvgMarkerSymbolLayer"
+        mFilePath = QDir.toNativeSeparators(
+            f"{unitTestDataPath()}/symbol_layer/{mTestName}.sld"
+        )
 
         mDoc = QDomDocument(mTestName)
         mFile = QFile(mFilePath)
-        mFile.open(QIODevice.ReadOnly)
+        mFile.open(QIODevice.OpenModeFlag.ReadOnly)
         mDoc.setContent(mFile, True)
         mFile.close()
-        mSymbolLayer = QgsSvgMarkerSymbolLayer.createFromSld(mDoc.elementsByTagName('PointSymbolizer').item(0).toElement())
+        mSymbolLayer = QgsSvgMarkerSymbolLayer.createFromSld(
+            mDoc.elementsByTagName("PointSymbolizer").item(0).toElement()
+        )
 
         mExpectedValue = type(QgsSvgMarkerSymbolLayer(""))
         mValue = type(mSymbolLayer)
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
         assert mExpectedValue == mValue, mMessage
 
-        mExpectedValue = 'skull.svg'
+        mExpectedValue = "skull.svg"
         mValue = os.path.basename(mSymbolLayer.path())
         print(("VALUE", mSymbolLayer.path()))
         mMessage = f'Expected "{mExpectedValue}" got "{mValue}"'
@@ -1166,8 +1195,8 @@ class TestQgsSymbolLayer(QgisTestCase):
 
         # Check values set from the query string in OnlineResource
         self.assertEqual(mSymbolLayer.strokeWidth(), 2.0)
-        self.assertEqual(mSymbolLayer.strokeColor().name(), '#ff0000')
-        self.assertEqual(mSymbolLayer.fillColor().name(), '#00ff00')
+        self.assertEqual(mSymbolLayer.strokeColor().name(), "#ff0000")
+        self.assertEqual(mSymbolLayer.fillColor().name(), "#00ff00")
 
         ctx = QgsRenderContext()
         self.assertCountEqual(mSymbolLayer.usedAttributes(ctx), {})
@@ -1192,17 +1221,29 @@ class TestQgsSymbolLayer(QgisTestCase):
     def testSldOpacityFillExport(self):
         """Test issue GH #33376"""
 
-        vl = QgsVectorLayer('Point?crs=epsg:4326', 'test', 'memory')
+        vl = QgsVectorLayer("Point?crs=epsg:4326", "test", "memory")
 
-        foo_sym = QgsFillSymbol.createSimple({'color': '#00ff00', 'outline_color': '#0000ff'})
+        foo_sym = QgsFillSymbol.createSimple(
+            {"color": "#00ff00", "outline_color": "#0000ff"}
+        )
         foo_sym.setOpacity(0.66)
         vl.setRenderer(QgsSingleSymbolRenderer(foo_sym))
         doc = QDomDocument()
         vl.exportSldStyle(doc, None)
-        self.assertIn('<se:SvgParameter name="fill-opacity">0.66</se:SvgParameter>', doc.toString())
-        self.assertIn('<se:SvgParameter name="fill">#00ff00</se:SvgParameter>', doc.toString())
-        self.assertIn('<se:SvgParameter name="stroke">#0000ff</se:SvgParameter>', doc.toString())
-        self.assertIn('<se:SvgParameter name="stroke-opacity">0.66</se:SvgParameter>', doc.toString())
+        self.assertIn(
+            '<se:SvgParameter name="fill-opacity">0.66</se:SvgParameter>',
+            doc.toString(),
+        )
+        self.assertIn(
+            '<se:SvgParameter name="fill">#00ff00</se:SvgParameter>', doc.toString()
+        )
+        self.assertIn(
+            '<se:SvgParameter name="stroke">#0000ff</se:SvgParameter>', doc.toString()
+        )
+        self.assertIn(
+            '<se:SvgParameter name="stroke-opacity">0.66</se:SvgParameter>',
+            doc.toString(),
+        )
 
     def testQgsVectorFieldSymbolLayer(self):
         """
@@ -1223,36 +1264,47 @@ class TestQgsSymbolLayer(QgisTestCase):
 
     def test_should_render_selection_color(self):
         layer = QgsSimpleFillSymbolLayer.create(
-            {'color': '#00ff00', 'outline_color': '#0000ff'}
+            {"color": "#00ff00", "outline_color": "#0000ff"}
         )
         render_context = QgsRenderContext()
-        context = QgsSymbolRenderContext(render_context,
-                                         Qgis.RenderUnit.Millimeters,
-                                         selected=False)
-        self.assertFalse(
-            layer.shouldRenderUsingSelectionColor(context)
-        )
-        layer.setUserFlags(
-            Qgis.SymbolLayerUserFlag.DisableSelectionRecoloring
-        )
-        self.assertFalse(
-            layer.shouldRenderUsingSelectionColor(context)
+        context = QgsSymbolRenderContext(
+            render_context, Qgis.RenderUnit.Millimeters, selected=False
         )
+        self.assertFalse(layer.shouldRenderUsingSelectionColor(context))
+        layer.setUserFlags(Qgis.SymbolLayerUserFlag.DisableSelectionRecoloring)
+        self.assertFalse(layer.shouldRenderUsingSelectionColor(context))
 
         layer.setUserFlags(Qgis.SymbolLayerUserFlags())
-        context = QgsSymbolRenderContext(render_context,
-                                         Qgis.RenderUnit.Millimeters,
-                                         selected=True)
-        self.assertTrue(
-            layer.shouldRenderUsingSelectionColor(context)
+        context = QgsSymbolRenderContext(
+            render_context, Qgis.RenderUnit.Millimeters, selected=True
         )
-        layer.setUserFlags(
-            Qgis.SymbolLayerUserFlag.DisableSelectionRecoloring
+        self.assertTrue(layer.shouldRenderUsingSelectionColor(context))
+        layer.setUserFlags(Qgis.SymbolLayerUserFlag.DisableSelectionRecoloring)
+        self.assertFalse(layer.shouldRenderUsingSelectionColor(context))
+
+    def test_force_vector_rendering(self):
+        render_context = QgsRenderContext()
+        context = QgsSymbolRenderContext(
+            render_context, Qgis.RenderUnit.Millimeters, selected=False
         )
-        self.assertFalse(
-            layer.shouldRenderUsingSelectionColor(context)
+        self.assertFalse(context.forceVectorRendering())
+
+        # render context flag should force vector rendering
+        render_context.setFlag(Qgis.RenderContextFlag.ForceVectorOutput, True)
+        context = QgsSymbolRenderContext(
+            render_context, Qgis.RenderUnit.Millimeters, selected=False
         )
+        self.assertTrue(context.forceVectorRendering())
+
+        # symbol render hint should also force vector rendering
+        render_context.setFlag(Qgis.RenderContextFlag.ForceVectorOutput, False)
+        context = QgsSymbolRenderContext(
+            render_context,
+            Qgis.RenderUnit.Millimeters,
+            renderHints=Qgis.SymbolRenderHint.ForceVectorRendering,
+        )
+        self.assertTrue(context.forceVectorRendering())
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
